(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    212964,       6116]
NotebookOptionsPosition[    205508,       5843]
NotebookOutlinePosition[    206375,       5871]
CellTagsIndexPosition[    206332,       5868]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The field from a magnetic dipole or current element", "Section",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 "Fix the funny output  from when ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  doesn't know that a square root is of a positive number"
}], "Subsubsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"powerfix", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", "x_", ")"}], "^", "2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"Rational", "[", 
          RowBox[{"n_", ",", " ", "2"}], "]"}], ")"}]}], " ", ":>", " ", 
       RowBox[{"x", "^", "n"}]}], ",", " ", "\n", "    ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", "x_", ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"-", "2"}], ")"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"Rational", "[", 
          RowBox[{"n_", ",", " ", "2"}], "]"}], ")"}]}], " ", ":>", " ", 
       RowBox[{"x", "^", 
        RowBox[{"(", 
         RowBox[{"-", "n"}], ")"}]}]}]}], "}"}]}], ";"}], " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.629760893649679*^9},
 FormatType->"InputForm",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Recurse", "[", "sublist_List", "]"}], " ", ":=", " ", 
  RowBox[{"sublist", " ", "//.", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x_", " ", "->", " ", "y_"}], ")"}], " ", ":>", " ", 
    RowBox[{"x", " ", "->", " ", 
     RowBox[{"(", 
      RowBox[{"y", " ", "/.", " ", "sublist"}], ")"}]}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.629760897993925*^9},
 FormatType->"InputForm"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The position of the source dipole or current element", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sourcepos", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"dx", ",", " ", "dy", ",", " ", "dz"}], "}"}]}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.629760900894987*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnitude of the source dipole", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sourcedipole", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"m1x", ",", " ", "m1y", ",", " ", "m1z"}], "}"}]}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.629760903248999*^9},
 FormatType->"InputForm",
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnitude of the source current element", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sourcecurrent", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"j1x", ",", " ", "j1y", ",", " ", "j1z"}], "}"}]}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.6297609053456*^9},
 FormatType->"InputForm",
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cartesian coordinates", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 CellChangeTimes->{{3.629760939127244*^9, 3.629760943669847*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"coordinates", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"Xx", ",", " ", "Yy", ",", " ", "Zz"}], "}"}]}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.6297609053456*^9, {3.629760947128353*^9, 3.629760976616811*^9}, {
   3.629761057822153*^9, 3.6297610600522137`*^9}, {3.629765589863089*^9, 
   3.6297655948853817`*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The vector from the dipole to an arbitrary test point", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sourcefieldvec", " ", "=", " ", 
  RowBox[{"coordinates", " ", "-", " ", "sourcepos"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.629760910854231*^9, 3.629760925048678*^9}, 
   3.6297610687772617`*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "dx"}], "+", "Xx"}], ",", 
   RowBox[{
    RowBox[{"-", "dy"}], "+", "Yy"}], ",", 
   RowBox[{
    RowBox[{"-", "dz"}], "+", "Zz"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6297609638773108`*^9, 3.62976098238972*^9}, 
   3.629761069344572*^9, 3.629765497407464*^9, 3.629765612741287*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The distance to the test point", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["rsf = Sqrt[Dot[sourcefieldvec,sourcefieldvec]]//Simplify", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6297608037079144`*^9, 3.6297608049539747`*^9}, {
  3.629765420131254*^9, 3.629765421888967*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{
  3.6297607460019493`*^9, 3.62976080606793*^9, 3.629760988332975*^9, 
   3.629761246603603*^9, {3.6297654054854937`*^9, 3.629765422615346*^9}, 
   3.629765500954382*^9, 3.629765613006118*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Given the B of a bar magnet, work back to the dipole moment, assuming perfect \
dipole field pattern.\
\>", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Formula from Plonus, \"Applied Electromagnetics\", p336", \
"Subsubsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Baxialint = (mu0 M/2) (
\t\t(1-2z/l)
\t\t/Sqrt[(2a/l)^2+(2z/l-1)^2]
\t\t+(1+2z/l)
\t\t/Sqrt[(2a/l)^2+(2z/l+1)^2]
\t)\
\>", "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "M", " ", "mu0", " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "z"}], "l"]}], 
     SqrtBox[
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"]}], 
        SuperscriptBox["l", "2"]], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          FractionBox[
           RowBox[{"2", " ", "z"}], "l"]}], ")"}], "2"]}]]], "+", 
    FractionBox[
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"2", " ", "z"}], "l"]}], 
     SqrtBox[
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"]}], 
        SuperscriptBox["l", "2"]], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          FractionBox[
           RowBox[{"2", " ", "z"}], "l"]}], ")"}], "2"]}]]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.62976074604352*^9, 3.6297609936638823`*^9, 
  3.629765509675819*^9, 3.629765617863461*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The velocity of the test point", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell["velocity = {vx, vy, vz};", "Input",
 InitializationCell->True,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A dipole source", "Section",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["The magnetic scalar potential from the dipole", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
dipolepot = -1/(4 Pi) Dot[sourcedipole, Grad[1/rsf,coordinates]]\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.629760822277351*^9, {3.629761021891614*^9, 3.629761041898787*^9}, {
   3.6297612051347027`*^9, 3.629761209213696*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "\[Pi]"}]], 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"m1x", " ", 
       RowBox[{"(", 
        RowBox[{"dx", "-", "Xx"}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]], "+", 
     FractionBox[
      RowBox[{"m1y", " ", 
       RowBox[{"(", 
        RowBox[{"dy", "-", "Yy"}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]], "+", 
     FractionBox[
      RowBox[{"m1z", " ", 
       RowBox[{"(", 
        RowBox[{"dz", "-", "Zz"}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.629760831764098*^9, {3.629761014388562*^9, 3.6297610437844763`*^9}, 
   3.629761104729642*^9, 3.629761210235743*^9, 3.629761253181223*^9, 
   3.629761288216268*^9, 3.629765509957355*^9, 3.629765627266629*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnetic field from the dipole", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"dipoleBx", ",", " ", "dipoleBy", ",", " ", "dipoleBz"}], "}"}], 
  " ", "=", " ", "\n", "  ", 
  RowBox[{"dipoleB", " ", "=", " ", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"mu0", "*", 
      RowBox[{"Grad", "[", 
       RowBox[{"dipolepot", ",", " ", "coordinates"}], "]"}]}], 
     ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.629760845682268*^9, {3.6297612959965878`*^9, 3.6297613028756733`*^9}},
 FormatType->"InputForm",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", "\[Pi]"}]], 
    RowBox[{"mu0", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"3", " ", "m1x", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], "+", 
       FractionBox[
        RowBox[{"3", " ", "m1y", " ", 
         RowBox[{"(", 
          RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"dy", "-", "Yy"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], "-", 
       FractionBox["m1x", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]], "+", 
       FractionBox[
        RowBox[{"3", " ", "m1z", " ", 
         RowBox[{"(", 
          RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"dz", "-", "Zz"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", "\[Pi]"}]], 
    RowBox[{"mu0", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"3", " ", "m1x", " ", 
         RowBox[{"(", 
          RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"dy", "-", "Yy"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], "+", 
       FractionBox[
        RowBox[{"3", " ", "m1y", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], "-", 
       FractionBox["m1y", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]], "+", 
       FractionBox[
        RowBox[{"3", " ", "m1z", " ", 
         RowBox[{"(", 
          RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"dz", "-", "Zz"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", "\[Pi]"}]], 
    RowBox[{"mu0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["m1z", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]]}], "+", 
       FractionBox[
        RowBox[{"3", " ", "m1x", " ", 
         RowBox[{"(", 
          RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"dz", "-", "Zz"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], "+", 
       FractionBox[
        RowBox[{"3", " ", "m1y", " ", 
         RowBox[{"(", 
          RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"dz", "-", "Zz"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], "+", 
       FractionBox[
        RowBox[{"3", " ", "m1z", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6297608461739397`*^9, 3.629761303877532*^9, 
  3.629765509987742*^9, 3.6297656388816633`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The potential of a dipole in the magnetic field", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dipole2pot", " ", "=", " ", 
  RowBox[{"dipoleB", " ", ".", " ", 
   RowBox[{"{", 
    RowBox[{"m2x", ",", " ", "m2y", ",", " ", "m2z"}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.629761332309572*^9},
 FormatType->"InputForm",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "\[Pi]"}]], 
   RowBox[{"m2x", " ", "mu0", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", "m1x", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "m1y", " ", 
        RowBox[{"(", 
         RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]], "-", 
      FractionBox["m1x", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "m1z", " ", 
        RowBox[{"(", 
         RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "\[Pi]"}]], 
   RowBox[{"m2y", " ", "mu0", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", "m1x", " ", 
        RowBox[{"(", 
         RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "m1y", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]], "-", 
      FractionBox["m1y", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "m1z", " ", 
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", "\[Pi]"}]], 
   RowBox[{"m2z", " ", "mu0", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["m1z", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "m1x", " ", 
        RowBox[{"(", 
         RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "m1y", " ", 
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "m1z", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.629761312965747*^9, 3.6297613330170097`*^9}, 
   3.629765510023555*^9, 3.629765639142068*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The force of a dipole in the magnetic field", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dipoleforce", " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"Grad", "[", 
    RowBox[{"dipole2pot", ",", " ", "coordinates"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.62976131968218*^9, 3.629761325322212*^9}},
 FormatType->"InputForm",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"m2y", " ", "mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"15", " ", "m1x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"15", " ", "m1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "m1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "m1x", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"15", " ", "m1z", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]]}], ")"}]}]}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2x", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"15", " ", "m1x", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "3"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1y", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"9", " ", "m1x", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "m1y", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1z", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "m1z", " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2z", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", "m1z", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1x", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1y", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "m1x", " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1z", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]]}], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"m2x", " ", "mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"15", " ", "m1x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"15", " ", "m1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "m1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "m1x", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"15", " ", "m1z", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]]}], ")"}]}]}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2y", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"15", " ", "m1x", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1y", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "3"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "m1x", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"9", " ", "m1y", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1z", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "m1z", " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2z", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", "m1z", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1x", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1y", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "m1y", " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1z", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]]}], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"m2x", " ", "mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], "+", 
         FractionBox[
          RowBox[{"15", " ", "m1x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"15", " ", "m1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "m1x", " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"15", " ", "m1z", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]]}], ")"}]}]}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2y", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", "m1z", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1x", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1y", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "m1y", " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1z", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]]}], ")"}]}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2z", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", "m1x", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], "-", 
        FractionBox[
         RowBox[{"3", " ", "m1y", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"9", " ", "m1z", " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1x", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1y", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"15", " ", "m1z", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "3"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"7", "/", "2"}]]]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6297613221752*^9, 3.629761326099451*^9}, 
   3.629765510057315*^9, 3.629765639185758*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The potential of the dipole induced in a small bit of magnetic material in \
the magnetic field\
\>", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dipole2potinduced", " ", "=", " ", 
  RowBox[{"mm", "*", 
   RowBox[{"dipoleB", " ", ".", " ", "dipoleB"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.62976135593117*^9},
 FormatType->"InputForm",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"mm", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"16", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], 
     RowBox[{
      SuperscriptBox["mu0", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "m1x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "m1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox["m1x", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "m1z", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}], "2"]}]}], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"16", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], 
     RowBox[{
      SuperscriptBox["mu0", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "m1x", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "m1y", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox["m1y", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "m1z", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}], "2"]}]}], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"16", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], 
     RowBox[{
      SuperscriptBox["mu0", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["m1z", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]]]}], "+", 
         FractionBox[
          RowBox[{"3", " ", "m1x", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "m1y", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "m1z", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}], "2"]}]}]}], ")"}]}]], "Output",\

 CellChangeTimes->{{3.6297613505710363`*^9, 3.629761356878504*^9}, 
   3.6297655101062717`*^9, 3.629765639226186*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The force on the dipole induced in a small bit of magnetic material in the \
magnetic field\
\>", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dipoleforceinduced", " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{"Grad", "[", 
    RowBox[{"dipole2potinduced", ",", " ", "coordinates"}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.629761370136766*^9, 3.629761374586314*^9}},
 FormatType->"InputForm",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "mm"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "3"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"9", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox["m1x", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox["m1y", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "m1z", " ", 
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
             RowBox[{"5", "/", "2"}]]]}], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["m1z", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
             RowBox[{"3", "/", "2"}]]]}], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}]}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "mm"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox["m1x", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "3"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"9", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox["m1y", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "m1z", " ", 
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
             RowBox[{"5", "/", "2"}]]]}], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["m1z", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
             RowBox[{"3", "/", "2"}]]]}], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}]}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "mm"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox["m1x", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "m1z", " ", 
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
             RowBox[{"5", "/", "2"}]]]}], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox["m1y", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "m1z", " ", 
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
             RowBox[{"5", "/", "2"}]]]}], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Pi]", "2"]}]], 
       RowBox[{
        SuperscriptBox["mu0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["m1z", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
             RowBox[{"3", "/", "2"}]]]}], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"3", " ", "m1z", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "m1x", " ", 
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
             RowBox[{"5", "/", "2"}]]]}], "-", 
          FractionBox[
           RowBox[{"3", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "-", 
          FractionBox[
           RowBox[{"9", " ", "m1z", " ", 
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1x", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1y", " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]], "+", 
          FractionBox[
           RowBox[{"15", " ", "m1z", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "3"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"7", "/", "2"}]]]}], ")"}]}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.629761375400269*^9, 3.629765510156659*^9, 
  3.629765639276354*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnetic field gradient tensor", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dipolegradB", " ", "=", " ", 
    RowBox[{"Grad", "[", 
     RowBox[{"dipoleB", ",", " ", "coordinates"}], "]"}]}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.629761383224361*^9, 3.6297613886566687`*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The rate of change of B seen by the test point as it moves", \
"Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "dipoleBdotx", ",", " ", "dipoleBdoty", ",", " ", "dipoleBdotz"}], "}"}],
     " ", "=", " ", "\n", "   ", 
    RowBox[{"dipoleBdot", " ", "=", " ", 
     RowBox[{"dipolegradB", " ", ".", " ", "velocity"}]}]}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.629761402310061*^9},
 FormatType->"InputForm",
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test plots", "Subsection",
 InitializationCell->True],

Cell["testplot = True; (* whether to do test plots *)", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6297614083119297`*^9, 3.629761408767542*^9}}],

Cell["\<\
testval1 = Recurse[{dx->0, dy->0, dz->0, Xx->0, mz->1, mu0->1, \
Pi->N[Pi],m1y->0,m1x->0,m2x->0,m1z->mz,m2z->1,m2y->0}];\
\>", "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"testplot", ",", " ", 
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"dipoleforce", "[", 
         RowBox[{"[", "3", "]"}], "]"}], " ", "/.", " ", "testval1"}], ",", 
       " ", "\n", "    ", 
       RowBox[{
        RowBox[{"dipoleforce", "[", 
         RowBox[{"[", "2", "]"}], "]"}], " ", "/.", " ", "testval1"}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"Zz", ",", " ", 
       RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"Yy", ",", " ", 
       RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", 
     RowBox[{"VectorPoints", "->", 
      RowBox[{"{", 
       RowBox[{"9", ",", "9"}], "}"}]}]}], "]"}]}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.629760565516567*^9, 3.629760569705894*^9}, {
   3.629761444609624*^9, 3.629761463097123*^9}, {3.629766775843874*^9, 
   3.6297667832670803`*^9}, {3.629766848169301*^9, 3.629766863663275*^9}, 
   3.6297669048193502`*^9, {3.6297670310568457`*^9, 3.6297670326873083`*^9}},
 FormatType->"InputForm"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
    {Arrowheads[{{0.00004100397974094997, 1.}}], 
     ArrowBox[{{-1.000030517578125, -0.999908447265625}, {-0.999969482421875, \
-1.000091552734375}}]}, 
    {Arrowheads[{{0.00007989729450298138, 1.}}], 
     ArrowBox[{{-0.999977372583002, -0.7498133238097667}, \
{-1.000022627416998, -0.7501866761902333}}]}, 
    {Arrowheads[{{0.00015139015828895302`, 1.}}], 
     ArrowBox[{{-0.9998023576462395, -0.4997035364693592}, \
{-1.0001976423537604`, -0.5002964635306407}}]}, 
    {Arrowheads[{{0.0002447293907139157, 1.}}], 
     ArrowBox[{{-0.9994938470416107, -0.24972510658294378`}, \
{-1.0005061529583894`, -0.2502748934170562}}]}, 
    {Arrowheads[{{0.0002934005953561487, 1.}}], 
     ArrowBox[{{-0.9993094660339975, 0.}, {-1.0006905339660026`, 0.}}]}, 
    {Arrowheads[{{0.0002447293907139157, 1.}}], 
     ArrowBox[{{-0.9994938470416107, 
      0.24972510658294378`}, {-1.0005061529583894`, 0.2502748934170562}}]}, 
    {Arrowheads[{{0.00015139015828895302`, 1.}}], 
     ArrowBox[{{-0.9998023576462395, 
      0.4997035364693592}, {-1.0001976423537604`, 0.5002964635306407}}]}, 
    {Arrowheads[{{0.00007989729450298138, 1.}}], 
     ArrowBox[{{-0.999977372583002, 0.7498133238097667}, {-1.000022627416998, 
      0.7501866761902333}}]}, 
    {Arrowheads[{{0.00004100397974094997, 1.}}], 
     ArrowBox[{{-1.000030517578125, 0.999908447265625}, {-0.999969482421875, 
      1.000091552734375}}]}, 
    {Arrowheads[{{0.00005788485252632964, 1.}}], 
     ArrowBox[{{-0.7501018233764909, -0.9999094903320082}, \
{-0.7498981766235092, -1.0000905096679917`}}]}, 
    {Arrowheads[{{0.00012959282486029247`, 1.}}], 
     ArrowBox[{{-0.7500964506172839, -0.7497106481481481}, \
{-0.749903549382716, -0.7502893518518519}}]}, 
    {Arrowheads[{{0.0003151957565619408, 1.}}], 
     ArrowBox[{{-0.7497991527974234, -0.4992858766130608}, \
{-0.7502008472025767, -0.5007141233869392}}]}, 
    {Arrowheads[{{0.0006770373701172182, 1.}}], 
     ArrowBox[{{-0.7487422117626563, -0.24902172025984384`}, \
{-0.7512577882373436, -0.25097827974015613`}}]}, 
    {Arrowheads[{{0.000927290770508233, 1.}}], 
     ArrowBox[{{-0.7478175716630044, 0.}, {-0.7521824283369954, 0.}}]}, 
    {Arrowheads[{{0.0006770373701172182, 1.}}], 
     ArrowBox[{{-0.7487422117626563, 
      0.24902172025984384`}, {-0.7512577882373436, 0.25097827974015613`}}]}, 
    {Arrowheads[{{0.0003151957565619408, 1.}}], 
     ArrowBox[{{-0.7497991527974234, 
      0.4992858766130608}, {-0.7502008472025767, 0.5007141233869392}}]}, 
    {Arrowheads[{{0.00012959282486029247`, 1.}}], 
     ArrowBox[{{-0.7500964506172839, 0.7497106481481481}, {-0.749903549382716,
       0.7502893518518519}}]}, 
    {Arrowheads[{{0.00005788485252632964, 1.}}], 
     ArrowBox[{{-0.7501018233764909, 
      0.9999094903320082}, {-0.7498981766235092, 1.0000905096679917`}}]}, 
    {Arrowheads[{{0.00008397615050946344, 1.}}], 
     ArrowBox[{{-0.5001976423537605, -1.}, {-0.4998023576462395, -1.}}]}, 
    {Arrowheads[{{0.00020583769247254992`, 1.}}], 
     ArrowBox[{{-0.5004240107609952, -0.7497656782636606}, \
{-0.49957598923900487`, -0.7502343217363394}}]}, 
    {Arrowheads[{{0.0006560636758551995, 1.}}], 
     ArrowBox[{{-0.50048828125, -0.49853515625}, {-0.49951171875, \
-0.50146484375}}]}, 
    {Arrowheads[{{0.0024222425326236603`, 1.}}], 
     ArrowBox[{{-0.49683772233983164`, -0.24525658350974744`}, \
{-0.5031622776601683, -0.25474341649025256`}}]}, 
    {Arrowheads[{{0.004694409525697954, 1.}}], 
     ArrowBox[{{-0.4889514565439602, 0.}, {-0.5110485434560398, 0.}}]}, 
    {Arrowheads[{{0.0024222425326236603`, 1.}}], 
     ArrowBox[{{-0.49683772233983164`, 
      0.24525658350974744`}, {-0.5031622776601683, 0.25474341649025256`}}]}, 
    {Arrowheads[{{0.0006560636758551995, 1.}}], 
     ArrowBox[{{-0.50048828125, 0.49853515625}, {-0.49951171875, 
      0.50146484375}}]}, 
    {Arrowheads[{{0.00020583769247254992`, 1.}}], 
     ArrowBox[{{-0.5004240107609952, 
      0.7497656782636606}, {-0.49957598923900487`, 0.7502343217363394}}]}, 
    {Arrowheads[{{0.00008397615050946344, 1.}}], 
     ArrowBox[{{-0.5001976423537605, 1.}, {-0.4998023576462395, 1.}}]}, 
    {Arrowheads[{{0.0001232567948617544, 1.}}], 
     ArrowBox[{{-0.25020071582832676`, -1.0002094426034713`}, \
{-0.2497992841716732, -0.9997905573965287}}]}, 
    {Arrowheads[{{0.00034624253858328954`, 1.}}], 
     ArrowBox[{{-0.2506987712429687, -0.7504192627457812}, \
{-0.2493012287570313, -0.7495807372542188}}]}, 
    {Arrowheads[{{0.0013436184081514445`, 1.}}], 
     ArrowBox[{{-0.25316227766016836`, -0.5}, {-0.24683772233983162`, \
-0.5}}]}, 
    {Arrowheads[{{0.010497018813683192`, 1.}}], 
     ArrowBox[{{-0.2578125, -0.2265625}, {-0.2421875, -0.2734375}}]}, 
    {Arrowheads[{{0.07511055241116742, 1.}}], 
     ArrowBox[{{-0.07322330470336313, 0.}, {-0.42677669529663687`, 0.}}]}, 
    {Arrowheads[{{0.010497018813683192`, 1.}}], 
     ArrowBox[{{-0.2578125, 0.2265625}, {-0.2421875, 0.2734375}}]}, 
    {Arrowheads[{{0.0013436184081514445`, 1.}}], 
     ArrowBox[{{-0.25316227766016836`, 0.5}, {-0.24683772233983162`, 
      0.5}}]}, 
    {Arrowheads[{{0.00034624253858328954`, 1.}}], 
     ArrowBox[{{-0.2506987712429687, 
      0.7504192627457812}, {-0.2493012287570313, 0.7495807372542188}}]}, 
    {Arrowheads[{{0.0001232567948617544, 1.}}], 
     ArrowBox[{{-0.25020071582832676`, 
      1.0002094426034713`}, {-0.2497992841716732, 0.9997905573965287}}]}, 
    {Arrowheads[{{0.00014670029767808613`, 1.}}], 
     ArrowBox[{{0., -1.0003452669830013`}, {0., -0.9996547330169987}}]}, 
    {Arrowheads[{{0.00046364538525412824`, 1.}}], 
     ArrowBox[{{0., -0.7510912141684978}, {0., -0.7489087858315022}}]}, 
    {Arrowheads[{{0.0023472047628489887`, 1.}}], 
     ArrowBox[{{0., -0.50552427172802}, {0., -0.4944757282719801}}]}, 
    {Arrowheads[{{0.03755527620558371, 1.}}], 
     ArrowBox[{{0., -0.33838834764831843`}, {0., -0.16161165235168157`}}]}, 
    {Arrowheads[{{0.03755527620558371, 1.}}], 
     ArrowBox[{{0., -0.08838834764831843}, {0., 0.08838834764831843}}]}, 
    {Arrowheads[{{0.03755527620558371, 1.}}], 
     ArrowBox[{{0., 0.33838834764831843`}, {0., 0.16161165235168157`}}]}, 
    {Arrowheads[{{0.0023472047628489887`, 1.}}], 
     ArrowBox[{{0., 0.50552427172802}, {0., 0.4944757282719801}}]}, 
    {Arrowheads[{{0.00046364538525412824`, 1.}}], 
     ArrowBox[{{0., 0.7510912141684978}, {0., 0.7489087858315022}}]}, 
    {Arrowheads[{{0.00014670029767808613`, 1.}}], 
     ArrowBox[{{0., 1.0003452669830013`}, {0., 0.9996547330169987}}]}, 
    {Arrowheads[{{0.0001232567948617544, 1.}}], 
     ArrowBox[{{0.25020071582832676`, -1.0002094426034713`}, {
      0.2497992841716732, -0.9997905573965287}}]}, 
    {Arrowheads[{{0.00034624253858328954`, 1.}}], 
     ArrowBox[{{0.2506987712429687, -0.7504192627457812}, {
      0.2493012287570313, -0.7495807372542188}}]}, 
    {Arrowheads[{{0.0013436184081514445`, 1.}}], 
     ArrowBox[{{0.25316227766016836`, -0.5}, {
      0.24683772233983162`, -0.5}}]}, 
    {Arrowheads[{{0.010497018813683192`, 1.}}], 
     ArrowBox[{{0.2578125, -0.2265625}, {0.2421875, -0.2734375}}]}, 
    {Arrowheads[{{0.07511055241116742, 1.}}], 
     ArrowBox[{{0.07322330470336313, 0.}, {0.42677669529663687`, 0.}}]}, 
    {Arrowheads[{{0.010497018813683192`, 1.}}], 
     ArrowBox[{{0.2578125, 0.2265625}, {0.2421875, 0.2734375}}]}, 
    {Arrowheads[{{0.0013436184081514445`, 1.}}], 
     ArrowBox[{{0.25316227766016836`, 0.5}, {0.24683772233983162`, 0.5}}]}, 
    {Arrowheads[{{0.00034624253858328954`, 1.}}], 
     ArrowBox[{{0.2506987712429687, 0.7504192627457812}, {0.2493012287570313, 
      0.7495807372542188}}]}, 
    {Arrowheads[{{0.0001232567948617544, 1.}}], 
     ArrowBox[{{0.25020071582832676`, 1.0002094426034713`}, {
      0.2497992841716732, 0.9997905573965287}}]}, 
    {Arrowheads[{{0.00008397615050946344, 1.}}], 
     ArrowBox[{{0.5001976423537605, -1.}, {0.4998023576462395, -1.}}]}, 
    {Arrowheads[{{0.00020583769247254992`, 1.}}], 
     ArrowBox[{{0.5004240107609952, -0.7497656782636606}, {
      0.49957598923900487`, -0.7502343217363394}}]}, 
    {Arrowheads[{{0.0006560636758551995, 1.}}], 
     ArrowBox[{{0.50048828125, -0.49853515625}, {
      0.49951171875, -0.50146484375}}]}, 
    {Arrowheads[{{0.0024222425326236603`, 1.}}], 
     ArrowBox[{{0.49683772233983164`, -0.24525658350974744`}, {
      0.5031622776601683, -0.25474341649025256`}}]}, 
    {Arrowheads[{{0.004694409525697954, 1.}}], 
     ArrowBox[{{0.4889514565439602, 0.}, {0.5110485434560398, 0.}}]}, 
    {Arrowheads[{{0.0024222425326236603`, 1.}}], 
     ArrowBox[{{0.49683772233983164`, 0.24525658350974744`}, {
      0.5031622776601683, 0.25474341649025256`}}]}, 
    {Arrowheads[{{0.0006560636758551995, 1.}}], 
     ArrowBox[{{0.50048828125, 0.49853515625}, {0.49951171875, 
      0.50146484375}}]}, 
    {Arrowheads[{{0.00020583769247254992`, 1.}}], 
     ArrowBox[{{0.5004240107609952, 0.7497656782636606}, {
      0.49957598923900487`, 0.7502343217363394}}]}, 
    {Arrowheads[{{0.00008397615050946344, 1.}}], 
     ArrowBox[{{0.5001976423537605, 1.}, {0.4998023576462395, 1.}}]}, 
    {Arrowheads[{{0.00005788485252632964, 1.}}], 
     ArrowBox[{{0.7501018233764909, -0.9999094903320082}, {
      0.7498981766235092, -1.0000905096679917`}}]}, 
    {Arrowheads[{{0.00012959282486029247`, 1.}}], 
     ArrowBox[{{0.7500964506172839, -0.7497106481481481}, {
      0.749903549382716, -0.7502893518518519}}]}, 
    {Arrowheads[{{0.0003151957565619408, 1.}}], 
     ArrowBox[{{0.7497991527974234, -0.4992858766130608}, {
      0.7502008472025767, -0.5007141233869392}}]}, 
    {Arrowheads[{{0.0006770373701172182, 1.}}], 
     ArrowBox[{{0.7487422117626563, -0.24902172025984384`}, {
      0.7512577882373436, -0.25097827974015613`}}]}, 
    {Arrowheads[{{0.000927290770508233, 1.}}], 
     ArrowBox[{{0.7478175716630044, 0.}, {0.7521824283369954, 0.}}]}, 
    {Arrowheads[{{0.0006770373701172182, 1.}}], 
     ArrowBox[{{0.7487422117626563, 0.24902172025984384`}, {
      0.7512577882373436, 0.25097827974015613`}}]}, 
    {Arrowheads[{{0.0003151957565619408, 1.}}], 
     ArrowBox[{{0.7497991527974234, 0.4992858766130608}, {0.7502008472025767, 
      0.5007141233869392}}]}, 
    {Arrowheads[{{0.00012959282486029247`, 1.}}], 
     ArrowBox[{{0.7500964506172839, 0.7497106481481481}, {0.749903549382716, 
      0.7502893518518519}}]}, 
    {Arrowheads[{{0.00005788485252632964, 1.}}], 
     ArrowBox[{{0.7501018233764909, 0.9999094903320082}, {0.7498981766235092, 
      1.0000905096679917`}}]}, 
    {Arrowheads[{{0.00004100397974094997, 1.}}], 
     ArrowBox[{{1.000030517578125, -0.999908447265625}, {
      0.999969482421875, -1.000091552734375}}]}, 
    {Arrowheads[{{0.00007989729450298138, 1.}}], 
     ArrowBox[{{0.999977372583002, -0.7498133238097667}, {
      1.000022627416998, -0.7501866761902333}}]}, 
    {Arrowheads[{{0.00015139015828895302`, 1.}}], 
     ArrowBox[{{0.9998023576462395, -0.4997035364693592}, {
      1.0001976423537604`, -0.5002964635306407}}]}, 
    {Arrowheads[{{0.0002447293907139157, 1.}}], 
     ArrowBox[{{0.9994938470416107, -0.24972510658294378`}, {
      1.0005061529583894`, -0.2502748934170562}}]}, 
    {Arrowheads[{{0.0002934005953561487, 1.}}], 
     ArrowBox[{{0.9993094660339975, 0.}, {1.0006905339660026`, 0.}}]}, 
    {Arrowheads[{{0.0002447293907139157, 1.}}], 
     ArrowBox[{{0.9994938470416107, 0.24972510658294378`}, {
      1.0005061529583894`, 0.2502748934170562}}]}, 
    {Arrowheads[{{0.00015139015828895302`, 1.}}], 
     ArrowBox[{{0.9998023576462395, 0.4997035364693592}, {1.0001976423537604`,
       0.5002964635306407}}]}, 
    {Arrowheads[{{0.00007989729450298138, 1.}}], 
     ArrowBox[{{0.999977372583002, 0.7498133238097667}, {1.000022627416998, 
      0.7501866761902333}}]}, 
    {Arrowheads[{{0.00004100397974094997, 1.}}], 
     ArrowBox[{{1.000030517578125, 0.999908447265625}, {0.999969482421875, 
      1.000091552734375}}]}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-1.176776695296637, 1.176776695296637}, {-1.176776695296637, 
   1.176776695296637}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.629761417552228*^9, 3.629761447393906*^9}, 
   3.629761495301654*^9, 3.629765510529538*^9, 3.629765639694581*^9, 
   3.62976678477063*^9, 3.6297668643536463`*^9, 3.629766908695718*^9, 
   3.62976703357019*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{"testplot", ",", "\[IndentingNewLine]", 
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"dipoleBz", "/.", "\[InvisibleSpace]", "testval1"}], ",", 
       RowBox[{"dipoleBy", "/.", "\[InvisibleSpace]", "testval1"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"Zz", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Yy", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"VectorPoints", "->", 
      RowBox[{"{", 
       RowBox[{"9", ",", "9"}], "}"}]}]}], "]"}]}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.6297605859803343`*^9, {3.629761506393105*^9, 3.629761507448741*^9}, 
   3.629767065627595*^9}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
    {Arrowheads[{{0.00032803183792759976`, 1.}}], 
     ArrowBox[{{-1.000244140625, -1.000732421875}, {-0.999755859375, \
-0.999267578125}}]}, 
    {Arrowheads[{{0.0005133958728910967, 1.}}], 
     ArrowBox[{{-1.0006505382386917`, -0.7510182337649086}, \
{-0.9993494617613085, -0.7489817662350914}}]}, 
    {Arrowheads[{{0.0007742218529743527, 1.}}], 
     ArrowBox[{{-1.0013834964763237`, -0.5011858541225631}, \
{-0.9986165035236763, -0.4988141458774369}}]}, 
    {Arrowheads[{{0.0010476827563251228`, 1.}}], 
     ArrowBox[{{-1.0022995052506132`, -0.2508901310647535}, \
{-0.9977004947493867, -0.24910986893524648`}}]}, 
    {Arrowheads[{{0.0011736023814245004`, 1.}}], 
     ArrowBox[{{-1.00276213586401, 0.}, {-0.99723786413599, 0.}}]}, 
    {Arrowheads[{{0.0010476827563251228`, 1.}}], 
     ArrowBox[{{-1.0022995052506132`, 
      0.2508901310647535}, {-0.9977004947493867, 0.24910986893524648`}}]}, 
    {Arrowheads[{{0.0007742218529743527, 1.}}], 
     ArrowBox[{{-1.0013834964763237`, 
      0.5011858541225631}, {-0.9986165035236763, 0.4988141458774369}}]}, 
    {Arrowheads[{{0.0005133958728910967, 1.}}], 
     ArrowBox[{{-1.0006505382386917`, 
      0.7510182337649086}, {-0.9993494617613085, 0.7489817662350914}}]}, 
    {Arrowheads[{{0.00032803183792759976`, 1.}}], 
     ArrowBox[{{-1.000244140625, 1.000732421875}, {-0.999755859375, 
      0.999267578125}}]}, 
    {Arrowheads[{{0.00043330391687504123`, 1.}}], 
     ArrowBox[{{-0.7500565685424949, -1.0010182337649087`}, \
{-0.7499434314575051, -0.9989817662350914}}]}, 
    {Arrowheads[{{0.0007775569491617177, 1.}}], 
     ArrowBox[{{-0.7505787037037037, -0.7517361111111112}, \
{-0.7494212962962963, -0.748263888888889}}]}, 
    {Arrowheads[{{0.0014054462836256944`, 1.}}], 
     ArrowBox[{{-0.7520307883816084, -0.5026110136334966}, \
{-0.7479692116183916, -0.49738898636650347`}}]}, 
    {Arrowheads[{{0.0022843982691832542`, 1.}}], 
     ArrowBox[{{-0.754751644452187, -0.25251557647468725`}, \
{-0.7452483555478129, -0.24748442352531272`}}]}, 
    {Arrowheads[{{0.0027818723115247226`, 1.}}], 
     ArrowBox[{{-0.7565472850109866, 0.}, {-0.7434527149890134, 0.}}]}, 
    {Arrowheads[{{0.0022843982691832542`, 1.}}], 
     ArrowBox[{{-0.754751644452187, 
      0.25251557647468725`}, {-0.7452483555478129, 0.24748442352531272`}}]}, 
    {Arrowheads[{{0.0014054462836256944`, 1.}}], 
     ArrowBox[{{-0.7520307883816084, 
      0.5026110136334966}, {-0.7479692116183916, 0.49738898636650347`}}]}, 
    {Arrowheads[{{0.0007775569491617177, 1.}}], 
     ArrowBox[{{-0.7505787037037037, 
      0.7517361111111112}, {-0.7494212962962963, 0.748263888888889}}]}, 
    {Arrowheads[{{0.00043330391687504123`, 1.}}], 
     ArrowBox[{{-0.7500565685424949, 
      1.0010182337649087`}, {-0.7499434314575051, 0.9989817662350914}}]}, 
    {Arrowheads[{{0.0005311118094860497, 1.}}], 
     ArrowBox[{{-0.49960471529247896`, -1.0011858541225631`}, \
{-0.500395284707521, -0.9988141458774368}}]}, 
    {Arrowheads[{{0.0011111028463190423`, 1.}}], 
     ArrowBox[{{-0.499854943687028, -0.7526110136334966}, \
{-0.500145056312972, -0.7473889863665035}}]}, 
    {Arrowheads[{{0.002624254703420798, 1.}}], 
     ArrowBox[{{-0.501953125, -0.505859375}, {-0.498046875, -0.494140625}}]}, \

    {Arrowheads[{{0.006193774823794695, 1.}}], 
     ArrowBox[{{-0.5110679718105894, -0.2594868329805051}, \
{-0.4889320281894107, -0.24051316701949488`}}]}, 
    {Arrowheads[{{0.00938881905139592, 1.}}], 
     ArrowBox[{{-0.5220970869120796, 0.}, {-0.4779029130879204, 0.}}]}, 
    {Arrowheads[{{0.006193774823794695, 1.}}], 
     ArrowBox[{{-0.5110679718105894, 
      0.2594868329805051}, {-0.4889320281894107, 0.24051316701949488`}}]}, 
    {Arrowheads[{{0.002624254703420798, 1.}}], 
     ArrowBox[{{-0.501953125, 0.505859375}, {-0.498046875, 0.494140625}}]}, 
    {Arrowheads[{{0.0011111028463190423`, 1.}}], 
     ArrowBox[{{-0.499854943687028, 0.7526110136334966}, {-0.500145056312972, 
      0.7473889863665035}}]}, 
    {Arrowheads[{{0.0005311118094860497, 1.}}], 
     ArrowBox[{{-0.49960471529247896`, 
      1.0011858541225631`}, {-0.500395284707521, 0.9988141458774368}}]}, 
    {Arrowheads[{{0.0005811498305153291, 1.}}], 
     ArrowBox[{{-0.24896151375778758`, -1.0008901310647536`}, \
{-0.2510384862422124, -0.9991098689352466}}]}, 
    {Arrowheads[{{0.0013540747402344437`, 1.}}], 
     ArrowBox[{{-0.24804344051968769`, -0.7525155764746873}, \
{-0.2519565594803123, -0.7474844235253127}}]}, 
    {Arrowheads[{{0.004248894475888332, 1.}}], 
     ArrowBox[{{-0.24683772233983162`, -0.5094868329805051}, \
{-0.2531622776601684, -0.4905131670194948}}]}, 
    {Arrowheads[{{0.020994037627366385`, 1.}}], 
     ArrowBox[{{-0.265625, -0.296875}, {-0.234375, -0.203125}}]}, 
    {Arrowheads[{{0.07511055241116742, 1.}}], 
     ArrowBox[{{-0.42677669529663687`, 0.}, {-0.0732233047033631, 0.}}]}, 
    {Arrowheads[{{0.020994037627366385`, 1.}}], 
     ArrowBox[{{-0.265625, 0.296875}, {-0.234375, 0.203125}}]}, 
    {Arrowheads[{{0.004248894475888332, 1.}}], 
     ArrowBox[{{-0.24683772233983162`, 
      0.5094868329805051}, {-0.2531622776601684, 0.4905131670194948}}]}, 
    {Arrowheads[{{0.0013540747402344437`, 1.}}], 
     ArrowBox[{{-0.24804344051968769`, 
      0.7525155764746873}, {-0.2519565594803123, 0.7474844235253127}}]}, 
    {Arrowheads[{{0.0005811498305153291, 1.}}], 
     ArrowBox[{{-0.24896151375778758`, 
      1.0008901310647536`}, {-0.2510384862422124, 0.9991098689352466}}]}, 
    {Arrowheads[{{0.0005868011907122454, 1.}}], 
     ArrowBox[{{
      0.0013810679320049757`, -1.}, {-0.0013810679320049757`, -1.}}]}, 
    {Arrowheads[{{0.0013909361557623596`, 1.}}], 
     ArrowBox[{{
      0.0032736425054932755`, -0.75}, {-0.0032736425054932755`, -0.75}}]}, 
    {Arrowheads[{{0.0046944095256979635`, 1.}}], 
     ArrowBox[{{
      0.011048543456039806`, -0.5}, {-0.011048543456039806`, -0.5}}]}, 
    {Arrowheads[{{0.03755527620558371, 1.}}], 
     ArrowBox[{{0.08838834764831845, -0.25}, {-0.08838834764831845, -0.25}}]}, 
    {Arrowheads[{{0.03755527620558371, 1.}}], 
     ArrowBox[{{0.08838834764831845, 0.}, {-0.08838834764831845, 0.}}]}, 
    {Arrowheads[{{0.03755527620558371, 1.}}], 
     ArrowBox[{{0.08838834764831845, 0.25}, {-0.08838834764831845, 0.25}}]}, 
    {Arrowheads[{{0.0046944095256979635`, 1.}}], 
     ArrowBox[{{0.011048543456039806`, 0.5}, {-0.011048543456039806`, 0.5}}]}, 
    {Arrowheads[{{0.0013909361557623596`, 1.}}], 
     ArrowBox[{{0.0032736425054932755`, 0.75}, {-0.0032736425054932755`, 
      0.75}}]}, 
    {Arrowheads[{{0.0005868011907122454, 1.}}], 
     ArrowBox[{{0.0013810679320049757`, 1.}, {-0.0013810679320049757`, 1.}}]}, 
    {Arrowheads[{{0.0005811498305153445, 1.}}], 
     ArrowBox[{{0.2510384862422124, -0.9991098689352464}, {
      0.24896151375778758`, -1.0008901310647536`}}]}, 
    {Arrowheads[{{0.0013540747402344437`, 1.}}], 
     ArrowBox[{{0.2519565594803123, -0.7474844235253127}, {
      0.24804344051968769`, -0.7525155764746873}}]}, 
    {Arrowheads[{{0.004248894475888317, 1.}}], 
     ArrowBox[{{0.25316227766016836`, -0.4905131670194949}, {
      0.24683772233983162`, -0.5094868329805051}}]}, 
    {Arrowheads[{{0.020994037627366385`, 1.}}], 
     ArrowBox[{{0.234375, -0.203125}, {0.265625, -0.296875}}]}, 
    {Arrowheads[{{0.07511055241116742, 1.}}], 
     ArrowBox[{{0.0732233047033631, 0.}, {0.42677669529663687`, 0.}}]}, 
    {Arrowheads[{{0.020994037627366385`, 1.}}], 
     ArrowBox[{{0.234375, 0.203125}, {0.265625, 0.296875}}]}, 
    {Arrowheads[{{0.004248894475888317, 1.}}], 
     ArrowBox[{{0.25316227766016836`, 0.4905131670194949}, {
      0.24683772233983162`, 0.5094868329805051}}]}, 
    {Arrowheads[{{0.0013540747402344437`, 1.}}], 
     ArrowBox[{{0.2519565594803123, 0.7474844235253127}, {
      0.24804344051968769`, 0.7525155764746873}}]}, 
    {Arrowheads[{{0.0005811498305153445, 1.}}], 
     ArrowBox[{{0.2510384862422124, 0.9991098689352464}, {
      0.24896151375778758`, 1.0008901310647536`}}]}, 
    {Arrowheads[{{0.0005311118094860274, 1.}}], 
     ArrowBox[{{0.500395284707521, -0.9988141458774369}, {
      0.49960471529247896`, -1.0011858541225631`}}]}, 
    {Arrowheads[{{0.001111102846319043, 1.}}], 
     ArrowBox[{{0.500145056312972, -0.7473889863665034}, {
      0.49985494368702793`, -0.7526110136334965}}]}, 
    {Arrowheads[{{0.002624254703420798, 1.}}], 
     ArrowBox[{{0.498046875, -0.494140625}, {0.501953125, -0.505859375}}]}, 
    {Arrowheads[{{0.006193774823794689, 1.}}], 
     ArrowBox[{{0.4889320281894107, -0.24051316701949485`}, {
      0.5110679718105893, -0.2594868329805052}}]}, 
    {Arrowheads[{{0.009388819051395944, 1.}}], 
     ArrowBox[{{0.4779029130879204, 0.}, {0.5220970869120797, 0.}}]}, 
    {Arrowheads[{{0.006193774823794689, 1.}}], 
     ArrowBox[{{0.4889320281894107, 0.24051316701949485`}, {
      0.5110679718105893, 0.2594868329805052}}]}, 
    {Arrowheads[{{0.002624254703420798, 1.}}], 
     ArrowBox[{{0.498046875, 0.494140625}, {0.501953125, 0.505859375}}]}, 
    {Arrowheads[{{0.001111102846319043, 1.}}], 
     ArrowBox[{{0.500145056312972, 0.7473889863665034}, {0.49985494368702793`,
       0.7526110136334965}}]}, 
    {Arrowheads[{{0.0005311118094860274, 1.}}], 
     ArrowBox[{{0.500395284707521, 0.9988141458774369}, {0.49960471529247896`,
       1.0011858541225631`}}]}, 
    {Arrowheads[{{0.0004333039168749942, 1.}}], 
     ArrowBox[{{0.7499434314575051, -0.9989817662350914}, {
      0.7500565685424949, -1.0010182337649085`}}]}, 
    {Arrowheads[{{0.0007775569491617177, 1.}}], 
     ArrowBox[{{0.7494212962962963, -0.7482638888888888}, {
      0.7505787037037037, -0.751736111111111}}]}, 
    {Arrowheads[{{0.0014054462836256758`, 1.}}], 
     ArrowBox[{{0.7479692116183916, -0.49738898636650347`}, {
      0.7520307883816084, -0.5026110136334965}}]}, 
    {Arrowheads[{{0.002284398269183251, 1.}}], 
     ArrowBox[{{0.745248355547813, -0.24748442352531275`}, {
      0.7547516444521871, -0.25251557647468725`}}]}, 
    {Arrowheads[{{0.0027818723115247226`, 1.}}], 
     ArrowBox[{{0.7434527149890134, 0.}, {0.7565472850109866, 0.}}]}, 
    {Arrowheads[{{0.002284398269183251, 1.}}], 
     ArrowBox[{{0.745248355547813, 0.24748442352531275`}, {0.7547516444521871,
       0.25251557647468725`}}]}, 
    {Arrowheads[{{0.0014054462836256758`, 1.}}], 
     ArrowBox[{{0.7479692116183916, 0.49738898636650347`}, {
      0.7520307883816084, 0.5026110136334965}}]}, 
    {Arrowheads[{{0.0007775569491617177, 1.}}], 
     ArrowBox[{{0.7494212962962963, 0.7482638888888888}, {0.7505787037037037, 
      0.751736111111111}}]}, 
    {Arrowheads[{{0.0004333039168749942, 1.}}], 
     ArrowBox[{{0.7499434314575051, 0.9989817662350914}, {0.7500565685424949, 
      1.0010182337649085`}}]}, 
    {Arrowheads[{{0.00032803183792759976`, 1.}}], 
     ArrowBox[{{0.999755859375, -0.999267578125}, {
      1.000244140625, -1.000732421875}}]}, 
    {Arrowheads[{{0.0005133958728911094, 1.}}], 
     ArrowBox[{{0.9993494617613083, -0.7489817662350914}, {
      1.0006505382386917`, -0.7510182337649086}}]}, 
    {Arrowheads[{{0.000774221852974322, 1.}}], 
     ArrowBox[{{0.9986165035236764, -0.49881414587743683`}, {
      1.0013834964763235`, -0.5011858541225632}}]}, 
    {Arrowheads[{{0.0010476827563250988`, 1.}}], 
     ArrowBox[{{0.9977004947493868, -0.2491098689352465}, {
      1.0022995052506132`, -0.2508901310647535}}]}, 
    {Arrowheads[{{0.0011736023814245004`, 1.}}], 
     ArrowBox[{{0.99723786413599, 0.}, {1.00276213586401, 0.}}]}, 
    {Arrowheads[{{0.0010476827563250988`, 1.}}], 
     ArrowBox[{{0.9977004947493868, 0.2491098689352465}, {1.0022995052506132`,
       0.2508901310647535}}]}, 
    {Arrowheads[{{0.000774221852974322, 1.}}], 
     ArrowBox[{{0.9986165035236764, 0.49881414587743683`}, {
      1.0013834964763235`, 0.5011858541225632}}]}, 
    {Arrowheads[{{0.0005133958728911094, 1.}}], 
     ArrowBox[{{0.9993494617613083, 0.7489817662350914}, {1.0006505382386917`,
       0.7510182337649086}}]}, 
    {Arrowheads[{{0.00032803183792759976`, 1.}}], 
     ArrowBox[{{0.999755859375, 0.999267578125}, {1.000244140625, 
      1.000732421875}}]}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-1.176776695296637, 1.176776695296637}, {-1.176776695296637, 
   1.176776695296637}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.629761508309902*^9, 3.629765510621128*^9, 3.6297656398014383`*^9, {
   3.62976705327962*^9, 3.629767066032682*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A current element source", "Section",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["The magnetic vector potential from the current element", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["currentA = mu0/(4 Pi) sourcecurrent/rsf", "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"j1x", " ", "mu0"}], 
    RowBox[{"4", " ", "\[Pi]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}]]}]], ",", 
   FractionBox[
    RowBox[{"j1y", " ", "mu0"}], 
    RowBox[{"4", " ", "\[Pi]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}]]}]], ",", 
   FractionBox[
    RowBox[{"j1z", " ", "mu0"}], 
    RowBox[{"4", " ", "\[Pi]", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.6297655106384363`*^9, 3.6297656398222637`*^9, 
  3.6302251028683233`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnet field from the current element", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["currentB = mu0/(4 Pi) Curl[sourcecurrent/rsf, coordinates]", "Input",
 InitializationCell->True,
 CellChangeTimes->{3.630225057008062*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"mu0", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"j1z", " ", 
         RowBox[{"(", 
          RowBox[{"dy", "-", "Yy"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]], "-", 
       FractionBox[
        RowBox[{"j1y", " ", 
         RowBox[{"(", 
          RowBox[{"dz", "-", "Zz"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]]}], ")"}]}], 
    RowBox[{"4", " ", "\[Pi]"}]], ",", 
   FractionBox[
    RowBox[{"mu0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"j1z", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]]}], "+", 
       FractionBox[
        RowBox[{"j1x", " ", 
         RowBox[{"(", 
          RowBox[{"dz", "-", "Zz"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]]}], ")"}]}], 
    RowBox[{"4", " ", "\[Pi]"}]], ",", 
   FractionBox[
    RowBox[{"mu0", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"j1y", " ", 
         RowBox[{"(", 
          RowBox[{"dx", "-", "Xx"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]], "-", 
       FractionBox[
        RowBox[{"j1x", " ", 
         RowBox[{"(", 
          RowBox[{"dy", "-", "Yy"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]]}], ")"}]}], 
    RowBox[{"4", " ", "\[Pi]"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.62976551065145*^9, 3.62976563986307*^9, 
  3.630225103155353*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The magnetic field gradient tensor", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["currentgradB = Grad[currentB, coordinates]", "Input",
 InitializationCell->True,
 CellChangeTimes->{3.63022506954357*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "j1z", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}]}], 
      RowBox[{"4", " ", "\[Pi]"}]], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "j1z", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox["j1z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["j1y", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "j1z", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"3", " ", "j1z", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], "+", 
         FractionBox["j1z", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], ",", 
     FractionBox[
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"3", " ", "j1z", " ", 
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"5", "/", "2"}]]]}], "+", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}]}], 
      RowBox[{"4", " ", "\[Pi]"}]], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["j1x", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
            RowBox[{"3", "/", "2"}]]]}], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1z", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox["j1y", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]]}], ")"}]}]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox["j1x", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]]}], ")"}]}]}], ",", 
     FractionBox[
      RowBox[{"mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}]}], 
      RowBox[{"4", " ", "\[Pi]"}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.629765510690061*^9, 3.629765639910775*^9, 
  3.630225103206195*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The potential of a dipole in the magnetic field", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["currentdipolepot = currentB.{m2x,m2y,m2z}", "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"m2z", " ", "mu0", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"j1y", " ", 
        RowBox[{"(", 
         RowBox[{"dx", "-", "Xx"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]], "-", 
      FractionBox[
       RowBox[{"j1x", " ", 
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]]}], ")"}]}], 
   RowBox[{"4", " ", "\[Pi]"}]], "+", 
  FractionBox[
   RowBox[{"m2y", " ", "mu0", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"j1z", " ", 
         RowBox[{"(", 
          RowBox[{"dx", "-", "Xx"}], ")"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]]}], "+", 
      FractionBox[
       RowBox[{"j1x", " ", 
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]]}], ")"}]}], 
   RowBox[{"4", " ", "\[Pi]"}]], "+", 
  FractionBox[
   RowBox[{"m2x", " ", "mu0", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"j1z", " ", 
        RowBox[{"(", 
         RowBox[{"dy", "-", "Yy"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]], "-", 
      FractionBox[
       RowBox[{"j1y", " ", 
        RowBox[{"(", 
         RowBox[{"dz", "-", "Zz"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]]}], ")"}]}], 
   RowBox[{"4", " ", "\[Pi]"}]]}]], "Output",
 CellChangeTimes->{3.629765510857744*^9, 3.629765640211891*^9, 
  3.6302251032388573`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The force of a dipole in the magnetic field", "Subsection",
 Evaluatable->False,
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
currentdipoleforce = -Grad[currentB.{m2x,m2y,m2z}, coordinates]\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{3.630225088671234*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"m2z", " ", "mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox["j1y", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]]}], ")"}]}]}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2y", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", "j1z", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dx", "-", "Xx"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], "+", 
        FractionBox["j1z", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"3", " ", "j1x", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "-", 
    FractionBox[
     RowBox[{"m2x", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", "j1z", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "j1y", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]]}], ")"}]}], 
     RowBox[{"4", " ", "\[Pi]"}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "\[Pi]"}]], 
      RowBox[{"m2z", " ", "mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "+", 
         FractionBox["j1x", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]]}], ")"}]}]}]}], "-", 
    FractionBox[
     RowBox[{"m2y", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", "j1z", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], "+", 
        FractionBox[
         RowBox[{"3", " ", "j1x", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]]}], ")"}]}], 
     RowBox[{"4", " ", "\[Pi]"}]], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2x", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", "j1z", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "-", 
        FractionBox["j1z", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "j1y", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]]}], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"m2z", " ", "mu0", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " ", "j1y", " ", 
           RowBox[{"(", 
            RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{"3", " ", "j1x", " ", 
           RowBox[{"(", 
            RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"5", "/", "2"}]]]}], ")"}]}], 
      RowBox[{"4", " ", "\[Pi]"}]]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2y", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["j1x", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]]}], "-", 
        FractionBox[
         RowBox[{"3", " ", "j1z", " ", 
          RowBox[{"(", 
           RowBox[{"dx", "-", "Xx"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"3", " ", "j1x", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]]}], ")"}]}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", "\[Pi]"}]], 
     RowBox[{"m2x", " ", "mu0", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["j1y", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"3", "/", "2"}]]], "+", 
        FractionBox[
         RowBox[{"3", " ", "j1z", " ", 
          RowBox[{"(", 
           RowBox[{"dy", "-", "Yy"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"dz", "-", "Zz"}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]], "-", 
        FractionBox[
         RowBox[{"3", " ", "j1y", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dx", "-", "Xx"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dy", "-", "Yy"}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"dz", "-", "Zz"}], ")"}], "2"]}], ")"}], 
          RowBox[{"5", "/", "2"}]]]}], ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6297655108738623`*^9, 3.629765640229388*^9, 
  3.6302251032888527`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End stuff", "Section",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Sacrificial calculation with throw-away result to stop .m file returning junk\
\
\>", "Subsection",
 InitializationCell->True],

Cell["0;", "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{654, 651},
WindowMargins->{{Automatic, 257}, {Automatic, 0}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb",
PrivateNotebookOptions -> {"ColorPalette" -> {RGBColor, 128}},
RenderingOptions -> {"ObjectDithering" -> True},
RenderingOptions -> {"RasterDithering" -> False},
CharacterEncoding -> "MacintoshAutomaticEncoding",
MacintoshSystemPageSetup -> \
"00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001\n\
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 143, 3, 68, "Section",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[748, 29, 108, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[881, 36, 256, 8, 24, "Subsubsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[1140, 46, 991, 31, 45, "Input",
 InitializationCell->True],
Cell[2134, 79, 446, 12, 29, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2629, 97, 147, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[2779, 102, 275, 9, 29, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[3091, 116, 129, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[3223, 121, 307, 10, 29, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[3567, 136, 138, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[3708, 141, 306, 10, 29, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[4051, 156, 182, 4, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[4236, 162, 428, 12, 29, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[4701, 179, 148, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4874, 186, 269, 6, 29, "Input",
 InitializationCell->True],
Cell[5146, 194, 358, 10, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5553, 210, 125, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[5703, 217, 244, 4, 28, "Input",
 InitializationCell->True],
Cell[5950, 223, 518, 15, 39, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6517, 244, 204, 6, 51, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[6746, 254, 155, 4, 24, "Subsubsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[6926, 262, 193, 9, 98, "Input",
 InitializationCell->True],
Cell[7122, 273, 1100, 38, 94, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8283, 318, 125, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[8411, 323, 93, 2, 28, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8553, 331, 61, 1, 68, "Section",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[8639, 336, 140, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[8804, 343, 284, 7, 28, "Input",
 InitializationCell->True],
Cell[9091, 352, 1975, 61, 150, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11115, 419, 129, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[11269, 426, 538, 16, 45, "Input",
 InitializationCell->True],
Cell[11810, 444, 7786, 233, 574, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19645, 683, 142, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[19812, 690, 302, 8, 29, "Input",
 InitializationCell->True],
Cell[20117, 700, 7571, 232, 574, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27737, 938, 138, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[27900, 945, 311, 8, 29, "Input",
 InitializationCell->True],
Cell[28214, 955, 33719, 966, 2275, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61982, 1927, 198, 6, 51, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[62205, 1937, 264, 7, 29, "Input",
 InitializationCell->True],
Cell[62472, 1946, 8520, 244, 577, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[71041, 2196, 194, 6, 51, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[71260, 2206, 331, 9, 29, "Input",
 InitializationCell->True],
Cell[71594, 2217, 59820, 1642, 3976, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[131463, 3865, 129, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[131595, 3870, 309, 9, 29, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[131941, 3884, 155, 4, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[132099, 3890, 441, 14, 45, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[132577, 3909, 59, 1, 35, "Subsection",
 InitializationCell->True],
Cell[132639, 3912, 159, 2, 28, "Input",
 InitializationCell->True],
Cell[132801, 3916, 172, 4, 28, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[132998, 3924, 1142, 29, 61, "Input",
 InitializationCell->True],
Cell[134143, 3955, 12761, 240, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146941, 4200, 791, 22, 61, "Input",
 InitializationCell->True],
Cell[147735, 4224, 12871, 245, 366, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[160667, 4476, 70, 1, 68, "Section",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[160762, 4481, 149, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[160936, 4488, 108, 2, 28, "Input",
 InitializationCell->True],
Cell[161047, 4492, 1414, 46, 105, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[162510, 4544, 90, 1, 35, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[162625, 4549, 169, 3, 28, "Input",
 InitializationCell->True],
Cell[162797, 4554, 3945, 122, 202, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[166791, 4682, 129, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[166945, 4689, 152, 3, 28, "Input",
 InitializationCell->True],
Cell[167100, 4694, 16852, 484, 1063, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[184001, 5184, 142, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[184168, 5191, 110, 2, 28, "Input",
 InitializationCell->True],
Cell[184281, 5195, 3844, 121, 202, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[188174, 5322, 138, 3, 35, "Subsection",
 Evaluatable->False,
 InitializationCell->True],
Cell[CellGroupData[{
Cell[188337, 5329, 182, 5, 28, "Input",
 InitializationCell->True],
Cell[188522, 5336, 16632, 484, 1100, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[205215, 5827, 55, 1, 68, "Section",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[205295, 5832, 136, 4, 35, "Subsection",
 InitializationCell->True],
Cell[205434, 5838, 46, 1, 28, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
