(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1391354,      27043]
NotebookOptionsPosition[   1339532,      26138]
NotebookOutlinePosition[   1340170,      26161]
CellTagsIndexPosition[   1340127,      26158]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Analysis of the sweet spot for the coil - T1000164-v5, 2023-04-10\
\>", "Title",
 CellChangeTimes->{{3.662846845378744*^9, 3.662846854708425*^9}, {
  3.799225299045371*^9, 3.799225299730547*^9}, {3.814249802711513*^9, 
  3.814249820917439*^9}, {3.8322464004572487`*^9, 3.832246405192521*^9}, {
  3.832396485348632*^9, 3.8323964854750767`*^9}, {3.8896088949225693`*^9, 
  3.889608902920835*^9}, {3.8901274811250563`*^9, 
  3.890127494274313*^9}},ExpressionUUID->"3dfe1237-ce63-495a-9b65-\
ebf5ff37ac1c"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Instructions",
 FontColor->RGBColor[1, 0, 0]]], "Section",ExpressionUUID->"bb0d3673-5957-\
440e-805b-8cf3d0ee019a"],

Cell["\<\
1. Make sure that the notebook of utility functions for magnetic dipoles, \
MagDipole.nb, and the associated autosave file, MagDipole.m, are in the same \
directory as this notebook.
2. Do likewise for NewCoilTheory.nb and NewCoilTheory.m.
3. Evaluate the Preliminaries section.
4. Evaluate other major sections of interest and/or hack around to your \
heart's content. Evaluating the whole notebook is slow, so don\
\[CloseCurlyQuote]t do more than you need, but obviously the summary section \
depends on most previous ones. \
\>", "Text",
 CellChangeTimes->{{3.662606486924474*^9, 3.6626064944261007`*^9}, {
  3.814249688783947*^9, 3.8142497436548767`*^9}, {3.814249788522298*^9, 
  3.814249792232605*^9}, {3.814249905142769*^9, 
  3.8142499305492163`*^9}},ExpressionUUID->"639e0d4b-79f4-4554-935e-\
ec18c521377a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Preliminaries",
 FontColor->RGBColor[1, 0, 0]]], "Section",
 Evaluatable->False,
 AspectRatioFixed->
  True,ExpressionUUID->"ae6c7bba-54b3-4d61-9f0a-2d04a3ee297b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"useprecomputed", " ", "=", " ", "False"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "whether", " ", "to", " ", "use", " ", "archived", " ", "values", " ", 
     "for", " ", "certain", " ", "time"}], "-", 
    RowBox[{"consuming", " ", "calculations"}], " ", "-", " ", 
    RowBox[{"only", " ", "patchily", " ", "implemented", " ", "so", " ", 
     RowBox[{"doesn", "'"}], "t", " ", "save", " ", "much", " ", "time"}]}], 
   " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.480244231326439*^9, 3.48024423792516*^9}, {
  3.480703939177309*^9, 3.48070394080156*^9}, {3.481941928523884*^9, 
  3.481941957601687*^9}, {3.662606252913006*^9, 3.66260627414581*^9}, {
  3.662606542247143*^9, 3.662606543728855*^9}, {3.6628468634118023`*^9, 
  3.662846863916623*^9}, {3.81424759380504*^9, 3.814247594453456*^9}, {
  3.8323964985378532`*^9, 3.832396503424221*^9}, {3.832578444222866*^9, 
  3.8325784620056963`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"880f8f56-0e29-4ae5-b330-3294a7b28cc9"],

Cell[CellGroupData[{

Cell["Dependencies", "Subsection",ExpressionUUID->"c8619771-36ca-45a5-aa35-9b680d81934d"],

Cell[CellGroupData[{

Cell["\<\
The path in which the MagDipole.m and NewCoilTheory.m files are installed. \
\>", "Subsubsection",
 CellChangeTimes->{{3.799225271705007*^9, 3.799225288807975*^9}, {
  3.814246719441493*^9, 
  3.814246726620619*^9}},ExpressionUUID->"a0d974f5-90d7-4db0-ad7e-\
fd24e90e28de"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Path", " ", "=", " ", 
   RowBox[{"Append", "[", 
    RowBox[{"$Path", ",", 
     RowBox[{"NotebookDirectory", "[", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.453747804876116*^9, 3.4537478086805983`*^9}, {
   3.662606320813328*^9, 3.662606344907859*^9}, {3.662606620105997*^9, 
   3.662606660892832*^9}, 3.662606796394608*^9, 3.799212631891096*^9, 
   3.812979216939597*^9, {3.814246699803422*^9, 3.814246710187633*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"cdb3efd8-18de-4355-af3a-39095dd99e02"]
}, Open  ]]
}, Open  ]],

Cell["<<\"MagDipole.m\"", "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"5372f101-ca2f-49e6-9a12-063152ae5f8d"],

Cell["<<\"NewCoilTheory.m\"", "Input",
 CellChangeTimes->{3.631828660846888*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"c342b927-7087-4eee-8bf4-9e186f897796"],

Cell[CellGroupData[{

Cell["Disable spell-checking", "Subsection",ExpressionUUID->"9780a3d9-9540-4886-9697-f741c422a5fb"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"General", "::", "spell"}], ",", 
   RowBox[{"General", "::", "spell1"}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"cf85e739-cd86-4302-aacd-ac44fc545330"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions for manipulating lists of substitutions", "Subsection",ExpressionUUID->"9adcfee4-a22e-4c6d-bdb2-90b11cf7b5de"],

Cell[CellGroupData[{

Cell["Replace a single substitution", "Subsubsection",ExpressionUUID->"ffc09f59-ca70-4cb8-affb-eabdf7057e11"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Override", "[", 
   RowBox[{"oldsubs_", ",", "newsubs_"}], "]"}], " ", ":=", " ", 
  RowBox[{"oldsubs", "/.", 
   RowBox[{"(", 
    RowBox[{"newsubs", "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"param_", "\[Rule]", "newval_"}], ")"}], "\[RuleDelayed]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "oldval_"}], ")"}], "\[RuleDelayed]", 
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "newval"}], ")"}]}], ")"}]}]}], 
    ")"}]}]}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"a8c3bb97-4087-4d53-8662-a22df462b79d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A function to reduce a substitution list to fully numerical form by applying \
it repeatedly to itself:\
\>", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 
  1}},ExpressionUUID->"506e45ed-ac8b-4ade-b72f-98885d921fd4"],

Cell["\<\
Recurse[sublist_List] := 
\tsublist//.(x_->y_):>(x->(y/.sublist))\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"6e6dff58-ddc2-4d85-a678-de8a16047112"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function to scale a substitution list:", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 
  1}},ExpressionUUID->"6638e03a-c5f4-4afd-9d19-0630b8b3b919"],

Cell["\<\
scale[sublist_List, factor_] := 
\tsublist/.(x_->y_):>(x->factor*y)\
\>", "Input",
 CellChangeTimes->{3.453749631833597*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"c7541543-1c68-47d5-98c0-53e6f0bec293"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derive the axial and radial components of B", "Subsection",ExpressionUUID->"678e8115-2bb6-4ba0-aeb9-afed12599c78"],

Cell[CellGroupData[{

Cell["\<\
Baxial = Simplify[
\tTogether[
\t\tdipoleB[[3]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]
\
\>", "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"d534ff9f-4118-48a0-8862-c08ac405a88b"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m1z"}], " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1x", " ", "r", " ", "z"}], "+", 
     RowBox[{"2", " ", "m1z", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965547722*^9, 3.453749599994955*^9, 3.4638444535242777`*^9, {
   3.478894405842181*^9, 3.478894421027747*^9}, 3.478960340825461*^9, 
   3.479485741071822*^9, 3.479486052836144*^9, 3.4796583821237583`*^9, 
   3.480082564582583*^9, 3.4802436759582167`*^9, 3.4806922469034033`*^9, 
   3.481566005895687*^9, {3.4819409141959743`*^9, 3.48194093732237*^9}, 
   3.48194192328915*^9, 3.662606573885989*^9, {3.662606989900323*^9, 
   3.662607015810851*^9}, 3.662607108876596*^9, 3.6626240600072823`*^9, 
   3.799212563574514*^9, 3.799212646045431*^9, 3.8141937153971453`*^9, 
   3.8142478934071712`*^9, 3.832158970804611*^9, 3.832246368647851*^9, 
   3.832396527787216*^9, 3.8324030912681847`*^9, 3.8324032466283216`*^9, 
   3.832578689245048*^9, 3.88969600411446*^9, 3.890118802350545*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"15d278e7-78bc-45cf-864c-27891c65dd47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Baxial", "/.", 
  RowBox[{"r", "\[Rule]", "0"}]}]], "Input",
 CellLabel->"In[11]:=",ExpressionUUID->"2456c139-a623-4985-af3d-765900d42720"],

Cell[BoxData[
 FractionBox[
  RowBox[{"m1z", " ", "mu0"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["z", "2"], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.4537479655831127`*^9, 3.453749600034116*^9, 3.4638444538148317`*^9, {
   3.478894405888887*^9, 3.478894421080052*^9}, 3.47896034086206*^9, 
   3.4794857411376143`*^9, 3.4794860528885927`*^9, 3.479658382192664*^9, 
   3.480082564654179*^9, 3.480243676115644*^9, 3.480692246945731*^9, 
   3.4815660059479713`*^9, {3.4819409142460823`*^9, 3.4819409373890877`*^9}, 
   3.4819419233788652`*^9, 3.6626065739127083`*^9, {3.662606990014765*^9, 
   3.662607015954369*^9}, 3.662607108934417*^9, 3.662624060038443*^9, 
   3.799212563624206*^9, 3.799212646050994*^9, 3.814193715404127*^9, 
   3.814247893412601*^9, 3.832158970821735*^9, 3.832246368690373*^9, 
   3.832396527795813*^9, 3.8324030912754908`*^9, 3.832403246635352*^9, 
   3.83257868925167*^9, 3.889696004117558*^9, 3.890118802395389*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"72251593-aae5-47aa-89aa-38dc32f73a6b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Btransverse = Simplify[
\tTogether[
\t\tdipoleB[[1]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]\
\>", "Input",
 CellLabel->"In[12]:=",ExpressionUUID->"fa895aba-bd45-47e1-b999-8f3ea924fac8"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "m1x", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1z", " ", "r", " ", "z"}], "-", 
     RowBox[{"m1x", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965615678*^9, 3.453749600077715*^9, 3.463844455487849*^9, {
   3.478894405942997*^9, 3.4788944211302834`*^9}, 3.478960340942863*^9, 
   3.479485741189885*^9, 3.4794860529295588`*^9, 3.4796583822416077`*^9, 
   3.480082564700638*^9, 3.48024367617673*^9, 3.480692246987156*^9, 
   3.481566005979335*^9, {3.481940914277701*^9, 3.481940937448995*^9}, 
   3.481941923414253*^9, 3.662606573961648*^9, {3.662606990066422*^9, 
   3.662607015998637*^9}, 3.662607108999185*^9, 3.662624060105956*^9, 
   3.799212563635304*^9, 3.7992126460936937`*^9, 3.814193715427429*^9, 
   3.8142478939887047`*^9, 3.832158970858761*^9, 3.832246368733734*^9, 
   3.832396527826013*^9, 3.832403091308158*^9, 3.832403246662184*^9, 
   3.832578689271515*^9, 3.889696004128603*^9, 3.890118802408864*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"b96e4a03-66d2-4819-bba2-a2c47d5ab46d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
force[Zz_] = Simplify[-mz \
D[dipoleBz,Zz]/.dx->0/.dy->0/.dz->0/.Xx->0/.Yy->0]/.powerfix\
\>", "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"657f57ee-cbd8-4b4b-ad07-337e3f815d14"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", "m1z", " ", "mu0", " ", "mz"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox["Zz", "4"]}]]], "Output",
 CellChangeTimes->{
  3.453747965823358*^9, 3.4537496001121492`*^9, 3.46384446080796*^9, {
   3.4788944059930553`*^9, 3.478894421180645*^9}, 3.47896034097888*^9, 
   3.4794857412398157`*^9, 3.479486052963105*^9, 3.479658382309431*^9, 
   3.4800825649222116`*^9, 3.480243676306188*^9, 3.48069224701851*^9, 
   3.4815660060302887`*^9, {3.481940914334242*^9, 3.481940937496923*^9}, 
   3.481941923466711*^9, 3.662606574022719*^9, {3.6626069901552343`*^9, 
   3.662607016065351*^9}, 3.662607109064283*^9, 3.662624060172635*^9, 
   3.7992125636946898`*^9, 3.7992126461435432`*^9, 3.814193715463139*^9, 
   3.814247894143971*^9, 3.8321589710988407`*^9, 3.832246368779505*^9, 
   3.8323965278601513`*^9, 3.832403091349923*^9, 3.8324032466931047`*^9, 
   3.832578689295928*^9, 3.889696004141819*^9, 3.890118802425701*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"6ab945c6-9801-4d7e-85ed-c30911b5a5f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"force", "[", "1", "]"}], "/.", 
     RowBox[{"mz", "\[Rule]", "1."}]}], "/.", 
    RowBox[{"m1z", "\[Rule]", "1."}]}], "/.", 
   RowBox[{"Zz", "\[Rule]", "1."}]}], "/.", 
  RowBox[{"mu0", "\[Rule]", "1", " ", 
   RowBox[{"(*", 
    RowBox[{"4", " ", "Pi", " ", 
     RowBox[{"10", "^", 
      RowBox[{"-", "7"}]}]}], "*)"}]}]}]], "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"b11f8f4d-4fab-4c28-89c0-ba9ed0b4562c"],

Cell[BoxData["0.477464829275686`"], "Output",
 CellChangeTimes->{
  3.4537479659442177`*^9, 3.4537496001816998`*^9, 3.463844461260048*^9, {
   3.478894406093301*^9, 3.4788944212800493`*^9}, 3.478960341011427*^9, 
   3.4794857412898493`*^9, 3.47948605300837*^9, 3.4796583823753366`*^9, 
   3.4800825649736032`*^9, 3.480243676359799*^9, 3.480692247054192*^9, 
   3.4815660060631313`*^9, {3.481940914365226*^9, 3.481940937547433*^9}, 
   3.4819419235105124`*^9, 3.6626065740757732`*^9, {3.662606990213984*^9, 
   3.662607016116412*^9}, 3.6626071091101513`*^9, 3.662624060236904*^9, 
   3.799212563699902*^9, 3.7992126461500683`*^9, 3.814193715467792*^9, 
   3.814247894150564*^9, 3.8321589711163187`*^9, 3.832246368792591*^9, 
   3.832396527867955*^9, 3.8324030913582153`*^9, 3.8324032467004843`*^9, 
   3.832578689302677*^9, 3.889696004144928*^9, 3.890118802429178*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"eb0564cd-7731-49de-83c4-4f871a2ea820"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic constants", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->
  True,ExpressionUUID->"edcb98b6-a535-42a2-abc3-024a620de9bf"],

Cell["\<\
basicvals = Recurse[{
\tkB->1.38 10^-23,
\tT->295,
\tg->9.8,
\tmu0->4 N[Pi] 10^-7,
\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\tmassM->rhomM l N[Pi] a^2,
\tBresid->1.25,\t\t\t\t(* Residual field *)
\tPi->N[Pi],
\tl->0.003175,\t\t\t\t(* Length of magnets *)
\ta->0.0009525,\t\t\t\t(* Radius of magnets *)
\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\tmasspullapart->0.060\t\t(* Force (in kgf) to separate magnets *)
}];\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[15]:=",ExpressionUUID->"19e1338f-4a6c-44a8-827f-3217503d699e"],

Cell["\<\
SOSvals = Recurse[{
\tdpend->0.248,\t(* SOS final design *)
\troptic->0.0762/2,\t(* SOS final design *)
\tdyaw->0.0157,\t(* SOS final design *)
\tmassoptic->0.25,
\tw0->2 N[Pi] 1.0
}];\
\>", "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"fdca09ed-d11f-4dbe-b709-0ac511c38634"],

Cell["\<\
LOSvals = Recurse[{
\tw0->2 N[Pi] 0.743,
\trwire->0.0031/2,
\tawire->N[Pi] rwire^2,
\tdpend->0.450,\t(* LOS final design *)
\tdyaw->0.0333,\t(* LOS final design *)
\tmassoptic->10.7,
\tloptic->0.1,
\troptic->0.125,
\tIoptic->0.25 massoptic*roptic^2 + (1/12) massoptic loptic^2,
\twpitch->2 N[Pi] 0.6,
\twpend->2 N[Pi] 0.744,
\twyaw->2 N[Pi] 0.5,
\tkpitch->wpitch^2 Ioptic, (* Angular restoring force *)
\tkyaw->wyaw^2 Ioptic, (* Angular restoring force *)\t
\tpitchlever->0.0808,\t(* lever arm, pitch direction, per magnet *)
\tyawlever->0.0808,\t(* lever arm, pitch direction, per magnet *)
\tkxpitch->kpitch/pitchlever
}];\
\>", "Input",
 CellChangeTimes->{3.478894781983313*^9},
 CellLabel->"In[17]:=",ExpressionUUID->"84d4f767-3885-464a-9226-6977164a18a0"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for bigmagnetvals 10x10 magnet, old 400 turn coil\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.799216647040254*^9, 
  3.7992166586940813`*^9}},ExpressionUUID->"2ae1367f-56e4-4279-9cb4-\
f02578c0d682"],

Cell[CellGroupData[{

Cell["\<\
bigmagnetvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.16*0.0254,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254,
\t\tcoilrad2->0.55*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"1a638f07-39e3-4615-8baa-7d495e3444de"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.005811946409141117`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.007999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.004064`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.002032`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.002032`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.008889999999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01397`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.9375038750077497`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.463844663941598*^9, 3.479667628840351*^9, 
  3.480245057580022*^9, 3.48069224815385*^9, 3.4815660167539787`*^9, 
  3.481941596985648*^9, 3.481941924708386*^9, 3.662623278532525*^9, 
  3.66262406040844*^9, 3.7992125637743483`*^9, 3.7992126469013*^9, 
  3.814193715513921*^9, 3.814247894196075*^9, 3.832246368863431*^9, 
  3.832403091429172*^9, 3.8324032511365843`*^9, 3.832578689445447*^9, 
  3.889696004163066*^9, 3.8901188024540977`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"8952b828-1e54-4302-b85a-a7fd0c927fc2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BM", "]"}], " ", ":=", " ", "bigmagnetvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"902df673-dd1f-4fb6-888a-fc33cf3e4da3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.084332204665714`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.006361536563952735`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"BM", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.479667207329587*^9, 3.479667207950783*^9}, {3.4802442654999228`*^9, 
   3.480244302808629*^9}, 3.6626232869812593`*^9, 3.832402613917573*^9, 
   3.832402745881968*^9, 3.832402900980329*^9, 3.832402993964534*^9, 
   3.8324031637947683`*^9},
 CellLabel->"In[20]:=",ExpressionUUID->"445ff0c9-759b-41bc-bd85-1effc873d84c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.0843322046660526`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006361538984579861`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6626243337155247`*^9, 3.799212563827639*^9, 
  3.799212646948718*^9, 3.814193715525363*^9, 3.8142480954368467`*^9, 
  3.8322463689239264`*^9, 3.832403091523506*^9, 3.832403259072109*^9, 
  3.832578697320484*^9, 3.889696007608657*^9, 3.8901188054704943`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"de548478-e796-4e65-8ef6-61c2493efb8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8VW8cB3A/DaIQmSmlKFERFcKHiiT8yMgooSFCGZd7z71klboaGsqI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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 1.0843321794484708`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BM", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.479667208457279*^9, 3.479667208895832*^9}, {
   3.48024520498495*^9, 3.4802452202413063`*^9}, 3.662623284294729*^9},
 CellLabel->"In[21]:=",ExpressionUUID->"449b716a-aa12-4cf6-bd1e-313b91961256"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV12k8VP0bBnCPFqIQWZIWilIqokK4tFDZHrIUSmgRoRjDnDNDtrbRokVZ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       "]]},
     Annotation[#, "Charting`Private`Tag$23831#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 1.084332179448471}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662624366216887*^9, 3.79921256389085*^9, 
  3.799212646998053*^9, 3.814193715554414*^9, 3.814248123157708*^9, 
  3.832246397098259*^9, 3.8324031200198298`*^9, 3.8324032890650587`*^9, 
  3.832578724380621*^9, 3.8896960192793407`*^9, 3.890118816572092*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"99ebf50e-d20c-4cdd-93bc-400e90bc76cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.4796672094171343`*^9, 3.4796672098856077`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"95d58a8b-5990-4a03-a515-fea0840c57ce"],

Cell[BoxData["0.006361538984579861`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.4796682577475853`*^9, 3.4802452914839983`*^9, 3.480692248270643*^9, 
  3.481566016936092*^9, 3.481941597128859*^9, 3.481941924843739*^9, 
  3.662624366497341*^9, 3.7992125639351587`*^9, 3.79921264700364*^9, 
  3.814193715560705*^9, 3.81424812321885*^9, 3.8322463974115477`*^9, 
  3.8324031201731873`*^9, 3.8324032891326313`*^9, 3.832578724448758*^9, 
  3.8896960193222313`*^9, 3.890118816599949*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"dca5cfb5-7a26-4b5f-bf2a-8913b90b1f8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.479667219043417*^9, 3.4796672194929113`*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"58b82fc2-4281-4e19-9c58-3ceab85f654e"],

Cell[BoxData["1.0843322046660526`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.479668257772698*^9, 3.48024529160467*^9, 3.480692248321662*^9, 
  3.481566016972385*^9, 3.481941597184218*^9, 3.481941924879663*^9, 
  3.662624366528409*^9, 3.7992125639402847`*^9, 3.799212647046083*^9, 
  3.814193715582225*^9, 3.814248123224889*^9, 3.83224639747169*^9, 
  3.832403120182303*^9, 3.8324032891425962`*^9, 3.832578724460927*^9, 
  3.8896960193276577`*^9, 3.890118816603426*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"ffb24ee5-1c65-4765-bb49-f25fb71dba43"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"34545ddd-03f8-4d06-b2de-379474b8d110"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVyWlM0wcAhvGu1BGwEo7WQamiiIJDVA5xQrtXlKJcCgxUohyDAhtU6NgY
IFe5oQiaUBCmbNMFJ3boMByCtRtmRbGoK4EqV2TlKrS0/QtClgCZ+/Dk9+HZ
GZcWlkAmkUisD/3v8o1uu7yTOjaJZG7hZcz/fKIlULLc54znrgtbfbmtaP8l
ibzpHQvVabTFR3VSmGf+e+KqgIOvxkWKEnEfgjQsbwU3CFE5zdycNy+Q7XQu
IVgfCoZngOGabBCHvLhJZ3gRsCky280OUeK2b0XXLo9IpNMvsZvpo/jBU9MU
sHABDkle6+vtE5AcD3kbcDAWQ84ebVmCSZSpO+sHzeMwnRxjTWGrIJP4pfAU
8Rha2SyLfjkFGWXF1L0yAbldVfJO/xns8G9TnE9Mgk/hsyizoVnoJXUd9bu+
xtz0M+tiNzVsXMr+dP84BdR/7DfUjfOgWNTXr7/lYUUidr4/vQCuw6vKkcZU
RCcKH8ZTtDBnmA5WsfgQX/7ITeKwiDtHehfdmd9gn1RrkDN0SD27waw2S8dI
T4O4bLMetAPytty1dMRQH3FsJ/TI+HFfRMbotyCzLta4+hpgRKVR7eTfwT+c
zuutNSDI4qpCIc7A4a5Qo2sKAzL+vr7GqPgee0qjub+SCQxUu3jTMzOx+DJS
tdeZwITqiwrrM1m4cncsKoxDwNaTND9wIhuhMwZhQgQBr+Os+58cuoR+xl8z
nEgCVmpqSYplDopaSlafhhFgVMXz+ORcmKxtNYn0ITAmOxWfr8rFrb3dasKR
QF5P/x/20jzUOqZ62xoTCGp9fiDrt3zcOqvfcnrMAOXh2HtKYQEWNo6OZ4oN
8Jtk71hiC2C6jaOU8Q0oMNTxC+4J4PKw4/FRDwPuTHQsKZmF2JF8SsRT66Hu
byCViwqRbVIpOxeuxyZyn8ibUoSpot7YF090+OxI54OTeUUYeuLzZeJ2HS4E
pxrtXP7w5y0XczIXEdXKH1uPK0b8O1359GstMqiebPexYoSHMEqbHbVI7uLs
uRhYAh2Vrl0RaHAa246ld5eg9W65JmB8AYF9XXOvDpaikcSXvndagEPjDZrb
z6XY3kTf31Q4D1qKr1xrXYaN0erhkQE1lm3a29OvlCEtRWdZy1SjjZa6e329
DH5D+11bsudQaqaxm8woxxaK1W2yfBae4Q9uPp0px/AI09Tr01lsNLBajWMq
8LuZFUmWP4POnhqNpbIC51k+5rkj0wh0cm6z51Qi8v3wdY9j01gVCUlVjytR
0Kdaqrk5BUGwx+tVFyGYw6vSN2ZTIESeadKfhFgJIoQdeSr8B+ndzKk=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$44951#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.0842951750980083`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVyWlM0wcAhvGu1BGwEo7WQamiiIJDVA5xQrtXlKJcCgxUohyDAhtU6NgY
IFe5oQiaUBCmbNMFJ3boMByCtRtmRbGoK4EqV2TlKrS0/QtClgCZ+/Dk9+HZ
GZcWlkAmkUisD/3v8o1uu7yTOjaJZG7hZcz/fKIlULLc54znrgtbfbmtaP8l
ibzpHQvVabTFR3VSmGf+e+KqgIOvxkWKEnEfgjQsbwU3CFE5zdycNy+Q7XQu
IVgfCoZngOGabBCHvLhJZ3gRsCky280OUeK2b0XXLo9IpNMvsZvpo/jBU9MU
sHABDkle6+vtE5AcD3kbcDAWQ84ebVmCSZSpO+sHzeMwnRxjTWGrIJP4pfAU
8Rha2SyLfjkFGWXF1L0yAbldVfJO/xns8G9TnE9Mgk/hsyizoVnoJXUd9bu+
xtz0M+tiNzVsXMr+dP84BdR/7DfUjfOgWNTXr7/lYUUidr4/vQCuw6vKkcZU
RCcKH8ZTtDBnmA5WsfgQX/7ITeKwiDtHehfdmd9gn1RrkDN0SD27waw2S8dI
T4O4bLMetAPytty1dMRQH3FsJ/TI+HFfRMbotyCzLta4+hpgRKVR7eTfwT+c
zuutNSDI4qpCIc7A4a5Qo2sKAzL+vr7GqPgee0qjub+SCQxUu3jTMzOx+DJS
tdeZwITqiwrrM1m4cncsKoxDwNaTND9wIhuhMwZhQgQBr+Os+58cuoR+xl8z
nEgCVmpqSYplDopaSlafhhFgVMXz+ORcmKxtNYn0ITAmOxWfr8rFrb3dasKR
QF5P/x/20jzUOqZ62xoTCGp9fiDrt3zcOqvfcnrMAOXh2HtKYQEWNo6OZ4oN
8Jtk71hiC2C6jaOU8Q0oMNTxC+4J4PKw4/FRDwPuTHQsKZmF2JF8SsRT66Hu
byCViwqRbVIpOxeuxyZyn8ibUoSpot7YF090+OxI54OTeUUYeuLzZeJ2HS4E
pxrtXP7w5y0XczIXEdXKH1uPK0b8O1359GstMqiebPexYoSHMEqbHbVI7uLs
uRhYAh2Vrl0RaHAa246ld5eg9W65JmB8AYF9XXOvDpaikcSXvndagEPjDZrb
z6XY3kTf31Q4D1qKr1xrXYaN0erhkQE1lm3a29OvlCEtRWdZy1SjjZa6e329
DH5D+11bsudQaqaxm8woxxaK1W2yfBae4Q9uPp0px/AI09Tr01lsNLBajWMq
8LuZFUmWP4POnhqNpbIC51k+5rkj0wh0cm6z51Qi8v3wdY9j01gVCUlVjytR
0Kdaqrk5BUGwx+tVFyGYw6vSN2ZTIESeadKfhFgJIoQdeSr8B+ndzKk=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$44951#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.0842951750980083`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {49}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGJDBgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gb71C/bgCY0Qu1vtH/+e+XHS75NUHc02WcyzzW7kNkMdU+z/RuuCdVn
W1vs14Ld1WqfJ9QMtKIV6r42+0+SZawn9rZB3dluX6yY6XX0Zru9Cdi9HfZf
NWL6D33tsN8GdnenfTnIWsEuqPu77AGyNMFI
   "], CompressedData["
1:eJwBmQFm/iFib1JlAgAAADEAAAABAAAAAAAAAAAAAAD4AMncqMayP4UqdsrG
vMI/9YH4t2ECzD8uYYLNBZXSP/ZmMh69FNc/F+0rnhZ72z+85jqMuMLfP6G0
2iAb8+E/FtspKg7w4z8VVl4kgdXlP9+kYo3QoOc/rGGR7HZP6T+JfsxfG9/q
P6Y+53KgTew/kb+vizKZ7T+7tGjNVMDuP38tCw/swe8/1qrwlaNO8D/DuIcl
EqnwPyTGYt5Z8PA/1aLrIcsk8T8qRpbA7EbxP56nllB4V/E/Sa9jDFVX8T83
Z2tzkUfxP+U4G8NbKfE/qtBCq/n98D/1eyxXwMbwPy3VRd0KhfA/e2/EgzM6
8D+n4sO7GM/vP2/9LveyHO8/u/Ey+5hf7j9KDRCUAprtP/45jVT4zew/TV3h
RFH96z/ypSwQsynrP3ksZeqSVOo/vAjN1zd/6T+E67BavaroPzcXB8cW2Oc/
Hk9itBII5z+AlclNXjvmP5AE3OOIcuU/HQLQHweu5D95fSoYNu7jP9b1cRVe
M+M/pyZmgbV94j8c9smt
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662624375842202*^9, 3.799212564060957*^9, 
  3.799212655130692*^9, 3.814193723911942*^9, 3.814248131589074*^9, 
  3.83224640554515*^9, 3.832403121870832*^9, 3.832403297903576*^9, 
  3.832578732328252*^9, 3.889696022687495*^9, 3.890118819815455*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"1f396b2a-dc0c-41a0-9061-a3425bdb2a35"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BM", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, 3.799212531109395*^9},
 CellLabel->"In[25]:=",ExpressionUUID->"64ff4a14-8871-4129-af87-06c0713c3594"],

Cell[BoxData["53808.57264516576`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626243761012707`*^9, 3.799212564110034*^9, 3.799212655225871*^9, 
   3.8141937240434504`*^9, 3.814248131667664*^9, 3.832246405800445*^9, 
   3.8324032980114307`*^9, 3.832578732407949*^9, 3.8896960227289248`*^9, 
   3.890118819856008*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"ec9390d8-1303-4e51-b1eb-a22563c4c163"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"BM", ",", 
   RowBox[{"-", "0.0064"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"f8cf4648-752b-474a-bc39-f37770b6d3f7"],

Cell[BoxData[
 RowBox[{"-", "1.084292460250462`"}]], "Output",
 CellChangeTimes->{3.453749602972189*^9, 3.453749666574046*^9, 
  3.453750876352957*^9, 3.453752731604185*^9, 3.453823764931923*^9, 
  3.453823801509736*^9, 3.4538385837598877`*^9, 3.453838637735564*^9, 
  3.46384467782513*^9, 3.4796682584643373`*^9, 3.4802452924391212`*^9, 
  3.480692249102811*^9, 3.481566017649225*^9, 3.4819415980291986`*^9, 
  3.4819419259636927`*^9, 3.662624376253016*^9, 3.7992125641161833`*^9, 
  3.7992126553405027`*^9, 3.8141937241571083`*^9, 3.814248131805183*^9, 
  3.83224640594308*^9, 3.832403298171874*^9, 3.832578732527194*^9, 
  3.889696022779839*^9, 3.8901188199053*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"13c60b1e-7dcb-4a27-b72d-98ed14ba4edf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"53a96b9e-449f-4ee8-9791-f3779fc8cb23"],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.453823764961364*^9, 
   3.463844678344269*^9, 3.479668258488261*^9, 3.480245292474451*^9, 
   3.480692249189704*^9, 3.481566017673868*^9, 3.48194159812962*^9, 
   3.481941926000042*^9, 3.6626243762992783`*^9, 3.799212564182468*^9, 
   3.7992126553465853`*^9, 3.814193724162015*^9, 3.814248131810624*^9, 
   3.832246405956505*^9, 3.8324032981812468`*^9, 3.832578732534313*^9, 
   3.889696022809247*^9, 3.8901188199091063`*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"ca3ed090-a762-4c54-bce6-1d78810d464a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"BM", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
  3.453823813188589*^9, 3.4538238137302923`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"401ce758-5327-4811-82da-38866b3dedee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.051149`", ",", 
   RowBox[{"-", "1.0436583953898717`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823765066656*^9, 
  3.45382381697288*^9, 3.4638446806023808`*^9, 3.479668258688435*^9, 
  3.480245292720821*^9, 3.480692249415637*^9, 3.481566017911345*^9, 
  3.481941598383407*^9, 3.481941926247629*^9, 3.662624376460092*^9, 
  3.799212564277938*^9, 3.799212655477284*^9, 3.81419372429537*^9, 
  3.814248131960349*^9, 3.832246406114231*^9, 3.8324032983482018`*^9, 
  3.8325787326601267`*^9, 3.889696022866014*^9, 3.890118819962296*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"cd59c321-27e8-4254-a3d1-fa3d1b029132"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sweet spot of hybrid OSEM with dipole correction (two 10 mm long by 10 mm \
diameter magnets, 5 mm between faces) relative to centre of coil\
\>", "Text",ExpressionUUID->"36002a4d-5c80-4599-85a4-f80a15a9331b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", "\[IndentingNewLine]", 
  RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VG8UB3DZk6SxlSxRRJhCtHsLbUhaaEMimpEsKTH3zpA9ayGkItoo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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-0.01, 0.5},
    PlotRange->{{-0.01, -0.003}, {0.4602013907859698, 0.9124418225431208}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"BM", ",", "p"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"BM", ",", 
          RowBox[{"p", "-", "0.015"}]}], "]"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"-", "0.010"}], ",", 
       RowBox[{"-", "0.003"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.453823411637844*^9, 3.453823415837685*^9}, {
  3.480245301978496*^9, 3.4802453263238277`*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"a754fc22-647b-40ae-bb7f-9655f6a4fb9d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nk8VG0UB3CJIUmypGQJKcKUvf0hKiG0oAWJ0owkUmLunbEvWQshldBG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       "]]},
     Annotation[#, "Charting`Private`Tag$45307#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.0028541666666666732`, 0.4602013907859714},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, -0.003}, {0.4602013907859704, 0.9124418225431205}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.453823529739856*^9, 3.463844847582552*^9, 
  3.480245328076311*^9, 3.480692249849388*^9, 3.481566018664538*^9, 
  3.481941598416605*^9, 3.481941926329867*^9, 3.662624416436451*^9, 
  3.799212564286899*^9, 3.799212655484116*^9, 3.814193724305381*^9, 
  3.8142481682970943`*^9, 3.832246441385016*^9, 3.832403334480356*^9, 
  3.832578765971678*^9, 3.889696037133375*^9, 3.8901188336704273`*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"7ac88fbb-6007-4dd5-811a-e5f3fb272088"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
If[
useprecomputed,
{-0.912442, {p \[Rule] -0.00680076}},
FindMinimum[fz[BM,p]-fz[BM,p-0.015],{p,-0.007,-0.006}]
]\
\>", "Input",
 CellChangeTimes->{{3.45382342881886*^9, 3.4538234334668007`*^9}, {
  3.4538235413508263`*^9, 3.453823587089514*^9}, {3.480245341853726*^9, 
  3.480245360684174*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"beec4926-b1cd-4634-9cc5-b505164c56d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9124418416938308`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", "0.0068007647960816155`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.453823532157748*^9, 3.4538235906330833`*^9}, 
   3.463844850994608*^9, {3.480245357148303*^9, 3.480245361221218*^9}, 
   3.480692249882522*^9, 3.481566018727625*^9, 3.48194159846943*^9, 
   3.4819419263446903`*^9, 3.662624418589693*^9, 3.7992125643326483`*^9, 
   3.799212655516746*^9, 3.8141937243287077`*^9, 3.814248169987566*^9, 
   3.832246442963361*^9, 3.832403336241687*^9, 3.832578767565505*^9, 
   3.8896960378073053`*^9, 3.890118834342157*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"8ea39ccc-2552-4d73-a1fb-87452671904f"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 
  3.4538236144707003`*^9}},ExpressionUUID->"c37bd691-811c-4570-8675-\
b60bafa8e5bf"],

Cell[CellGroupData[{

Cell["\<\
OOvals = Recurse[
\tbasicvals~Join~LOSvals~Join~{
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* preferred value of magnet dipole moment per volume *)
\t\tmz->mzpref/(l*N[Pi]*a^2),
\t\t(* nominal distance between PAM and optic magnet centres *)
\t\tz0->0.013,
\t\t(* thread spacing (40 tpi, cf. 32 in original design) *)
\t\tthreadpitch->0.0254/40, \t\t
\t\t(* standard perturbation to (normalised) magnet strength *)
\t\tspert->0.1, 
\t\t(* standard perturbation to magnet position *)
\t\tzpert->threadpitch, 
\t\t(* elasticity of pendulum mode *)
\t\tkpend->massoptic g/dpend,
\t\t(* distance that the magnet sticks out of the OSEM *)
\t\tstandofftoosem->0.00114681,
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254,
\t\t(* the ends of the coil relative to the end of the OSEM *)
\t\tcoilz1OSEM->0.12*0.0254,
\t\tcoilz2OSEM->coilz1OSEM+coillen,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.302*0.0254,
\t\tcoilrad2->0.498*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.4538264235745993`*^9, 3.45382644840556*^9}, {
   3.453837031795086*^9, 3.453837041528119*^9}, {3.453837099708474*^9, 
   3.453837132901514*^9}, 3.453837267777411*^9, {3.453840139813717*^9, 
   3.453840149255684*^9}, {3.4538402007979527`*^9, 3.453840204355585*^9}, {
   3.4538636089891777`*^9, 3.453863609530529*^9}, {3.453863819107182*^9, 
   3.453863840974169*^9}, {3.45386389080914*^9, 3.4538638933349*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"b4827e9a-2581-400c-b635-ff1b6db624ad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535085`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"z0", "\[Rule]", "0.013`"}], ",", 
   RowBox[{"threadpitch", "\[Rule]", "0.000635`"}], ",", 
   RowBox[{"spert", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"zpert", "\[Rule]", "0.000635`"}], ",", 
   RowBox[{"kpend", "\[Rule]", "233.0222222222222`"}], ",", 
   RowBox[{"standofftoosem", "\[Rule]", "0.00114681`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1OSEM", "\[Rule]", "0.003048`"}], ",", 
   RowBox[{"coilz2OSEM", "\[Rule]", "0.008305799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.007670799999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5281505471815046`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538636242380333`*^9, 3.4538639022226553`*^9, 
  3.463844851197278*^9, 3.4806922499105587`*^9, 3.481941926405641*^9, 
  3.662624418650628*^9, 3.799212564338482*^9, 3.799212655522147*^9, 
  3.814193724335094*^9, 3.8142481700320663`*^9, 3.832246443049244*^9, 
  3.832403336293612*^9, 3.83257876760286*^9, 3.889696037813952*^9, 
  3.890118834348618*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"38dcb07c-b710-4018-95e7-bce594ff6b65"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "OO", "]"}], " ", ":=", " ", "OOvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
  3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
  3.453837393571328*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"75fa72e5-f61a-4b00-87b8-d570a6556952"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"OO", ",", 
   RowBox[{"-", "0.0064"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}, 
   3.453823640650034*^9, 3.453837393601057*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"20077e92-d012-4e5b-862a-5fbaddf3cbfd"],

Cell[BoxData[
 RowBox[{"-", "0.015387096244059588`"}]], "Output",
 CellChangeTimes->{
  3.453749602972189*^9, 3.453749666574046*^9, 3.453750876352957*^9, 
   3.453752731604185*^9, 3.4538236694422503`*^9, 3.4538259483409157`*^9, 
   3.453826469350016*^9, {3.4538373992114477`*^9, 3.4538374256931763`*^9}, 
   3.453837477368595*^9, 3.453838646018355*^9, {3.4538401571878767`*^9, 
   3.453840174075727*^9}, 3.453840210377989*^9, 3.4538636411134653`*^9, 
   3.453863909646071*^9, 3.463844851305705*^9, 3.480692249973194*^9, 
   3.4819419265374804`*^9, 3.662624418743021*^9, 3.799212564389861*^9, 
   3.799212655582581*^9, 3.8141937243677397`*^9, 3.814248170070281*^9, 
   3.832246443117552*^9, 3.832403336337735*^9, 3.832578767639967*^9, 
   3.889696037843342*^9, 3.890118834372643*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"3afdb193-bc7c-4f18-b8bc-b271d6e91377"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"bc336c19-1cb1-43a6-baa9-f8f5c9d85fcc"],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.4538236694697313`*^9, 
   3.453825948369759*^9, 3.453837425726906*^9, 3.453840157247375*^9, 
   3.4538402104113083`*^9, 3.453863641155484*^9, 3.453863909695507*^9, 
   3.4638448513697023`*^9, 3.4806922500076113`*^9, 3.481941926588934*^9, 
   3.662624418792185*^9, 3.7992125644349127`*^9, 3.799212655587611*^9, 
   3.814193724372637*^9, 3.814248170082432*^9, 3.832246443132986*^9, 
   3.832403336348516*^9, 3.832578767646083*^9, 3.8896960378470783`*^9, 
   3.8901188343758574`*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"68d152e1-5b22-41bd-8814-2208e683ca26"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
   3.453823640684885*^9, 3.453823640735626*^9}, {3.453826474859961*^9, 
   3.45382647576938*^9}, 3.4538373936510477`*^9},
 CellLabel->"In[35]:=",ExpressionUUID->"27952e17-6cd1-4d1f-ac44-4d2f63fd648a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.011286`", ",", 
   RowBox[{"-", "0.015851396334673775`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823671960964*^9, 
  3.453825948604528*^9, 3.453826476451028*^9, 3.453837425763947*^9, 
  3.453840157347342*^9, 3.453840210506116*^9, 3.453863641201985*^9, 
  3.4538639097501583`*^9, 3.463844851469378*^9, 3.480692250041*^9, 
  3.4819419266883163`*^9, 3.662624418850252*^9, 3.799212564443059*^9, 
  3.799212655620996*^9, 3.814193724403779*^9, 3.814248170131605*^9, 
  3.832246443185629*^9, 3.832403336384632*^9, 3.832578767678669*^9, 
  3.889696037861691*^9, 3.890118834391464*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"d3fd5428-f955-4db0-9e2f-51af12d7fb43"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", 
    RowBox[{"-", "0.010"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751088575416*^9, 3.453751089087048*^9}, 
   3.453823640769184*^9, 3.453837393699996*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"3a518087-6cae-40e0-983d-81d102009411"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.008399`", ",", 
   RowBox[{"-", "0.010507386986391542`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453749683527301*^9, 3.45375109040812*^9, 
  3.4538236722686167`*^9, 3.453825948821306*^9, 3.45382648659874*^9, 
  3.453837425793631*^9, 3.4538401576313677`*^9, 3.453840210546205*^9, 
  3.453863641238579*^9, 3.453863909799973*^9, 3.4638448515362864`*^9, 
  3.4806922500657587`*^9, 3.481941926915098*^9, 3.662624418897685*^9, 
  3.79921256448658*^9, 3.799212655656489*^9, 3.814193724429985*^9, 
  3.814248170167042*^9, 3.8322464432423067`*^9, 3.832403336417548*^9, 
  3.832578767703679*^9, 3.889696037873968*^9, 3.890118834407547*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"27f74ec4-1455-4fb3-86b9-ad19586fbee1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", 
    RowBox[{"-", "0.003"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751094726705*^9, 3.453751095317946*^9}, 
   3.453823640822011*^9, 3.453837393750527*^9},
 CellLabel->"In[37]:=",ExpressionUUID->"11708426-b2bc-4205-9106-debb6efe02c5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.016002`", ",", 
   RowBox[{"-", "0.012824745749794315`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537496838232193`*^9, 3.4537510967086277`*^9, 
  3.453823672557324*^9, 3.4538259490222588`*^9, 3.4538264890979757`*^9, 
  3.453837425851626*^9, 3.4538401579824533`*^9, 3.453840210608426*^9, 
  3.4538636412980003`*^9, 3.453863909861566*^9, 3.463844851657218*^9, 
  3.480692250121179*^9, 3.481941926976323*^9, 3.662624418971629*^9, 
  3.799212564493863*^9, 3.799212655703897*^9, 3.814193724471422*^9, 
  3.814248170234256*^9, 3.832246443296812*^9, 3.832403336464943*^9, 
  3.8325787677468977`*^9, 3.889696037892515*^9, 3.890118834425123*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"d2899fad-810e-466a-a295-3ed242224d2f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"18b6656e-f25d-4227-9736-\
711dee46383f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"OO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"7f8d5b99-3877-44ef-993a-cb12d9cd2d89"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk8VO/3AHCEipK0iCSphKQsidApW5JEC4kkJck+M3fGWsnM0GDuFaVE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       "]]},
     Annotation[#, "Charting`Private`Tag$79584#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.015861531207785717`, 0.015861531161368958`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.453840159929102*^9, 
   3.453840225991082*^9, 3.4538636558574543`*^9, 3.453863924479361*^9, 
   3.4638448686389313`*^9, 3.4806922643363953`*^9, 3.481941942064209*^9, 
   3.662624432690221*^9, 3.7992125646333*^9, 3.799212667535213*^9, 
   3.814193737109878*^9, 3.814248182353356*^9, 3.832246456477652*^9, 
   3.832403348808413*^9, 3.832578779605871*^9, 3.8896960428760967`*^9, 
   3.8901188391693697`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"2b58a7af-bcac-4356-bac6-5a2acff40d20"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"OO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"25973c72-5333-4fd9-80f7-7ac37d6298d6"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13k4VO0bB3DLmxSRfUmUikqElBZ8WyS0SUKKlLJlmTFzZobsZuzNDKUS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       "]]},
     Annotation[#, "Charting`Private`Tag$105869#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.015861531364868304`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453840161864758*^9, 
  3.4538402352085543`*^9, 3.4538636649073067`*^9, 3.453863933391049*^9, 
  3.46384487886052*^9, 3.480692273326301*^9, 3.481941951327619*^9, 
  3.662624441306498*^9, 3.79921256464925*^9, 3.799212675206346*^9, 
  3.814193744471572*^9, 3.8142481901192007`*^9, 3.832246464695753*^9, 
  3.8324033564192047`*^9, 3.8325787869445972`*^9, 3.889696045919751*^9, 
  3.89011884207312*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"64d0aa98-0e64-4c62-b7f6-8f5dda9aeb33"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSdata", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fz", "[", 
      RowBox[{"OO", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, {3.453862450307226*^9, 3.45386248039209*^9}, {
   3.453862568949154*^9, 3.453862570115514*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"f0fefd8d-0148-4c32-af44-6cb5456687f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.015861531596904687`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005325276189286488`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453840162093855*^9, 3.4538402359560423`*^9, {
   3.4538624679971113`*^9, 3.4538624812382927`*^9}, 3.453862586264966*^9, 
   3.4538636654918613`*^9, 3.463844880212677*^9, 3.480692273883992*^9, 
   3.4819419518975058`*^9, 3.662624441878827*^9, 3.799212564668103*^9, 
   3.799212675733951*^9, 3.814193745062067*^9, 3.814248190659827*^9, 
   3.832246465255034*^9, 3.832403356971117*^9, 3.832578787433281*^9, 
   3.889696046126237*^9, 3.890118842289896*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"193218bf-1610-45ea-82dc-e624dc8f8b80"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpos", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"p", "/.", 
   RowBox[{
    RowBox[{"SSdata", "[", "OO", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862483701729*^9, 3.4538625105182133`*^9}, {
  3.453862576749049*^9, 3.453862581411574*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"313eb942-123a-45f1-b00f-bd8283f90fa0"],

Cell[BoxData["0.005325276189286488`"], "Output",
 CellChangeTimes->{{3.4538625068641663`*^9, 3.4538625109082727`*^9}, 
   3.4538625864136257`*^9, 3.453863665522478*^9, 3.4638448803345337`*^9, 
   3.480692273901267*^9, 3.48194195198164*^9, 3.662624441920925*^9, 
   3.799212564688949*^9, 3.7992126757388983`*^9, 3.81419374506698*^9, 
   3.814248190664809*^9, 3.832246465269703*^9, 3.83240335697928*^9, 
   3.8325787874389544`*^9, 3.889696046130349*^9, 3.8901188422944*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"1e6cc67d-a854-4e75-8b6a-b420836c291d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"SSdata", "[", "OO", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862473476694*^9, 3.453862474190342*^9}, {
  3.453862598812314*^9, 3.453862615921789*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"2f158e54-941f-4e8f-ab4b-59c160c12ea7"],

Cell[BoxData["0.015861531596904687`"], "Output",
 CellChangeTimes->{3.453862616387323*^9, 3.4538636655554333`*^9, 
  3.463844880438141*^9, 3.480692273921216*^9, 3.4819419520177402`*^9, 
  3.662624441968322*^9, 3.799212564746285*^9, 3.799212675784647*^9, 
  3.814193745097251*^9, 3.814248190698557*^9, 3.8322464653091097`*^9, 
  3.8324033570153723`*^9, 3.832578787462289*^9, 3.889696046139806*^9, 
  3.890118842306069*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"6c725f26-6aa6-44f2-b261-c2d338f16566"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for value-engineered LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}},ExpressionUUID->"ec1821fe-d639-4dd4-9f6a-\
4568230a7630"],

Cell[CellGroupData[{

Cell["\<\
VEvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.347*0.0254, (* increased from 0.16\" for LIGO-I *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\tcoilz1OSEM->0.05*0.0254,
\t\tcoilz2OSEM->coilz1OSEM+coillen,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.334*0.0254, (* 0.334=0.498-0.164, increased from 0.302 *)
\t\tcoilrad2->0.498*0.0254, (* same *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, {3.453862135114468*^9, 3.4538622312380953`*^9}, {
   3.4538622812810287`*^9, 3.453862282014607*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"56560bf5-235e-4f9a-a92f-cf475feab4d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008813799999999998`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004406899999999999`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004406899999999999`"}], ",", 
   RowBox[{"coilz1OSEM", "\[Rule]", "0.00127`"}], ",", 
   RowBox[{"coilz2OSEM", "\[Rule]", "0.010083799999999999`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0084836`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.0894799325270267`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453862217965355*^9, {3.453862264142426*^9, 3.453862285813403*^9}, 
   3.463844880536422*^9, 3.4802620957847557`*^9, 3.48069227394248*^9, 
   3.481941952073387*^9, 3.6626244420201607`*^9, 3.799212564753502*^9, 
   3.799212675794528*^9, 3.814193745106379*^9, 3.814248190714933*^9, 
   3.832246465330971*^9, 3.832403357099465*^9, 3.832578787468157*^9, 
   3.889696046143848*^9, 3.890118842311604*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"76abb933-2112-4b8b-ba33-495e91773e45"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "VE", "]"}], " ", ":=", " ", "VEvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
  3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
  3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"7e81a715-9ca1-4856-9954-33ef64603726"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.013119230572857864`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.006315461295902202`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"VE", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.48026206168556*^9, 
   3.480262062286573*^9}, 3.480262239842697*^9, 3.662623959952838*^9, 
   3.8324026205976267`*^9, 3.8324027473059464`*^9, 3.832402858956901*^9, 
   3.832403017625313*^9, 3.832403164883951*^9},
 CellLabel->"In[45]:=",ExpressionUUID->"4f67205c-9f43-4fbf-838f-c912f0c00cca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.013119230572841652`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0063154541967454705`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662624488662723*^9, 3.799212564807518*^9, 
  3.799212675846784*^9, 3.814193745135684*^9, 3.81424823319797*^9, 
  3.832246465380772*^9, 3.832403357606947*^9, 3.832578787977721*^9, 
  3.8896960463531857`*^9, 3.890118842522916*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"8962ea9e-65a2-4df5-a7c8-72fe02ce14a4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4lOsbB3CHQrYsWVORVhGFUuGLpA3hIJVUKrQgzDDvLPZt3lQqKkRE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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"VE", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.48026206307683*^9, 3.4802620637527103`*^9}, 
   3.480262264694813*^9, 3.662623963897244*^9},
 CellLabel->"In[46]:=",ExpressionUUID->"9fb2e2ba-9280-42e7-a100-e0021c15e7da"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VWsbBnBHZZ5lTEVKJaKkKNyoNCGEJkNRaKCwN3vtwTztlUpFhYiS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       "]]},
     Annotation[#, "Charting`Private`Tag$124904#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662624495590671*^9, 3.799212564857132*^9, 
  3.799212675886161*^9, 3.814193745162251*^9, 3.814248239137711*^9, 
  3.832246472375054*^9, 3.832403363955212*^9, 3.832578793959775*^9, 
  3.88969604880396*^9, 3.890118844874776*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"441ad41c-de78-4231-9068-d2a165700b8d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "VE", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "VE", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.48026206489049*^9, 3.480262065861014*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"32643f23-3336-44ca-99ec-f76e90a3f4e3"],

Cell[BoxData["0.0063154541967454705`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480262195337325*^9, 
  3.48069227397675*^9, 3.4819419522162*^9, 3.662624495638719*^9, 
  3.79921256486833*^9, 3.799212675895667*^9, 3.814193745167288*^9, 
  3.8142482391650667`*^9, 3.8322464724581747`*^9, 3.832403364035555*^9, 
  3.832578793986223*^9, 3.889696048823112*^9, 3.890118844897253*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"f52285f8-95bf-4d8d-8e49-36449ed36a80"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "VE", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "VE", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.4802620669164543`*^9, 3.480262067600336*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"1b78dee0-4370-4b8b-84b3-39acbd94d674"],

Cell[BoxData["0.013119230572841652`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480262195361561*^9, 
  3.480692273996217*^9, 3.481941952298916*^9, 3.662624495703776*^9, 
  3.799212564916767*^9, 3.799212675930348*^9, 3.814193745198924*^9, 
  3.8142482391708813`*^9, 3.83224647247607*^9, 3.8324033640502577`*^9, 
  3.8325787939942207`*^9, 3.889696048826284*^9, 3.890118844900754*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"69b67000-72da-4ed7-9552-d713efa4ee14"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"VE", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623545865924*^9, 3.662623547424322*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"91096579-c078-45df-9be3-2862295967db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXtQ0wUAB/AFaBdx8nDVRBzPCEUOY7yE4beU97vxEBQubrxScNBwMJC9
3z8CSeYOERSTOAqwBgNOA4HugBA8HCSpRHIISS7enCQnWP3xuY89M4+RaUQi
kej/+f+N2tu2vNClABIp7SvyQdNj099FdG8MuuL8dpa0fysEupvZRrvW6GC8
6j6UsZIEi6JXIZXCIEhMJO4lXCYiDXR/fUYkCMY/hWPhX6DYJSkzavkz0BI0
c28kLHj5ZWQn5iaAzfAi1+5nozFQ2eXomYyoUa1vuR0HNd6GuvAXKXClDyWf
MeKi+0Ts0/Ajafgoy6miuq4E8oVOzbgFExRc7bh2koeB7uCcXH06xrNjqpZ+
EWDA5KUpTZUJX9H92cfviGAXptWfzsrGW4tVNXG+Yix3X+7QOJ4BjV6fsnZc
gn1u8j7a7hzw7eNEjgwpTCw1mu2nufC6fiOxIEyGDKcx1eMrLHw70RT1J1UO
C2vT8TJ6PgwX6rSGNTmajvYv0my+hLl1qoDZqADr5I5N+R42zr1R/CyJV4Ls
PqItfc1GWMjmkvaFEpxrhxM4Twrg6VfWzs9QwdiMbGY7ch5u1OePin5VIdKy
Uq9v5mDlx9SGxkMEOA+uvrZWFmIu9tMEGovAaLmb/3tFRZjdzLu42kBgejZO
SUnkglb26Gb8EIH93qS/RkOKUd7gOTH9hIDfCfoPH3iVIPql5AV1msDeBTNp
jtUFtPSb8wcfELAuS8/NNyrFJsnah6sjMDUQnc6fLYW6pmFrdzkB3p3hXoe7
PMw2+1junCIQ2XrPndvCxyWt/dfzFAKTPmm3JgkBSMuXkq30KgTPBNitBwhB
3bLceL9YBcHK5XzBLSEcQtcWA6kqNE13rE/aiGDotRpd7FFiYbiapFCL4HEg
dq9btBK7jAbV/iZiHKbVpsfMKOB7tLMtlCdGLyP64/l0BVKiWMb2G2LkqGt1
v8/JkdqaP7XNlOBhWqtz51k5OGbeAbQpCVSVPqfMn8lwtivI+VyEFOFcXWE/
U4YYHDjOvi1FRfX9nyqfSREx2PV87IgMLmZemuAkKZyu1JI96mXos6UKqh5K
QM4JHPmbIofdapdxS4gEG/t0OvZFOeIHfauSe8TQklkfbm/Lwexb9KEGiCHb
Y7Cd4SgQGdb4zbvtInjHt90YmleAMqQtyaaJsFNNb337cyXq5/TNw98L0Xmn
wmA1qQSl7WBmu7MQES6uWocgFRRWqfA4LcCmmiCV9agQPdFmsZDMhzDK87dN
NwJD946tf5LHw6raO+/udQIVBY4efyhK8S981rbt
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$143304#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.013117066890568154`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXtQ0wUAB/AFaBdx8nDVRBzPCEUOY7yE4beU97vxEBQubrxScNBwMJC9
3z8CSeYOERSTOAqwBgNOA4HugBA8HCSpRHIISS7enCQnWP3xuY89M4+RaUQi
kej/+f+N2tu2vNClABIp7SvyQdNj099FdG8MuuL8dpa0fysEupvZRrvW6GC8
6j6UsZIEi6JXIZXCIEhMJO4lXCYiDXR/fUYkCMY/hWPhX6DYJSkzavkz0BI0
c28kLHj5ZWQn5iaAzfAi1+5nozFQ2eXomYyoUa1vuR0HNd6GuvAXKXClDyWf
MeKi+0Ts0/Ajafgoy6miuq4E8oVOzbgFExRc7bh2koeB7uCcXH06xrNjqpZ+
EWDA5KUpTZUJX9H92cfviGAXptWfzsrGW4tVNXG+Yix3X+7QOJ4BjV6fsnZc
gn1u8j7a7hzw7eNEjgwpTCw1mu2nufC6fiOxIEyGDKcx1eMrLHw70RT1J1UO
C2vT8TJ6PgwX6rSGNTmajvYv0my+hLl1qoDZqADr5I5N+R42zr1R/CyJV4Ls
PqItfc1GWMjmkvaFEpxrhxM4Twrg6VfWzs9QwdiMbGY7ch5u1OePin5VIdKy
Uq9v5mDlx9SGxkMEOA+uvrZWFmIu9tMEGovAaLmb/3tFRZjdzLu42kBgejZO
SUnkglb26Gb8EIH93qS/RkOKUd7gOTH9hIDfCfoPH3iVIPql5AV1msDeBTNp
jtUFtPSb8wcfELAuS8/NNyrFJsnah6sjMDUQnc6fLYW6pmFrdzkB3p3hXoe7
PMw2+1junCIQ2XrPndvCxyWt/dfzFAKTPmm3JgkBSMuXkq30KgTPBNitBwhB
3bLceL9YBcHK5XzBLSEcQtcWA6kqNE13rE/aiGDotRpd7FFiYbiapFCL4HEg
dq9btBK7jAbV/iZiHKbVpsfMKOB7tLMtlCdGLyP64/l0BVKiWMb2G2LkqGt1
v8/JkdqaP7XNlOBhWqtz51k5OGbeAbQpCVSVPqfMn8lwtivI+VyEFOFcXWE/
U4YYHDjOvi1FRfX9nyqfSREx2PV87IgMLmZemuAkKZyu1JI96mXos6UKqh5K
QM4JHPmbIofdapdxS4gEG/t0OvZFOeIHfauSe8TQklkfbm/Lwexb9KEGiCHb
Y7Cd4SgQGdb4zbvtInjHt90YmleAMqQtyaaJsFNNb337cyXq5/TNw98L0Xmn
wmA1qQSl7WBmu7MQES6uWocgFRRWqfA4LcCmmiCV9agQPdFmsZDMhzDK87dN
NwJD946tf5LHw6raO+/udQIVBY4efyhK8S981rbt
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$143304#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.013117066890568154`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {19}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.0037916666666666667`, 0.004333333333333333, 0.004875, 
   0.005416666666666667, 0.005958333333333334, 0.0065, 0.0075833333333333326`,
    0.008666666666666666, 0.00975, 0.010833333333333334`, 
   0.011916666666666666`, 0.013}}, {{0.}, {0.0018644318321832706`}, {
   0.0036876886214778624`}, {0.005429815153356176}, {0.00705335776406612}, {
   0.008524729334094025}, {0.009815593418634019}, {0.010904253703901249`}, {
   0.01177662050414163}, {0.01242691342244898}, {0.012857731971128843`}, {
   0.01307941905708495}, {0.01310903905222783}, {0.01268384663076328}, {
   0.011787555304705316`}, {0.01062464586507396}, {0.009362830205797324}, {
   0.008119625649188396}, {0.006965511055875091}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662624496599176*^9, 3.799212565011959*^9, 
  3.7992126767249527`*^9, 3.8141937459911537`*^9, 3.814248239953046*^9, 
  3.8322464733844337`*^9, 3.832403364908279*^9, 3.8325787947600117`*^9, 
  3.8896960491647*^9, 3.8901188452187147`*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"09bf9214-f28d-4989-8f54-9070f2d0db80"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "VE", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "VE", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626235494568357`*^9, 
   3.6626235537922993`*^9}, 3.799212531123786*^9},
 CellLabel->"In[50]:=",ExpressionUUID->"bc47da5d-ca01-4d8c-8301-7c1274c233c7"],

Cell[BoxData["603.0661618688983`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624496679113*^9, 3.7992125650365887`*^9, 3.799212676779603*^9, 
   3.814193746037196*^9, 3.8142482399588614`*^9, 3.8322464734682693`*^9, 
   3.832403364927157*^9, 3.832578794766141*^9, 3.8896960491687*^9, 
   3.890118845223207*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"f120a0f7-4985-491f-a3bf-231edd6432be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "VE", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.4794964690726423`*^9, 
   3.4794964944567127`*^9}, {3.479496975356181*^9, 3.479496976183571*^9}, {
   3.47949787094656*^9, 3.479497874578391*^9}, {3.4794981429899273`*^9, 
   3.479498147044504*^9}, {3.479498193967552*^9, 3.479498236581649*^9}, {
   3.479662116006764*^9, 3.479662117075882*^9}, {3.479666955542605*^9, 
   3.479666963425733*^9}, 3.480262070375884*^9},
 CellLabel->"In[51]:=",ExpressionUUID->"f177b1a4-497f-4cd3-a2b6-4e2abe2cce05"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VWsbBnBHZZ5lTEVKJaKkKNyoNCGEJkNRaKCwN3vtwTztlUpFhYiS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       "]]},
     Annotation[#, "Charting`Private`Tag$124904#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480262195466113*^9, 3.480692274101901*^9, 
  3.481941952516597*^9, 3.662624496743587*^9, 3.7992125650886*^9, 
  3.7992126767896137`*^9, 3.814193746064599*^9, 3.814248239982746*^9, 
  3.832246473512594*^9, 3.832403364960744*^9, 3.8325787947840757`*^9, 
  3.8896960491785088`*^9, 3.890118845235003*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"8a8ca9a9-6955-4abc-88e8-0db7b5603197"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"VE", ",", "0.0064"}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}, 
   3.453823640650034*^9, 3.453837393601057*^9, 3.45383890126833*^9, 
   3.4538394359743757`*^9},
 CellLabel->"In[52]:=",ExpressionUUID->"d9a8c6be-6da5-4103-bcc6-df8f9e62e8bc"],

Cell[BoxData["0.013117074132794832`"], "Output",
 CellChangeTimes->{
  3.453749602972189*^9, 3.453749666574046*^9, 3.453750876352957*^9, 
   3.453752731604185*^9, 3.4538236694422503`*^9, 3.4538259483409157`*^9, 
   3.453826469350016*^9, {3.4538373992114477`*^9, 3.4538374256931763`*^9}, 
   3.453837477368595*^9, 3.453838646018355*^9, {3.453838905538686*^9, 
   3.453838910306279*^9}, 3.453839436745421*^9, 3.463844880639366*^9, 
   3.4802621955329037`*^9, 3.4806922741384277`*^9, 3.481941952544153*^9, 
   3.662624496811386*^9, 3.799212565098648*^9, 3.799212676829167*^9, 
   3.814193746094886*^9, 3.814248240010482*^9, 3.832246473553226*^9, 
   3.832403365009407*^9, 3.832578794812265*^9, 3.889696049190844*^9, 
   3.890118845245955*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"45404ec7-bd5c-44e1-a887-29b0d2ef2b61"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"c841c6ca-eda9-4bed-9488-ff5a80345e79"],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.4538236694697313`*^9, 
   3.453825948369759*^9, 3.453837425726906*^9, 3.453838918528926*^9, 
   3.4638448806922894`*^9, 3.480262195562632*^9, 3.4806922741597643`*^9, 
   3.481941952586825*^9, 3.662624496879122*^9, 3.7992125651519547`*^9, 
   3.799212676836163*^9, 3.814193746100417*^9, 3.814248240016282*^9, 
   3.8322464735716143`*^9, 3.832403365085966*^9, 3.8325787948182793`*^9, 
   3.889696049194572*^9, 3.890118845249372*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"e17c1642-203f-467e-b84f-87c0cddbd9c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
   3.453823640684885*^9, 3.453823640735626*^9}, {3.453826474859961*^9, 
   3.45382647576938*^9}, 3.4538373936510477`*^9, 3.453838901300256*^9},
 CellLabel->"In[54]:=",ExpressionUUID->"852f2c59-3560-4124-807e-a41c924f82e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.008567`", ",", 
   RowBox[{"-", "0.012695220225685581`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823671960964*^9, 
  3.453825948604528*^9, 3.453826476451028*^9, 3.453837425763947*^9, 
  3.453838918661368*^9, 3.4638448807548018`*^9, 3.4802621956072607`*^9, 
  3.480692274189659*^9, 3.4819419526252537`*^9, 3.662624496930757*^9, 
  3.799212565160301*^9, 3.799212676876684*^9, 3.814193746126855*^9, 
  3.814248240041987*^9, 3.8322464736139307`*^9, 3.8324033651442623`*^9, 
  3.8325787948445683`*^9, 3.88969604920662*^9, 3.8901188452595882`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"3a18bbd8-7a48-47ce-a416-e95536ce6eb7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", 
    RowBox[{"-", "0.010"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751088575416*^9, 3.453751089087048*^9}, 
   3.453823640769184*^9, 3.453837393699996*^9, 3.453838901333053*^9},
 CellLabel->"In[55]:=",ExpressionUUID->"ee93f305-a43a-4d89-be9d-92f02104aeb3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.007656`", ",", 
   RowBox[{"-", "0.010337130337810321`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453749683527301*^9, 3.45375109040812*^9, 
  3.4538236722686167`*^9, 3.453825948821306*^9, 3.45382648659874*^9, 
  3.453837425793631*^9, 3.453838918742206*^9, 3.463844880837522*^9, 
  3.4802621956487217`*^9, 3.480692274215329*^9, 3.481941952668998*^9, 
  3.662624496982448*^9, 3.799212565207038*^9, 3.799212676929386*^9, 
  3.814193746150473*^9, 3.8142482400751247`*^9, 3.832246473663391*^9, 
  3.832403365181662*^9, 3.832578794869689*^9, 3.889696049217956*^9, 
  3.890118845274675*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"b82e90df-e092-4cb3-8c71-49c7ef7ac2fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", 
    RowBox[{"-", "0.003"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751094726705*^9, 3.453751095317946*^9}, 
   3.453823640822011*^9, 3.453837393750527*^9, 3.453838901368658*^9},
 CellLabel->"In[56]:=",ExpressionUUID->"f54f6b89-9c65-45e5-b085-01740ff4004d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.009195`", ",", 
   RowBox[{"-", "0.009243782811928638`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537496838232193`*^9, 3.4537510967086277`*^9, 
  3.453823672557324*^9, 3.4538259490222588`*^9, 3.4538264890979757`*^9, 
  3.453837425851626*^9, 3.4538389187839413`*^9, 3.46384488093897*^9, 
  3.480262195696735*^9, 3.480692274248917*^9, 3.48194195271663*^9, 
  3.662624497032889*^9, 3.799212565296081*^9, 3.799212676971652*^9, 
  3.81419374617684*^9, 3.8142482401093388`*^9, 3.832246473707204*^9, 
  3.832403365215926*^9, 3.832578794900918*^9, 3.889696049230637*^9, 
  3.890118845285652*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"dd06969b-dd7b-4f30-a6e7-c1ef69e7ae7a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"548ecba9-2816-4f3d-b1ee-\
a36844dfb2ab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9},
 CellLabel->"In[57]:=",ExpressionUUID->"854f4323-71fb-46f6-9e95-f9c32d166838"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk4lN0bB3CRJakQhSSRFnqlspRwC4lCqJCElBSyjWWeGcY2g3mIvGmP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       "]]},
     Annotation[#, "Charting`Private`Tag$143678#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.01311922838888413, 0.013119230426461693`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.46384489286368*^9, 3.4802622059949303`*^9, 3.480692283838723*^9, 
   3.481941962908568*^9, 3.662624508597904*^9, 3.79921256536007*^9, 
   3.799212686463931*^9, 3.814193756085533*^9, 3.8142482500588837`*^9, 
   3.8322464842160873`*^9, 3.8324033750746107`*^9, 3.832578804468409*^9, 
   3.889696053260541*^9, 3.890118849152321*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"d33c3715-63ae-4950-b036-401b4c007d28"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9},
 CellLabel->"In[58]:=",ExpressionUUID->"a531a3ec-79d9-4e67-a8a0-42db602ff2ca"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13k8VN0fB3AqHpW1EBGekod4bClL8mmR0GZLaUdalC1jzL0zss1grmSJ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       "]]},
     Annotation[#, "Charting`Private`Tag$170146#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.013119229771598732`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.463844900055211*^9, 3.480262212578673*^9, 3.48069228997019*^9, 
  3.48194196963024*^9, 3.66262451582117*^9, 3.79921256539148*^9, 
  3.7992126922677517`*^9, 3.814193762162031*^9, 3.81424825638132*^9, 
  3.8322464910995483`*^9, 3.832403381099104*^9, 3.8325788105939083`*^9, 
  3.8896960557580433`*^9, 3.890118851539898*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"b0326fc2-dccf-414a-8ecb-91aff459eb7f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSdata", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fz", "[", 
      RowBox[{"VE", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, {3.453862450307226*^9, 3.45386248039209*^9}, {
   3.453862568949154*^9, 3.453862570115514*^9}, {3.45386264847299*^9, 
   3.453862649636854*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"da98ea8e-ec18-4fb9-bbee-2bc2c2834481"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.013119230572841652`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.0063154541967454705`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453840162093855*^9, 3.4538402359560423`*^9, {
   3.4538624679971113`*^9, 3.4538624812382927`*^9}, 3.453862586264966*^9, 
   3.453862659344542*^9, 3.453862832601221*^9, 3.463844900650577*^9, 
   3.480692290440241*^9, 3.481941970310296*^9, 3.662624516428594*^9, 
   3.7992125654098177`*^9, 3.799212692813489*^9, 3.8141937627041073`*^9, 
   3.814248256949712*^9, 3.8322464916841173`*^9, 3.832403381699399*^9, 
   3.832578811137774*^9, 3.889696055982019*^9, 3.890118851759233*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"2a71b9c2-a481-4e89-8cf0-d4ac649a6d2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpos", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"p", "/.", 
   RowBox[{
    RowBox[{"SSdata", "[", "VE", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862483701729*^9, 3.4538625105182133`*^9}, {
  3.453862576749049*^9, 3.453862581411574*^9}, {3.453862650555091*^9, 
  3.45386265144018*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"d60bd202-0290-480e-b2e6-e79e6533ec6f"],

Cell[BoxData["0.0063154541967454705`"], "Output",
 CellChangeTimes->{{3.4538625068641663`*^9, 3.4538625109082727`*^9}, 
   3.4538625864136257`*^9, 3.453862659454235*^9, 3.4538628327231894`*^9, 
   3.463844900679907*^9, 3.480692290473279*^9, 3.481941970349381*^9, 
   3.6626245164738493`*^9, 3.799212565472928*^9, 3.799212692820784*^9, 
   3.814193762710079*^9, 3.814248256955119*^9, 3.8322464916979*^9, 
   3.832403381710353*^9, 3.832578811144356*^9, 3.889696055987294*^9, 
   3.8901188517636013`*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"76e58164-c409-4c77-b267-aec63fd001b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"SSdata", "[", "VE", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862473476694*^9, 3.453862474190342*^9}, {
  3.453862598812314*^9, 3.453862615921789*^9}, {3.453862652024186*^9, 
  3.4538626531996193`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"4c9c9ec2-9442-4edb-8b9c-33797d9b231d"],

Cell[BoxData["0.013119230572841652`"], "Output",
 CellChangeTimes->{3.453862616387323*^9, 3.4538626595105743`*^9, 
  3.453862832777169*^9, 3.4638449007258987`*^9, 3.4806922905067368`*^9, 
  3.481941970402519*^9, 3.6626245165282593`*^9, 3.799212565485951*^9, 
  3.799212692855546*^9, 3.8141937627382812`*^9, 3.814248256989457*^9, 
  3.832246491741679*^9, 3.832403381740081*^9, 3.832578811172202*^9, 
  3.889696055996828*^9, 3.89011885177451*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"c1718071-00a7-456b-913f-b1c5942590d9"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for alternate value-engineered LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 
  3.4538410760356073`*^9}},ExpressionUUID->"82586c70-4af1-4da1-b79a-\
96177a9bd8e0"],

Cell[CellGroupData[{

Cell["\<\
VE2vals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.334*0.0254, (* 0.334=0.498-0.164, increased from 0.302 *)
\t\tcoilarea->0.347*0.164*0.0254^2, (* desired area, same as VEvals *)
\t\tcoildr->coilarea/(0.207*0.0254), (* desired difference in radius for \
desired area and length from OOvals *)
\t\tcoilrad2->coilrad1+coildr, (*  *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"dfd7ef58-4e21-45e6-92c1-45dafe32170f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0084836`"}], ",", 
   RowBox[{"coilarea", "\[Rule]", "0.00003671476528`"}], ",", 
   RowBox[{"coildr", "\[Rule]", "0.006982914009661837`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.015466514009661838`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.089479932527026`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.481941970502873*^9, 3.662624516578066*^9, 
  3.799212565535537*^9, 3.7992126928651*^9, 3.814193762747999*^9, 
  3.814248256997662*^9, 3.8322464917542877`*^9, 3.832403381786332*^9, 
  3.832578811178706*^9, 3.88969605600526*^9, 3.890118851779201*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"808c2d12-1d19-4df5-93e4-c3fa6e7a0cda"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "VE2", "]"}], " ", ":=", " ", "VE2vals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9},
 CellLabel->"In[63]:=",ExpressionUUID->"2d189b41-9222-4a58-8e19-ccb2814792be"],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"90754ed9-7f5e-430b-bf5c-\
44472a83d5ba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE2", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9},
 CellLabel->"In[64]:=",ExpressionUUID->"b4d67e0f-c1af-4f6b-88d6-e95aa3eb5c9f"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk4VN8bAHDZKiWKsqSFJElIkmyvLCUhkmTJ2qLshpk79mbG3FtJC5VK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       "]]},
     Annotation[#, "Charting`Private`Tag$187896#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.011911333952159101`, 0.0119113346320878}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.4819419881990843`*^9, 3.662624531874794*^9, 3.799212565596328*^9, 
   3.7992127058594303`*^9, 3.814193776802593*^9, 3.814248271356222*^9, 
   3.8322465063620443`*^9, 3.832403395088256*^9, 3.83257882421379*^9, 
   3.889696061447688*^9, 3.890118856987756*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"bd4778ec-890e-4883-ade5-dcadb909c3c6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE2", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9},
 CellLabel->"In[65]:=",ExpressionUUID->"e7191882-4686-421a-b6f1-453a24ea51af"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nk8lFsYB3BxSdaICSlCKpXkKpL8JGVJobIkZImyb7O8M1NhDPMqUbrc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       "]]},
     Annotation[#, "Charting`Private`Tag$215218#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.011911334644876745`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.481942001190299*^9, 3.6626245411818647`*^9, 3.799212565612917*^9, 
  3.7992127140092773`*^9, 3.814193785594626*^9, 3.814248279384671*^9, 
  3.832246515465438*^9, 3.8324034031345177`*^9, 3.83257883215844*^9, 
  3.889696064744326*^9, 3.8901188601929007`*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"82b7126b-deff-4ce2-8010-67ab08320c0c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"VE2", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9},
 CellLabel->"In[66]:=",ExpressionUUID->"8c873269-2f83-46ca-9455-031edfe1f7e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.011911334644952167`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005962869126797827`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.481942002157364*^9, 3.6626245418391943`*^9, 3.799212565624192*^9, 
   3.7992127145622997`*^9, 3.814193786200769*^9, 3.8142482799676867`*^9, 
   3.832246516110931*^9, 3.832403403762414*^9, 3.8325788327387543`*^9, 
   3.889696064978795*^9, 3.890118860428527*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"23a4d42d-3006-4601-a356-981a96d22c3f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "VE", "]"}], "/", 
  RowBox[{"SSpeak", "[", "OO", "]"}]}]], "Input",
 CellChangeTimes->{{3.453865307265691*^9, 3.453865311272402*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"ba4ea7a9-e82a-4e5e-9d30-94aeec41edf7"],

Cell[BoxData["0.8271099479070366`"], "Output",
 CellChangeTimes->{3.4538653118630533`*^9, 3.463844933516652*^9, 
  3.48069231654394*^9, 3.481942002211248*^9, 3.662624541891303*^9, 
  3.799212565670024*^9, 3.799212714568256*^9, 3.8141937862056007`*^9, 
  3.814248279972476*^9, 3.8322465161234703`*^9, 3.832403403773985*^9, 
  3.8325788327450323`*^9, 3.8896960649827757`*^9, 3.890118860432695*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"53568528-cfec-4733-aeb2-5f53b9d554a3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for AOSEM (D0901048-v4) and LIGO-I magnet", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 
  3.4806947920213118`*^9}},ExpressionUUID->"46df04c7-2007-4642-9b1f-\
9ec7b09d28cd"],

Cell[CellGroupData[{

Cell["\<\
AOvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"1409a6fd-6943-472f-9135-d85b2b6bf26a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.481942002252563*^9, 
  3.662624541953936*^9, 3.799212565684411*^9, 3.7992127146122417`*^9, 
  3.814193786245295*^9, 3.814248280003996*^9, 3.832246516158906*^9, 
  3.8324034038221903`*^9, 3.832578832769534*^9, 3.889696064994473*^9, 
  3.890118860444336*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"454fc121-d90c-4273-ab46-4ade39d18e20"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AO", "]"}], " ", ":=", " ", "AOvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"487e2fda-2a80-4287-b27d-746da4ecf6fe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.01577331278972314`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"AO", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, 3.6626239713916283`*^9, 
   3.83240262644514*^9, 3.8324027481937017`*^9, 3.832402863495736*^9, 
   3.832403029261478*^9, 3.8324031657752743`*^9},
 CellLabel->"In[70]:=",ExpressionUUID->"8f7817b5-563b-4f5f-af31-f465c6488b7c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.015773312789701857`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005342364901049084`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6626245970991707`*^9, 3.7992125657357073`*^9, 
  3.7992127146635113`*^9, 3.8141937862765903`*^9, 3.81424832902533*^9, 
  3.832246516206975*^9, 3.8324034043194437`*^9, 3.832578833238538*^9, 
  3.889696065189149*^9, 3.8901188606370687`*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"8c901930-9198-407c-a48d-050e6f6abcdf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AO", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, 3.662623973998605*^9},
 CellLabel->"In[71]:=",ExpressionUUID->"e162c8e4-f5a2-40d6-858a-8d9f8094479b"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4VN8fB3C0UEmyk74oKdm1SXirpBSiSBtJyRLCzJ1hRnbKMHPHHtEi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       "]]},
     Annotation[#, "Charting`Private`Tag$234313#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.01577331278116164}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662624605422865*^9, 3.799212565785183*^9, 
  3.799212714676622*^9, 3.814193786285582*^9, 3.8142483363406553`*^9, 
  3.8322465237152653`*^9, 3.832403411494681*^9, 3.832578840121408*^9, 
  3.889696068121745*^9, 3.890118863505918*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"b88bde2d-85be-4919-b346-114c011be677"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AO", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AO", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"429d9939-6034-4001-9360-c57125af8fcc"],

Cell[BoxData["0.005342364901049084`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.4819420024634247`*^9, 3.6626246054880657`*^9, 
  3.7992125657946*^9, 3.799212714711656*^9, 3.814193786312977*^9, 
  3.814248336367216*^9, 3.8322465238558073`*^9, 3.8324034115654716`*^9, 
  3.832578840151334*^9, 3.889696068146813*^9, 3.890118863536921*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"e4b78ba3-7545-41b9-a076-9aab699725ee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AO", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AO", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"5b4d0698-1f1e-4aaa-ad24-9ac9c6332d15"],

Cell[BoxData["0.015773312789701857`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.4819420025016727`*^9, 3.662624605533827*^9, 
  3.799212565841427*^9, 3.799212714721059*^9, 3.814193786318369*^9, 
  3.814248336375039*^9, 3.832246523870159*^9, 3.832403411576632*^9, 
  3.83257884016222*^9, 3.889696068150885*^9, 3.8901188635446463`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"ce33cff3-6a2f-43ee-bc62-4de9de29684b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AO", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.6626235658776608`*^9, 3.662623567527854*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"7f5887ee-98f1-42d5-b63c-2b9651d20454"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXtQEwQAB+Dx0tOWAg4bjIfyEONpDFbK5k+R9yMYhiQR0GAQbCIMx3tj
G3uPsZ0HO0AsCk4hAw6CTYywEugMPIHzMOGIRXZRVKCQHBdg9cd331HW5WS2
JYFAoP/n/zdah9wE0X8xCISsJGLYodMLXXHDG+O+6EpP3FpvZ2KgPc/S5jkd
enNax55kFmzLtqL0oghwtHXLdQ4cxK/QQ6dz4jEa6P/6T/eKUXH8XXbCKhMd
8yobP0YpQk7l5F3gpuBDz08rhTGVuBGuNHkEX8T5uw4/U6RCtNBWrsf+no5X
ma3MXoYYw+eSFmNPZCEowECZfimBfNlomLFlYY01e4U1KcXYcCSHO50N00VL
W2qGHGPWL/ZTVWzwEr3zDz5Q4EhM3/R7uXk4nFvSahWqwupw46DBIx+VQc6i
mWI1HP3lX1P3cJBJJhHMbRpY2xkMO4tcvLHZ8OyDm3XI8XyoetJcCBpLfaZN
oIWt0/4ZDb0I+h7yZ5fC69F58ps/qc7FiL6dmcderEdh6q6z9gAP5GY/rjlX
B1LgRF/1Ng/93pEEwqQO/I/8UvhzJbhnb0js3auHFZFEdJu4gpSZ/AA7Vz3i
7fTT07f44H47xFYe04M/dW3bSVmKJAlz31MPPSa1/qEOZWVwoS94NTnosbB0
Xkm+UA43F6+OkW0dKDTCb5NRFQj0Of3yC6MOp87Re18LqURMQlbLo0wdDi0T
pRz7KkztjD5nEnRw0mRziyyroQ0h7Xaq6zE/9na2cKkanrz03cN29RDcuX/X
fUSAuUjOk3K9FvHd3weWfy6EttVAbfqnDrNvZvXMqmuQzI6Vs/LrEGlmHFln
iKCf6/UIH9WgZq2xqKZHhLCloKIXnhp0LgyuzzqLcf3muixYpsby/SaCokEM
R1fiqOmRCjaW4w2h1hI4aw/aEgNUeOuksT9aIEHmK2k5PuVKpCcUWh3dkGBN
2GWkjCnwfnfR/A6rFrfGfK1LXBXgE2kM6nwtJrQZZ1UFchSYIo5dipMiY+mG
T+CoDIlwCeMNSZEsngt76i5D3Ljp14cnZCibERoppVJ4NreSgtpkaDJ8+feZ
x7UgccIn/iDL8cArdnXXvxYbjgMDPJ0c3hZVFiaNBH2kQq+dHTlqBlO3rm2K
ITuw4mbmKxBUX2AhSxOD9k7/J9/9osA+Ab0qdUKE3SZ6995MJax+2LztEiyC
8U79iv2sElVkHVcYVYO447597hEqmBPrKKazQmw2qAmar1RobFW1VwUIIEoI
frzpr0ZhPuPHqZBqPGugXR75WI0SytWKlrAq/AuH/6e7
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$252660#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.015771990975226677`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXtQEwQAB+Dx0tOWAg4bjIfyEONpDFbK5k+R9yMYhiQR0GAQbCIMx3tj
G3uPsZ0HO0AsCk4hAw6CTYywEugMPIHzMOGIRXZRVKCQHBdg9cd331HW5WS2
JYFAoP/n/zdah9wE0X8xCISsJGLYodMLXXHDG+O+6EpP3FpvZ2KgPc/S5jkd
enNax55kFmzLtqL0oghwtHXLdQ4cxK/QQ6dz4jEa6P/6T/eKUXH8XXbCKhMd
8yobP0YpQk7l5F3gpuBDz08rhTGVuBGuNHkEX8T5uw4/U6RCtNBWrsf+no5X
ma3MXoYYw+eSFmNPZCEowECZfimBfNlomLFlYY01e4U1KcXYcCSHO50N00VL
W2qGHGPWL/ZTVWzwEr3zDz5Q4EhM3/R7uXk4nFvSahWqwupw46DBIx+VQc6i
mWI1HP3lX1P3cJBJJhHMbRpY2xkMO4tcvLHZ8OyDm3XI8XyoetJcCBpLfaZN
oIWt0/4ZDb0I+h7yZ5fC69F58ps/qc7FiL6dmcderEdh6q6z9gAP5GY/rjlX
B1LgRF/1Ng/93pEEwqQO/I/8UvhzJbhnb0js3auHFZFEdJu4gpSZ/AA7Vz3i
7fTT07f44H47xFYe04M/dW3bSVmKJAlz31MPPSa1/qEOZWVwoS94NTnosbB0
Xkm+UA43F6+OkW0dKDTCb5NRFQj0Of3yC6MOp87Re18LqURMQlbLo0wdDi0T
pRz7KkztjD5nEnRw0mRziyyroQ0h7Xaq6zE/9na2cKkanrz03cN29RDcuX/X
fUSAuUjOk3K9FvHd3weWfy6EttVAbfqnDrNvZvXMqmuQzI6Vs/LrEGlmHFln
iKCf6/UIH9WgZq2xqKZHhLCloKIXnhp0LgyuzzqLcf3muixYpsby/SaCokEM
R1fiqOmRCjaW4w2h1hI4aw/aEgNUeOuksT9aIEHmK2k5PuVKpCcUWh3dkGBN
2GWkjCnwfnfR/A6rFrfGfK1LXBXgE2kM6nwtJrQZZ1UFchSYIo5dipMiY+mG
T+CoDIlwCeMNSZEsngt76i5D3Ljp14cnZCibERoppVJ4NreSgtpkaDJ8+feZ
x7UgccIn/iDL8cArdnXXvxYbjgMDPJ0c3hZVFiaNBH2kQq+dHTlqBlO3rm2K
ITuw4mbmKxBUX2AhSxOD9k7/J9/9osA+Ab0qdUKE3SZ6995MJax+2LztEiyC
8U79iv2sElVkHVcYVYO447597hEqmBPrKKazQmw2qAmar1RobFW1VwUIIEoI
frzpr0ZhPuPHqZBqPGugXR75WI0SytWKlrAq/AuH/6e7
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$252660#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.015771990975226677`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {22}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.0037916666666666667`, 0.004333333333333333, 0.004875, 
   0.005416666666666667, 0.005958333333333334, 0.0065, 0.0070416666666666666`,
    0.0075833333333333326`, 0.008125, 0.008666666666666666, 
   0.009208333333333332, 0.00975, 0.010833333333333334`, 
   0.011916666666666666`, 0.013}}, {{0.}, {0.0027369652020360563`}, {
   0.005376030254553374}, {0.007826552614291077}, {0.010011596064347237`}, {
   0.011872863945006772`}, {0.013373609984324767`}, {0.014499299932574523`}, {
   0.01525611725026921}, {0.015667709333090477`}, {0.015770789908488913`}, {
   0.015610306666795384`}, {0.015234823589392855`}, {0.014692617726235245`}, {
   0.014028750564330596`}, {0.013283178230669233`}, {0.012489794780202254`}, {
   0.011676214940912713`}, {0.010864077036726105`}, {0.009304649284073284}, {
   0.007891430464800063}, {0.006655314612367336}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626246067933207`*^9, 3.799212565930393*^9, 
  3.799212715805522*^9, 3.814193787369897*^9, 3.8142483375310087`*^9, 
  3.832246525042039*^9, 3.8324034127741337`*^9, 3.832578841219968*^9, 
  3.88969606860946*^9, 3.890118863988823*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"8758c84c-481b-404b-82d3-3eb9ebcc4fcb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AO", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AO", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623569112307*^9, 
   3.662623572807571*^9}, 3.799212531131391*^9},
 CellLabel->"In[75]:=",ExpressionUUID->"4bf6b1ea-d75e-4ae1-b0e8-b869c889ad9f"],

Cell[BoxData["919.3144173821112`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624606848462*^9, 3.799212565984627*^9, 3.799212715855835*^9, 
   3.814193787413155*^9, 3.814248337563813*^9, 3.8322465252133503`*^9, 
   3.8324034128368692`*^9, 3.8325788412525187`*^9, 3.889696068617154*^9, 
   3.8901188639964123`*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"a1784ff8-6a03-4223-ab1e-86024d66548a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "AO", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fmax", "[", "AO", "]"}], "-", 
      RowBox[{"0.5", "*", 
       RowBox[{"coupling", "[", "AO", "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "-", 
          RowBox[{"zmax", "[", "AO", "]"}]}], ")"}], "^", "2"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0.", ",", "0.013"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Red"}], "}"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.66284663709056*^9, 3.662846643001965*^9}, 
   3.7992125311324997`*^9},
 CellLabel->"In[76]:=",ExpressionUUID->"f61de3d9-71a3-4818-af8b-1595bc09f16a"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13k4VN8fB3C0UEmyk74oKdm1SXirpBSiSBtJyRLCzJ1hRnbKMHPHHtEi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        "]]},
      Annotation[#, "Charting`Private`Tag$234313#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nk8lNsfB3BK2cpaluiGlAiRbmnho02L5aZISSqlkGXGzDNm7OvEyDyj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        "]]},
      Annotation[#, "Charting`Private`Tag$252726#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.01577331278116164}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6628466519886923`*^9, 3.799212566044846*^9, 
  3.799212715906108*^9, 3.814193787457467*^9, 3.8142483375977573`*^9, 
  3.83224652528377*^9, 3.8324034128950377`*^9, 3.832578841290278*^9, 
  3.889696068635913*^9, 3.890118864014866*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"7043cdb4-4c30-4102-a589-3a481563ab10"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"0049aa13-92b2-432b-b51a-\
22a4c957b0b5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9},
 CellLabel->"In[77]:=",ExpressionUUID->"d87e340b-f959-45cb-b783-62f31ee81cd3"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk0Vd0bB3BRCiEzpYFKqDRJKvWEFJI0SIgokshw7z33GstwLzLcc00l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       "]]},
     Annotation[#, "Charting`Private`Tag$252841#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.015773312770077808`, 0.015773310655553995`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.481942019293109*^9, 3.662624620495331*^9, 3.799212566076847*^9, 
   3.7992127281406612`*^9, 3.814193799325103*^9, 3.8142483502185087`*^9, 
   3.832246537898939*^9, 3.8324034250374203`*^9, 3.832578853260667*^9, 
   3.889696073597952*^9, 3.890118868774618*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"23eae4d7-dfe5-41e6-a08e-22d39a4931cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9},
 CellLabel->"In[78]:=",ExpressionUUID->"bf29ff74-3fde-4839-941c-f36d95b618c9"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nk4VF8YB3BSlpAlFCUi2vyQduGrTZaypSxFyVKUjJm515Bszcg+Q1K2
9iIhiopU9rQqLYoUFSKiElnK7/TXfT7Pfc49z7nnPe/3zN3jb+81SUhISEJY
SOjfc+WGob5DUr3GIXMbnhc1ypnIrLyddrPsgUlBjWOkl/OAicaO6vCwsrcm
xXmXjNc6C0HHbxPbo6zbhHW1pk/HWRZLaImD28pGTCyLy2RUnNVxPbjH17pM
AorRV+r7nPQxOO7SbVmmjKfW1y02O5lC0eTYAouyheg6Mt/76TZblAp/SjRv
MMQzbnqF1uhuuCwImb2/Zz3qWAUc5zk+eFjK+Ri22RI62YcdHhxmYE9il1ds
pi3EJtQOx11h40dZgNnVpq3QlLimsJXDwaZnOasUnBwRXK+1/zgVguPNTprq
9S7oVFcbl1INx9CHriDRP65InXi57dujCEh3yQWk3t6NPXaap5Kij+DyDrUW
pR178HtXzYwuWR4qLX0qfX94oCjicMNAcBSMCmIK3fK84GPSR9l2H4UpP+3V
PfO9+CK+zCZUKwbZn8NEKsV8YBrhYRuxKxaxxefyj9/1hVW+i78pHYdh4ZKE
JscD6EnbY5OzKx511Vl06fSDyNh0PbwFCVAToY+LX/MHl/Wkcf5QAr7dUbCX
KvWHfH6UypSRBJRzrk+TrfBH85hXeNtYAly+DRyd8dQfElX62UnCiUh9uz9Y
u8cfEUGrvFqlEiH2plBPQ44BDrOxVkUzEaEFlxRMLRhoq4ww1LVOhN+O5PeH
ShngDv2+UnkqEQ+XNHv0lTMwHj3vwuyzidAW1+h2q2DAMzPjNXU+Ee+Li36u
vc9Arh3nq0ZOImynPRcXf8XA/T82zXuLErGsUmZpygAD1s/0fmdWJ2JMO+Fo
3vwA2Ni9zijpTETMj6P6rccDkKo+sTlvPh9t2WsE09MCsNQjIoVeyMcq1/5+
i8wATNyVcsViPr7c3371xrkAzJUXZj7W5cMsS0tXcDUAF1RvFr5czsck8+rF
6x8EYNUqKi9rPR/BWX+1L48HwEjccVzejY9G+2tRHyYCcC55R23+Lj4Wint3
KoowURJTorjJnY83zCcXIyWYePEftlCefKwwz5y3U4kJw2Yb1QpfPn78WK0h
o89EdVK7v0wgH77mlCrlwQRvppdjaiIfubmGdwa8mQgWr506V8BHj5SQ6wFf
Jj4WOUnmJvGx/3lspkcAE1NEF/26kcLHAZczs+zDmOhcuZFVns7HwQOPlPUy
mAiL2e1EX+KDJZir1N3IhI7Aoja7nI/iH50lnq+Z2LlW/cr4HT4GHfK2tb1l
IjNnd5fNPT7YyiuPN7Uxcap7xON7JR/0uc0Kdd+YUHjqSqvf54NTHCh/fioL
lzvq1+k95yPkzZNprutY8Hb3OiH3mY9byhPRWRtZWC5z7+GcDj5+uuiLvDdn
wfZC8LFFnWS9rcnDbjYsvGxW6TT+wofjR8e23TtZsBqcdWJrLx8Gve1FnjQL
efHr3NcMkv2a+OVwIJeF1BR7gzBhAeatnd+Ql8+Cp9N9937iXZFOFn2FLJx4
MK3NbZIAryffNj54k4UU2bMP1ogIUC0Rrs2oYaHRP9qhb7IAp6ZP/c16z4JT
r+5ePXEBts6fk3FIno2oCReG/jQBuO2byq8osrFtu/3vaOLijIDWlplsOPdo
NrcRK8jWqhmpsaEk0nwlUYbM93v/hfHFbJgxl8R9lBXA6WFp/uGNbKyanr19
/3QBormfnuabs9E12hhXSlxqIj3QasXGhx99s8UUBFC5vtvAxJ6NSazArWeI
WzLEbv51Y+MiMhQfKQrg5retIozDxnJ5Y8lJMwVInB/WfvUQGzk6i2TMiO+2
50xqC2Vjc6xmQAyx2vbxDaY8NibSK22mKQvQZnL+gVAyG9IFzEOyKgJ4yH5v
jCB9zpWVlDs0S4CUhyqDRQVs0BXWp/VnC1DD3aD4sYiNcG/jQR/ieSMnHNfd
YqNg6up7zcSd7SbvJtWyIWJ4t7VYVYB91+M7jrxnI8g2ydlKTYAIlXqzkXY2
8vPv+YURp0eI5BzsYIOz0af+GvFjm2Bf51429hkP2c1QF2BJ795+3VE2vkZd
Kmsittx63vbCHzZ8xwrEROcK4Fn2vkhZmMLAlczMpcSp0dvYk8UpvHzSciqe
eHTe+pG3ihTK/JskVmgIMD0+1MVGmUJm63C6G7HOz9LbNbMpCA3tpaKI3Sr1
Q69qUtCK7RB9SVzlOkeEt4TChS3uZ701yf+vcfYcXUZBO687IoZ4cPHxWv9V
FHxjF+dfIdYelYx2AYVG8eTPfcRxqSNS+lsoZG3tbfGZJ8CFP8sOXrSl0D3H
ZMZR4ruejAYVBwqp9TdOnSceMOhKmrKDQqX684RmYol0jZ/BbhTUl78cHSTW
EHZzGHCnMCezpHialgAODS+VWvZR4Os+kjEl9lshy7E9QGGJw44iR+KoLKu3
tf4UqvyizhwkvrW/KqOQpqDoY70vnXi2eKF6FJdCyInX57qJl/t/jRg7SmG4
R//GGLH1a+1PjDgKLlUbZ0prCxB+IevijmQKn0UqH/5HnCb5VvT5cTK/7/pZ
xsTXmAr7zNIoGDZF37Yi7jCNW7TkDIWvdpK93sR/s+viLp2n8CooJ4RFPFNm
Ut+sbAq5YRWuYcRLaGPrpFwKDl8j+LHElq2cq6IFFC5ZzZI/TuyxoVg2pIhC
zYo7HaeIQ670B3wvpqBgkTw1h7ggyHvZu9tkP4NTzW8RV92TZijdo0jdaX27
S/x6SskV2yqyf+mzxmuIe6x2dsXWUuj5dZr5kHgiSUSztp7CTb03dg3ECm9y
3SYeUbhj3ZP2gnjBHPv01Q0UVHeNWzYRG3mOvGI1UhgPWObVTGybe0au4BWF
Y1m3vrwj9hzYtOXLG7L+8YJX74k5K/qjNd6R+io01mkjjg9Jrdn5gYL+u9je
fz5TZSx04iOFhtxypXbiYvGONc87KNyyHMn9977eOj5QspuCW7/35Q/E71KW
Xt/YS+Fbzlz5f9//3tz8LayfgqeEZ0cLsejcyEVlPyiEallqviVW2bvQe/AX
hRvrRx+9ItbNf3ZWd4SCQC71w3PidT8DW/eNk/pYtMXtCfH21WrK5yfI/EvX
mtcT+4bVObROouFw9GRWFXForZ9ghigNy8ggt3LiZEnFx3YSNKKipsaVEF+y
KxeLl6KxbzRAs4C47ITH+joZGnXmr+dfIn7aOjVMaDqNr22uJ7OIP2leKzNU
IuNX6FEpxL99nIfYyjR4lYy7/+pBqlDI4OpsGnZ/zdnhxMuMbC5ratJYkOKo
7UtsHjn02VWbhvVYs4Yb8c76LPWTC2n46PPj7Yi5Dr0npPRppFtq5KwgPpl+
7IXZUhqt9VluC4jz2gxlIlbQYESkhCoTvzoQE/XLiIaZWKj4KDkPPdf0q/RM
aWTNu8v8d17+/m7647OeRqGMp9UbYm2eNvXegka/Soh5MTGdVe1xfzuNZJYy
7UUc+8n3tLALjVjbGkdb4lML5VvWuNLgDk+9bEh8v2S3faEHmb9bNEOaeObT
P6ZpDBoHFEYq8sj511G4GPKCRePvu1LNY8SmLptvSQfSkI2zG+YQ7+tM14s8
TCNGN+f7OuLSvyvn7I+lEe4uuvIZ6Uc3vg+k9STQyFT9ffIq8bXPlxV9k8h4
4f8cEonzHs6S9jlJo91Zo8mC+EzqxJj3JRrNIxkKpaQfRuvef7uniobRsHY6
h/RX3tzwbR9raXhNnM7eQhypsPq5+wMaFuX75TSIQ0Zz63c/o6Fl4DxWT/o3
oy7xptt7Gnp5p3VkiB3dth93GaXxQ+egzuE5pJ/Zycg1/6Hx7pDrDHNi2w31
8c7Cgbg+/MRdnthykSHXSTwQP7XHFC+SfDEZUmVtVwqERqeIcDXJH+3EDlt7
g0A8zK2Rbid59usOW8rSNxDbGWv3ZCuRfFqorVfqF4jhcwaDu4jfHG+yWxAQ
iEKhI99nEJf7GZ4Q5QTima2QXhTJV66qkEY1LxAsneyyHSR/FQ7HrTQ6Gwgt
p0MmX+UEMDA6t0f3TSA003U3ZUmRPMzZystqCcQV1YKz64mVFKbkSH0IhLVI
tF+3JMmjr3v7ejoCUXBfw2UpcWXGf5zsn4HwcjgbVyFB1jt2K0FdhoOhaczg
ClEB/MsabsmbcVAf8+m1oxCp5yl9JWYWHNwe8u7omuDD3Hbq9eDNHIzHrdFT
I9bo3JD/0Z6DyV9LR2P/8PFaruzstV0c7NFOCHIc5cPE50KsfRAHacNZLjU/
+Zg2M2hnch4Hie67HvaT+1gBpSEkPz0IDvWlO06R+xzXz844TikIQ2WWD47W
8eHiFR48WSUI+w/+Ws6o5WPKtveDQ+pBsH3En2ZSzcfOZendLbpB8Grpr3ty
l4+pP+VeXLQMQk8unXunhA9vhvCl1ZFBqDHz+9p+jo85+9us3L8HwWiTzH27
YD62qqUadFUEY0CxMUVIi486Wd+m7fGHUPrmiLRRXSJ8jS6HK/mEQHv7DBUT
h0S80G6rkVp5GE3+qfNOtiXAzypSeqtSKD7cLX7p6pKAx7qzvzd0hkIpJcb7
xat4+Ni8TF5xPQwza6Jq5ljHY/arQ5m0eTgMcpXOHimJQ6e7hHHf1XDkCzlG
dGnE4UHc4w+S6hHw0J9exwiPhdXLU+5qiREwMMldrP8+BnrjvfpPByOQ4XRt
ssrGGOhUMiZpeUai0e9z7vesaMR5MebOeBwJ0fPBwl7C0YhZEKb2d8kR9G9W
kB/ZexRnoqvVEs4cwazhB1FKVVFQrj/id1OMizWSRhXrFkThqeczBa4EF4uG
p6SmakWBK6xabivJRcaSX7wejSgMGN6Y2jONiz065cXJqlGoy/+SPVuJi19v
ltl9lo8C89iWjxHzuCg3ajsd/4eHx24zHDev5UJPbJ37j0YeIsc8/s5cz8W6
P1+LLZ7xsPJk4cWODVzMlXTXPvuEh3PPLQZDzblo+j7bw7aeh6ANIUlFNlxs
lu41K7zDg/ai9kdKblwo3Vn2jMrh4V3df6xPu4g7Tkk3XOQhySNYpdCdi+XS
fN8F53kYz5zuY+HFxayffkdasnh4IWMmGnKAi2/VKsvWH+MhOi853/wgF5Hi
uYwsAQ8mFh8cFBlcaH1OfTKcwENuJOd8AYuL1imDX/KieditVmt5iOJCk5OW
LRbFg2K53I9NgVw8eit6dM8RHh46uaUpBHFRXJBx9E44D+G/ck3bg7nIaevK
mRnKw/9jAo49
       "]]},
     Annotation[#, "Charting`Private`Tag$279309#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.015773312580828865`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.481942029259119*^9, 3.6626246289498587`*^9, 3.799212566105277*^9, 
  3.799212736159642*^9, 3.814193806690032*^9, 3.814248357828968*^9, 
  3.832246545429995*^9, 3.832403432431555*^9, 3.832578860600061*^9, 
  3.8896960766372757`*^9, 3.890118871734421*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"a4fb964c-c1c6-4b21-b69e-b4d77f80b107"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AO", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9},
 CellLabel->"In[79]:=",ExpressionUUID->"bc34bb23-ffa4-4c43-9f52-1efa7479be62"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.015773312789701857`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005342364901049084`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.481942029872281*^9, 3.662624629579126*^9, 3.799212566119658*^9, 
   3.799212736690179*^9, 3.814193807225954*^9, 3.8142483583228493`*^9, 
   3.832246545989801*^9, 3.8324034329663363`*^9, 3.8325788610998783`*^9, 
   3.88969607688406*^9, 3.8901188719398537`*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"b9500fa9-6697-4046-ac4b-c5059ccd1036"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for AOSEM (D0901048-v4) and extra small, \[OSlash]2 mm x 0.5 mm \
magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
   3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
   3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
   3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
   3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, 
   3.480699179006065*^9},ExpressionUUID->"b7ab0cf5-cedb-47b9-b53a-\
ccf94e68fe80"],

Cell[CellGroupData[{

Cell["\<\
AOESvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.0005,\t\t\t\t(* length *)
\t\ta->0.002/2,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.480699187974929*^9, 3.480699197276938*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"b19586bb-2c7d-4055-af11-8df359e66e66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.000011623892818282234`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.017499999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.0005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699218382852*^9, 3.481566729144149*^9, 3.481942029907995*^9, 
  3.6626246296430073`*^9, 3.799212566169499*^9, 3.799212736698094*^9, 
  3.8141938072328672`*^9, 3.814248358328946*^9, 3.832246546017557*^9, 
  3.832403433011101*^9, 3.832578861106352*^9, 3.8896960768905897`*^9, 
  3.890118871945334*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"071570ad-2aee-47f4-aeac-68c9c50ef409"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AOES", "]"}], " ", ":=", " ", "AOESvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"c52d5242-bbcc-40db-a078-c25af1a1a30f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.002807824198073727`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005198473408953153`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"AOES", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, 3.480699359418405*^9, 
   3.832402635125214*^9, 3.832402749077567*^9, 3.832402865797595*^9, 
   3.832403039609604*^9, 3.832403166697279*^9},
 CellLabel->"In[82]:=",ExpressionUUID->"9d4f343d-a4ba-47fb-921e-e99e5a4ea1c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.002807824198069128`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005198470254921349`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.4806993237886267`*^9, 
  3.4806993994484053`*^9, 3.48156682235257*^9, 3.481942029984186*^9, 
  3.662624679655575*^9, 3.79921256622328*^9, 3.799212736738921*^9, 
  3.814193807272809*^9, 3.814248406208023*^9, 3.8322465460807037`*^9, 
  3.832403433415251*^9, 3.832578861482093*^9, 3.8896960770581083`*^9, 
  3.890118872106576*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"d5678ccf-c634-4023-a014-4ced1791130b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3Bxi0qSypBuKIXiRikUvgglQ5mHUqazKeI45+zjGDJHjkhF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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.002807824129332503}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AOES", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, 3.480699363708275*^9},
 CellLabel->"In[83]:=",ExpressionUUID->"a06c1d25-0451-4c24-b8a2-00e990c77f60"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1mk4VW0XB/CiQZKkMjQZUlIUpVD4SyiFcsxKmc6mhDPtw3FkjpyQZExJ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       "]]},
     Annotation[#, "Charting`Private`Tag$297854#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.0028078241293325035`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699332309153*^9, 
  3.480699399566325*^9, 3.481566829952278*^9, 3.481942030040433*^9, 
  3.662624688188848*^9, 3.7992125662863483`*^9, 3.799212736777196*^9, 
  3.8141938073109283`*^9, 3.814248413500161*^9, 3.832246553799429*^9, 
  3.8324034407566633`*^9, 3.8325788685693703`*^9, 3.889696080033721*^9, 
  3.890118874997334*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"a2de952a-6509-4021-a1ac-282bf59742f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AOES", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AOES", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"ef704f4c-43be-4ad3-afed-5069b47c3194"],

Cell[BoxData["0.005198470254921349`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.480699332401712*^9, 
  3.481566830010151*^9, 3.48194203006644*^9, 3.6626246882658*^9, 
  3.799212566296227*^9, 3.799212736786602*^9, 3.814193807317873*^9, 
  3.814248413526589*^9, 3.83224655389476*^9, 3.832403440837998*^9, 
  3.832578868600473*^9, 3.889696080054243*^9, 3.890118875018113*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"bc0eaf68-1cb3-495d-a499-4f87d6e0a380"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AOES", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AOES", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"d9119b47-bb99-4d17-b0c5-4e3ac9c41aa2"],

Cell[BoxData["0.002807824198069128`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699332444682*^9, 
  3.481566830040126*^9, 3.481942030118945*^9, 3.662624688341494*^9, 
  3.799212566344317*^9, 3.799212736823483*^9, 3.8141938073526382`*^9, 
  3.81424841353319*^9, 3.8322465539159403`*^9, 3.832403440850705*^9, 
  3.8325788686108303`*^9, 3.889696080065219*^9, 3.8901188750232487`*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"c8d79368-6088-493b-b26a-0ace50a5fe07"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AOES", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.6626235829632797`*^9, 3.662623584946313*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"17ec380f-903d-48ad-840f-942a66457bc7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkVdQEwYAhnPIaLmgBNNjlLIcgIBig8hKfs6whyBhNoCBDMSwLUsJhJUQ
OIZn5MRapIfH6bWAoQhKmfVA1onhIcqIUHpcoaAMocCVYOnDd9/L9/aZx6eG
cNUIBILbIf9768ELU4HPRyqB0P9HuvsqVfnEv3tryAabjIvDnvPWaG9MUNPY
dIPyeVSf/nsX6GbvedcIPUEwrdO4M01HwIqbq5wTAIaHu6HyCz/kWkVyA9eu
ILFtnh7sG4wLLpyE8KQwwL5KpkNloMmjrPOEQxRa3H0O2oLDcd9x5Ue/v6MR
bmKtr38+Ct304Dk/exYiJDTLt78xIVrqqJ3UjceSudmfGoxYDHZ78ZPkbGRM
rVhyfFkYVP9HmyLhwjdPGjx3OQ5mvjI5k5cApqXPxPqVeKx1331WeyIR3sRh
pxhbNgztRP0UTT5WnXdZgs9sqJNqa1VzSdA+05Ne/SsHnJMTkqm6FLzeizvT
6sGFrpH2ZIVbGpYtGtjTI1w8dh74QDFOR7JWFoVgz0NKxIFx5dEMNJDS5EIR
D+RzY7K8/Qzk9BXSTF7ykFlvG5Y5fQO9xTOLzCUejhDJRNOx72EdVv3v4j4P
AaQaufznTITOSYS3Dw77Nz/sG5VlISv18+ijdR7GK+1cv8rORvbWawFNzoNy
gVFmEJ4DMS3yqW0TD187EpbHvXPRtE5snE3kwYXu1qp/4SZI05vXaRY8HF8i
lvD1bkGfxO/SUHBhVMFOSlPLw2jIdrXPTS5mBi+z8xfysG0URP7dmAtB10if
Ra8Ak4smgqYuDgKaR8/l/JKPs8X5bWQ/DhQXWS2K8gJUnN0d01Ky4TVPNftE
FaLfvfKhM5uNgvW7aQUtQvADXRT0j/F4rHz2SWFciLUnO5qXcg8/jtwjiKWF
WHhX6HBrNw4aakNSV/UiDLWLl/YK4uDk3NHmIyjC+JeSbaaKhejAlCPmW0UQ
78o4JAELMc1pM6r4YmzoSHQGNVjIJDpSKTPFCHj0MuKO9lVc7/Q8nexfgg4T
rs4Nk1gE4ZtLGS9KQKuaPUZziYH/UOdfE/alsCq02qV7ReNk3QPytw2lsJ2S
6F3jMUHme4ytGojwfOba09ic77Bl2N6eUS2CaqBxvVsaBRk55ZRKJcKbU1lF
/MFIlB5dMZ3PFCMweWP4w3IEHEPbfnq1KMZ7z9PaThYROLjn1qx1tQwGdbeP
1weFo6OrakVPUYb6pN7WWVEY/K1sZBaeErzSPDZGlodiR1pOqOiRQFxFcbfR
C4Uw0OHtjl05HBZDz7/jMrAhdUztfViOgfs1cn5PCP4DxMKuhw==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$315209#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.0028069345319713754`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkVdQEwYAhnPIaLmgBNNjlLIcgIBig8hKfs6whyBhNoCBDMSwLUsJhJUQ
OIZn5MRapIfH6bWAoQhKmfVA1onhIcqIUHpcoaAMocCVYOnDd9/L9/aZx6eG
cNUIBILbIf9768ELU4HPRyqB0P9HuvsqVfnEv3tryAabjIvDnvPWaG9MUNPY
dIPyeVSf/nsX6GbvedcIPUEwrdO4M01HwIqbq5wTAIaHu6HyCz/kWkVyA9eu
ILFtnh7sG4wLLpyE8KQwwL5KpkNloMmjrPOEQxRa3H0O2oLDcd9x5Ue/v6MR
bmKtr38+Ct304Dk/exYiJDTLt78xIVrqqJ3UjceSudmfGoxYDHZ78ZPkbGRM
rVhyfFkYVP9HmyLhwjdPGjx3OQ5mvjI5k5cApqXPxPqVeKx1331WeyIR3sRh
pxhbNgztRP0UTT5WnXdZgs9sqJNqa1VzSdA+05Ne/SsHnJMTkqm6FLzeizvT
6sGFrpH2ZIVbGpYtGtjTI1w8dh74QDFOR7JWFoVgz0NKxIFx5dEMNJDS5EIR
D+RzY7K8/Qzk9BXSTF7ykFlvG5Y5fQO9xTOLzCUejhDJRNOx72EdVv3v4j4P
AaQaufznTITOSYS3Dw77Nz/sG5VlISv18+ijdR7GK+1cv8rORvbWawFNzoNy
gVFmEJ4DMS3yqW0TD187EpbHvXPRtE5snE3kwYXu1qp/4SZI05vXaRY8HF8i
lvD1bkGfxO/SUHBhVMFOSlPLw2jIdrXPTS5mBi+z8xfysG0URP7dmAtB10if
Ra8Ak4smgqYuDgKaR8/l/JKPs8X5bWQ/DhQXWS2K8gJUnN0d01Ky4TVPNftE
FaLfvfKhM5uNgvW7aQUtQvADXRT0j/F4rHz2SWFciLUnO5qXcg8/jtwjiKWF
WHhX6HBrNw4aakNSV/UiDLWLl/YK4uDk3NHmIyjC+JeSbaaKhejAlCPmW0UQ
78o4JAELMc1pM6r4YmzoSHQGNVjIJDpSKTPFCHj0MuKO9lVc7/Q8nexfgg4T
rs4Nk1gE4ZtLGS9KQKuaPUZziYH/UOdfE/alsCq02qV7ReNk3QPytw2lsJ2S
6F3jMUHme4ytGojwfOba09ic77Bl2N6eUS2CaqBxvVsaBRk55ZRKJcKbU1lF
/MFIlB5dMZ3PFCMweWP4w3IEHEPbfnq1KMZ7z9PaThYROLjn1qx1tQwGdbeP
1weFo6OrakVPUYb6pN7WWVEY/K1sZBaeErzSPDZGlodiR1pOqOiRQFxFcbfR
C4Uw0OHtjl05HBZDz7/jMrAhdUztfViOgfs1cn5PCP4DxMKuhw==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$315209#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.0028069345319713754`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {16}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.004333333333333333, 0.005416666666666667, 0.0065, 0.0075833333333333326`,
    0.008666666666666666, 0.00975, 0.010833333333333334`, 
   0.011916666666666666`, 0.013}}, {{0.}, {0.000501666113757372}, {
   0.0009842959308477663}, {0.001430330205101185}, {0.0018250102805042352`}, {
   0.002157399470547845}, {0.0024209766904133385`}, {
   0.0027377720363055188`}, {0.002803854187632368}, {0.002684795884917627}, {
   0.0024536167769683786`}, {0.0021713112937943}, {0.0018801200172207423`}, {
   0.001605003619186088}, {0.0013581947508779346`}, {
   0.0011437942978251281`}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626246894085207`*^9, 3.799212566435601*^9, 
  3.799212737703001*^9, 3.8141938082410707`*^9, 3.81424841443318*^9, 
  3.8322465548413687`*^9, 3.832403441693201*^9, 3.832578869483407*^9, 
  3.889696080436386*^9, 3.8901188753708982`*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"733e2c0e-978b-43f1-be46-b4a508a11116"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AOES", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AOES", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623586641572*^9, 
   3.662623589762891*^9}, 3.7992125311352167`*^9},
 CellLabel->"In[87]:=",ExpressionUUID->"71f8cc29-6a67-4f1f-8629-2e048d5742fa"],

Cell[BoxData["169.00623530595902`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624689486725*^9, 3.799212566446608*^9, 3.799212737753663*^9, 
   3.814193808291259*^9, 3.814248414439293*^9, 3.832246554927899*^9, 
   3.832403441713673*^9, 3.8325788694903307`*^9, 3.889696080440633*^9, 
   3.890118875377035*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"382d63b1-62e8-4934-995a-e755f520cf92"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"671e63b2-895c-417b-b8b0-\
1aa4e7ad2546"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AOES", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9},
 CellLabel->"In[88]:=",ExpressionUUID->"f3feb58d-577f-4328-83e7-9422619e6a79"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk8VN//B3AhFSVp0SJJu6RIWqh3obKUlC3K2GauLFlm5s4MYwlDsmQt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       "]]},
     Annotation[#, "Charting`Private`Tag$315336#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.0028078239864345544`, 
   0.0028078241960445755`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699347175211*^9, 3.481566843006109*^9, 
   3.481942047830917*^9, 3.662624703720014*^9, 3.7992125665071373`*^9, 
   3.799212750152135*^9, 3.814193820639947*^9, 3.814248427710821*^9, 
   3.8322465676499662`*^9, 3.832403454114255*^9, 3.832578881994769*^9, 
   3.8896960855263042`*^9, 3.890118880338922*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"98d763d7-53e6-43dd-95fc-a61c94941946"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AOES", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9},
 CellLabel->"In[89]:=",ExpressionUUID->"52d51435-012e-48ca-8a75-f644918ad052"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nk4lO0XB3AqIpSyFL9CXkmbpN4WMd9SCW2ylppBzGNnzMwzBmWdVpKU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       "]]},
     Annotation[#, "Charting`Private`Tag$341682#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.0028078240720868976`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699356475226*^9, 3.481566851563313*^9, 
  3.481942060181831*^9, 3.662624712512875*^9, 3.7992125665384007`*^9, 
  3.7992127578078413`*^9, 3.814193828341084*^9, 3.81424843704254*^9, 
  3.832246576308676*^9, 3.832403461975217*^9, 3.832578889803329*^9, 
  3.889696088702592*^9, 3.890118883428082*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"ef0ffc7e-2dd8-43af-8ae0-394fe6bfc1dd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AOES", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9},
 CellLabel->"In[90]:=",ExpressionUUID->"58668235-e7ab-469b-a144-2d91f6ec5bda"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.002807824198069128`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005198470254921349`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.4806993585664883`*^9, 3.481566852005377*^9, 
   3.481942060656612*^9, 3.662624712959793*^9, 3.799212566553184*^9, 
   3.799212758196513*^9, 3.814193828747492*^9, 3.8142484374965687`*^9, 
   3.832246576762941*^9, 3.832403462429717*^9, 3.8325788902894363`*^9, 
   3.889696088865233*^9, 3.890118883589025*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"5515de2c-ccfb-43fd-a8b5-fb2869eba226"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for AOSEM (D0901048-v4) and (approximately) double length, \
\[OSlash]2 mm x 6 mm magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
  3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, {
  3.480699105085774*^9, 3.480699140273758*^9}, {3.480699240398816*^9, 
  3.4806992456450768`*^9}, {3.4806992858633623`*^9, 
  3.480699289781164*^9}},ExpressionUUID->"ea161608-72ba-489b-84b2-\
a25ca58a24b6"],

Cell[CellGroupData[{

Cell["\<\
AODLvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.006,\t\t\t\t(* length *)
\t\ta->0.002/2,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.48069930379321*^9, 3.480699340598193*^9}, {
   3.814193129413525*^9, 3.81419312998516*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"833a7cc4-7698-419b-8138-47a32295faaf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0001394867138193868`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.011999999999999999`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.006`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699411967904*^9, 3.481566894140891*^9, 3.4819420607019053`*^9, 
  3.6626247130171137`*^9, 3.799212566602963*^9, 3.799212758204702*^9, 
  3.814193828754212*^9, 3.81424760819058*^9, 3.8142484375029497`*^9, 
  3.8322465767792377`*^9, 3.8324034624688587`*^9, 3.83257889029945*^9, 
  3.889696088870954*^9, 3.890118883596674*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"ff254159-8e20-41ae-92cf-a15a75644094"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AODL", "]"}], " ", ":=", " ", "AODLvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}, {3.480699304968781*^9, 3.480699305631609*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"be4e8432-0b2c-4c7b-8ead-9006ac266c55"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.030934223187134777`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005708650603607415`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"AODL", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, {3.480699306305072*^9, 
   3.480699307040391*^9}, 3.814247793051222*^9, 3.832402648881462*^9, 
   3.832402750073822*^9, 3.832402868198324*^9, 3.832403048494061*^9, 
   3.832403167709867*^9},
 CellLabel->"In[93]:=",ExpressionUUID->"ef0bc78a-c785-440d-86b2-44ebe6c8e09d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030934223187089303`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0057086431276502595`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.480699516644302*^9, 
  3.481566985502486*^9, 3.481942060779174*^9, 3.662624769885214*^9, 
  3.7992125666558647`*^9, 3.799212758243636*^9, 3.8141938288098907`*^9, 
  3.8142476564225397`*^9, 3.814248487730007*^9, 3.83224657683683*^9, 
  3.832403463076935*^9, 3.8325788909256907`*^9, 3.889696089124428*^9, 
  3.890118883850676*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"b96607ab-1d4a-4b34-8b6b-565c2ece997c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AODL", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, {3.480699307709909*^9, 
   3.4806993083441687`*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"7be5236c-19c8-4a9a-acc4-e94c22ff0d3d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4VdsbB3BJESVTQkqGZl1CM77K0FWUMUnJGAnhDPsclMw6OaLMw9mm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       "]]},
     Annotation[#, "Charting`Private`Tag$360594#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.030934223178893414`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699525015361*^9, 
  3.481566993083891*^9, 3.4819420608359413`*^9, 3.6626247782161903`*^9, 
  3.799212566665503*^9, 3.799212758279677*^9, 3.814193828842387*^9, 
  3.8142476639051523`*^9, 3.8142484951274137`*^9, 3.8322465843933077`*^9, 
  3.832403470559317*^9, 3.832578898206912*^9, 3.8896960920787354`*^9, 
  3.890118886742152*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"a09a2a65-1a87-4f48-bab7-6634b54d8f10"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}, {3.4806993090802107`*^9, 
   3.480699309671587*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"61afc4f0-c899-47cb-b3ea-0b99486537da"],

Cell[BoxData["0.0057086431276502595`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.4806995251344767`*^9, 
  3.481566993139513*^9, 3.481942060861919*^9, 3.662624778303006*^9, 
  3.799212566717863*^9, 3.799212758288528*^9, 3.814193828847475*^9, 
  3.8142476639519873`*^9, 3.814248495180724*^9, 3.832246584453712*^9, 
  3.8324034706197977`*^9, 3.832578898233987*^9, 3.889696092105317*^9, 
  3.890118886762349*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"b7df5935-b8cd-444e-bb91-bccb23ff5c2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}, {3.4806993103161793`*^9, 
   3.480699311077731*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"f1dc5dde-6f3b-400d-b913-88e2d8e5ff9a"],

Cell[BoxData["0.030934223187089303`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699525202236*^9, 
  3.481566993161881*^9, 3.4819420609176197`*^9, 3.662624778357869*^9, 
  3.79921256673073*^9, 3.799212758322772*^9, 3.814193828888041*^9, 
  3.81424766395932*^9, 3.81424849521527*^9, 3.8322465844687157`*^9, 
  3.832403470632868*^9, 3.8325788982434187`*^9, 3.889696092111187*^9, 
  3.890118886765877*^9},
 CellLabel->"Out[96]=",ExpressionUUID->"fd181db9-1c09-4e6e-988d-b136debf14a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623603106723*^9, 3.662623611969966*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"440efa85-b8a4-4816-83fc-a299e3eb1262"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXs8FAYAB/ALp099KHGWsCFUi6v7DJfHnR8h5rHaGSYseSTzuqkbyftx
7k7e57rjHqn1sMZ2Pt5dV/Jh4+pj7g8yHzHVRievNJ8Utv3x/XytYtIY8VoE
AoH2n/9fFXdb5Pgt0AkEj5W+fCv3yaYAxeqAHXgvb7MKdkSj7UaCFnGFhqXd
vzz/5EcmDDLe+Vbl+2COcfNu9+1MBGpobiNxgeB3SXUPUPJx6dDX8UGLX2Kl
RhI8418MJ9e4hNDkEAgWbdQ+uhzc8uZ0WjuGY4HBrXy3XIZ6qkbi/yoSP9DD
mnbfqoTC69SUPyUaC3zx9KOsarBnOwRqgxj0FTunh1Jq0a84kZQ8Eov1qGBR
VCsf/Tr/7HTgxkNZEua59JEAlp/LRyLOJcAFbXb38q5iUVHXLrBORJNT4qMj
nULsI7MfOugmIes9b+vavAg6ewSCjalkqCNn+rW36hFnM8wdF6XiMGX94OiL
BhiY7lSX0ZjoqRivtOgV445L72sH8+/g7exZu3BBgtSwTfPyXen4bWqH6RMT
KUhHVfLsD+k4b654OyyRgiW1D2H9cQFn4+hco20yaOuR9CxUF8FoTxmyZcgQ
uKdqZOQuCzGaQXsztgys3xs+mHK+x4MIcm3HDRkel5PdjDMycMpCi0FqlmFy
JphjEpoJT3aRi6pRBjMqYe6x7yUY12z5bCuQwdWL9vNepyzYbZdb1QXJYDSr
V5xkeBlDS1cyB/RlMC2LTWZqZeOeSnj5YZcUE/1fxObOZGM55vTNPyOkyOkZ
fLBfmYMuVXha3lsJApuHjmb+lIvmwpD1tSwJRo9Ft4zy8qC0OS933RLjxDTd
8g09HwTip4dtmGLkLdUx81ry8eysguD9vAF3JtvfjJoXQFdJvM8NbsDsoJBQ
yi9AH+P0kG9rPYhaA3w3nUI4B+gfebq3Hs4uHa1+OYW4kugXZZciQmRQqrbV
aiHGrr9qONgnRFQzc2IjpgjuLfODXtZCsPSodIeJIky5dpYZs67i206fAykB
xcj2sB3PVgtwEh8fT+8uBnndsKXKQYCAgc6/hyklINYVHHfi1MFGJCZ9dq0E
JSvfGD+d44OU5K2aN2EjutvxHNmDj9V9bW3plWzkpjyZtRTXQk5Ktd3YYOPi
s80yEbEWJbs0FtOsUrgkv7YOia8B9avWxl9flqLqr/djQ+pqbAppzdvPcGDf
eIaccawaHT0VGsNRDl4o3U3ar1ch4JCdfL8PF7G9fZqTZlVY4/MIZfe5CKNa
zUlNKpEf5Di2RuZBQTHSnyJVYJlPTVPKeFjV4a2EG5fjX4g+vH4=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$379376#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.030933682923687755`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXs8FAYAB/ALp099KHGWsCFUi6v7DJfHnR8h5rHaGSYseSTzuqkbyftx
7k7e57rjHqn1sMZ2Pt5dV/Jh4+pj7g8yHzHVRievNJ8Utv3x/XytYtIY8VoE
AoH2n/9fFXdb5Pgt0AkEj5W+fCv3yaYAxeqAHXgvb7MKdkSj7UaCFnGFhqXd
vzz/5EcmDDLe+Vbl+2COcfNu9+1MBGpobiNxgeB3SXUPUPJx6dDX8UGLX2Kl
RhI8418MJ9e4hNDkEAgWbdQ+uhzc8uZ0WjuGY4HBrXy3XIZ6qkbi/yoSP9DD
mnbfqoTC69SUPyUaC3zx9KOsarBnOwRqgxj0FTunh1Jq0a84kZQ8Eov1qGBR
VCsf/Tr/7HTgxkNZEua59JEAlp/LRyLOJcAFbXb38q5iUVHXLrBORJNT4qMj
nULsI7MfOugmIes9b+vavAg6ewSCjalkqCNn+rW36hFnM8wdF6XiMGX94OiL
BhiY7lSX0ZjoqRivtOgV445L72sH8+/g7exZu3BBgtSwTfPyXen4bWqH6RMT
KUhHVfLsD+k4b654OyyRgiW1D2H9cQFn4+hco20yaOuR9CxUF8FoTxmyZcgQ
uKdqZOQuCzGaQXsztgys3xs+mHK+x4MIcm3HDRkel5PdjDMycMpCi0FqlmFy
JphjEpoJT3aRi6pRBjMqYe6x7yUY12z5bCuQwdWL9vNepyzYbZdb1QXJYDSr
V5xkeBlDS1cyB/RlMC2LTWZqZeOeSnj5YZcUE/1fxObOZGM55vTNPyOkyOkZ
fLBfmYMuVXha3lsJApuHjmb+lIvmwpD1tSwJRo9Ft4zy8qC0OS933RLjxDTd
8g09HwTip4dtmGLkLdUx81ry8eysguD9vAF3JtvfjJoXQFdJvM8NbsDsoJBQ
yi9AH+P0kG9rPYhaA3w3nUI4B+gfebq3Hs4uHa1+OYW4kugXZZciQmRQqrbV
aiHGrr9qONgnRFQzc2IjpgjuLfODXtZCsPSodIeJIky5dpYZs67i206fAykB
xcj2sB3PVgtwEh8fT+8uBnndsKXKQYCAgc6/hyklINYVHHfi1MFGJCZ9dq0E
JSvfGD+d44OU5K2aN2EjutvxHNmDj9V9bW3plWzkpjyZtRTXQk5Ktd3YYOPi
s80yEbEWJbs0FtOsUrgkv7YOia8B9avWxl9flqLqr/djQ+pqbAppzdvPcGDf
eIaccawaHT0VGsNRDl4o3U3ar1ch4JCdfL8PF7G9fZqTZlVY4/MIZfe5CKNa
zUlNKpEf5Di2RuZBQTHSnyJVYJlPTVPKeFjV4a2EG5fjX4g+vH4=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$379376#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.030933682923687755`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {25}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.0037916666666666667`, 0.004333333333333333, 0.004875, 
   0.005416666666666667, 0.005958333333333334, 0.0065, 0.0070416666666666666`,
    0.0075833333333333326`, 0.008125, 0.008666666666666666, 
   0.009208333333333332, 0.00975, 0.010291666666666666`, 
   0.010833333333333334`, 0.011375, 0.011916666666666666`, 
   0.012458333333333332`, 0.013}}, {{0.}, {0.004980807111936512}, {
   0.009810238162392296}, {0.014346227217215901`}, {0.018464393153341006`}, {
   0.022064704980054188`}, {0.02507593216416842}, {0.02745766837337204}, {
   0.029199977122328285`}, {0.030320906486767236`}, {0.030862268772346026`}, {
   0.0308842021317498}, {0.030459093699435374`}, {0.029665456441492124`}, {
   0.02858268400791406}, {0.02728600390974771}, {0.025843747988008547`}, {
   0.024315097005136864`}, {0.02274929181787214}, {0.021185702162765375`}, {
   0.019654527865652402`}, {0.018177876179563502`}, {0.016771007101224995`}, {
   0.015443590647925323`}, {0.014200880244211496`}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.66262477963708*^9, 3.7992125668182993`*^9, 
  3.799212759422963*^9, 3.814193830045418*^9, 3.8142476651285677`*^9, 
  3.814248496506193*^9, 3.832246585826889*^9, 3.832403471820972*^9, 
  3.83257889946497*^9, 3.88969609260695*^9, 3.890118887232382*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"6ae9ff4e-8d28-4279-a914-86eeefdd9a51"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AODL", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AODL", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626236050185127`*^9, 
   3.662623609386401*^9}, 3.799212531136713*^9},
 CellLabel->"In[98]:=",ExpressionUUID->"90692c4b-af96-47c0-bba3-84fe2d59ded3"],

Cell[BoxData["1637.373176226694`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624779712291*^9, 3.7992125668301373`*^9, 3.799212759473455*^9, 
   3.7992244859239483`*^9, 3.814193830086604*^9, 3.81424766517454*^9, 
   3.814248496558289*^9, 3.832246585917547*^9, 3.832403471871211*^9, 
   3.832578899503787*^9, 3.8896960926118937`*^9, 3.890118887239876*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"a4bb7413-6558-49a3-bb08-433a8d422f09"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"ed069afb-65a9-4706-a035-\
58555d00a52a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AODL", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9, 3.48069931407596*^9},
 CellLabel->"In[99]:=",ExpressionUUID->"de04cda8-cce7-4f5f-8e4c-19e1df4a03ea"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk8VN//B3ApKkIlVCS0WSIhJfQuSyEJhZREKikMxsydsRXGkkgh+8yt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       "]]},
     Annotation[#, "Charting`Private`Tag$379503#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.03093422027097565, 0.030934222090156477`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699539484208*^9, 3.481567006130314*^9, 
   3.481942077639205*^9, 3.66262479351025*^9, 3.799212566887249*^9, 
   3.7992127713239603`*^9, 3.8141938426948*^9, 3.814247677077408*^9, 
   3.814248508713516*^9, 3.8322465987260523`*^9, 3.832403484227762*^9, 
   3.832578912561508*^9, 3.889696097558321*^9, 3.890118892086204*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"a49138a1-5431-446a-9467-77dde69ced16"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AODL", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9, 3.480699314862365*^9},
 CellLabel->
  "In[100]:=",ExpressionUUID->"c546244e-c6e7-4dcf-8f92-58c09faf7ac7"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3BkFaUhKUQlLQn5JpKXSlbJSFYoe2Tfce5FSDdFJcQ1cu8J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       "]]},
     Annotation[#, "Charting`Private`Tag$405910#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.030934221846478892`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699548181242*^9, 3.481567013982223*^9, 
  3.4819420873711357`*^9, 3.662624801931018*^9, 3.799212566920704*^9, 
  3.79921277848875*^9, 3.814193849918408*^9, 3.81424768483092*^9, 
  3.814248515915031*^9, 3.8322466063238688`*^9, 3.832403491773119*^9, 
  3.83257892021352*^9, 3.88969610056495*^9, 3.890118895071004*^9},
 CellLabel->
  "Out[100]=",ExpressionUUID->"412763f3-32e4-4f22-8dc6-33b97de63e8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9, 3.4806993158810596`*^9},
 CellLabel->
  "In[101]:=",ExpressionUUID->"82eafcc7-3e81-42cc-8856-b31f68018464"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030934223187089303`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.0057086431276502595`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.480699548871449*^9, 3.481567014542268*^9, 
   3.4819420880567417`*^9, 3.662624802649501*^9, 3.7992125669352283`*^9, 
   3.799212779099167*^9, 3.814193850545944*^9, 3.814247685479968*^9, 
   3.8142485165567408`*^9, 3.832246607095829*^9, 3.832403492430838*^9, 
   3.832578920858622*^9, 3.88969610083928*^9, 3.89011889532402*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"15ddf1a9-fc3b-4917-a9fe-1fffd6ffba91"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["New coil calc for HDS (Peter\[CloseCurlyQuote]s \
emails of 2020-10-22ff), AOSEM wire, larger coil, double length, \[OSlash]2 \
mm x 6 mm magnet",
 FontColor->RGBColor[0.5, 0, 0.5]]], "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
  3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, {
  3.480699105085774*^9, 3.480699140273758*^9}, {3.480699240398816*^9, 
  3.4806992456450768`*^9}, {3.4806992858633623`*^9, 3.480699289781164*^9}, {
  3.8141930745129423`*^9, 3.814193111317787*^9}, {3.814246806524312*^9, 
  3.814246853517599*^9}},ExpressionUUID->"15c61cc8-f405-4731-8c4f-\
20dd7c6baf74"],

Cell[CellGroupData[{

Cell[TextData[{
 "HDS0vals = Recurse[\n\tLOSvals~Join~{\n\t\tkB->1.38 10^-23,\n\t\tT->295,\n\t\
\tg->9.8,\n\t\tmu0->4 N[Pi] 10^-7,\n\t\trhoeAl->2.65 10^-8,\t\t\t(* \
Resistivity of Al *)\n\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., \
GUESSTIMATE *)\n\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, \
measured *)\n\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)\n\t\t\
massSOS->0.25,\t\t\t\t(* Final design value *)\n\t\tmassM->rhomM l N[Pi] a^2,\
\n\t\tBresid->1.25,\t\t\t\t(* Residual field *)\n\t\tPi->N[Pi],\n\t\t\
rhomM->7400,\t\t\t\t(* Mass density of magnets *)\n\t\tztube->0.0155,\t\t\t\t\
(* Separation for magnet to push its own weight, measured *)\n\t\t\
zpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)\n\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate \
magnets *)\n\t\t(* preferred value of small magnet dipole moment *)\n\t\t\
mzpref->0.007945632135874319,\n\t\t(* magnet moment per unit volume for \
magnet stuff, assumed the same for big and small *)\n\t\t\
mz->mzpref/(lold*N[Pi]*aold^2),\n\t\tlold->0.003175,\t\t\t\t(* length of \
small magnets *)\n\t\taold->0.0009525,\t\t\t(* radius of small magnets *)\n\t\
\tl->0.006,\t\t\t\t(* length, ",
 StyleBox["Peter email 2020-10-22",
  FontColor->RGBColor[1, 0, 0]],
 ", as for AODLvals *)\n\t\ta->0.002/2,\t\t\t(* radius, ",
 StyleBox["Peter email 2020-10-22",
  FontColor->RGBColor[1, 0, 0]],
 ", as for AODLvals *)\n\t\t(* coil length *)\n\t\tcoillen->0.005, (* ",
 StyleBox["Peter email 2020-10-22",
  FontColor->RGBColor[1, 0, 0]],
 " *)\n\t\t(* the ends of the coil relative to the centre of the coil *)\n\t\t\
coilz1->-coillen/2,\n\t\tcoilz2->+coillen/2,\n\t\t(* the inner and outer \
radii of the coil *)\n\t\tcoilrad1->0.010/2, (* ",
 StyleBox["Peter email 2020-10-22",
  FontColor->RGBColor[1, 0, 0]],
 "  *)\n\t\tcoilrad2->coilrad1+coillen, (* ",
 StyleBox["make cross section square, Peter email 2020-10-22, 2020-11-12",
  FontColor->RGBColor[1, 0, 0]],
 " *)\n\t\t(* the number of turns *)\n\t\tcoilturns->((coilrad2 - \
coilrad1)*(coilz2 - coilz1))/wireareaAO, (* ",
 StyleBox["derive from cross section, assuming AOSEM wire",
  FontColor->RGBColor[1, 0, 0]],
 " *)\n\t\twireareaAO->6.47708\[Times]10^-8, (* 1/coilsigma/.AOvals - same \
wire as AOSEM *)\n\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - \
coilz1)),\n\t\twirearea -> 1/coilsigma\n\t}\n]"
}], "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.48069930379321*^9, 3.480699340598193*^9}, {
   3.814193152626812*^9, 3.8141931681875067`*^9}, {3.8141932051916847`*^9, 
   3.814193240900976*^9}, {3.8141933150605392`*^9, 3.814193329634098*^9}, {
   3.81419350992902*^9, 3.814193605612219*^9}, {3.8141936599727077`*^9, 
   3.814193703912157*^9}, {3.814245962285343*^9, 3.814246054493347*^9}, {
   3.814246096882122*^9, 3.81424609767097*^9}, {3.814246191198668*^9, 
   3.8142462185994873`*^9}, {3.814246258711887*^9, 3.8142463584737673`*^9}, {
   3.814246404736154*^9, 3.814246425590207*^9}, {3.8142464623580513`*^9, 
   3.814246481204917*^9}, {3.8142465287931967`*^9, 3.814246570064755*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"9fd1e2ef-a506-4fc5-bf65-c8c766bb0595"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0001394867138193868`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.011999999999999999`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.006`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0025`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0025`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "385.9763967713846`"}], ",", 
   RowBox[{"wireareaAO", "\[Rule]", "6.477080000000001`*^-8"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439055870855384`*^7"}], ",", 
   RowBox[{"wirearea", "\[Rule]", "6.477080000000001`*^-8"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699411967904*^9, 3.481566894140891*^9, 3.4819420607019053`*^9, 
  3.6626247130171137`*^9, 3.799212566602963*^9, 3.799212758204702*^9, 
  3.8141938505514174`*^9, 3.8142461557551527`*^9, 3.814246236167638*^9, 
  3.814246865465023*^9, 3.814247685526759*^9, 3.814248516564362*^9, 
  3.832246607114332*^9, 3.832403492471035*^9, 3.832578920866465*^9, 
  3.889696100844755*^9, 3.890118895329077*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"cd440c3f-07fa-44ef-9116-e7fe37c579c4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "HDS0", "]"}], " ", ":=", " ", "HDS0vals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}, {3.480699304968781*^9, 3.480699305631609*^9}, {
   3.8141937544519453`*^9, 3.81419375866918*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"089f13c1-0769-4ba7-a784-1e1e57798c72"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "HDS0", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.05125731583419942`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.004554212103051588`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"HDS0", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, {3.480699306305072*^9, 
   3.480699307040391*^9}, {3.814193775850436*^9, 3.814193777343864*^9}, 
   3.814247837428177*^9, 3.832402652614616*^9, 3.8324027512685547`*^9, 
   3.8324028703413754`*^9, 3.832403056459584*^9, 3.832403168580743*^9},
 CellLabel->
  "In[104]:=",ExpressionUUID->"75c012f6-a2db-4e29-9109-38e62a6e26b6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.05125731583409274`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.004554203052992813`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.480699516644302*^9, 
  3.481566985502486*^9, 3.481942060779174*^9, 3.662624769885214*^9, 
  3.7992125666558647`*^9, 3.799212758243636*^9, 3.8141938506025248`*^9, 
  3.814246865526308*^9, 3.8142477545299807`*^9, 3.8142485847839003`*^9, 
  3.832246607189231*^9, 3.8324034934219837`*^9, 3.8325789217677*^9, 
  3.889696101215513*^9, 3.890118895684182*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"2d1db70a-d2d9-4dfb-96ed-a4c276c250e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "HDS0", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"HDS0", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, {3.480699307709909*^9, 
   3.4806993083441687`*^9}, {3.8141937781239767`*^9, 3.814193778723106*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"7c6ec243-96e8-44a2-8d68-e3decc755f1d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VdsbB3CUDLcUydBwM1UIpZBSvkQkqZTMDYbMh3P2cWRKkco5JG4k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       "]]},
     Annotation[#, "Charting`Private`Tag$425251#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.05125731525002315}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699525015361*^9, 
  3.481566993083891*^9, 3.4819420608359413`*^9, 3.6626247782161903`*^9, 
  3.799212566665503*^9, 3.799212758279677*^9, 3.8141938506505527`*^9, 
  3.8142468655727882`*^9, 3.814247763779603*^9, 3.814248593768003*^9, 
  3.832246616396536*^9, 3.832403502811569*^9, 3.8325789309193983`*^9, 
  3.889696104989223*^9, 3.8901188993812723`*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"8a9e47cb-9b6d-4cf1-a10e-bd86e1beb834"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "HDS0", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "HDS0", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}, {3.4806993090802107`*^9, 
   3.480699309671587*^9}, {3.814193779450665*^9, 3.8141937800273237`*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"4b1376f1-44cd-40b5-aed1-69982f1c6526"],

Cell[BoxData["0.004554203052992813`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.4806995251344767`*^9, 
  3.481566993139513*^9, 3.481942060861919*^9, 3.662624778303006*^9, 
  3.799212566717863*^9, 3.799212758288528*^9, 3.814193850662404*^9, 
  3.814246865582979*^9, 3.814247763822814*^9, 3.814248593809575*^9, 
  3.8322466164854097`*^9, 3.8324035028650837`*^9, 3.832578930947362*^9, 
  3.889696105005739*^9, 3.890118899403309*^9},
 CellLabel->
  "Out[106]=",ExpressionUUID->"eeb6bf81-65c4-427a-9e0b-81f4dd692446"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "HDS0", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "HDS0", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}, {3.4806993103161793`*^9, 
   3.480699311077731*^9}, {3.8141937806353197`*^9, 3.814193781189724*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"9c801f8f-3922-4118-9b24-9f2c78b2eace"],

Cell[BoxData["0.05125731583409274`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699525202236*^9, 
  3.481566993161881*^9, 3.4819420609176197`*^9, 3.662624778357869*^9, 
  3.79921256673073*^9, 3.799212758322772*^9, 3.814193850697136*^9, 
  3.8142468656046753`*^9, 3.8142477638299637`*^9, 3.81424859381728*^9, 
  3.8322466165015497`*^9, 3.832403502874968*^9, 3.832578930953417*^9, 
  3.8896961050143013`*^9, 3.890118899406725*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"dd39d9e2-928e-4aa9-af04-712f3efe6b86"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "HDS0", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"HDS0", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623603106723*^9, 3.662623611969966*^9}, {
   3.814193782119986*^9, 3.814193782621785*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"86c974b5-7a08-4eaa-a24f-09ed09efde10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXk0GwYAB+DUUVvrZa6Omj5X7HXTDFNRJH5blRjRlk6tZU3rqK6MNGR0
biGCMtoEcd+SKBbnc7bbc/Mesc1eWcbsommrjuklte2P733mwdF+YWoEAoH6
n//fLu81TfJ8QiMQngovbNq5KiTeA9uj1iibfnj6JxYLnXXhapqbVOw7W2MW
rJMGnbgX9IJUd7wUVgb8apcNhpLqIg9l4O0b5laDyQW4efSzMJ91X1g8iVsw
LRHAwTk0/HykP6SWR7bE7iVoPMXvsTx+AeLv5zmTuuUopSgrvB4GoW/in15N
YRUG3M4uedleRpwvaXjcrwa81e6iOZ1gOG33T330Sy1GBjwiIuUh2Fi82LFk
XY8RjZ0D9tlh6NfesfrNvwFmn8jkgVfD4ZE4vZbAacT6gLCryPILKBLe3JQx
m3CYzLtvvz8CfmGmL4gnxNDQLSpSLUViPJGvqv5LjFDSTPYDURSYb9Dl+tck
0DE+MJdLZYFnQ2vbmpVA7PTdY3uTGwh6RdfL15MiKuC1SR6RjXXutUvPHaUw
sJmSJe6ysW/8aksMVQpO5TF/zkIMRjOZ1hIrKdS1DbRNp2LBZEZEdW9IwNAt
kMubOZgsJdv9IZGAM1u2a8z/CsTrk2mDZySYziO7HIqLwwo5mOuyIIZi5Rzf
6Hw8KofnZKFBYrxDIaxN029CsVCdpjXSBGc3apuhw9eIltDJUssm6K9qZ0To
JWAmukWp4jbCODckkqWWiIEP4vaIMw1YHDkdkrySCIvS+x1DZg1I6pu4ZzGU
BP1lk9ZIdj0YLZM28XeTMWbp1n+wow7zjpdb53NSUMgVPR7eq4XHMs1si5YK
JWskcI9Wi5SnQlZKayrajfxjmnNqIFZ0bc2bpMFX/2QvQ1GN1YkSQpYgDR39
Dp0iUjU01UYFLhrpiK3Na/Z8XokTTt3tnknpWFBZfNsuqECQT5S6+XY64lsc
NV59XI7PW1iLqmAuXEF5z0GnDBxtCs1+kQsHrXsvZ2dEuN7j/u6X3hlQN/S4
09dWgjM4cpLdmwH3hEeM+qpieI/2/D1jm4lz+2UhWhlFIInKDT6szoSh5lJR
AE8Ig4hTU4+MeHD5oThWLUWA7cOdnexveNjRI8Xb8u9AZhBlpVLx8CCQWEi6
exuZRKXpMicLPu+vXaGPF4LyaXvN2J9ZmD10yZytKsDrEmqLFpOPjNsxRI1j
Bejuy1fqzfMR4uVTpyXPh/dRa5mFezZqaK5XRJw8PBPkEHIHs1F6sFhu+NYt
pPoc//kZOQcXhT+Odc3mYENAiR6qykHxrrP094ps/AuUNr7e
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$444858#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.05124246112553977}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXk0GwYAB+DUUVvrZa6Omj5X7HXTDFNRJH5blRjRlk6tZU3rqK6MNGR0
biGCMtoEcd+SKBbnc7bbc/Mesc1eWcbsommrjuklte2P733mwdF+YWoEAoH6
n//fLu81TfJ8QiMQngovbNq5KiTeA9uj1iibfnj6JxYLnXXhapqbVOw7W2MW
rJMGnbgX9IJUd7wUVgb8apcNhpLqIg9l4O0b5laDyQW4efSzMJ91X1g8iVsw
LRHAwTk0/HykP6SWR7bE7iVoPMXvsTx+AeLv5zmTuuUopSgrvB4GoW/in15N
YRUG3M4uedleRpwvaXjcrwa81e6iOZ1gOG33T330Sy1GBjwiIuUh2Fi82LFk
XY8RjZ0D9tlh6NfesfrNvwFmn8jkgVfD4ZE4vZbAacT6gLCryPILKBLe3JQx
m3CYzLtvvz8CfmGmL4gnxNDQLSpSLUViPJGvqv5LjFDSTPYDURSYb9Dl+tck
0DE+MJdLZYFnQ2vbmpVA7PTdY3uTGwh6RdfL15MiKuC1SR6RjXXutUvPHaUw
sJmSJe6ysW/8aksMVQpO5TF/zkIMRjOZ1hIrKdS1DbRNp2LBZEZEdW9IwNAt
kMubOZgsJdv9IZGAM1u2a8z/CsTrk2mDZySYziO7HIqLwwo5mOuyIIZi5Rzf
6Hw8KofnZKFBYrxDIaxN029CsVCdpjXSBGc3apuhw9eIltDJUssm6K9qZ0To
JWAmukWp4jbCODckkqWWiIEP4vaIMw1YHDkdkrySCIvS+x1DZg1I6pu4ZzGU
BP1lk9ZIdj0YLZM28XeTMWbp1n+wow7zjpdb53NSUMgVPR7eq4XHMs1si5YK
JWskcI9Wi5SnQlZKayrajfxjmnNqIFZ0bc2bpMFX/2QvQ1GN1YkSQpYgDR39
Dp0iUjU01UYFLhrpiK3Na/Z8XokTTt3tnknpWFBZfNsuqECQT5S6+XY64lsc
NV59XI7PW1iLqmAuXEF5z0GnDBxtCs1+kQsHrXsvZ2dEuN7j/u6X3hlQN/S4
09dWgjM4cpLdmwH3hEeM+qpieI/2/D1jm4lz+2UhWhlFIInKDT6szoSh5lJR
AE8Ig4hTU4+MeHD5oThWLUWA7cOdnexveNjRI8Xb8u9AZhBlpVLx8CCQWEi6
exuZRKXpMicLPu+vXaGPF4LyaXvN2J9ZmD10yZytKsDrEmqLFpOPjNsxRI1j
Bejuy1fqzfMR4uVTpyXPh/dRa5mFezZqaK5XRJw8PBPkEHIHs1F6sFhu+NYt
pPoc//kZOQcXhT+Odc3mYENAiR6qykHxrrP094ps/AuUNr7e
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$444858#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.05124246112553977}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {37}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0002708333333333333, 0.0005416666666666666, 0.0008125, 
   0.0010833333333333333`, 0.0013541666666666667`, 0.001625, 
   0.0018958333333333334`, 0.0021666666666666666`, 0.0024375, 
   0.0027083333333333334`, 0.002979166666666667, 0.00325, 
   0.0035208333333333333`, 0.0037916666666666667`, 0.0040625, 
   0.004333333333333333, 0.004604166666666666, 0.004875, 0.005416666666666667,
    0.005958333333333334, 0.0065, 0.006770833333333333, 
   0.0070416666666666666`, 0.0073124999999999996`, 0.0075833333333333326`, 
   0.007854166666666666, 0.008125, 0.008666666666666666, 0.009208333333333332,
    0.00975, 0.010291666666666666`, 0.010833333333333334`, 0.011375, 
   0.011916666666666666`, 0.012458333333333332`, 0.013}}, {{0.}, {
   0.005125718696972585}, {0.010191940042934422`}, {0.015140616860131897`}, {
   0.01991652248719171}, {0.024468472066211187`}, {0.028750342650427363`}, {
   0.03272186421536034}, {0.03634917602850702}, {0.039605163536282}, {
   0.04246960420439645}, {0.04492915767905281}, {0.04697723283470747}, {
   0.04861375885286397}, {0.049844875995189664`}, {0.05068255051974982}, {
   0.05114410835775569}, {0.05125167756198548}, {0.05103153047645989}, {
   0.04972923608805475}, {0.04749924779411141}, {0.04461427820132512}, {
   0.04300738798367451}, {0.04133008474943263}, {0.039608326853859094`}, {
   0.03786503094392313}, {0.03611997869379068}, {0.034389880665953367`}, {
   0.031027031640491216`}, {0.027856137204017858`}, {0.02492264016235568}, {
   0.022246638773665624`}, {0.01983067947522612}, {0.017665952927379547`}, {
   0.01573689692464275}, {0.014024439351222714`}, {0.012508180641859844`}}, {
   Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.66262477963708*^9, 3.7992125668182993`*^9, 
  3.799212759422963*^9, 3.814193853077264*^9, 3.814246867872548*^9, 
  3.8142477659461203`*^9, 3.814248595891169*^9, 3.832246618686345*^9, 
  3.8324035051034822`*^9, 3.8325789330589457`*^9, 3.889696105942383*^9, 
  3.890118900286674*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"0c6c878a-6c05-423e-bc86-e1dad73fc6b9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "HDS0", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "HDS0", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "HDS0", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626236050185127`*^9, 
   3.662623609386401*^9}, 3.799212531136713*^9, {3.81419378324492*^9, 
   3.814193784414452*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"cfe72ccd-d1d0-4461-9af4-93719237c0c9"],

Cell[BoxData["4533.877170403583`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624779712291*^9, 3.7992125668301373`*^9, 3.799212759473455*^9, 
   3.7992244859239483`*^9, 3.814193853141307*^9, 3.814246867917796*^9, 
   3.81424776598672*^9, 3.814248595928607*^9, 3.832246618779912*^9, 
   3.832403505170209*^9, 3.832578933103167*^9, 3.889696105947658*^9, 
   3.8901189002909193`*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"72ecd707-c5ac-40bd-976e-11279002251f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"e0bca399-1539-4b8e-931d-\
5f0814c26a4c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"HDS0", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9, 3.48069931407596*^9, 
   3.814193784954692*^9},
 CellLabel->
  "In[110]:=",ExpressionUUID->"d3bd0671-a5c6-4dca-bf62-2e3bdd6896fa"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk0VP//B3BLIWuJJFJRkrVkD69EQogWImvZs8zcGVuWFEmIlDSkkm3m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       "]]},
     Annotation[#, "Charting`Private`Tag$444985#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.05125731427504521, 0.051257296355897264`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699539484208*^9, 3.481567006130314*^9, 
   3.481942077639205*^9, 3.66262479351025*^9, 3.799212566887249*^9, 
   3.7992127713239603`*^9, 3.8141938712469807`*^9, 3.814246883847354*^9, 
   3.814247781671936*^9, 3.814248611221245*^9, 3.832246634162156*^9, 
   3.832403520769289*^9, 3.832578948544018*^9, 3.889696112156485*^9, 
   3.8901189063735857`*^9},
 CellLabel->
  "Out[110]=",ExpressionUUID->"18a81e2f-8f1f-414a-87de-213b3fa49094"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"HDS0", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9, 3.480699314862365*^9, 3.8141937856826353`*^9},
 CellLabel->
  "In[111]:=",ExpressionUUID->"b81c3c04-ef0c-456c-8765-09f9ff63e5a4"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13lcTF0YB/CINllaqbdNSIkWW0T90r6glLWUSGifuTMt2pd5hURCplQU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       "]]},
     Annotation[#, "Charting`Private`Tag$470294#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.051257310005113035`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699548181242*^9, 3.481567013982223*^9, 
  3.4819420873711357`*^9, 3.662624801931018*^9, 3.799212566920704*^9, 
  3.79921277848875*^9, 3.814193882907139*^9, 3.814246893343824*^9, 
  3.8142477919849243`*^9, 3.8142486206872263`*^9, 3.8322466443739243`*^9, 
  3.8324035302732277`*^9, 3.832578958465234*^9, 3.889696116044896*^9, 
  3.890118910192278*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"28adfdf4-4a29-425e-9e4b-abd7fd51d244"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"HDS0", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9, 3.4806993158810596`*^9, 
   3.8141937869577847`*^9},
 CellLabel->
  "In[112]:=",ExpressionUUID->"5fceeffa-2b7c-483d-88ab-075b2aeb142a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.05125731583409274`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.004554203052992813`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.480699548871449*^9, 3.481567014542268*^9, 
   3.4819420880567417`*^9, 3.662624802649501*^9, 3.7992125669352283`*^9, 
   3.799212779099167*^9, 3.8141938838027973`*^9, 3.8142468942345543`*^9, 
   3.814247792911677*^9, 3.8142486215825*^9, 3.832246645297275*^9, 
   3.832403531232609*^9, 3.83257895942653*^9, 3.889696116408997*^9, 
   3.890118910559944*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"8843d219-c193-42bc-8907-6f48696d6e59"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for HDDS (Srinath Karat emails, 2021-06-08ff), \[OSlash]2 mm x \
6 mm magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
  3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, {
  3.480699105085774*^9, 3.480699140273758*^9}, {3.480699240398816*^9, 
  3.4806992456450768`*^9}, {3.4806992858633623`*^9, 3.480699289781164*^9}, {
  3.8141930745129423`*^9, 3.814193111317787*^9}, {3.814246806524312*^9, 
  3.814246853517599*^9}, {3.832159171714485*^9, 3.8321591873972588`*^9}, {
  3.832396977157538*^9, 3.83239699378832*^9}},
 FontColor->RGBColor[
  1, 0, 0],ExpressionUUID->"eeb9e2a3-0791-419c-9e73-f668f10e8371"],

Cell[TextData[{
 "length of magnet: 6 mm\nradius of magnet: 1 mm\nlength of coil (as shown \
below in green): 0.400 inches or 10.16 mm\ninner ",
 StyleBox["radius",
  FontVariations->{"StrikeThrough"->True},
  FontColor->RGBColor[0., 0., 0.]],
 " [typo: should be diameter] of coil (as shown below in the black and white \
image): .275 inches or 6.985 mm\nouter ",
 StyleBox["radius",
  FontVariations->{"StrikeThrough"->True},
  FontColor->RGBColor[0., 0., 0.]],
 " [diameter] of coil: ",
 StyleBox[".2238 inches or 5.6845 mm",
  FontVariations->{"StrikeThrough"->True},
  FontColor->RGBColor[0., 0., 0.]],
 " [27\[CloseCurlyDoubleQuote] + 2 x (1000/42) x 0.0094\
\[CloseCurlyDoubleQuote] = ~.723\[CloseCurlyDoubleQuote]] (1,000 total turns \
of wire / 42 turns of wire per layer = ~ 23.81 layers --> ~23.81 layers x \
.0094 inches of wire diameter per layer = ~.2238 inches)\ncoil turns: 1,000"
}], "Text",
 CellChangeTimes->{{3.832242878783773*^9, 3.832242881043477*^9}, {
  3.832396655234991*^9, 3.8323967207067633`*^9}, {3.832396874727993*^9, 
  3.832396917464612*^9}},ExpressionUUID->"75120ed2-659f-43e4-98b2-\
2ae4ab0c2b87"],

Cell[BoxData[
 RowBox[{
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzsvWu0LddV33kl2TSmRczgQ3drxG5G8knpHuQD/UE9yGhG6GZcwpeMHmnQ
CElGkG0QDU1MMCiB7k4AA8IBOmATIvyQX5JsWbZ5g30lS7LTYOyrh8GQJtCi
saX7OOee937Wa+/qmmutudZ/rVpVu/Y+++zHOXNqTFftql21a++zz3H97n/O
//wbb/zBf3D/7ZcuXfrhr6z+5x+84V9+81ve8oYf+1++pnrwHW/+4e/73jd/
z3d/25t/5Hu+93ve8t+/8Y5q48PVc99RrbyqWi8hptOppOSFyclk4mVRFLVt
i2RR0LJQSzrnPKmP00uXE1hGsljCNUfOV8C+vNqWm/eW5ybp/an1Qi1Vmv3+
e+f1PHi/uV3mal0vs2obZZ7nZlllZjKHx3k8M5OpSbdena86LsvyMs2yMksp
aZtZp2W1L8ly85y8HFfbUrOepiYTWCZZmVTH0uNxtdSZVtuqVPuq5Tgtx7Q+
rvZxVo9HJsecZt+Inl/laESZqByOddK+kdk3xBym5WBQ5UjnkI6pcjCk5bha
jtU6L/sDnWqdH1f7aNkbjKuslv3qcX9UbaOkbSP1mPb3q30n1fK4V22npMcq
R+VJr8r+sNo3rNZheVJtr/K4Z5LWT4blUbV+ZNaPj6vHVR7S+smg2j5Q65RH
vI+XR9W+I/348HhQHlSPD6rlocp+KSEhISEhIbG6WPd9vaTkqpKZideXe25a
IlPO4MBWHg15r7BsV5jn2GWhGVBvq57HDDdpYFZYTiawtNfrZ4FJvGgZ0fBk
YdjSLPOALfOQQYkR6Ry5SWLJXG/j1Exp2JI4kNPwYK6Wmiv1dtqWawY1z3Hs
aHgyM6yZ5o4RE2LBzGzLdBo+TKr1xPClepxmNoklE5X0OFc5TnLNhfQc2p6k
ii3HCTNlarlxaLhwbLaPaN/Y8OUos8w4YjYcM1cyYzJLVtuGOhUvKp50j4kl
iRPVc0aJ5sKK+waGHweDsceStOz1DVP2NTcSTxJL9ogl+8yOhhuZJ6s87mtO
pP20PFIsOTIsWTHlydBwpFseqRypJbOkTsOSx4Ynj5glq+2HVR4xN2qe1Cyp
lxISEhISEhKri3Xf20tKrjqRJZeVmiEXvR63dDmBpa8hhjois2edLw0/Bvql
49HCLaOpzzEpwuMDxizcMg/T6IWF1Q59ruR1f7/TGHPWKG0aTkS2zAu7nvM+
oy/SuuVGw5WZSas30vMMP6bMlMiOmU7cpngzYWbUaVnS8iSzJOuPhh2N/oip
eNLyZciSmhmZJXldPa7xpNEnacl8Cdk3uqJmyUQtFU8ySw5An+y7JE3yxGiT
xJHHavvIY0qlTSpdUrMma5DMkoonjQ7JXHkIPHl8gixpeNJqjbzOmiTmsNwn
lqyWEhISEhISEquLdd/TS0quKn3uc9vWfV2nfl+chkELZtHC31YE2+o83Kaf
tmurRSS5JraA+lishbXLGen0Ts2VqVpq/VHVuhZmmeb1+tfM1bxi3SvXvmZZ
kGlhWNJwpqlx1dpkUO+amTrXcW51SatPmrQsOjZLYskRsmWk1pV1S9pOTDnU
GubQY8/E5tDUtY5MrWt/GNS/jjQzsk5JjKi4cqBrX/vAmT1a9vXzT4gre8yW
Y1P7qmtdiSlPgDN7tVpXw5InzJKaHZkfT4wmeejVu7p1xZGWMbHOdWA5k7jx
yNS47httUkJCQkJCQmJ1se57YEnJVSXqkMvqi9yWtDpmMWmsj23PIrLerf+z
plGCTjlPZrG0mqOuCVV63yhIqCNlDqtx2QiWFbehFshLqhkdmB5ErhVVy4Fb
DoDX+iYHrPupfkaj/xldUNeOmnrTUVK7nuEo7IsEDXKka1ddTyS+ViRtHWti
uVAz4siyomXGvmHGHnCi4UOtQw6N9sh6pMtjWB73sJ5V168e2z5Ix4q2F5KX
R9gXqXVI1QfJNa2gRx5ASkhISEhISKwu1n1vLym5qly0njXGnLxtXk+dVaar
azXrc9ejTuq1qN62Nu4zeqFZL+zj3NWpFnrp1a1mfk0q9z5msSR+zLVuSFrr
9oa+dvo8mCVtTyR454xM3Wq/xohjL/vslwNcqGtXuRdS16n2hiPdD6n6GoeK
D7l+VfdDjlTfI7JiDxhR7e9p9jvuD61nzompYT2ydaxDqF81vZBHugcyrF21
GXAiL/eVt05f5aFZ7h9W6wd6KSEhISEhIbG6WPe9vaTkNmYXJnV+rNjD6LQ8
9sTRfjeza0dPq0dOJpNGn1f0aUWdMrfp++t0q0n1NUn2ZrV+Ornz0/EYNCvq
Xq1N2mSmz7d7a7984qMvlh/72H8sP/bxP3X5sXp+FJbR/CgsnzBLk08E+dGP
/kktn3hCp13/aJBPuPzIE18sP1ad55FHvlD++Z/vqL5LYsEhapNGl1QaaqtH
q/HPsb2OcV2S9UjWJE88j1bTB2m2K29W1idPxr7XjknV29gf2rrVE0+PHBnf
HefVqnlzpHjy8KRvPVqJMQ+OQZckTfLQbbOa5HFf90kSPx73NFceih4pISEh
ISGx6lj3/bik5KpyUT0ylni+RV7H+qvyrJCJz5fooWp9cgK/G8eesTkhEQ01
qHFFfx7PrwdZcgIzQArnuVoYbxztuQqZh7M/HIPmlimNTln42qRjRKNTBixp
+xmBJ6lWleLzV58vL136V1X+cpW/WOUvbUnStf5KlT9WPvze31LvhXS+ofVl
TWyNreuB1LWzfWBJrUWmrudxEGdJ1jJpxgf1QfaGepZHvzcyzyd/1qGtaz2x
taxjo1uCpw5olbaGVbGk9tY5Mjx5ZPx0tHbpWNLWrar+R1O7GvRAqhkfppb1
4BhmfHg+O33NlIfCkRISEhISEquMdd/bS0puYp6GOfF4/5y8bp6jcqK2F1Po
XwQtb8KeqUFNKq/XuXJW+qwZZUucJVIAU3osGfqtwnUzY3o8WXgc6tfQ5k6b
zH2ezDPmydwyZQbeOeSTSp/lCy98oXz1q99W3n77w1W+s8p3bUm+s7zjjvdV
y7eWH3zkt9V7IVZjTXIY1LbaHkjsvaxxItWwjqD/sZ69oDfT9kGCD2sPNEdk
Rs2J2AtJXDg2sz4GjhNPht66zUgfJNe48qwPVfcKLHlkePKAZ0cSPx4a9qTl
gdYlJSQkJCQkJFYXm3LvvYpsur+X3Pzc9O9Wt+8fr5v3o3Ja8swQ6606ZW9V
Yq5pbVYkpjcnsmFmZDjLo+6Z09xfOQm3T9yMR6dBBt45M710XG1srV61yD2e
dDM96n2TlOR/SkEceccdbysvXXq4yndW+a4tSWLe91XLnyrf//7fUT/v4xM9
xxE1Rd3zqHVEtazypFdl3z1W2+w+PdNRaYcnY72EpNc4PnHrR8e8baQf8xyO
E123enisl0e0PDLLY7Ndcd3IMJ6ew3F4qPnvAHLf5MGh2UbLgz70TWqWPEC9
8WQAzGg0ScOTuk/SLA97iiclJCQkJCQkVhdncZ+/buaQlNzqJNZkzdJwpWXM
gmd4aMb0al1n6pFF2VwHOzvDmR42cT4HMGI3H1h/pkdhGJV50nr1FPG+SdIj
KTRH/puKx4jJ3l3le7Yk311x5AcUR378479r/ioTG+dVZpB5x8Rj0s45Vcss
eJxUS50TWJ9OYZ33TcfVd3ZcFvSY1icj/dgkr+e0nJjt1ZL+neBY8ajWLYkb
D06cFqnmexjdkln08JizXtsqISEhISEhsbpY5v3vpmtGeI2S25Wn+W5t8ndy
5rWbVPWvnMh1zJVFU86a39GmWTb4vwaJDLjoTI+Yj04KvZJRP9cquT9Sc+TP
VTz2AaNJvndL8mHDvu8ov+Vb3lbef/97y/ve8O7yjW98z8x8Q1tW5+Alne8N
M/K++4LHdvkutf5dZtt95rn3vSHI+2A7Lb/rXWr5XSZx/bvuo33vKv/pd727
/MEffEd5cHhoNFHumeR+ybqH64GXw2BdOFJCQkJCQmKVscz7fHt/Cz6Vm5B8
LcgjktuV+PPr8t1qmsux7u/iUr7Pk7ouaPXABf1UC+On6i+bMzYTUvc4Nniv
zj0fkmZ6IDtmJqv11GSNI39hCzmS8/3mun+11HW55zl/1eR7y6/5mu8s9/av
VxyZaE3ReLIeKE/Wvs+Oh4NynzLYdnBo/FqlrlVCQkJCQmKlcRb3+cJqkuvO
8PsYY8jGvsCWfZuQbX2Ljb2JtW2xmZCx+Y95dFsRmwlZGPYr2jXEpky99aJM
eD3V+9KKI2kuRppkdp1mLFK88MKLFUf+XxWbfNBw2fu2LqlP8o473n8B8n3l
q15F7/XR8uu+7rvL/YMbqj9T8SDNiFSzIXuGE/vl/rGuWd0/6Jd7B329jZPm
Rx4MzFL0SAkJCQkJiVXGWdy74/37JmV4jZLbkyEXLvqzXkS3ZL/SyYbomaxF
eo+bPFVb+xXDWtZwWx5kTLt0njvsvxPVG9N59Uhd15qaGZEuszJL0wY9kjjy
EcNl75fc2HxfedttxPqPlq9//ZsUR2o9Uvuv7rfpkQeBHsma5JHokRISEhIS
EquOdd3nC0dKruP7FTtneN46U/KcjW41tavgyBpPGnbk7Vkxw//GznmM8WRM
B40zpVfXihxZmHpWXnasbc0NO/Lcj4RnguSmljU3LJlkEY78t8KRW5FxjlQs
aOpaFUMea59W9m89ONB1rX5NK+SBcKSEhISEhMQqY918ICm5yoz9u0KdJ7Ee
1ul0rEduWq8l9kta/9MJeKnmZh8tsy49k7N8eHyeRI+drKmutgNHZjWOLCqO
NPMiVWZ6qfoj0waOfNSwygckNzbfX3Eksf5jFUe+seJI3R9JOuO+9WHtWy/W
AzP34yDWG2n4UvRICQkJCQmJ1ce67+slJdeVMT1SPzYs6XmjFronEPgR2XJT
MsqToQfPTC+esNa1qd5Vr0c5EnXJjhwZ1rbautZajyXVtsb0yF9UbKJZ5YOS
G5sfqDiSWP9DRo+8Vh6hHqm4se9mRtLSsKKnR4aapOiREhISEhISK41138tL
Sm5Ssh5pWTJktNCPh3lyzlmMZ13vmsN6ZrTIPKZLzvR1RabEHsmsXY9cgCND
hkz4cWaWae6WUY78JcUmmlUekdzY/GDFkcT6H6448rvLPaNHHqAeeWh6I4+d
5hj3ajVseaB7JyUkJCQkJCRWF+u+b5eU3MRkPdI9DpgNvFNZ/1s3R4YsaWeD
oB4592yQthrXHPTI/NQcmcLS1yO5rjV3y2h/pHDkdiRy5JtUXSvqkbqe1dW1
7nNd61HAkey5c9Av9/e1t6uEhISEhITE6mLd9+uSkpuak2lT/+REMabfN7kZ
mmSUJaFf0vZKLsSSnLl973mR1X12TtEfGfdrBY5M2/TItys20azyqOTG5iMV
RxLrP271yEPDkYdHjiNtveqRY0jkyP0LqEceHByUDzzwQHnXXXdVn98llXff
fXf50EMPLfV17r//fnVueq22oNel1+droeuiY+g6z+K4WNxzzz3qHFeuXJn7
2GUEvS69Pl2HxOlCPsvtj8cff9z73b7zzjvXfUnR4Gts+7tx9erV8t577/X+
3tI6/X1c5G/VeY1136tLSm5DIk/qetdCLXWdqNblJlaTXD9PWi0SWTLUI4su
vjttmqR+31mTHpl11yOZHfOQIVUdK/i1UiamRxI48vmKI29XHPm4YZXHJDc2
H604klj/IxVHfk95CznS1LTS3A/FigdOk9xDjgSGVHMkq+ftnXM9ku5b8P6M
7rXxMd3vLCP4Xn4WR9LrIcsyz/HjpvusRY9rCuHI8xPyWW53vPTSSx5v0c9x
WX+Xlhn0d42vs+nvBv1bF7IwvRf8W0XbiDMlhCMlJedJzZKaq1QPpZrRqPln
E/gx5EhmyUY9ci6O9Hky9zL3536EWuQcfq3MlM6rNXd+rUqPbPLZeUcpHLkN
iRzp65EHVo/sqVpW4sRDw417hiWtHqnqWvuKI/cO+ueeI5m/iLXofo2D7oPo
nob2nVaXJIbjc7VxJN9j0XPxPoyui9k2dv+46HFtIRx5fkI+y+0O5jNiyE0N
/Heypr8byMOkPWLgv+dt8vtcZaz7vlxScttS65DVOvQfcr3nuvVI5MeJYcds
EmHBcJ7knBzJ3jqZXeZlWpgex3B2JG1LZ2uRaR6pabU+O+DXqvTINKJHvkOx
iWaVD0lubD5WcSSx/hNKj9yz/ZHGW0fVtPajNa374M+6Z56zd9grbx1oXfK8
Bt7XIENyMJ+d9r7m8uXL3j1WE0dynVeMW9uuddHjNjmEfZYX8lludzBHhuy1
KUEMiDWqTRzJdf1N30P897Zl9xRsY6z7nlxSchtzAn6uzJKbVNfq+bUaboz6
tS6oRRagQ+aGI6N6ZNauR+LMSFz350YafuS6VqVFZmUKHPlcxZG33fHLwpFb
kXWOtHrkMc376BmtUfvr7Ac6pNMiadlXubffVzx5XuPBBx8sWYtsCr4vWrTW
ivqa+N6JNb4YR9L5+bWaalD5eLru0x636SHss7yQz3K7gzlyVl/1ugL7vmdx
JHFi2/to+xt50WLd9+OSkluZPF+y0H48er4k91Hma2HHqFcr1rMWwJEL6ZGF
8X7N1TJT/ZHaZycN2bEAHTLCkGE/pKdDZia5N5K4MTd1rcqnNbVs6euRwpHb
kciR91ccSfMjx0aPZC1Sa437gRbJafVI5siD3rnmyC73LKdhMP73dUrSAtte
j+/B2u71+Tmkb572uFnRVNfK94kU9JlgL+ksbyL6PMJjSMegmttQK0X2ifkg
0Xtpq7mlY+i+NfROavMdomsIj2m6vlnBnzldI7E+atLsf8QReqjQOm1rCjon
nQ+vk75jtC12XBtHYr9a7GfHnihYl03nafs50+uFx8z67JsC/40Ee4DpveK5
6OcTerd0ec1FjsPPMva95H9z4mvmz4GW9LjrZ4BcFmb43aefR9hn2PY70vVz
nRX83eJ/i5vVHzkrhCNdrP1+XFJyC5PYcWp8dqi+dWJ8bNatR9YYcon1rDno
kc5PxzBebvTILKJFBj47MYas6ZB5oEVmTotMKY0eOfI48t8pNtGs8mHJjc0P
VRxJrP9Ro0de03WtFQceHPe0386B1h2jOqTVIntq3sf+ITHkybmua+V797Z7
Fr7/X+S+ho9lBm27R5pV80XB+ik+Z9HjZsUsjuR7T/b9wHvpWP1d6GfEXkB4
j42aL9+f0nn53OExbewTcg/eY9P5Qn2ZeAKv5bT+H1iLiNeBnwHt4/38OeJ1
x+7F8Z6fj8HrjH2/mjhyFkPGPFFCT6qQOVh/x+sLf+7zcAq+Fn6G+F7oOtt+
3k0/u0WPC3+W4c+O+5T5cexz6xLMhvz9x583smr43Q5/H2O90V0+11mB9ax8
PafhSKzBl7pW4UhJyUVT17WyHkmMxXrk6jmymMQZUi2XWM+ae/WsuVfPmoWa
ZIea1lCHzDJ/XfMkMKRa13pkUtMjf0WxiWaVxyU3Nj9ccSSx/seMHnm9PDrW
eiT3Ru4fNuuQqEXuGT3yFjHlOdYju9zzdNH7YsH34HhcG0d2+Xd49LI47XGz
YhZHxu71UD8J9Ts+X+hnhHoI9qHiNYf+QXQMM3rYu4o9VqH2g8eFtcx8DeE9
N/LvPHoufhahxsNcz4laN3JB+Hr4mYQ/F3xv4UyIGEfOYkh8rVCLJ2bgzyT8
N4OmXl1k+3m0ffyckOn488S67vDnjT5TdF24b9Hj8Jro/aD+G/YJht91ZOxF
/k0i9juOP/PwO4Hfs/Azn/W5dgn+ncHrOg1HNn1/L2qs+15cUnIb0zKk8dzR
/ZHr4Uj01OFlxjWsIQ9mi+mRjh25rjWzDDmvP2vrnMjavEjTD1ktNUM6LTKu
RwpHbn4GHLl/reLIkeJH1Q95EMz44GQdkjhzX+uRe4esR/bOtR55VhzJ2hbX
s3KcJ45ser2YTwa+fqw+lNkPdZY2ZqJo8g+a5W2J9/p4jfx+Y3WhzEDzfAf4
Oui42L15m1aEvBGek+tsY9HUKxty5CyGpODPo8tr4ecfe30OYhmeE9g1kMVj
wSzTxbsFWWrR4/Ca2urTm77rXWogms4ZHoO/A01/w/B7GHsP8/zbCAZ/R8N/
j1mUI/Fza6vpvkix7vtxScltzIKXFTvmU6f3aYZcHUdGeyIL0CORJ0/hz1rY
fsiJ8dXJDEPmlv+itazZbIZMIpqkZsjCzvdQ2xVDppYhhSO3NZEjqa71Fd0f
qTiSPVidT+vBIWqSfVPbqud8KD1S6Zfnu671rDiyqafyPHFk02cWux6u3Zzn
nrXLNceuhRmxTfOKXQ/qlHQfe9p56LO+N121wHkj9pkgR3ZhSOSTNt2MmQg/
a2avWf2r876fpu/3rPdCEav9XvQ4PDb2/mb9O8Yi/X9NHNllHgh9j2PXO+tz
bQtk7PD7sQhHom4qfZEu1n0/Lim5bUl1rE6PnCg9UrPW6nx2cLaHXTfc6M35
yBdnSK5hdezIta0Vw1X8mJueSM9XJ9IPGeuDRI9W9tXxvVkLM9+jeq0UdUin
R1Jd67BW1/oxwyofkdzYfLziSGL9j4MemSg2DL11Dow+6WpZjV5JGqRlSNEj
KeblyLZexPPEkbO8YfF6Frl3Dv07YtF2f8y9XrFk1sSfUTj/jvfTNS/i1Ttr
VkPbd6/rz4ueR0mvFXrFxDgSewHbWBtfv+kzxH5A/LmG3jDs90KvtcjcmbbP
qSvvhvruoseF1xT7HZj192KZHMma6qx/n4lpoIvqhhRtPePznhf7fYUh/Vj3
Pbmk5Dal89eZmvmRU81ZOTPe2euRMYZEb1arQ2Ita8iVHb1ZkSc5szxrnvER
8WfNZuiRKdezEi+yR6uZE5mmhZnx4euQ41CPfL7iyNv/ffU3/tcMqzwhubH5
kYoj6b7n1yuO/N5yb+9aeXik9chwRmS9ntXXITU/cp5fjozpKWHM47PTVM/K
0cVnp+2esM1nZ97jZkUXv9a245bFkW3X3MaRXTI8N/ugxp5LjDbPPfesWQ2L
ciTtC3118BrbOJK5jo9v+p7GmLotw/dIGh/6yoSf+Tw8uSzexuctelx4TbFY
JUd2PVfseYtyZFM967znxX5eSvHVqce678slJbclmSGVHkn9kGaZG61vUhQr
4ciQJ2PerHnMm7UjQ+aWIVmPZL0xN76sWoucNSeyabZHON/D64n0fHXCfki9
nhgtsl7XSnrkx0vRIzc9WY/8NaVH3mI9UnEh1LMeQS2rqWfd2+9Zbx3FkAfw
+OD8cmQXRpxn7kebT39TcnRhvdj8jkWPmxXbzpGnqamke1y6XyZGD3moKwOd
BUeG/qn086Tz0/Y2v0zUI/l5/L5in+9p6mox6LOiawu10rY6zDDaPqd165Gx
OO96ZNO/YTRl7HNA76rQq0jCxbrvzSUltyEnvDRa5MTM/LA+rYohV1fPWuuH
NJyYNzHknL2QRahBWm/WvKYxNvnqNM6HzGE+pO2JhNkeZum4MbP+rAlokVTv
KnrkNibqkbqu9bDiyD2jRx5AT6TtlSSGVL6srpbVMqSqcT3femQXButyv8nB
Pv2z6gDRv58DfUuaIsa0ix43K5bJkV00U547wLrEohzZpT9y3kCv0a73/2fB
kehD23SdbRzZVMcbflZdOWveQA7uyi+znt9Fzzqr/shYrJIjl9EfOS9H0mfS
9jeOz8t15WFdd8iQy/x+nbdY9/25pOSmp6dD0jpxI3vrkC6Za83OaZGrqWv1
PHUmMN9j4VpW5lB/vgfyY25mRUY1SFhvY0j0ZXUMWQA/sjdranXHDHTIJAU9
cmQ48rmKI297SLGJZpWPSm5sPlFxJLH+b6i6VtIjD4weeXDkz/hw3jpab9wz
taw6mSFdret5jVn3y8yZ8+gnbTHrHrKNgZr8MU9zXJdrXQZHoq7T5Nca/hwW
5UicIdLWw0n3sHyNdE28bZ6+z7Y4C46cde+PevgsjqRgTorVt/J3qon92WuF
nsd6Ei353wOaYtkcuU6/1liskiOX4de6DC+kec4rDNk91n2PLim5yTmBJfvr
aIYrrA5ZkI/pGWqRsdmQMU+dHLlxbj3S1bBmdr6H8WVlJsxMXWtMg+zKkGFN
KzNkwvqj7odU9azgrYMMmTbqkb+q2ESzysckNzY/WnEksf5vVhz5v5a7wJHW
X+dAM+SeWu/pGZGKFV0vpNYjXV3rrf3zy5EUfD8ZznrDOeIxzYLvBxfpOWy6
h2S9JpwFh/PsYlrUosd1udZlcCRuj82PjNVYLsqR3KPKxzbNqmzSMemYkCVR
R+t673uWemTIdnS9YU11F47EGSjhPmR/4s2m+YrI3sg1MX8h/uznmQ84i0u6
zoEM/41g0ePwmmKxSo6k6Do/Mjx2HRyJ31FhyNmx7vt0SclNTatD4qxIYq6p
qWMtpoonlf5Y5GeiQxYxniz8nsjT1rLmDZ46Sock7ZH1SPRlTeM1rWEfJKed
7RH6smaF7YVMswz0SDcj0vZDmn2KJSkT0CMVR4oeuR1Z1yMPgSNxzseB7X0c
aGY08z2YHzmJIc87RyLH8P0fPm7ir7PgSArkHK4Nw8dNetmix8261mVxZOxz
brvGRTmSAutQ8bVwW/hvA03HYF/fsu79264d33v4OYf9keFniNfbhSPD1wp1
t1mvF9OUmo7hz3befrguvEOvGfvZtV3naY7bJI6k3xm8Zq6Zx+9t7G/YOjgy
9AtuS/FuFY6UlIxlTYdU/DjRvZGFYznlt3PGDFnEGDL0ZA35sRNLurke2A+p
NMnczPYw69F+yECDxOekwJWoP6ZNvqyGLdMUfVkzp0GmoEcmoEcajnxOOHKL
ckZd68HAsGLfzfiw9a09q0kSN9I2Wu7un++6Vg7Wc/DeC3v1YnFWHEkR+l3S
ddExs1hw0eParnVZHEnBn3OXazwNR1KQphT65NBr0T11070zHRN6wrCfzaJz
1Zft18q1o03Xx/+egOww67NETSusb6Vjw8+EPlP6bJvqpNn3FrmBP/t5Z390
5Z3Yz46uc9b3f5HjNokjObg3u+v3dtUceVoP4IsY675fl5TcpMT61XBGZG4Y
UqXafnb9kFGGDPVH8IpdZE4kzobEfsg8557IotmXtWE2ZOtcD/RlBV+dNPV9
dXC2B+qQaepnQnrkUOpaty/9ulZPjzS8yHMib5neSK1Jaj2SeyE9PXLv/OuR
EhISEhISmxbrvm+XlNyEtB46lBO3bWqYkRnO6ZAFzPmYnBlLog7JnjpF7phy
UT+dooEhmR81F4IOGfPUifizNjFkrZ41hYz6smaWIVGTZH6kJF1yCHrkbbe/
U7GJZpWPS25sfqziSGL93/I58sDNj9yLzInkOR/7xrdVMeT+xdIjJSQkJCQk
NinWff8uKbkxyfrjNOiJtCzHfZFhHevyGBJ1SPbTKcCT1XmqRnTIzn46Lb6s
OWuQ3Rgy1guZtjEk1bIqD51C+ehwLaubCZlZLTKmQyqeHLt1rmu9KnrkFmVE
jzwyda2HPN+D61cHrpbVcKNlzH3XF8lcKSEhISEhIbG6WPu9u6TkBuRkEnqy
Tj0tUNezhnWsy61p9RgStM8cHtc8WefQH52fDvuyFmZ7xWXMkIXxvkE/ndCX
NahlTSMMaR/XGJLneOSGIbGWNbPzPOxsD+iHZA0ygRx6/ZGiR25HBnrknubI
vQN/vofTId2MSMpbBz5Dsi4pHCkhISEhIbHaWPf9u6TkOnISpPJgtb2Qof6o
fVnVbI9iuRok1q629UOeTod0fqyFp0Fy7SowJPZDRmZDhn46oQ6ZZG4uJPIi
M6TricwChmz2ZU3SgCENW9JyABx5x+3vUmyiWeXXJDc2P15xJLH+b/tzP/b7
dr6H4slDM+PD9kE6TRI1SNEjJSQkJCQk1hPrvp+XlFxHWj9W6oU0+uPU1pNO
FTt6vqwT9GVdvgbp1bIafszQEyc202Muhixqdayen04BdaxFvI61iR89T1bU
I9GXNWH9se6nkwS+rGm4nuha1gSYkpbjikNFj9zGRD3ye8td0iMPE/DN6VmG
dFpjz+uHRE3SzQDprfn/TSUkJCQkJC5WrPt+XlJylYleOhPw02EP1oJnRHr8
eHa+rKEGWfNi5W2hn85cda3Ajo1+OhEdssWbNQNe5JkedT/WwvPU0b6s7Kfj
vHXGgSYZerKGtaxjSsOUQ9EjtzB9PfLWrWvlQcWRqidS9UMSE55o3x0z34M9
d3b3gCFNH+Utw5C3RI+UkJCQkJBYaaz7vl5SclWpGBLZcep6Ia2fDvZCep6s
y2XIsI51Yrg1m4Ana4wbO2qQzk+H+XFi+DHz+NH66XRkx5ifThbyJDMk9zYa
T9Ys0CGxlpW1xihDpi5JgxwRi6rHpEcm6u/Yc88RR75bsYlmlV+X3Nj8tYoj
ifV/p+LI76vY8JVy/2js+iONN+se65FYv7oXMKTy3XFLCQkJCQkJidXFuu/t
JSVXkRNY1tjR48eJ6oWMs+PyeiLRT4cZErVI66kzp+6IfqzOT4c1Se2nk8f8
dEJ+hH5I3pYCVybMkNAPWfPTwbkeaQr8mEVrWWsMaWpZx4YniSHHaW6yOj7J
RI/cyvT1yJ29a+W+qmv1Z3vsA0PifA+c+aF1yJ5myYOTNf+/qYSEhISExMWK
dd/fS0qeZdq5kBPHj1P00ym4F7KwHq2qD7IIPVlPx5Btfjr5pO6nU+t/7MiS
uceTcT8drUc2+OlEGLJxLqTph/Q8WNlPJ80NX6InK/AjMyTUsrJHa62WVfFj
5viR1pOspkfefpvokduRdT3y4HCsalk1S2ptkX1bsSfSeuuwd+u+yerY3X3h
SAkJCQkJiVXGuu/zJSXPIsM+SFvHSsw4nZg+yKnVAieTSTDbY/merN5j4L7l
+emE/JhbD9asYO0x92pWF/XTsQzJGmTop8P8aPohU+DHFDRIrGVlH1b0ZXW1
rLnSHyk1S6bVeloOh2P1d+y5q1LXuj3ZVNfK/qw9T3O08z24hlXpj7TtxOwj
hjyuziN1rRISEhISEquMdd/vS0qeSbLuOA1rWZkhXT2prWmtzYY8Az8d8PBR
OmTur9f8dFo5ErmRHud1hmQ/VuunU8Q5MuiJjHnqoJ+OV8eaFZ6XTt1Pp2LB
hp7IqJ8O+LKyDuk0SaNFJolash55lfTI29+j2ESzym9Ibmz+esWRxPq/q+d+
7L1cHhyNPN/V0Jv11gGypOmN3OuZHsleubN3XD0WPVJCQkJCQmKVsfb7fUnJ
JSZyo5oLWeuD9BlS64/hPI/lz4a0DBmpY/VyLi8dPIfjSeunY7XF3HqpNtay
NmiPnp9OC0OmtrY15qdjPFkjXjopapA416PKETOkqWHVemSqtMhxwnqkq2u9
7Y53C0duRSJHkh755Yojx4Yfe85TB+Z7sA7JSTWstG13X9ez7t6i5fnXIx94
4IHyypUr676MrYqrV6+Wly9frr5vl2zStlUE/azo9e65556VvN62xUsvvVTe
e++95Z133ml/NvSzOs13fNFzHhwcqN+vu+66yx539913lw899FDrcfg6TTlP
LHLMMoO+q/T6F/HvzDr/VmxzrPu+X1JyGWn7ICmJG82y3gcJXjc1DXI5DBnW
sTI3ToAfsRcyn8tLBxky0gdpeh9V/yNrkhn3SFaZnsJPJ0c/1sBPJ9MaZNRP
x/Q92u2JX8eaRP10HEOOiRvV/tRmMq62VzkYoB4pHLkdiRz5/R5H7sN8D6tJ
cp2r8tk5Ufqj1iorjtw7Uam0yXNe10r3tBf1/u40wVxA9/t0j0xJzLCKEI5s
Dro/Zwbjnw0y3Cx+W+Y56fvAv1/888LHxKWxIGadxZDCkdsT6/xbsc2x7vt/
ScnTZMiPthdSMdzU9kHiPEirQxZnw5A1PTLwY7UMmUX4sQNP5lGGNDWspheS
udGrY430Qs7lp6M40DAl++kYTVJri2ncT8f2S4KfTurqWFMzEzIx/ZTEjCOo
ZbU65Dg1S2LIVNe1Gj3y8zT34473KDbRrPKbkhubv1Fx5K+XVo+89XLFj2PN
h6hFer2RPVfLSvx4cOIxJPPleQ6+v7yI93eLBnMcJd3zr+v1hSPrwffsxGh4
r/7ggw8u/DNb9Jz0fNYfcT/9/JhLYwz6+OOP2+OWFcKR64l1/63Y5lg3B0hK
LpqNXjqKE7UmqWpYc2C9M9IgkSE9fizidaw1DbKzlw7rkXmJ8yGJIZWOaPkx
4scaqWNtqmlNcuiFhPkeWY5+rMCHEX705nhE/HTq8yGdJysx4ph9dYgZU90P
OQaGVHrkEPRIqWvdkvT7I3eII40eabkRZ34cuD7IPVPHugMapGJIw5fnOYQj
5w++N1zmff5Fj2VwDjEZnYO4LxbMdU064DLPiZpijB/azkt1sLTv/vvv73yd
mx4XnSPlb8X8sW4WkJScJyeQPj8iw7l+yAkwmNMfw5key6tjDTXIbFLnx/kY
sihxLmS9jjV3/jmF6YNEP51YHWs+W4O0vZFYx5rlzk/H+LF28tNJHG/G/HTG
OBvSsKPVIlmDrLaNiB/Huq51VDHkqNrWB468TfTILUnWI3+vfB3XtRo9khny
lq1n7UV9WZkfVbJGKRwpEYTogcuPZXAk96A18Rf/3EgLPOtzslbZxg9NvXLM
XIvU4G5qXHSOlL8V88e6uUBSsmu21bA6fpy6+R2qnrVp/uPy+yDbNMhoH+RM
DdJ56TiGnCjtkfsg06COtVGDzOIMyf2QXh2rZcgcvHQK0/9YBH46yI3aTycJ
9MeaJyv6sYZ+OkkGemRi+iFZh9TbRyZp3dcjH1ZsolnltyQ3Nn+z4khi/U+o
/kilRx6MNQ/CfEjug6TaVe6H1DrkiWZLYklgyPOqR7LmESZtx/1t9z+xe3+8
b6L7Y75/pPtsvhfHe0qq4UMPCtJn6LWb+ofomNDvhO7V246ZFXS/ztfE1xrz
UMEatabPLRaz6hS5brJJ8+L9zBtN96Z8LfQ5sE7GfjD42dA6/SxC75e2z5A0
tfAYWqfXWUa93jI4ssu/iczrc7LoOfn71Pa94OcQc2Lwd3uZXiyxz5d/x2lJ
r4W/V7Sc9bONfSeavkf4O085z+88RXh9/P1vY+1t/Fsh4WLdbCAp2SXbaljR
k3Vi2Iw4sWBWLEIf1jPugwwZcqGZkIXXB1nALI/CzIF0Mz1yX4MMa1gzX3uM
zvRAhuT5Hmnhz/TI0E8ns146zJCWH2N+OmNgyMSf6dHkp8O9kE6HzJQOOQSe
9DjydtEjtyNRj/y+cmf35Yodx55/zt4+8OSe82jduXWsmHF3z7HjLuR5jPB+
iO6v8L7stBxJ56N7LPQl4fsnfl1mHX4OepDEmIt5jO89Y8fMc39Iz8XPgM+J
98VYr8hczK+Jvhld/TfD6ws9VcL7dt6PjDmLI/k98bXi89Azhp8TfgYhv9A1
hD4z4b30aZnntBxJn2sX5uP30UUXO805+TvSxgzMUvgc/D7Q/mVxextH0uvw
e4j9bGOvN+t7FP4u4ney7Xc+9vvLNcBNx8V8a7b5b4WEjnXzgaRkW8ZrWEMN
0vQ9Fo4hnY/Ocnsgu/ZB1hjyVH2QOBPSzPMo3EyP1j7IzOfHkCdT0wvp+bGm
PCfEr2PV3qw40yPzZ0HO8NNhhky5ZjXVWmSSBnM9TKIGyQw5Qj0S+yOvih65
Pen0yL/++u8vb4LPDvGi9Wjdd6nrV8Gbdb9n9Uiuc905536tTffJp+VIvtcK
dTAKvB8L+8rw+PB+i+/Zwu14TxtqO23B9/F0bPj+0UMlPOcitWrMzOG14z1y
bD9fB9ZVzuLIUMviz52W/DmFnjG0zp9HyPBNPYDoR0rHniZOy5H4vWmLLjrh
Ms7ZhT9jv2PIP00MtAi3t3FkjKuIHdFfCKPte0TH8bXiceHvPB7T9juP+8Lf
Q/oM+LXCuuNt/lshoWPdnCAp2ZSeBjk1HGl7H7GG1TAk168Wy69hjfZBIj8G
fZCLMSRrjw19kOjHmkNfZIsG2TYfkrmR+yFdL2REh7T8CPoj+ulkea2eFetY
kSXtTA9Vv5ob7TGDuR6+n84IGJKZkvnS40jRI7ckAz3yVqBHHvi1qjwfkn11
rAa553TIHZPnOc6SI5vu01CbiAXfs4X3r3zemI5Ar0X3jl29SVD3abrX588g
7H1b5N6Q+SDkLfT0jL3n2FyWWRzZxHT8fprqZ+lzjd1/88+L3kMYfF8+z2eB
TNElu8R54Uj63OlnQBkei4xGn/k8elobRzadi/ko/L7M+h6xHy2+r1m/803/
VoG1C7Gg7x+/N9RNt/lvhYSOdbOCpCQm8mJ9jgfXjrInq6slrWuQy/XQifZB
Gn7MIn2QHkPO4aPjPFgL6Hs0fZBGh/Q0xaY+yCzCjA38WOuFpGWS29pVrmNN
MvZo1X2Q1jsnQ60R1kM/HZgL6fvpwEyP1NSxjnw/HdYfRyZZn+T5kZ9/7sXy
9ttEj9yOdHrk60x/5B7okZontb/Ozr7ph0RfHcOXO/tOh7xpdMnzHGfJkU33
XLPu5Ztem3WE086Ux9douhemaKprXPTekOt8MZjbmDPxevj1u96b8rU2fa78
Wm06DN1bhyyKOiVd52ln3wlH6ujyOxYGaoHz9Nm1cWTT6ze9f2bZefS8RX7n
kd/a9NfY9Wz73woJ4UjJ9Wfon2O3NfnoMJdh/+MZ17CGGmR0HmSsD7JzDavf
C5mhFyv3QXrerN36ILl2lbcnOMfD9kKin05u/XQyT4fMo7Wssfke9Xkevidr
ggyp9MeIn87Y99MZIz8ahqRt1q/1asWRt79XsYlmld+W3Nj8rYojifU/WXHk
/6Z9dqxfq/FnPTDMeMttwxrW3SBvVs/buSUcOetYjC733m36Vttrh95A7HFB
94/z9oyx/jGrHjPW57bovSG/Jr/vsPcx1FW45rWp9reJI5vum3k/90zGklkT
zx3zDKH97M+yjJiHGWNxUTiSgll/nuPaOHKWF214XJf3FsYiv/P4+k3fV8oY
V2/73woJ4UjJ9eYE16F+lXiysLM8pjUNspkfz7APcuLXsLbOgyy6MaXrg2RN
0tWw5qaGFfsga3WsoEM29UGGMz0y1iEVFxbgx+r76bT2QqZ+L6StY23w0xmZ
fkjrx5pm7X46CfjpYF8kcmb1XKtHfp7qWkmPFI7c/ESO/H7LkcSNzpeV53v4
sz1uQS0rMeaO8XDd2e2p3snzHOvkyFk1YrHXJrbCXrGQbbreI3blidjzFr03
ZM2R79tDTgznPbAOGN57n5Yju2R47tBjEzNWgzlvnJYjUQ9qY9tFfXbmPWcX
zS7ms9MlkJG6RhtHNr3+WXDkPL/zbZ6nsQzfxzb/rZAQjpRcfUbnd7AOybxI
7FiYnER8dGrMuFx+jPZBFnF+XLQPMvfYMeyD9L10Gvkxko0zIbHWFWtYcSak
9dNJ6wzJ+mPm65B2RuTY99NJwE/H1rIaPx3uiWz00wk8dRw/poofRyPKrOz3
x+rv2OeUHil1rduRWNdKeuSXy73DkfNl3eN+SFfDegv7Ia2vzonOWz31/F3R
I6PH4T02xllzJAfdA9J9IjFY6GnZJdalMRBz8DWG3juhPsQ6Shin5cjTMB/9
3Ilr6RrDe/TTzP84LUdSdGHELly4jHN2YcSmuR/0ObbVDneps2y6xth5toEj
TxPb+rfiose6mULygmbNfzXw0PF0R6wvPdsa1qY+SKxjtUyZLcqPOA8y99Yz
y5C5r0E2eLGGtayNGiT0RYYMydoi1bC2+ulkrnYV61jTsBfSMmRu/XSSGkNG
/HTGgZ/OOKhzHZt+yVGmOHJYPe6zHil1rVuUfl3rTeOzY/sfbT8k6I+w3MHc
1Qy5syd65Ly9U6viyDDQ97TL/e26ep74nhT9MJm/2DOE+xBpPeYvsihHdumP
nDfQ//I0c/GWwQuz2I0/txibL/uc7FHTRc9H/uzyWXblmthrYSzKkV20Vn7v
/N4W+Z3v2h85b2zL34qLHmvnCckLkzX/1Smyo+uB1Nqj6YvkPsgi9GI9mxrW
WX2Q7KNThD46nRjSr2PNrSbJfY/c++hmeShNklgxDXTHwEuH+yD5cRIwpPXV
8fogczMjsu7H6jFkOMcj9GPFXkicC8l9kKaWVWuP5KXjuFEzZFrzY/X8dUYp
MGS1HGqGHFbrvYHWIzVHvk+xiWaV35Hc2PztiiOJ9a9oPXL3y+X+4cjUsjpP
nVaGNPqjZsgTszxe8/+bnm003U/N4sGm2rqz4kjiKp5/MO97icW6PBixtjV2
b4r+ILSM9ZMtypHMH+E8FgzuN2O2oM+Jt7UdswkcyXzQ9P6afIDP4pyzGKjJ
CxV/RrFAf9J55hAukyObvrsc/B3H35tF/+2I/+2jiZnZd4iex78r5+VvxUWP
dbOF5PlOZkevbnUKtauq31DXr7r5HYbnilj96vI0yCKynDUPssaMc2mQYR0r
8CN767Ava4c+yKZeSOyD9DXIvEMfJDAkaJVKj0xgvkfopZNg76PTIMd2NmRa
uvkeXJ8KHqyhnw4uR8CQVQ5Iixwl1bak7A9G6u/Y56++YDhS9MjNT78/8uat
L5W3Doa6NpV9WUGP9HxZzQyQ3V2sa9UMed45krkl5BW8dwrvkXFe2qo4Eq8n
5gvC99+LaE2zZsKF99mnuTdED9bYZ4s9iE3vZVGOpM8Q581jHSpdF3+G4TnQ
eydkKdR2lqkZLRo48xCvFX+esfrbpp/1ac6JM11wP8/FiLEgcmL4ejgvcd7v
3jI5sm1+ZJM+vShH4jxN+r1vmlWJ/85xXv5WXPRYN2dInt9UDBn0PvJyYrxz
uIZV9z5OO3iwniFDRvjR88TJjBbZSYN0syBjGqStYQV+9Pog22pZ23oheRZk
rI6VGTJDhkztfA/dBwkaZOirE9axejxJXjo5zIV03qxjZEj20gm9V0M/ncSv
ZR2PtP44NPWso/HY1LWiHil1rduRyJH/vLyx++Xy1v7QaJGmrnU/mBPJHGl8
WZkfNXtSHp37ula8P6J7HbyvZd2BtQf086R7Mb43xDjLulZkFr5e9GukZZMf
ZCzovhNnUITvsUm7Ou29IbJiyBF4T9qkwSzKkRR4n8/nwM+wiW1ix+DndBot
cpmB18rfEbzOJg2v7X0sek76fmEPKWtkbd8titj3HI+j9XlnryyTI5s+k7b3
dlpvrdjvPW4L/w3jvPytuMixbtaQPF9Z89Dh7eEMD9YdDUP6vY9n48Ea638M
r4cZ0vPWidWxduTHqAYJfZDIj7U+yIAfm3ogPS8dnumBGqSpY3V9kK6ONYv4
sVoNEvgRGdLvg4Q6Vtv/iDM9nB8r82MC/OjN8vB6Iv1aVubH4TipHmstkpaW
Iz8vda3bk1jX+uby5s6Xyz3DkbvoqcNzPtiXlXTHXebGY8OWx16e56D7I+Sa
kF1Cz0Na5/vmVXMkn5+uEbmG7uXoHm5Rnxd6P+F9advcudPeG+I9bnjNXeoW
T8ORFPSaoU8Of4ZtWmboUzLrc1pX8LXid2TWdc7i4UXOSUG/X3RO/Nzwd2jW
ewiPW7S3ddkc2XaNsfd22p5oOi72WvQ9bvq9Pw9/Ky5yrJs7JM9HxvgxrF/V
vGZqWBUzTv3+x+Js6lej/Y8zNMgoP3aqY/X5MV7HWtg+SLdueLGlDxLnQXr8
iF46iiVz6IMsXA1rOqMPkn10QoZMIr2QSW59dOp1rIYdrQap9cSYH6vrkwz8
dEbgp1Px4lDxpGZHxZLjNKJHCkduRyJHfn95c5fqWkeuNxJne4S+rLumF9Jq
kscqb1bbKCUkJCQkJCRWF+vmD8ntz9oMj6mb31F49at+D6TOthmQp+fI2gyP
GD+GGmQTPzYypM+MjbMg2TencAyZI0OGWmTgo9M2D9J56ZiZkNgHaWtZM6hh
9RkSZ3iEMyEVQ4LPjmJIr/fRMaTzYgWGNLWsHj8GvZEqqf8xSQ0zVssh17Cm
lh8VU3J/ZLWkuR/TUuuRt93+fsUmmlV+V3Jj83cqjiTWf1L7tUJdK/Oj7Yc0
S+upw746e8SOx2pJj2+YpYSEhISEhMTqYt0MIrmdOYGMzfAopsyQULtaINet
2H8V2BHrVxtrWOfiRzxXrIa1sAzpzfJo6YOc6aODPZDYB5kbfkywDzILGDKr
ebF6MyETfyYkM+RY7dO8OLJcSY9Tw5fEj4mua4U6Vq9uNQn4Efx0hub5XMc6
UP46oEHa+la33vPqWoUjtyPrHLln9MjYbA/kRz3fg5jxyHnsVDx5wzxHQkJC
QkJCYnWxbh6R3K5EduTU2yagQU5gfgfXsob1q2c/AzLGjuEcSI8B55rl4c+B
bKphTY0fax54sWYz+iAbfXRQg8wCL1bsg2QdEnx0kqY+yKbZHonTI3kmJPMk
16iO2VMH5kIm7KUDdavDgCdHXj1rCrWsmg9HphdSa5DIj4YrzTarR37uxfIO
qWvdkgzrWjVH7hh/nV2jQ+7eOrFzPXZusa/OsallPTH1rKamdVenhISEhISE
xOpi3Vwiufk5CZZe/+PU1a/aOlZTv8rM5XvohP2PZ+ihgwyJvDjRjLhYD2Tb
HI+GWR5FoC/yPMiQH4Eho/yI8yBz3Qep/VcNU1p21BpkBn2QvD7mmtZYH2Q4
ExLmeqCXDvvo8DwP4kbuh7R9jqHuCNzoNEj20YFeSNP3yLzIPDlCPZJzmJa9
3riclKJHbldG6lpZjzSzIW1aL52e2r9z60jz5J5hR7Pc2RE9UkJCQkJCYtWx
bkaR3Nyc4PoEcor9j65+led34AxIy4/Ik0vUIGP8GPNfzbEncuEeSHd82A/p
9UHOM8sj4MdufZC5P8vDeug09UE6PRK9dJAfPS8d0CXHiWPIBPjR9kGmTne0
vZDBDI8xpHo8QoaslkPHj0qLNH6suhcyzo+UgypPvP7IDyg20azye5Ibm79b
cSSx/qcqjvwBPfeD9Ejixn1Ty7pr/HZ4rofRH3U9K+iQxsP15o5eSkhISEhI
SKwu1s0qkpuX6L3K7Kj3TVTfIzNbHnjnTIwPq1e/Gp0BeYY9kMiQYf2q4cRo
D2SjDok9kEWDBpnZOR66FzL3+yBPWcNqvVhz8NHJoA/S9jgafkwjXqxYr8o6
ZOI0yQT6ILUWCXWrPAeSmNHWtCaKBfUMj1T7sRIbBvM8UH90eiQwZMWUzIda
gxy7Wtax7o9kvx1myP5A906q/kjgSNEjtyVZj3xK65Fq7sdIaYs7lhlP/L7I
W2a2B/IjM+SuXooeKSEhISEhsdpYN7NIbl6idw4/drM7sH51YnVG652zgvkd
0UStMWDIPMaOnXogsX+ysFzp+bAWpoY1dzWtno9OyI6RWR7d+LFwGiTqjzzT
I2vgR+iDDGdCMkumtVrWDOZ55G6eR60P0umPY6M/ch8kapLjJMKQwxTqWE3d
KvRDWn8d9tsZaf2RkzVJ5sjPKY4UPXI7EvTI1/1AeaPiyF3WI3d74KnjfFk1
Q54oPx3FjXuuJ5KZUuZ+SEhISEhIrDbWzSyS60/0WZ3UvHOQ14xfTjC/Q683
aY9nU79qtzPrTSaNMzzymH9Ohx7I2XM8nAaJsyBrGiSy44xZHkkWzIeEGR2O
ITNXj5qlAUOyF2vm9UGmoEcmwJBJMBPS+uggN5o+SKU/ptgHGfixBh6svh9r
6umQrDdqHTKiQQbPsQypuDIxemRSceTI6JEviB65Nenrkdd3K47cHylNkX11
dD2r4cc95sSKKQ1PegzJmqRwpISEhISExEpj3QwjuT52VEuuWWX/VfBdnYSz
Hy0zTvz61Zr36vLrV2szIIEf+bHlx9yvY+2uPcbmeOT1OR7hLEijQbb2QIaz
PvI6T1oNMisCdgzmQdr+yEwzJcz3qHmvZr7+mIT6I86ETDOb2Avp5kGm9T5I
9NDBuZCJ40f00xl7fAg65MjpktgLOYBeyIHtjdQcqfsjR9V3WfTI7cq6Hnlr
b2RqV1mPdBqkZUheN3WsqEOKHikhISEhIbH6WDfPSK6eH0P/Vee9atiRl8Bo
E+asFdWvNnrohPpjpAey5qHTkR9tHWzDHA/sgQxrWKMaZIceSOTHFB5bfqx5
6EANa+ClY3sd7YyPeA0r+ugofsQ+SJ4DCX2Q2osV+DHWBxl666Afa62O1TGk
X8cKPjqBBqm3J0qLZJZUemSP61pfKG+/TThyOzLgyJtfKnf3hrYn0tayGp70
aleRIa0mqRnzRrWUkJCQkJCQWF2sm2skV8+PU6xf9Tht6tWvOv8c1hhj7Ljc
LIJlyI+eB2vQ6zjfDA+nPaIHq++/WtRqWPXj5c7xsHWszIl50P9oPXRMTWvm
90F6MyDbfFixftX2QWZ+H2TCfqxZoEFqJkya+iBDPdLz0gnrWP05kFaDHNbr
WIemfnVADGm5kvXIxOqRf/j558vbb/9gSbWSmlU+Ibmx+XsVRxLrP12+7q//
M61H7o/AS+fI9Ef6njo3jS+rZUjix13NmTeq5Q3xa5WQkJCQkFhprJtvJM8+
X5leK797+t3lf1n+F+Vt5SWVf7P6763Tt2pmnE7tTEVXu1rY2lVdvxoyX71+
9Tum36HO/abpm+bmR76ukCXRf9WvNw1qV+fy0EF+bPJghRrWoH615qGzyByP
HHolraYIPqzgrerqV0P9se6l4/my4jxIr37Vnwfp9UHCTA/ug0wa+iDHUM/q
9UWGDMleOjjPA+ZEejM9wl5I1CDVkpmSclye9IbV99fokVLXuiUZ1rV+qbyl
9MjjRl9W68kKeiTrlKRDXjdcKeHHAw88UH3Ol8p77rln3ZciISEhIXEOY92M
I3k2yfojMSQxI3Pa367+w8ffOv1W8Mrh2lWc3eH6Idt6Hx+bPmbPOS9HFsCR
fC1evyPojzloj9H5HZ08dJAfJyV66BS2/xFqWMM5kAvO8aj1QOIcj9yvYcUe
yJR9dewsyIAf09zri0xBc6wxpOVFNw/S9kU29UFG/HNYd0Qv1rFlQ9cHObDb
Ai8d0COHPEOyWvZRh4SeyMEI+VEzZL/K45NR9R3iulbRI7cjQY9UHPlX5a39
QcWBR2pW5I5hQ0+HZHa0qWtftQ55rJ5/Y/do3f93unEhHCkhISEhcZaxbt6R
XC472nVTt/r3pn/P6o/PT16w9auPVtx3Z/mfq31vnbzV8BrWr3b3zXll8oo9
V1eODOtXLUdC7WpWTGr+q4oBswZ+nMGOrgeyzYM19M9xPqyh9+pcNazBHA/F
qejBmvk1rJntf8QaVkjQK9OQJ9lLB711ghpWrF9FHx2rTWIfZFLnR3+eB3qx
ZqBBZrU+SE+DRF4MeiGZF7kn0ufHUdnvj8vBIClPTthn5wWpa92aZI4kPfKf
ldcrjtzdd3qk9mU1uuOOP9uDmJHrWokbb5jlzZ3DKoUjwxCOlJCQkJA4y1g3
+0gulyHt7I7ppHx++rzlM8WQ04nyXeX6VeJH2kf1rvXex+6+q3+n+o9fpwtH
hgwZ1q9a7XHiOBFnQXb3YC28deyBDGdA5pYf2Xu12xzIWTWsSR7wY1jDavmx
0P2PgQdraw1ryzxIf5aHmwc5hh5IrUeGGmRa0yDH0PuIPjqOIYEfwUsH61h5
fRTUsBJD9kMvnWHieHJE3Mj1rFqD7A80Q+q6VuRIqWvdjuS61qcqjnyzrmut
OFLpi7eCWR5mnof11FFp9McdvbxJy5uHaruEH8KREhISEhJnGevmH8nFuRHn
Pk6BH3l2x1umP2y1SOt9anofC9P/yOz3yckngR+716T+8vSXbb0s/dfEkQXk
xPBh1IMV61nzhmz1Xp2U6L/qmDHmowMzH009a9RDJ8aPeTs/hhpkfY4H6I9p
UMMK9auoQ6Lm6M3ywD7IwI/V9kEmDbM80tCL1e93DL1Y0UdnbGpY/T5Inx+x
F9KbCRlqkLZ2FWZ7hHWsA8pEMWTfbGeO/EPRI7coQz1S+7UqrZFnRe7E61iZ
NZUGaZjyptIjjxRPSvghHCkhISEhcZaxbh6SXIwfp2buI89/1Dw5sXok8dnX
I9dx/yP3Phqe+9tT/Zy3TN8yN0NyPSvl85PnoxwZnd0BybqjV9dqdMdHCt1z
+fXVNb5cvKJ8fNAr6Bunf6d8dPJYQ/+j3wtZhPWrdoaH0yOt/tjS/+jx5Kwe
yA5zPJp7IOs1rDWeBP2x3gfpGNLrg7TaY32WR+iXMwbtcQwa5MjyY+bpj1p3
NH2QzJS2jjXxNEie/zgEhmQvnbCO1WNIo0kyS1o98nPEkY8oNtGs8knJjc1P
VBxJrP+00iOv3/xSubM3tLM+bu76vjpKczTbrpt+yJvcF7njGPI8c+SVK1cs
Dx4cHJT33ntveeedd6pttKTHL730Uu24WRz50EMPqX18Lsq77rpLne/q1ave
c2kb7b98+XLjddL5+BwSEhISEuc/1s1FknPyo2FI5sbpFGd3TD19j/10iOu4
97Fg7xzzmGtSF/FY5WM1g048jmSGmxQ4X8Ot58CQtGQ2zAvnoUOMqPTU6d+0
74XWiSuxH/Mdk3f45w78VwvFipl+zP6rwQyPKEPyduuDE+fGmXM8sA/Sm+OB
fZBujoedA5n6NayhBlnTH5M88F7lmtZUc6WZB6m0yXGEIQMfHY8n2X+V14eg
LY7QN4drV1GThLmQsZmQZqbHMPDSUX2QQ82PyJB91iOr5XHFkdWPXPTIrUrU
I99cXiM9kupadx0v7rDHjvVl1TWs13eOoa71qLxx80jXt6peyfPPkXfffbdK
XicGZP4jFgzZr4kjiUX5PHgu3EZJr8vx+OOP2+10fCyIMWn/gw8+uPwPQUJC
QkJi42LdfCQ5Bz8yM5q6Vdpu5z0ahnQzHx2bPVbxmD+3w+mOxHxclzoPQ9LM
kPC4qB5ZaH5y+mPhvHOg/9HqkVC3+mjhPGCJGz8x+aTdR/rkN06/0fZ3Ij+G
PZBZgfqj4cOAIbv658R0SOZH5E2PH9PC82FlHx3XK6k1Sas3LtIDmeAsjxxm
QPJcD82LykuH+TGJ1K1CH6SnRxrfnPEY+yA1M6q+R9YgeTvWsY7qPjqWGa0u
ydpjajXInu2D5LpWs264UumRxmfns6JHblHW9cjdW0OlJ3I/pPNn1bWsrENq
XtQa5A2jQeq61ouhRzIvIt8hE5IOiIzXxJG8nZ4f6pj0mLbHtEfeTrpjGHQc
X2NMG5WQkJCQOH+xbk6SnMGPtvfRsePEPNYcNjW636RWu2o5cvoosKNfu7oI
R1INK9az8rV8fU2PLOz3zLLdxPdfZe0xrGslnkSO9OtX9bmJK3n/c9V1+P6r
hZv/yPwYzIDMgrmP4XrIjbU61szXIFNPgzT6Y4L8mDv90fNizbwa1gRmQXbS
IKEPkv1zrJdOqhlQ90FW7DhyrFjTIJO6Hhn66KCXjtIfjQ+r9dOJeOkMjJeO
82Y1/Gj0SMuUA72ua1hZd0Q90vFj36xbPfIPhSO3JwOOvPGlih2NHgn6400z
+4N9WdV+5cvq+FHt23HzP85rIEfGGI7YkWtTcX8TRxIf0vNj56IgPZF1Soz7
778/uh2Paat7lZCQkJA4X7FuXpL0uRF9c3T9qtEfp3rd9RZOXY1qgT2PznfV
ceRjjUy4CEey7kj1rNj/iHok8Ru9rz//i1fKX/jV31XXjzMb88A3J6pHTh4L
+BJrV7X+6DjzEahhzV39KnMlzn+McWNYw9rmn4PsiLMfwUfH+uekjh+zYI5H
rQcSPVoDdkzH8VmQI5jlkSRuFiT7sEbnQXIfJPrpBF6sdu7HWM+CHI2YGzOP
IUd25kfqa5DspTNwOuTAzvAAfgxnegz8XsiB8dUZBPyoc1wenYyqn2/FkZ+T
utbtycBn56b22bF1raYf8obpjVS6o61jPbSapOJHw5DXTZ7XYI4k9msKZjzk
uEV9dpBbMdo0R9ZEqf5VQkJCQuJixLr56aJns28O1K9a/XFqfU6RH32GdLWr
Z8GRxI7K+yZ4Pl0X6pGkt1E8/fQXyv/6nv+9zM21a0/U+vzHmh4JHKn8ZgN+
ZKbk4x5RHOnzY5b7MyEbtUfUJ7vM8EB2rHmxOn7MoIbV58fM64NMQX9MQH+0
WmSthpV9c4Ia1hRqWI2PTuilE7LjGOpXLU/WNMjM81y1DGnqU4feMqhjBR1y
iDWstZmQyI+ujjXUHymp3lVlPymPT4Zaj5S61i3KhrrW3WMzI9Lw461jw5a0
btjxpqthvQ5+O9cuiB7ZxoMxDbELR5KWSecn/qPns1YZ40gK7smk53JQX+Ys
zpWQkJCQOH+xbo66qFn3zZkY35yJY0baDlyFMzssP/L2STj70fnssA9Om1dO
F5+dsJ41nPv49cb79Y3VuYiR6L195j/8SfnffsvPVBw3sdzm+avmbRz5qPFr
/foaP3LdquXI4hHLizy/wzJkW/3qjPkd6L9qZ3jkheVGrTWaHsjM1yBTmAWZ
wCyPmIdOyI21Hkie45H4/GhZMc08/TEBdgy9WL1ZkOinYxhyaDTIuhdr4nuv
mr5IYkM6DtnR8mPgnTOMeLH2YJ5HON+DntcbuJ5Ieu5JxY99lePy+HgEHPmo
YhPNKlckNzY/WXEksf4zFUf+oPZrvaXnfuwYPfJ6yI/kybprZkXuQu5o7x3O
8xpdODKmIbZxJNW0cr9jmLg9dlzoycpaKC0lJCQkJC5OrJunLlJOwuWkzTfH
MRpqjOy7ajVJfLwAI2KNahtDFqBdzpOf+cwXy7/1d99q9UhiNcuPwIz1+lWn
RxKfht45nE6PfFTP8Mh1b6T1x4nN74D61db5j6H/ah7451iG9OdAppnf/5gY
/dFqjlldf7R1rFF+dHrj2M5/dLM8WINMarM8fK3R815FTdKbBTljHqSd5zGj
D5LrWIdOg/QZErxY+74X68CrXQ10yOq5vd7YapKkR1ZfJfHZ2ar09chrPPdj
1++H1DMiD/Wcj5vOY4cZ8vqOq2fl+tbzGsvWI3mGB875oOeSJkn1qk11rRTY
i8n+sMydoV+shISEhMT5jnWz1UVIrF2doG8O9z1GfXMKzzeHdUifHdvnPXIN
alvNKnPYJ6ef9JgxTNr+k5O3KqbzsnTrPIuD/FNJQ6TX/cyn/6T8W9/8U3WO
LJo4srDa4yOeHpn7DGm4LtQja/M78kB7zPz61dY5HoH/qqtdBf9VM8Mjy1Kj
R/pzPMamfjUFfrR1q5mvNXpzIBNgxSR3PZBGk3R+rInfA5mw/phGeDFgSDXH
I+KjE9Ug2Z8VHoezPKwfqz/LI9QkUXOkpfViBd2Ra1mJG+k5PV7v6WN7rEdy
Xesfih65PVnXI6k/kvscNT/CXMjduqeO5UfWJM3yvAZzXdtcxq79kVyD2uTZ
Q8FMGuNICuZQek2eBxLz3pGQkJCQON+xbsY6jxl65mDPo1oSmxkN0mM1y4+o
OxaNMzu61KHGODHkTOI+ZMjauYo6V+aTSc17leta3zR5k+Ihis98ZhZH+n2O
uadHBhzJdaq5qV316lof9etWYwwZ8c/Bda9+NXP6YzM/6nkdWZoG/qvsn5O5
fseW+Y8eP1oPVle/6nMj17DquZBNGuSQPXOwhjXw0XF9kMyPmfZfHacBP6bQ
D5l6DBny47A2y6PZR0czpJsFGfZC2j7IgWZGyl6f62BpfVQenQyUz85nhSO3
KH2OJD3y5t6gYsGKE29pX9YbO4eeDysm17BiTat67s3zz5HhTEeOefxa27RG
DpxL2XY9xLXMrzIzUkJCQuLixbqZ67wlzuoI2dHqjtOp88yxvjlB3yMwXNPM
ji75rdNvtV41PKODkrx3WD/8yelbPYbEGR6qpnTiuC+H5PpUfmw5UvnszOLI
wjunr0cWRo98xHKk7X3k2R1FqEc+Gp//GKljbdIebf0qMV+eO56MzPDIcIZH
zYMVeiAzYMjM1atahkx9TdJ5ruZ29iMzpJrdYdkR+TGr9UC21bCGPjqWFUex
GlbWINv4Ufuv2hrWWh8kceGo7qNjeJG9WHu2nhX5MTH8mHj82BuMvLrWP5C6
1i1Kv671FeJI6o802qPyZd1xmiTWrV7bcTrk9ZvHzrP1xsXhSOJFrB+lOlT2
Sg01wVl6ZMh+dC7SM7FXsim4lpWXOLdSQkJCQuJixLq56zwk6o/u8SSoYQ08
V7FutShc72OLb84i+crkFeu3wzWu+Jg4M2RI1BaJJzOjR9b4MfPnd3h6ZCtH
svdq3XcV61c9jixyV4vKda1ZUdcjmR8DbozVsVp+BP/V1HqwFs5zFXoYrXdO
TX/MavMfcQZkrXYVGdLoj14NK85/pFpVO8cDfFYjHjq+76pjSY8fxwE/Yg/k
2GmQrTWsHlM2zPIgvXFk+h7741pNqzfPw+uDdDWsof5I2VdLve/oeFh9H0SP
3K4M9EiaH7k3sH46ypN199ib62G1R1jXy4ozb5qs1s9roP7HuiMxI+qGtC+c
xdG1P5L2M4tS4v6m4HPz8yUkJCQkLl6sm8G2OdEvZ4rMyNqjnfdo6ldr8x4D
z5wZvjmnYUnSCKl+lbmLWPKtoQ7JjBjokZYfc19/DL1yuuqRznt1YrVHvi47
q4P0yALqWrEWFWpXY3pkyI05cGNYw4r+OWlQu0oeOsSLPBsS/VdrMzyYHSMz
PNCDNQlnQGL9qtUdXe2qN8ej4r/E9D7afkfUH2GWhz/fA/THYYQfR8CPI/bQ
aebHAfKjqmUNZ3mMPd8cqzlyPeswaZwHqRkyqGE1/Kh1yLHxbB1VOS4PSY8k
jvwsc+QzhlWelNzYvFJxJLH+sxVH/nNd13qrr2pZeaaH4knof7y2G2dI1iHV
+gXQI4n3iBWJ25gniQOJ6WJ6YJtfK+1DdmS/HWZR1hmbeihxlqTMjJSQkJC4
mLFuFtu2DNmR+GvKsx6Nb04RznuEvkfU/OrsuFx+DBM9czxu5PrSoOcRtUfL
kJHZjzHfnDhH6ppUnN1RgPdqVuRQu1pYbRJ7GWPeq00aZMx/Ncv8GtY0czM8
dK2qS+2fk1n/VTfDg7XIrO6/GtEgZzNkFvjqgN6YBnM8rJ9OMMcjYEfmx3Gt
BzLUGutzPNp7ILmG1fVBts6CHGhdss91rMO6Bsns6DEk91FafjQM2XcMyXpk
9ZUyeuRjpeiR25CoR/6Q1iN3B0qHvGF8drA38vqu3w95A/ohWYdkljyv0cWv
ddXBHNnm/SMhISEhcb5j3Vy2LenVrarexwn0Pk4Nn01dL+Fk4mmPtuexCH1z
zj5r/BhJ5sc8ZEtmxwgrNjGkz5Ff9PRIxXnB7A7Fj7nrfbTPCXxyarMfI9yI
2iOus9bo9UAyOwYMyfWqWeC9mkTqV9E/J4V1q0eO60xJ3DhKM8+XdQw1rNQD
Sfxn90H/o+eZ09gDCXWsNR9WrF+Nz/EY8PNj/Ah6JNex9iM+rI4fHTvG6liZ
Dfs946XDvZF9V8d6MtBsyfyoGLJXLas8OhoGPjuiR25+oh75lvLa9b+qOLJv
+iLBfzXiqaN58dirZaXltZ1Dlec1NpEjWeukpYSEhITExYx189mmJ3uuqseo
P05Qd2zoe8SeR2bIJfQ8duHGRv0x0CE935wcdMgm7bGFHdE/h/iLgvXIrPp8
cuuR42pXLf+BHyvOeJzlv9rW/xjWr6a540aPIcMZHmlYv6rZccz9kND/mIYa
ZOjBGszxwDpWXb+a2n5Irl9V9azovxphSPs42gPpZkFiDevQ1rA6roz2QIYM
aWtYDTuaetaaDjngPsix9dGJzfIIvXR6PdYjR2aeh+6BPOE6VrMeMuQJ9Ef+
gdUjhSM3P5EjjR55a6CY8OYu+OmwJnkTalpv6P5JVetKnq6KKw/LV3YORI9c
QXDtLF0P19WGPZkSEhISEhcn1s1pi+QXpl8onz2j/56B5TPTam2qH9H6M+o/
vf3p6TPl05Nn1PKZCeXTKp+e6nxGpdmHj88wn25an7hrpeWnpiYnOtW+olov
3PrTBRyH69F82qY+59PlU/mn1Of49j9+b/l1P/TG6vWqz2zyqeo1PqX2q1Tr
5nHxtFsuKZ8yqdfNaxfmdXNKfZ0qeb9Zx3yy2vakWT5l1u1xudmf6Xwqg22Q
VygzveTnUl6x+VT1uMq02p4+VV6plpT8nE+m8Fyzz3ucuWMoP6nO8ZRa6vUn
VerHT6rE/SqTp8r/NPpL6IMEZhyiHhnUsNb6IIP1YUSDZC+dWB3rAOtYfX5E
hqT1w2PWI58XjtyaRI58oHzlxl9V/Ni3PZHXAz0S/XSoH9LqkTs6r6k8ED1y
BYH9lKJFSkhISEismwkXyf+p+o/9VSQlJZeXP5O9zcyBdNxY82EN+JFrWN12
nvURr2H15kEO2EsH5nn0oQ+y52uQdl9P76/rkdIfufmJ/ZFvKa9VHLlzq6+5
EPx0bqCfzk2/H9IxpK5nva5S9MizDvZxJS1SGFJCQkJCYt1MKBwpKbk5+TPp
26x/jmPJNh8d7oEc+zWsliH1c08GY6M/Jp7+qLlxGDAk17GOrAbZ6yFbcpIe
OSjTfFr+/mdFj9ye9PsjX7nxpfLGrYHSFUNP1tBPp8aQNyt+vElLrVdexHix
+u8x+e/C/zeo/juLGI/H5Y0bNyRXlEmSnMnPMRp/+URZ/r+PXcw8+OLqPudz
HutmQuFIScnNyZ/JftbXHxtmeShmbOuBHAY9kMCPOA+yD/M8Thq8dHrmMfLj
cZ9yVB4cDctU6ZHPGY581rDKU5Ibm09WHEms/+mKI39Y1bVev9VXHMncaPsi
bxz5Naw3D50GeZM9do4US55nPbItfqj6b91/NyTXn39Z/XcWcfPmzfITn/iE
5Iry1q1bZ/JzjMbDd5blOy9dzHzuX6/ucz7nsW4mFI6UlNyc1Hrk2Mz6aOqB
9B+HPZC9IL0a1n59HuTJADhx4PdB+hqk8dapHh8bpiQ9Msun5R+IHrlFGdcj
bV0raJC0tH461WP200FNkhnyouqRwpGSlMKR5yOFI4Ujty3WzYTCkZKSm5Ok
R/bZk3XY1AOZwLaKFWserK7nsd/nnkjNj/2B40etQY68eZDWR6dn6lt7xIyO
J497jiGPe8Py8KhfZtmk/P0/eF70yK1JX498+fqXypu7A6M78kwP8NcBZiSO
VJrkTadH2rwhHCl5cVM48nykcKRw5LbFuplwkWzza0W/1WensJw+4/xWS+O3
qnxXn7W+o88Y31XruTp5JvBcxeWafFencd9Vfg/KL7Vo8Vwtuviu8jm1h6pb
fgqW4H+K/qtm25Ps1/pHxq+1eNZ5pc7htxr6rn5Keaj6r0W+q9p/VXul8r7Q
i/VJ9l8F71V+zB6roQfrU+zDir6soQdr5h4rf9XceK+qZA9V7Z/qe6y2+K+m
vv/qFeu7yj6s7Ln6ZLAv8GJNdH6C02z/RPKkeszn+QRlte0/jV7SvDhi/1TQ
HxvneHCvY+L3QPbHbh/3QFpdMj7Loxd66fScHukYclgen+g8PNT9kU6PFI7c
/AzrWp0eaf10do68GZFcy3qNtUeeG8l5vUrhSMkLnMKR5yOFI4Ujty3WzYTL
yAmkejzh7XrOIy2LaTDv0cx41PMeC7PdzHucmH1qnfNsZj3inEec9xjOeVRz
HWGbnfmIsx6LhpmPxaRh7mMRJJ9TP87tEmY+mhmPKgudenYjbM8KNQ+R4jPP
frH8W//jT1XPm5qZkHpmI857jM1+TIPZj+p11cxG2kfzHguTZp4jz36kGY9m
PTUzIBMz/zE1cx4TM/8xgcc2w/mP6txm9iPNdeS5j/ZxZh6n1XNStxxndvZj
QnMaee6jmfnIcx9xJuSIj0nc/Eea8zji2Y5qDmRiZz7a7bQ+1j2NOAfSzu+w
czxSf45H4J/j17Aa/9SK2U4qBiR2U+v82Gw7xqy47sTwnXpeb1CtQ1aPjyhP
XB4fV3lklrz92KR5TLWrOvvl0VFfaZBHR/Scfrl/cFJ9Xnn5f//+1YpNHjUc
eWUDWEmyM0eiHmkZ8rjOj+i1Y/iRdUjuo7yIIRwpSSkceT5SOFI4ctti3Qy4
FIYkbpzA+pR50S2ZGy0/Tgw7WUYszHbkx7Njx5AjwyVzJLFjjssIP1p2DPkx
yo4hR04MK06AGzk1P2YqgR3zwnKlx4OZy2RsOPLTFUd+c8CRATNabuT1zK0T
czI/8rrjR82Jmk0rhkwdO3IyQyaWNR1PpmECQzquNAxZrevU60mSAU8SPyaa
IYEfVSY+J44Sx6D8eATHjMapx4+0HvKjZUraT/w4Th0/MkMOHD8ya3pzPIbN
HqyqZrXaXn0lGrP6apUZLYv2zGCZmmX18btlkCksE7OsPubGHI2n6nv23Av/
EfojRY/c7Ixw5M5AsyB45miGPAA/nXo9K+uQSpMUPVLyAqdw5PlI4UjhyG2L
dXPgabRHjx+nhsvMUuuPRo/0+DHQHScTq0c6hlyd9mjZETgX9UdmSI//kB9j
fNjIj77+yOxY1yBRf3R6oGXHoq4lWoY0j60e+WmnR2pGzC035nlde9T6I2uP
udUviRs1Q/rao+XJKD9mUX7kbag/Wh2StxlWtPxoeNJxZWr4MbX8mDA7Gn6k
HHqcGOiRljeBMw1DanYEvRG0Rs2aiWJL5EdmRsuP7Ls6TJrneIxChmQtclz+
0R+/WL74hc9VebX8wh9dLV+s8gvVOj1+wSxffJHy89X65/VjtfycWr7whc/b
5fPVc17AfCF4/KJ7zvOcL/Dyc+Xzz39OP6Z1yKvP/WH5J3/6QvmhDz8ieuTW
ZMCR14gj+4oRnZ8Oz4XUfqzMkNewlvWGY8hXquUrF0iPpNmNNMfxpZdeOhVH
Xnr8kjrPpXtmPO9KlZfNcynvrPLeat9LM17jJf089Xw+9rI+39zX+oA5/oH1
sRq/h3Uz4yZx5MMPP1y+5jWvUZ9L2/N+9Ed/tPyGb/gG+1zK17/+9eV99923
MHN9+7d/e/nTP/3Ta2e/886RB//2UvlA9Xt712vd78Dd/9Wl8qF/NPtYeg49
l4+jc9C56JyzXg+P6/p6YT7+Pfr4e/6GcORZxbq5sCs7Tg03qnXDj1NiRqM9
8j6tPRqGtPxIbJgbzTHkx9XojiE3umuAGtaJYceJY0jLlAvrjoW3jLFjWLuq
NEhbt2q2F0479LgxCxiS9UjDkZ/+dKSulXVGYMgsrF/NmR3N0qRmy9Roj6Z+
1fKjY0fkxyTQH5kfuXY1NayYcP1qmlnd0fKj2aZqVlOuXzX7iAdHXJMaaI1Y
ywrapKpd5edZHTL1tEauV2WG1Nqj0yNHRntkhhyYWlZd35rUtg08hozP8aBa
1jSbll/8kz8qv/Zr/2n5qlc9UL76K364fPWrG/JVLfvantvpuB+Jrr8KnvOq
V7+lWv7L8o47/kn1/xWPKDYRjtz0DH12/qq8sdu3vY841+Maao/82NSxvmJq
WWn5stl3EeLKlSvqvohYkmJhjjwAvmvhyEsPAQPepZ9rj6Pl1YbjrgbPu8cc
z+d6SDjyPHDk3XffbT+Xpud80zd9k33O137t16pjiCGRJ5944om5eIuPF448
RXTgSGI65DniMXx873/XfCztQw6kY/FxjCXD1+t6XNO13/mfCUeedSzMdhXn
rJQnoV7V6Y9Tw2ZTq+lh3yPWrBbF6utWw3pVux3ZketUm+pWYz2PnfkxXrda
WJZ09auKF/PC8SLUrVp+zCIMGWiSzJnjFj0yDXRIYseUtcpo/arTE/3a1cxx
IvNjFtceY/zo9UQqRnS1q7amlZlSMWOiGNJqkrYP0nBghBnHwTrrlUqPZG3R
1LJqPtR9j8iPihkNP45Ad7Q9kMiKpvfRzu0YJQFDQg/ksD7Hg/oaqa6UtL+v
/ur/s/r7+8EqH67yvRua7yk1P/5klaxHrnuuheRccz+4rvVmwJBKjzy0miP3
Qto6VqNJkg7JeRHirrvuKu+8887y4OBAPV6UIxXXMdM1ceRL8JwHAwa917Fl
9PzMjPfq59vtDwKPzdIzhSM3miNJD7TfjwaO/IEf+AG7nzRJ3Pf2t7/d6pPE
mvPwFp9TOPIU0YEjmQWJ3176abf9yg86RovphLSN9tFz6Lm8nc7BnBhjUGbG
8Djky8v/TTeORP4Ujjy7OA1D0tLd9599Ep+w/lgAQ3r8aGpWC2ZF5scCWW41
tau1nsfCZ8gm7ZEZcT7PnJAd49ojcyPXrmZ57rEj9j6ib04jO2IfIzyO6ZHE
igl75TAr5rAO9auhdw7xY5b5DJkEXjlpBrzIWiR75SA/JsCPVm/MnXdOYnTI
NIVtKfQ/prYelfsfh0nQ/zjOvHpVy5pQu6rZkTgvs6zo1auOWXdMTG2r40f0
0RlCPevQ8CNrkkPQHhVDYg/kwGmSA+O/emL0yBe/8Fz52tf+H9Xf3/dV9/zv
rJbv2tD8VXWNly7961Jz5KdL6Y/c9IzpkT1vngezpNcLecPvhXwFGPLaBdEj
H3rooRK1SIpFOBJZro0jLSveO4MVA23RaphNjDnjvJuawpE+A3rfoQaOZN2Q
mDO2nziQj6caWeHIzeFIYj7+nJEhQ1akWtVwH9fAxhiz6bzEjbwdGTKmL8b2
Yz74P/vfTeHIs4vT6JHrCO55LJgLbd0q8GMRst3Z6o+hP05tO/Bj6JvjsWFb
32PH2tXcLgvQH6Fu1XrnxHxzfC5sZcfM6Y+h5yrqkciRdAxxHtauphnXrDrv
HFe/mkH9au5rjw3eOQmwZBrreYT61SSsX0Xv1TTwX+X6Veh99Pxz0H8V+x2t
/sgMCX447J8TeOiMrC7p9z+G/Oj5r1ofHfTQMYxoGZI9dNwcSJzjoWZB9kbK
v+bFF58r/9prtR55222k+T28ofnuUmumP1El+ex8xrDKpyQ3Np+qvlNPqp/V
6173IxVH/n/l9d2TigcPbF1rWMtq/XRu+Bok73/lgnAkaZF0T8RaJMXcHPmS
qTOlvH8GR3Jd6uMN+1kjvBxs517K+xuOu+LqXdfNX8KR7dHEkciHbRzJda9t
vLcIEwpHLiFmcCSzGOmATc/hn8PVH3PbaJ23N9WgslZIr8Hb7v8fZr8eP6et
npbYlHiTkp8vHHl2sQhDEpfQ8tatnfIXfuHJ8ud+7rNV/n6Vf3AG+fvlz//8
Z8uf/dlny49//FNKj9Sc5fxWdS9krG71bNkxpjt63Ih+OaA51vxWY6wY64Xs
ULtaNOiPVmO0fY65Y8eisPM8GutWURueMbMjA458lv1ac6hrzczMDqxdzWBu
R6R+Nclghkek99GrXwXd0c3ucPrj2Nav5nHvVfbQGcO8D/TPidSu4jb9HKdZ
Kv1xDDM8QGdkrdGrX8VeyVgNq2JFw5BD0CFHY1u/ivM7BuCfY3nSMCTXtvIs
SKVH5qXyzHnta/9VSTWjt922TXWtxJGiR252oh75QPnlQI9EPx3uf7R+Ojd9
htTr/PzDNf+/6dkGa5GXL1/2ts/Lkbae9XHgwAhHWtZr4aYmHrQ6wJXZTNbU
X1l7fkNdq30/V8x7Qj+gu8zzD1rO+9CluodQgxcQfh7quLvhuLvrumzt+AeD
Y+66NNOvqHZ95ucVvtYqOZLZ8du+7ds8PXFRdpqHCcNaWk7WO3k/8eus14ud
l5ZUf0t9nPSYllSbGzIx+wbxueh5dGxTnyedA5/P18jn7sKR9O9HfA20jMU9
99xj9+O/N0VjBkcy65HnzaznIA8+cLmB3d5Zfw7WqPK5iP1mHdfGmnwe8thp
vBbhyKXFIhxJPELxZ3/2p9XP50eq/JUqqcbhl6p8x5Lz7eb8P13+/b//L9Tr
EhPQNVhOXEPfY1R3DNLTHZvqVmNaY+d5HfXa1XBmh1ejWgA/hp6rTfpjSy1r
jB95ZseI9Ug7P3Ji6lUz55kD/JimbvZjBn2PtgcStEbLkMHcjiRgSObLseef
g96ruetztEvDj57/ql+jWuNH9M9B7RH0x5HphdQeOkZ/HPv86OmR7K86Qn6s
M6Wd4WF6IIdDzZA9w4+aFTVfWmYc1BmSnk9JcyATpUcSR+pa0dtuI15734bm
w6Xmx7eWWo/8dCl65KZnqEf+VXndcCTWsGItq/XTuYEaJPVOGoa8cXju534Q
P6r7tQcf9LbPw5G2nvVywGYxjnzc3e82nu9q5DkHHTnyztnPmYsjuVaWPX0C
xoue8154zl2XZnoBeRzXdEysVvcgwpyhX1GEQa1ejMc0vNaqOJLrWYmbiJlO
y5HYP9mlrpWej94+pIsij52WI/nc7AdE/ZvMt7yPfYNoX8wzKHw94u3weplT
+Xxd9cirV6/a47C+nYJ9nKl/mp43M2ZwJPcjtnEkcWD4nEYNMKJ14nO6cOsD
8G8qbedlPhWOPPs4jR75F3/xZ+VXf/VPlHfc8b4q323yPUvOd5df8RV0/l8s
//E//gn1uqSJFUUB7Hi2PY9tdauhXw5qjnmwr8aPMQ2yQ+0q+uTEdMei4Nka
xieHfVfziO9qEy9CT2ps3mNt7mOG67niK4pPf/qPnR5Jz0lyv27VMiQwpWHI
Mdavcr1q5vOkV78K+uNYbTf1p4Efq/VeTY32SDWs41TvJ34cpcCWUMM6Bn4M
6lrRPwe1xwHUr4b8WPPTafDPGeD8R5PWk5UYceTXsXIPpOfHOoT6VY8pNT/2
+tV6n3x2RtXnWnHkC88ZjnysuucnXnv/huZ7S82PP2WWz5bCkZueyJEP6P7I
nZ5mwR2jQ+JcyJt+L6TVIG2vpGPJ8xy2fiy4P+zKkdY/9U6nz7VyZMu+Nu2x
i47p8V9H35yZHBlhOLyWGhPy+e68VGPZJi8gTwN7sOF8wTHeNd4d2QfX4e17
Ca4v0Gw9D92rq+NI4sbQJ/U0HEnnY54irW4ZGuZpOTK8FtQXkV9DXyD8HFBj
JDZm5iQGb2Jo3telrpX+LSn8e4B8SbULnWIGR/L52noRY5zWhQexFzLkzzYf
HX5OjCOpnpbrWbmeVjjy7GNRjqT48z//f6rfjZ8o9f0c9Sm95wzy3YpTL136
xfIf/sMfV6/rOPLs/XKi60XAjxOXrEOG8zqinjkdZ3bkQc1q7tWyFh472hkd
kFHf1Zb+xyxgyGjtKs32gJkdzI/c90gcRqH0yL9bcWQ2cbMeue/R1rAyP+pk
7TEJtccMuDHGkJYVYfZjAr2Pqp41DepXTd9jU/2qx4rAkOCdY+tXsXYV+x9H
fv9jbYYHzPoYDLD/EXmR+yFT91jpkCPDhY4ZLUOi9si1rIYfezwnktYVQ2qe
PDkZqv5ImuP42tf+ePV796Hqnp9+vz+wofk+dY1UryB65LZkwJHXXF1r6MnK
8z1ehl7Ia1DH+krFjsSUOmfUcG1x8KwPde8URGeOZD3s8QjDnAeObOrxZP0C
GRNnnjTUolpNE/bb99pwzTHfIe/zaKhfjV2jPa5JS73sX98qOJJ1NVrG+Gle
jmQuI8aax2PnrDky5L3wepvOzXWryJj8+cR0Sj6G9jF7du2PDOtX+drCuvfW
2DCO5FmPlDFfH2JDnGHZpJ/SedquTzhyuXEajiQ98qu+iurJznI2wMMVR9L9
4tvL7/zOH1ev6+uRZ6s7eutNfqvIjaArLjavI6xbrfc/NvY9Yu9j7vgxj/Fj
WKMa9D7GalfTgBtTOwMyB+9VzYVWj3xW65H6+VoDdP2QMPMR5zxmueefgx6s
SeLS6320/Y287upZnQ7pfHMSw4nR2tWkXrtaY8oktWw5GkPtaoQfmRF5RiTq
kahDuvkdXK/qvHSGI6xfHTv9cQD6I3rooAYJ+mNvwDWsjh+ZIWnp6lo/V3Ek
/RvR49U9P/1+P7Kh+QF1jZcu0b/Psl+rcORmZ72u1eqRwVyPUIN8hfsnb2iG
vGbylesH5bXr55cjuTeSfHbC6MKRjX4454kjm9gu8j5sze6cPj/he+3ynmzt
7OWW80auB2uG1XuY0Ud61hzJPMT1rKfhSDoeZ0ou4pVzlhw5i3ubvGdjr42+
trS/iVE5u3LkSy+9pOpX+fX478PMnkiMDeNIZEFaoncPMSTX0MaOi/VbCkeu
Jk7PkVRPRvdz3K/0/iUn1bTS+X+54sifUK97VhwZ5crC58ea3yrqjsiOc83r
cHyImmNe1GtY/Z7HoO8R9cim3sfQNwf9V5t6HrnvMahdVXMfazMfDUeOjB5p
61pdfyT75ViGxD5HrF8N+h9T0B1dP2QWeOdkrobVzn5MHUOCr2oCszts/Wro
verVr6Z+/Sqw4MDTGMNaVa5ldUzJx4TzH+2sx0jvY23+4wB40WqSvgdrvX51
rOpXmR8th/ZH1f5RedIbgB75k9Xv3Ueqe376/Xt0Q/OD6hovXfrZUvTIbcm6
Hnn95knFgofROlbPk9Vy5oHycFVsSQx5bV8df16D+55IgwhjFkdaHoF61nPJ
kbM8Ze9p3zYPRzb59kQ5MuyljOXd8c/Mq9nlcxCXPlS/hlkc6Z0HMvadwiCO
xPrTkNvm5UisjSUdMpwpuW6ObDuOea3pmpvOgfWwzOLE0aRBhr488/i1Pv74
4955O/VEYmwgR3JtKu8jnsQ5kDzPEo9jf1isZxWOXF3MPe8j4MjXfBX9DaH7
Oea+Dyw532848t8tnSNDX5xaRvxWo3Me23TGTtpjYc+N/FiwH471zMnAazXS
95g1sGPEN6dNd6z55nDdqq1dLUw/Y2H9VpkheebjuOImimef/SOjR05MXWqg
PQa+q55vDnrmBN453syOtK49Ws+cxPU6erMfI32POPsRWdLVr3Ltarx+1fY/
gsbI/qtt/Y9DrGEF/xye58HaI/Y7ov7oPw48WJkfjRbZ7yWKJW1dK60TQyqO
HJfHJ8OSSpKfVxxJtQZPVPf89Pv92IbmI+oaHUdSf6T4tW52ol/rj5Qvv0Ic
2VP6ovXTuen76VjtkWtYb3AeqHz5WpU3zq8eeSqOjNSzduLIDprdTJ+dFg1t
6T47TRrhWXDkHGxcY8EZ6Z3zwFzrXQ3Pv9/x5FlyZKyedRGOJC0OGXKWNrep
HNmknzadg1iR9qG3DiZ9rsyT83AkaY98DtIm59IiKTr67KAXa5htPjttfY4x
nx3UHokXuYaV+JAeU60r8yfOrIzVswpHri7m4ccJ+7V6euTPlLo/ibnvg0vO
D1QcSfexv1Jx5E+q110GRzb5rU5YdyziumMBvY6Ncx5nsqNjSMemrl617rsK
szl4e57X+x7zCDNG+LHRaxWzxo8wswPmdTBDss8qz3wk7qJgPTIxHKn9bepz
H+1jrlWt1a0a/xxmvZAfk1B71HWsSei9GvIj6pHBPA+e/2jrV2u1q0H/I24b
J169a4whWatk/dH1PPLsDsePPaM1al4cO/0xrF81TNljhuwbfjR1qz2oYSV2
7AND0pLqWsdWj6Rag49W9/yPmd/xTcxH1TWKHrlN6euRX74Gda21Wlascz2A
WlbNjVTLSjrkl68fih4Z45orDfzRlqwrxhix6fzh3I8OjNiFNc8VR3bUXVuZ
nfx/LsPnS3lvN45cNIgj5/0Oxeo+iRmJHWk/seRpGPI0HEm8tmqODD+H++67
T/VF8udByT2V83Akezh3/TeBWszgyBgjhhmb+9HGiLPqUGflQ//IPzfqml1T
6avCkUsL5ETkRZUTt5yapPUiBz3yNcSRHy4d9y27/+mDFUfS/eG/rzjyrep1
u3JkrM+x1u8Itas5MmSoSQYMOV/NahMnhv2OrnY1C3obtYdOXT9s8lpt0hmb
PHOQHbWuaepmDT9aHVJxXWF1xxQYMjVzOxQvGo581nDkuPp8uA7VzvQIGDGc
+ei2sb9qZr1YXT0r16+m7d450O+Icx6tv6rlx9SrXx1GvXMiszu4fjXCjVjD
ansdrdaY2lmQwxH0QRp+9PVG1iRd7apfvzr26le9/kfLkMCOxJHm+TQ38qRa
Hhk9cvs48m3m8WdKzSpPS25sfqr6ThHr/4eKI/+Fqmu9RnWtyjOHa1kP6346
3AtpNMhXDDu+fF0z5cvn2K+V69fm7Y9U7NFUS4kzJO6EbcB1s3iwse+SfWOa
ehYb+HNlHNlFa2Ud8P5TcmSH/siFuPJe/3rOkiOJi5oSZ17wtnAmYsiQTTMW
V8GRTfrpqjgyTOwTnYcj2bOVdEjy4eJeyXAuUGvM4MguPMjXjr2MXGdKOQ9/
dklmWz6OXovO1ZSoafI2da3CkUuLSUxzZGbkdbtvopI4h4I48iu/ir7L9P9x
zH3L7n96pOJIuj98aGE9sgi3NfnlTBxLWp+coqFudS6/nMKdx/LjpKzpjkpv
DPoeQz0yr2uMtb5H9M7B5zfVreY+P/IcD8eQrn415RpW9lzluY/s1Wp6HlmP
fOZZX49kFvRqWKF+1c7ySMEzh7XHJJzdoT1zPO+cBPoegR+RFT3PVc9PB/x2
wvrVmPfqmJkxMftm1a8m1nOVtcehV7vq+h8VQw5cbyN764T+q54GyUn82HNM
qZfEjIYhgTUVP6rUj1Vda6LrWv/aa+n/bz9W3fPT79+HNzQfU9d46dK/KUWP
3Jas65HXdnqKAy032l5IzY3OT2df9UNqhnT8qB6fY45chl9rV8aKskqMgQ4u
Rf1J1XE8l+KuS9FewqiH6go50qu9bfJr5XpgmO+xEEdGZnQ0XuPlYNvdPsd6
x1zxr2dV8yO7chkn+bAumyHbOHLW9TT56ZwVR9I2et+xmuDY9XbhSPTYYW5E
ruzcJzmDI6mONMaJIWdijSkn81uME5Ez0ZeVeyNj5wuPC/sgZ+meUtd6djEN
9EbmR9QjnY5XPS6mij8otB5J9WTkc8Hct+z+p0crjiRO/dWZHNnU52j3FW5b
jgyJXIk1q02eOR21R/RbzWt6pO551P2NBTCkmdVRON8czwsnKxo1SNYWm/oe
87xomPfI/Ah1q+yZkxVe3yPPe9TJ7OjmdjAjDgM9Msl8jrRzOqDvMUWdkWtY
vd5H1iZxtqPzXiUO5PpVqzcmkdpV7ImE/sfQO2dkPFZ975zEcuWI+XHc7L06
GGH9ahrMf0yt5ji0dapOf3T8GMzw8PxXx3bJ9aqoP7L2aH10BtAPafjxpGLO
nsmj42E59vTIj1f3/MRrj29ofkhdo+ZIWv90KXrkpqevR36JfHZ2er4eeePQ
aZLXuSey4sdrhiENP77MmuSN882RFLYmq2JKDOZIr4a1pZ50Ho60MwwDnlIc
xox5V8O5mTHv9VmyaTbjSjkSt8fmR97r9nnXvgBHekx6V+S14PNo5M+wt/UA
znl5szmS2Sv0eT1tMpuGnjc8r5EynPFI9aRY37gKjsQZkeG1oucQz6zswpF8
HWEdK84C6RSGI1kbjOmO7GtDPYjIfFQbyn44VGvaVH9Kz0GfHjoH9zPSufEY
YkM+Z7gPX6+tzlY4cvUxQb2RalYVN04NfxmGLDQ/2hrPzOmRr/lKqiejenPm
vmXXrT1mOPKd0brWJmYM53RgryNzYx6wofd4ob5H55nTxJCsPWaWD826qVm1
umSkt7GL72pb36PrcwzmPWbgu5rq3keuT82AHy1DejM78vrMjipHxq/1WdQj
LSfC7I7QdxX7Hr3tGTCkP7vD0xKD+tVY7+PYzu1o887xvVe9+tVx6Mea2hkd
1oOVdcoh1q8m1k9nUKtdba5frXvouNmPJ4PE82C1PGn0x57hR127Oi6PFT+O
a/xISduOwGdH65HbwpE/V0pd67akz5GsR75i534YP50bB+Cls+/qWIkhrzsN
8uUbru71PAf3QoV1a2fKkSHP3GVYietd72zR2K4Gz8M62hYdcFUc6fHiJcNl
M97bohzpcR++Fn4eEW3Wuz7+7O/xtzGLbyJH4syLLjnP/A+e1Ug8GdbSsi8Q
8yvtZ48bYkvmsFVwJCXWrvL1oIcrbeP5mbM4knulSXckXRIDdUp63szowJHE
dsx9/Bx8HPJejEGZQ9F3lR7HNEXmT2bQeV5POHI9YfmRuAu0R942UQyJup9m
HwqtR66PI2v1qoYdbb/jxGdIrGVFz5xl1K06j1V8zMsceh6BIa1nTuHP8WjT
HUGb7MSPGbCjrXnN/RmQQd1qynWrRmPM0szzxeG5Hd7MjmDWI9e1PvuM0yOJ
G4nbXO1qbmtRXe0q1K0yN3rsaGZ3ID+2zO0I+yF53qN6jmFH64Vjeh9HXg1r
6uY/Gp6MaY/9YZ0fh7WaVu59BIYcuLpUV9fq9z4OgvpVV8fq5nio5cD0O1q9
EXsloX6VubHndEu9faTqWsfptHz+hc9VHEm9z79W3fPT799HNjQ/rK7x0qWf
L4UjtyVbOPLmoe2HvKbqWU3dqtIhD8ovM0MafkSGPO8cyT2SodZw1hxpz30Z
zn+n4Z5ZeuJLhoXQF+Zy9+s7a460nHxPt/e2MEcySz4Yea3L7Uxduz7m0Acu
eVrpJnIk1pAumyNJy2OWRD0PdUDs3aR1Zs1VcyRfTzj/g66JjkGdto0jqV6V
j23qg+T6VsqwdqEWHTiSWZJ4jGtVmQNjOmSMC5ED6Rx0rra6VKpfpT5InP9B
j/9/9t4syrK7OvMUWAjBMriW5VqrXQizumrZBuqxH/zS3dSTn+vBgGzXa/Na
T24P5QnKBne5XFWucjUuG2yXl9vGzCAJSQhJSKkBxCQJhAAp54zpjme659wh
Mk+f/7D3/vb/nHsjIjPixpD/zfqve+MOEVeREcn95fft7+vKY40cefzDflXF
jZ4dzaW9f1dY0nKP65gXjjQ5F8R9h73/9PcNR5r3i39R33ef87Ua9lkEeiTl
rKJvlbXHcN+xy68aao8H8K2i/tjKy+GuR9p3FN1xaV4OMuQK3XHZ3qPKzFH3
LZgplXdV8ePCcSMzpHAj5ersp7Mj1COrGeiRM8rHgb1H5EfMXaXcnCmyIeTm
dGqNuvvRfQzeVeVfnQs/8t4j5OVUQRYrdD+q/UfyqbJ/dQb+VeJG6H9k/bHy
/lVgxEl7/zED76p4VrHDQ7TH3GuP1sdK3lXyuqaOH1NiS8uTpT/G11o037Pm
r9hvf71+i+XIzzXv+c3v3ydP6PmEfY133PEf6+hrPS2nzZHO1zq0eiQxJGbp
kHf1SocGebtwpBmTs2PeE6EOcSv7kfGcnXNcHBnP4Z6D5LXe8uyxH3mmT+TI
QxtiReJGzjC9Ltxoz3U61wM90uwlmZwL4r7D9q39Q8OR5v3ix+pf/dU/sl8X
9Uj22mJXRwcTLmXHfeWttnVH6noM9cddn4ezdN8xYMhVeTnMh/vs61A7j17f
JGZUvlWVvdrOzRHNUXJzuryryI9T6OwwuqNhLDPsa51f970ds87OR8pjpb5H
6u6oKslbpf7HMCunRO1R7T7OhB8bxqs8M4bZqyXk52D2KmfnVOJdxexV0hml
99E/X/Gjzs5BXZE/Rv1RdXhA/irvPnb4V1V3h9cXC82P5GNlDTJDhjR+V+d5
HSk90vy75mnjyCfryJEn/SBHmpydCw1HppYVqdNDZ+mIl7VLg7ydOPKjH/1o
HXrWIkfGY07kyLNxIkdGjjxtwwzJflbixvD6Ml+r2Uv6TC3cd9i+tU80HGn0
zo8zR5reCcNTvPsY5KwSNyI7troe99IkA4bUe5XCjNLxKLk5XfuOC8xanYN3
dcW+Y5f22Mpaxc4OtfNI97fzVvmo3Bz0p86Vb1VpjXPp5MBuR8rMoezVlh7Z
vAbDiiXpjsq/St5Uvfc45dycudp9DH2qqD2KpzXcfZwr/6piR9p9pNv5/mD/
sWjzo9Yeof9xQn7UUvlXmRUnlew9gvaoGRLyV/Op74KsoAsy9K8KOxo+VP5V
z4xOgwSG9PyYeE3S6JHV9Hr9zW8+5zny8817fsNrnzqh5x/ta3QcGfNaT8fB
vNbfqC9fvVhvbGXQ5zGUPUjix43l7Hg7caQZo0li53jkyHjMiRx5Nk7kyMiR
p21IY2RmRIYEdkSWPB6O/Jj4Wmde47seaI+h7rhMe9y37hj6VIPri4Xk4ixC
9lvsT3cMslhX9XRgXo7yrfLlgh/Xnbcq2iPuPc7n6F1t+1ZnqEMiS0LPI+au
2rxWxZEfqsvmdZAeqXJzwt4OzF2dam9q5+4j3wfao9Uc3W3MjuRRbTGkf0yY
nTOR7JxwzxH5sZWdU0J2zkT8q5ido3yreOmzcxwTUn5Oxfqj9a4WxI3Y4RH4
VzPvX1V6ZCk+Vv8x8WOSTZrbJ/ZynOTN9/NG/Q2rR5os5i807/nN79+nT+j5
pH2Nd9zxJ3XUI0/LQT3yN72vNW1YcVBfQ4aELJ1l+5DkdaXL22GoA4Q0yciR
8ZgTOfJsnMiRkSNP2wgnLuPGdr+G5kiTb2FyLoj7Dtu39o8NR5r3ix+vf/mX
/739utM56JGQlbNYlpWzp+6IOau474i5OdeV7ki+1cUu9jwuWj2P+9IdwcO6
176j5kevOy4oW3XZ3qPPW/W9jO5j7Ovo6HUEnpx26ZCgPc68J3VG2TjTueUq
M7gfOSWd0OfmdPEj5ubwLmPAjyXuPlZduavzwLtqeLHS7IhZOlVH9qrafSR+
FE8reVclOwd7HyuVhxNm51D2qtMeqxrzVzl7taiYE/k69HeQBtnaf8z0/mMG
u4+aHUmDbBgyndh8nTQt69G4aL4f5Gs9bRz5D5ZNHKs8Hs+JPY81P1OG9c+5
3o+r5+trW4nokMbLujFU7NjlZVWZrWe8PzKcD3zgAzXtSUaOjMecyJFn40SO
jBx52ib0rHZx48nhSJfXan2tZkcS+fDAWathXs71gCVD3yrxnfOsyq4i+VaB
BVdlrYLuGHJj5+4j9nSw9ii+1fkevlXxrgozhnmrU9pvpLzVjtwc7umYwh7k
rFuPNLuPRYl5rR9qbtv1O49TyWRV/Bj4VtG7il2Q/BjSHz1bYu8js2PH7qPf
jwyzWHn3saP3Mex+LErtXW1n5wT5q5C9qrJzWv5VzM4p2/7VouL+jpQ0yCzg
R85g1RplmiM7en7MhB/NSdjXGuqR5vfwuHkx6pFn54ge+bZ7f72+dOVCvbGZ
1leueR8raI0rfaxh9s5Z1SO/80crz/3f+d/rX//OHbf1+efp8XPccZ/IkWfj
RI6MHHnaZpXuuD+ONHtJn6uF+w57/+mTDUca3+xfsR45m4Ie2cWQ+2JHYkTd
76hyVtmzCp0c7Gf1DEl8uUfHIz8m8L8uy8xp86Noj3OVt7or2mOHb7WlOzJD
dvd14PXW3qNiR+l1rLijQ/hQ65EfrKu5y2QtwbMa9nYo3REzV+l27vFA/VH4
sSB+xM7HCjs9AnYMPayqt4N2Hen+qe6EnIh/NStg13HSkacT8KPKX13iX81J
c4T+x5ANcf8R/auiP7odyFB/TFr8SLeV9cjmtTYc+c2GI99qspi/6PXIz5zQ
8yn7Gu+44z/VUY88LUfrkZevXqivbaX15Q3xsq5iyNDLas5lc66dUY487vdb
p+Ckl/++7t/m/2venR3Jj5/pF6cesHiO/pjv99pmOqzrqn97nsVkfd/nMz77
Zcf9ceRR5GgQR/61cCTm7OzDr6o7OcJM10B39H7VWdjVATuR813NhV26I/pa
Q25cmZmjcnaop0NyV0V33G3rjuhbDfs6AjYMdUe8VLoj8qPq5nB9HRV0ebhL
41s1rFXZP6vHQY+0HFh6T2uH/qj6Hi1Des8q+VenPnd1Euw+hvxYBj5V7IKk
5yA7Ku8qao+y/1h08GPR8q5Wmh1V96POXmX/KvlRqQMkn0h2Tk59kC4Lp+Vd
zUSrxO4Ol7/qPuYMndz5V9PE8WKaCT+ODUv6MxwXzffrRv281SNNFvP9zXt+
o/t99oSeT9vXeMcd/7mOHHlajnCk1SMbjrxq9MjAy9pix8DLepmYszmXGoa8
Ejny9j2XHzjuP6U4ceLEuS3n1jnS+MlMXiJx32H71j7VcKR5v7iEI1cwpO51
7NIjF+BZXWh9UXV1LNiv2mLHPXTHTrZcaJ9q6FsVzRHzVh1DLsvLmS/zrYJX
VflWV+mOU9EcZ/7S6Y3etzql/kfodbRdHXK98Hokc+R0l/XIcqoZspXHSvk7
3O1BuTnuIB9OwLeKbFlC7yOz5iTYfyzBv+q5saDeDt8JKf5Vz4mTJd7VifCj
6u8ohBExezXPp9DdIfuPbgdSejtEY/TXwbtKt9PHidcreQcyL8W7an2spWdI
4UfSK0fG05p16ZGRI+M5Wo68aDhyy3Hkyj3IDc2TrEVeG9aXr46snnkm57gZ
7TScyJFx4sSJcyyzX3bchTP3HPlD5sgv1MJ9h+1b+3TDkUbv/JuGI//Aft02
R4ruiB2PXdeVrkjsSDuP7FUNdh5XeVaB/0JW7MrLmc+DzJxQdwx8q0p3nC3Y
+xDqjjNkxo7MHGbGudYfZzPQHaehZ5UY0vc9Ij9SX8fMdT1OITPH9DwaFjPz
xGOgR059f2OYm6OYUvYeybNKnR2YmyO5rOhVJS9rd26OXBd9ccI7juBZZf0R
snOU1lhx/ir2eWj/qs7Oybz2KN7VipkxK8S7mhaOIbnzMdAgswz8rUuycxKf
nYP5OUngXzUMOc5Ehxz7x47GefM9vF4/b3o/LEc+EDkynkM+6Gt1euSVFRwZ
6pHsY20ebxnSapHDqEfezidyZJw4ceIcy+yXHXfhNtQj714rR3bpkbugN4Ya
ZEfHI/HjruTlcNdjFzuu8K2SZrhs13H1vmOw99jKy9m1rDifge44n7XycmYd
uiPuPvL1Dt/qFI/SGoUnK+BK3feIBzRFz4KGqcygr1XycWAfkn2twI+KITFz
dSr9HKrzcdbSI0lnDHNXC/K8hvuP3NuxXH8Muzta3tUJaow6Owf50e0+ToQh
iRVzyV+l3Ud1FD/q7BzLkqQ7eiYM/as2R8fz45iuw2OTpKyHo7z5Xtyon//G
1+q3vsX4Wh9s3vOb38PPndBjXtsDzfkvdeTI03I6fK1b4mtdxo7Cj24X8rJn
R8OQl33O65mc42a003AiR8aJEyfOscwqfsSP8VLrkSbfgjjyKHI0iCP/Z4ce
qf2qy7JWLTN6RuR9R+LG3Y6s1ZAhO7JWW/2PcH3WwZBz5EfWHbGrY1d1dbAe
6ZmRdh/Znwp5OaHu2LX7GHZ1hPdxtg34WJkdve6o+zokb3XKnY/iTS28HvnY
41qPJF+r6JF+53EpP+p+jhJ0RuLHzswc7ueYcV9HmLvqOHMaHOrtCLo6gB+7
snOy8HRl57B3lfJzRHMkH2uaVqJFon8VPKyUpRPmr7L2mLn8nBT0R2TIhPch
vTaZGIacWKZ0vR/X629YPTJyZDxHy5H3LuHIK5viZW3vQQ7dIU1ygz4eHNv/
jx7pHDejnYYTOTJOnDhxjmVCzVHxo2e068HuoeEVMz/44Sv1my1HfrEW7jts
39pnGo40+5fCkYZ7nP9U+1V3OQennbO6oI7Hro6OVR2PQVZOqD0u3Xech8xI
miPqjrvMjDPOyJmBb3WhTicbBrpjmJdDOTkzpTvO/X2YtypZOsq7qvgR+zpm
LXbEfNV80t6PpN1G8a46zyrl5jBDYm5OpX2r6GtdlblKPlXSF2n/kXyrpD9O
yoYbyyrocqR+R2DHoP9RvKtTnZ3DXR2UqQP8iL2PiiFl9zHrzM8RflzW/ZhA
9mrqtUfyrwpDuscaXhwnPl/H5O54hjSXw3HefH936+e/+WzDkf+hjhwZzzo5
knJY1S7kNXdpmfHqkDVJ4UnHkGeZIx/5t3fUpi/yF/7X42M187XNazCv5di5
8TbhyF/7tV+rH3nkkeN+GbflmO/7L/7iL9qfeXN+/Md/vH7f+95nO1vX/TnN
/eZx5vH0XPN5Vv1sPP/88/zYZecXfuEXDvTaD/qcwx7zte3fQSf0d2I4HNY/
/dM/fazfo+MY1BkNLyI/ElfafNPrcpQeebfZSyKOPIr9J+LIv/UceaPhG9Qj
F9zDsQBuJHZkTXIVP3btOga649Kc1YX4VZVv1e890k5k2POIPR3Os+o/ns1F
W+SeDmJI6e7o6npkrgzzcqaSmSO+VeDHqWiQ1Ux7V2nn0eqOU8lOXdr36G9n
X6vfjyynztdK3Rucm6NyVcPeDsjTgcycMuBHystROTnlVPTICeqRledNw4gl
7DhW4FEN9Ejq62CmxOwcnZ+ToX/V7j9OhClz5Efwsy7bfcxEi0T/qmVHZsiw
z6NU+4/kX+W9yAR1SOLJie2NHKdFw5FZ8726Xn/9G895jvxS857f/B5+/oQe
89oebM6f1pEjT8vZQ49sdXoM/S7kiH2swo/CkGfZ1xo58vbjyHe+8531SX7P
fJbnox/9aE2sRVxADGcuDaOt63Oa2/Fx5nnm+fS5zOfd6+tFjlzf0Pf9wx/+
8HG/lLXNLrKjvyRe3N0VhkQ9cu71yB/+0PhaDUeanAvivsPWGz7bcKTxzf5t
fd99tB8J+TioP3JHh/hVmSu79h3hY95z7MjL6dx/DLNy5ni7Z8LFLntSrfaI
u4rMjHPIXdVdj5iZw7rjXr0dwb7jzGbkzEVrnC1Af5wDT5LuOJfMHNh3nBI7
Qr9j2NeBeiT6Wt9pfa0L9rCq/g3ee5SMVd57ZJZs64+089jd+wh6JGfqEDti
Zo5ckq8191ypdUfRH5kbKYcV8nNy1B8L1B9L1f2oeh9X7T62/Kuy/5imqEkK
GybAj+hfVdpj4vYiDTdaL2vDkKPm+qi5b2D2Izlnx/haH2re85vfwy+c0GNe
25ea81/ryJGn5eytR7Z3IWkPsosfB/zxmZzIkbclR9J7/ZP8nvksjtH+6HuP
LGC0JqMJEgeu63MSM5rHmcfTmM9Dn7NLz/zABz5g7zOXhzGRI/c/5t+ADPPj
n9dZngWyI15ix+LCZOu4Y64b3jHzwx+8Ur/5zcZP9kAt3HfYesPnGo40euff
1f/m3/xx7fRIz12+s0OycogtNRMu3XdE7+oe3KiyclqZObDv2KU70s4jM6Nn
SNXTQWcO+mO37tiVl4O+VdEd58yh4l/tyssB/RG0RvKfMjeGfY/TgB9Bj8xZ
j3zB65ELl7s6gUzVCvsedW4Oe1hRf+zofOTcHNh9FD2SfK1VLf2O7uDeY4E7
j8HeY466Yz71J+x+LH12DjBk6Fnt7H7s1h9V9mqus1eZDcPsHPKvkv6YEitO
bH5Ogtqj4cfEcaNjyIm97vRIk7PTcCTrkZEj4zl6jjR5rZeJIyFH5zJoj7IH
OQz4cXjm9ciTcCJHrnciRx7PENeZy64hrlumAx7m5yRtaxljrvq8xFyf+MQn
9v06T/qcFo403/NVf95nbXY79EZiR8WPS/TIN79pXRz5/9W/8iv/T2040mhp
4lOVnUfKT13a77gia7UrbzXMWlVZOZy1upBdSNh55GycOXR1zOfMk3rvca46
OVCz7OrqCHse6T6Vreo/rrwOyTuRft+RsnM4R4fycmxvh/Blp2+V2FHxI+w8
2rzWyv6MPPaY0yPNzp3hwqIM+h4r7WklPbKTHctAe2RdcuofN2W25Myc0Leq
8lV1b0c+AQ+r35d0nDj12qPk5nB2TgG7j/523nsERszU7qPff2R2bGev8u4j
7TumkqczTtvZOY4fJ8qz6vixBH703Ej6I+1JEk96PdL6Wp83HPnHze/dw817
fvN7+MUTesxrMxz53+rIkafldPRHbqaOETe9BnnVZ7FaTXIAPNnWIJEnz+Qc
N6NFjjyWiRx5PEMe0mX8ZXZWaT/xqD8n7VIu0xRJIzSfP5xVWuVpndPCkWbo
3wbO0vd/2ewu2txI17u4ssWRbzZ7SQ/WxHyHrzd8vuFI45v9u/q++yBnp3kN
q3yqndwY7Dku5ccwKwdud9rjLmSt0nXf1cHcCAw5C3s6Au0x1B1h/5H5MdQe
WZOc67wcZMcpsCPtPk51Zg7tOjqGdFmqih+n3bqjaJNhX4c7Rq8z85WvvFD/
POmRlcu1Ed1xyt7Wzr1HpTsSO6J3darZ0WbmhPrjNOBH4Mmwt4O1x6nSH8Wz
Slk6mL1ayu4j9Haw/phi7moVZOeUbf2RuTH0r5ZqH7Irf5V0yMQzpPhXgRU7
+NFeH5us1kk9HObN93TX65GGIx86BRz5UO30yL9vzpPN+UrtWDKek3m+0vxM
PVob5r/33v+7vnTF+VrdHqT0ebCHVWmQ/ZYGSY+7fIY5cpmv9dd+0d1uLp//
zTvq9/1vzXvKN/oMjze6j1/7g+X8ZT4vPoe+xkd/ZTVHmvOL75bn/PRPuNcw
/E/Lv9Yn/i/9HPM1zceruNS8DnzO0te3D46k55sx79txx2yvzBIzhgHCjJRV
z6PHoXeRvtYqvxsxRXjM7Xj/Kn8h/rfSoC/R7NzRe3Lz30Gcgu/Tw/9e8/0y
X/ugXj36nPs9xzn0PVr1Olax22F/zv38WwI9BvcrKWNnv69xP7PM13qrPzPm
eWGGkPmcXXovfq0ws2g/X+ugv8NmzOvA56x6fTiH7Ss+ycOMGOqRePsqPVL5
Wo8iR0P0yF/+5T+sra91Chy5xKe6WMGOXboj7zYudFYOMSMxpPRz+KxV7Nxg
ZpzDdWHG2Wxv3bGVt4pZq1O8bw77jn4HEnYe1d7jFDTIKsxcbXNjiXuQge5I
3EjaY0V5ORVwYHM9Yz3yBatH0nMnJXpZaQ9yee7qJMjN4d4O1iMrn8VaqbxV
6eeoWHvkzkelOVJvB2bm6M7HjDNYMXsVsnNw9zHwrlL2apoBPzaPsX2PzfWl
2avAlZyRk6JnNchfTSfiXcX9R/Kvpo4h3f0F64/Ej+aMQY/82vPP1m95i+HI
R04BRz5cR1/raTptPfLKZlpfuiZZOtrDGuqQ7lwOGPJ25kjDWsSC5jHEfMRr
XSxpWAwfY57zzv9FbjN82cWRdNn1HHO9iyXN50LmNM8zl3TbB/6P9nPMbfh5
w+eo13cAjsR9NMw6WeVVRA6k5yGHdr1XxPecdGn2pvbaLzOvAdmLnkOv7VY5
kna3MLOFGJW+Lv330mMo84eef5A5TRxJfsRVrwNzUI/ycxoe2g9H0s8vPgb9
sOHPuPnzu5l/D9iLI2/mZwazgLqeF/pC8Xdp1dfq+m+7md9hYkH8PcTnrPKt
0vfroLu0p3GWaY5L2XJ3Fzjy+4EeeRT7T6RHEkfW9bRy/KbYkDJWg5ycMG91
me6o83I8Fy7peETdkbs8ZqHuCJoj8mOH7sjaIjFj5fXHWaA9wo6jZcfpQnYg
pwu5D/cdqeuxoq7HmeLHvfJyQt9qBbqjZchW36NjPqPZmXnsse84X2vz+qiv
UeWzQmYO9nJQ7mpBeuOEcnSmfMm+1SA3p/D8yLk6oXeVOj4m2NsB2mNOt5Xi
ZeXdR9p51Nk5qrMDvauw+5gxP+rex1B/pI/tbdTfQdk5gX+VvKtd/tUx64+F
ZLMiPybCkCPb+TGp+w1H5pNF/c1vP1//k39iOn2MHml+D4+bF1dxpPn72vha
zf9fn6sdqzwRz4k9jzc/U4b1n67/2b2/UV+4cqFhwNR7WSmbtTuPFZkRPz7r
vta9OLKL4Qw7EneFTEifz5wP/+v2fcSkqPshm5rPh18LP1+oFdJrNJ8z1B6N
Rklfy1zH107PMTrrMv7l+w7Akfa/OchSxPeYYW4mcZt5zxq+nzeMsMyziF8P
P+d+378vY4hb5Uh6b4uvg64j84XvkfH5B9kNPIoxr7dLU16VXbqf2c/31sx+
+O5WP+d+dEwz9GdG/xZgBvlnGQMt461lsxdHHvRnBu8Lfx/NffR7hc8Lvxa+
/lVf62Z+hykbqStLF/l3VXbvfh5zFqabFYUZ5XKXPzb8ZMbmtb7Z6ABmP8kx
3+G/T/xCw5FG7/w74UjQI8NcnC5mRI2x07Pq2ZHycmbIjrTvyHuPkJMDWauY
lTPzHRusOyI/Ltt3xL7HDnakXscKejwkL2fOHY/Gwzql6wfMy2npjp2+1Q5u
rKaSr+r3HnOvRxpfq9Ujq4Xk53CeKmarSt8j7zpybwfm5lTiTwVG5M7HiXQ+
Ym6Ozl7F3BzpfCT9kTo7sjzwrhZaewyzV3XuquiPCdyG+iOzIvhXlfaIDIkZ
O0nZ7u1IJ8yLxI7oX7W9HuO2Bkn7ksOxO4Nh1vx3zuuXvvdifc9PmX8jMhxp
fg/vP6HH/L1j9Mi4H3l6TqBHXnZ65OVrA+mFXJKlc9nrkMiTdC7dxhxpeKtL
BzSMaLnhJ7q1xZAv8fOa56BOiHpk13NIc8TPaV5TF5Pu9Rrpv9ewcddzjP5q
7uPPeUA9smtQV6Ex71O73s/iUG5mqDsg39zMHCVHLuskQL2na8jfd9z5Icu8
v/TnQH9W5s+PmOogn/cscCRpdeF+HjLaYfR+3OzPTNfvGw79OwHqhHt9ra7c
oZv9HUb9ftl/l7lv1b9RkE561jtAlvOjMCRmt5p81FlLjySOPArdgjhS9Eij
w1GvRpfeOEN+nC/JyvGdIe7+heTuzHfBs6r3HWnXcanuSNpjh+44RW6caV5U
LNnSHiVDR3V1WIYUz6riRtYfhR9beTlwyoAtRXf0vlWTs1p16472tqCvw9xu
+MwM+VqVHhnsPrK+WM5UXg7tQ0puzlR7V7mzo+refcTcnMmUfaih9uj0x5J5
ktgxp7zVoqqX9XZkmexCki5Jl4nXH9Ng91HyV8uAHyfsXR2r/Ue/70g6pGfD
BLofR6A9jlR2TqG5kbRHqz8WVoOk65SzY/TIF7/7Qv2T9xjP+iOngCOjHnm6
juiRb7v3N+qLV843HJmsyNIZso811CTpXLzNOXIZ26FOiGzX0vP2cYgjzddc
xp7hayHt0LDkss/b9XrMJd1Gu58rX98BOHKZNkD+Q9wpI91h1Z4Z+g/xc/Pr
h/f3B5mj5Mhl/NPFJAf92usY8zrMnwnpR4aV6LZlfLnfz3sWOHKv2c/PwrLn
LOPIg/zMLPud2Wtu5mvd7O8weo3N570ZTfFm/mxO47T1xl3ujSSGpNsX/lL0
yJe9HmlyLoj7Dvt94hcbjjS+2b9v70fukbE6V15VnbEq3Oiuh/uKmJMz89oj
ciNn5pBnFfckod8R2RBzcma4+zjTfFiCb5V1R39d+jw8Q1boWwXPahWyoc5b
LeEwMyrf6owzc7h/Q/Gj7nTE/scuPbKoFpYbLedhz0cpuiP3dHT6VoPcHNQe
g8wcnZszZS9q3pWbQ7mrOeSuel0yLcp2bk6498i5q6XOzWF+nLB/VWmP5F/N
gt5HZEfOXm0+HmN2TqHzV1vao+TntPmxEIa09xfu+PtIj3zxu9+p77nH/BuR
4Ujze/jACT3m75wvN+fP6siRp+UgR/56w5GiRy7jx1UaJJ3beT+ya79wGUd2
3XYQjkT/6V4ciXop7W12HX5P+2/bX491pp9wWqdh05b2esCcna7B943kl0M/
nHlPuOx0vSc/6Pv0Za/3KDhy2ezVFXEzHHkU+5FG3+l6X9/ldzVff7/dF7cL
R5ohrWy/z9uLIw/yM7Pf/7ZwbuZr3crvcPiza36ujNZp2HQ/nmDSR2/Wk3Ba
BrkRNUfkxoXtaVw01xdej5zZ5xo98k1vOl49ssuzOg88q+xVRX70GTmsPTI7
zpkd53OtO3JHB+qLofaIPBp2dISa41TrjpSXY/lxirqj1h6nXmOcVpCXM+32
rWLWaqg9kueV+LKcSF5OS3eEXg7JxZnCY2bqkB5JHJmXokfqXUjZg2TvKuat
Ag9K32PV6Vcl7TGDXUnWIIPcnAy9q0WQmwP8mC3pfWx3Pnr9Mdx9THx3R6g9
kn8VOh/HqdYlqQMyCfyrkpPTzs5hjqTsHK83ind1Itw4LuDk9WiU1/1h2nzf
ZvVL332h4UijRz4c9ch4Dvks0yP7S/s8VjHkZb9TaXJ6zuTsgyOXaYRHwZHL
8lVXceR+D35uw4rkr+16rGFn5slD4Eh8DL2XXOWf7Hz9Z4Qjl73mk8KRRzVd
mnQ4N5uzc9DPuV/NritnZz+zl0c0nP3ktXbNUXDkQb7WrfwOd/27hPo76AMf
2Ff28nHr90c9C+BGzY7N5cIxpHQ1Oj+o4RozhiPvPgY90nRITLG3kT2rxJYL
2XfkfBzodgwzVkFzZHacITfOld8Udx759iAvJ/SuYk+HaIqeH4kbUXeErg7J
zCFuxI5H4MeOnkfZeaQdR5232spabflWiRsxH2fqtMdqqp/n9x3z5hi+MvPo
o6JHTnwnx2Qy1Qxpu0DEt1qovo7KZ+YQL7a9q7TzaDXGCXVzSHeH9a6q3FVh
yJxZkXJzKtYYu3JXVW9HXgJDIj+WsPtI/DhhRsTsVclg9fxImiN6V/3Oo+Sv
dnV3FB3ZOYXyr448Q7KPtWFHo0GOPEMOR0U9GGTNf+O8fvGlF/x+ZNQj4zlK
jvzNhiNfazhy7PXIod+BHLS4saVBXnMMyddvYz3ypHPkMt/tfo/xtZo9Ssyl
NYd3MY9Yj7yZ94HHxZHIHzjHxZGnafbDiAft/biVz7kfRlzGmnv5MPfaT1z2
Gk8rR97qz6z5fhod3GiL6J9e9f27vfRI0hx3neboOcwxpNf1zHXPl7O5cOSb
3mR0AJNzcVSaBXHkPzBHVl7XC3cdHU8G3MgZq6hJSlbOyozVecicS/yqQUYO
H/KrTh2HYs7qtEN3rJgfJWuV9h4pb3VpXg7qj6HuSNxIuiN1dfi81Ql5V6up
9qdCpqq7f+Y7IDt6OoLrokd+x3PknPVC5V0tMS9H+1TJt1pMhBsL0B07c3NI
h6TdR/Ctcu5qAbmrhdMjU9hzpM7HFBgz1B9V72MOvR0Z5K4yP5bau5qR9gj8
6PNzDAtKl0ch3lXu74DcHHN93OVfLZx/dSx7j5ynk3gfq2FI5EdzxkaPzJrv
y7x+wfpazb8Rfbl5z2947cETeszfEaaL8L/XkSNPy1mmRw469yAvbbT3ICnT
FfXIy1GP3BdH7mc/kjJb8evdDEfuZz/yZg72iByUI5f1gt/sfuReX2/dHLns
PXrkyP3NXuxG34ODsMHNfk7KqFnmPe3iT+TWVT97pLHtNwPmMDlyP1or5QHh
827ma93K7/CqwYznZXO77EcaLlwsgB0tM/qzEE8r5tnMZsiR69Qj/6D5qtcb
FkImBF1ytpCdR89385lojs7HqrsdSZOckeY4n+s9R5XD2s7MUTuPQU6O0x4p
J4e4ERhyhgwJ3Oi1R5WXY/TEKbBgoDtiV0cV6o6l5OeQfljyvuNMZa2KV5WY
UXRHfC5nrqrMHOnkMOxlBvcjqe+R+ziC3Jyuvg7MY1U7j6Q/cm5O1e7sgH4O
8q+mHZ2PuPuYgXc1Czsf1d6j1x/TFbk5medB6uvIAu3R5+dQho7VH5ETsbsD
MnXGtPsY8ONQ8aNnR2JJ718V7TF3OiUwpLns0X6k0SPjfmQ8R86RvxlwZLvb
Q+mQpEFe0x/bczVy5H440hzqfFyW10rdjUb/uxWOpP4O+371X69+jeY1Uc+l
+Vzm433vfR6AI5e9p+vSZyj7f9X7bcx1REY9Ko7ciwfRx3eQ55mJHLlaQzL8
Q/x1kO6Tm/2c2APZ5Z9cloVKn2+ZVkb5pKv+XSWcw+RIM7Sfuew1Us4ufs9u
5mvd7O+w+Vzm465eSXzOqt8n+m887p6cox7yglqt0euOi0V3N+PCdzPOpsCR
d5MeSdx32O8T72840uxfoh7pPah+v5F2HcWzOhe/KjHjTPo5kA2JG7GPg/yq
KjMHdxph33E61fex1ugzVnnHcVnWKnPjzPtVQXfEncaqQ3cMb6OcHHMf5+TM
wLc695w4Zd8qcSL7Vn3eKuWvll26Y9mRtxrk5aQ5+Vq/U/+80iNLycwhVsRs
HNAeMVMnm4g3NS2IIZfk5uSYm0OsSbzos3GCvUfmxpZ3tVLZOa3c1Uw6O1q5
OZidw7k5wo/oX6X9R8eMRSs/p2v3sVN/RO1x7PXHEWiPQ+FHw5KWH+nj5tLo
kc7X+p36np+KemQ86+fI1v6j50XyrqIeiQwZOXL/HLmqPxL7Gbtybw7Ckcik
RpNc1VXZpWOaE+b6GD2VOJg594D9kfi+zrw/xw718H01vZ81963quQvfJ98q
Ry7rpcT3xeF7cOSDyJE3N8u4A39OurrlV2Wg3uznNINMiCy5igXxvvBnFvsS
bybj9bA4clUPDfYzduXeHPRr3czvML6G8HfQ/DkQI67SpZdprnv9m9Zpm4X3
qlp23G33aCwChlzMQz3S6ADm54G477DfJz7QcKTROz/RcKT587/h9EjIyEE+
nLP2GOwx4vEZqypXNfCsKn5clZVDflX2pWq/Ku89qj1HylqdQ8cjZeGA7hh2
PNLjuro6puBX9XuPE8+OJXY8kvYY7DZSfwfnsgI/IjPqvkfpeeTcnIn7HIbJ
zIiv1WmRtLso+41BDqvyq8pOpGPEqfasYt9jAXuPBfBj7rRJ8qW2+BFzc6i3
I9M7j9j5mLb2Hpfk5pAGiUxJ3lXPj+Jf1dk5nKmDu4+h/piE/lXJ0hlBfo71
r4L+yNqj1x8HI69J+vt6A+drfTH6WuM5Bo4MM1iVbzXUHwOGjL7W/XNkyGom
y8Z8bsy0Cfseb5YjQx8qfS1iQdIiwwzWrudghqu5jfTLg3Akvf8z78/N+0Z6
D4k9EuGgh42eR5+HPmeoF90qR5LWRN4+ZF/smafXg7xB77dxIkfuf5Ahun5O
uryYe3Vp3MznNGNux8fhn/UqravrZxafd9AO0MPmyGXfk1X/bbfytW7md7jr
OZgbZW7byyff9e8DZ44jgRfnITfOd7Uu6S81R65fjzS8ZNhMceN80bnrOCNu
nAM7BmwZcuF0umjtO4qX1WuLwImUtToF3yr6Vbnfkfyqnh85K4f5Meji6Orp
mGrPqj2gOVJfB+47cs5quNtIu5CQuVqC3jhBfvTMKNojHd3zSFk6aT6xPyOP
Pvpt3o/EvkfKYm3tPXLHxxSyVSGDFbyrbu9Rdhhzrz+S7tiZm8MMWULuquTm
WHbk3scJdHccJDdnIlmrqEMGuasjYkPf+8i3p5opu7TH0Tj0ryJDOu2Rdh9J
a7SsONa3ucvca5OFzWt1euS363t+0vxuP9q85ze89qUTeszfEabT/v+tI0ee
lqM58kLDkZcbjrwEeuTFMFvnWtvDqk70tR6YI+n+MLvGfNzFirfCkcSt4dcy
jzUaZavHA54T9n8Y5jRfSz3nABwZZjCa9+bm/eJe/j7znjbM2DDvKY2+0eU5
vFWONJ+TWLJL9zCvJ3wfTO+7I0fe+pjvAX7/9/o52U8n40E/J4253zwOf/bM
59nrZ4u+Xvi8/fagdP33HSZHrnqNXZ/vVr/WQX+H6Tlh5rD5XTNfa1VWKzFo
FyueSY5cwo3oaZ0DS1Je6w/WrEfe5/VIwz2zhs2WZeTMZh3dHOhX7cjIafV0
qMcF/Y3kW/X5OZyjqvJVnXd16nNyKtYU/cfAjdW0w68Kl/IYz5ylfy4xoz9O
d5wLH5JvFXVHr0dOwoxW8K3qfceZylfl2ycz1dnBfR1eG0y8HvnlL2tfa1aA
lzXQHpXmiFmrnLFaye5jsPfo+jo69h5Bd+SPva/V9T3SZbfuSJ0dSYsfOzof
+XbSE0uftyr644i0R8+K4xT8qqRJjictD+uQvaqTTn5s+VdHwI2kPY5FeyRt
ku8bOp9rb5A2//2z+sUXvx31yHiO6LQ5sqVHXutgxw79Ud12hvXIePY4h9T7
ESdOnDiHMcSq+90/Pc3TYkfgxvmizZBtPdK8f/syvK87bL3hwYYjjd75Se9r
ve70PM+QlK0qGThztecYdjsuy8iZhp5VlaUq2TiUm6P0SK85kneV9x1ZT/Sd
j1Xbr4r6Y7jv6LjR+1xp95G6OqyeOFdZqk5PhLwc6PBg3ZF6OwKGLCboWaW8
HPGt8nXOWfWXPi+n4E4O51E1zGXG7Efa/kijR9JjluWtFlPYcdR9j5SZk1Pe
KtyXcucj6ZDeqxr4Vmn/UbRHx7vCkKI7kvaYBLuPVmPMQobEzkfJXk2w8zHF
nUfJzRklOjtn7DsfqaOD/avEj8SOyZLsHNYeybeae14EhmQ/KzFk7k9R9/pZ
833x+5H3RD0ynqPnSPK1Gj0S9yD5XIV9yCtafwyZ8kzOcTPaaTiRI+PEiXNC
hvy6B/UOn9ZZBLw4x93IhWbI+bHqkf9Y33efyWu94bgLeDHMyEFu7MzICa+3
dh0XateR+jp0R4f3qs7aHR16l3GmdxkD3bGVpaN8q9LNgR0dnJvDntUK9h1F
aywDryrqjiE7hnk5xJNy6fs6oKuDmRAzVz1bphlw5L9qOLJ53QXtNgJvOuaD
vBzeaaw8L0pfB+09EjdmoDui9ij8WIJv1fFjgrk5wW5jO3c16Owg3dGzo/Kt
cmYOZOeQXzXMXWX9EZjRa4/UATmkng/kR+7s0HuPo7F0dwzHQXZOl3+Vj/Gx
5u6M3NkxemQ+c77We8zv9lea9/yG1x46ocf8HWGYxPy9HTnydJy2Hnmp4ciL
1wb73oNs6ZGRI2/vEzkyTpw4J2SMZ97okat8r2dpQq1x0cGNtusDTuU58pUf
rFeP/JVf+Q+10SONDmf3I5dojiE7Yp8ja48z0RUVNzIv6l3HKbCj6+ig/UbJ
WKWODtIOw6xV5Eb2rGLWKjPknDVHZkjo6KC8Vel4lHwc1BztbRO979jaeVT7
jnoPspjIvmNeVuJbDXJxcLex8HxIvtZHvyz9kehdzZR3VfJWc9AekSGlrwN9
qaI3om+VdyNV3qrPzclJX/SHtcd27uoY9Mjxksyc7tycQvTHxGWuSu6q6I+4
9zjm3o6Jz8iRHg/cfaT9R8eGedDb0dYeRX8U/yodZMjBMLOnN0ia//5p/eKL
3zqFeuQ/NOep2nHl4/Gc2PNY8zNl/szO2f7I87Afud89SGHHgTpnco6b0U7D
iRwZJ06cEzCkRe63l/MszDLNceZ3I82ZwTEfT6eoR5r3b4/C+7rD1hu+5Dny
U/Wv/uqfNF911+Xs0G4kcKPSGQN+VL2OkKNa+W5HydYRlnR+1aDfsSKGJHb0
3Y5BjmoF+qLqd8Tb2a8qXtWqRH4EbiwxK2da6+5H8bWS/liUHVk50NvBO4/Y
A0n7jkp/JN2xCro4KC9H8yRdV75Wq0fOvJZYqrycnPJyOF/V8yP3dZR+71H4
EXXHVDEk8GOGumPFvY900LvKfZBp0NnR6u2Ansegr2OcigdVdh/Juwo5rEmb
HXEv0vEieVlztwc59prjGLyrwImcnQN7j4NxqD86/6rjxsLrj5m7r+FH0/dh
9ch+2nyvZvULUY+MZ4165OWNhiOvDrr1x6vD1h6kMKTulDyTc9yMdhpO5Mg4
ceIc81AX6O2QQ4Wj2HHuNUfiR+ZJ3zFpuyYX1stp5gdr0yONb/aT9futr/W6
ZS7SI1lzDDJyWl5V7nJciP5IO5DsXSXNEbTHSu86suY4lTwdrSvKnmO488ha
Je09EjdWojtOlO4I+47IidzxOGM9sjMzB7mxxJ3GIGeV9x0r61nlzBz0q/o9
RrqP+THofiSfK+uRJq+14cis+Xo2ZzUTPsx916Noj9jXUfLOY8qZrEHfI2Xk
ZJK7Slmrrb6OTHRHzY8TzY9Bbg6xoL0vmYgGCZ0doyQXVkyFLZfxo+SudmmP
tAOZS4bOKOTH3Pd0wG14SfxI2uMoB4YU7bHvj7m/P8y9Hok5O6eNI//Rsolj
la/Gc2LPE83PlGH9ZxqO/K36wuWAI5fx41Vhx8usXQ78dXfO5HzsTfHsda48
dNx/SnHixIlzW85srhlyznuSC69HLjxbLtp65CukR67D1/opzms1O4KW6Zb1
OqqMHMlW1b2OnitJc5wJL7qM1Znv5iAfKmTeTOftPNWqQ3ckXXIqmqPsPM5h
57Fbd+S8HM5YnQpDYsdjZ1aO50TWFVFzhJ1H0B3Fsyq+1Zy5EXo64DIv8Ehe
juEoM6xHFnN7f+pzcpgfWXfEvNWK83C6+zr0zqP4VitgR/Gt6p1H5EevQWaB
d5VycxLZjUw8Q0rfo2fDVLyrmJtj+dFojqOw9xE7H0HDJM+qZ0j2roIG2cmP
Y8xfzSE7R/JzZP8R+NFrkX1gSHO71SPTWf3CC9+qf9L2fhgPouG1h0/oMX9H
GCb58zrqkaflLO/96PSwXkX/6pD9r5eBIS9f69sTJ06cOHHixFnfzD0jzhfE
jAvfy+h1SNvLaM6u5TRz3TCWGeHIo/a1kh5p+iOv1+XE8Z30Ogobiq6I+arI
jYFPNex1xIwc3lmU7BzV7xiyI+iO7FWlfseS+jj8vqLv5iA2LDlrVftTiRux
p4M0xnZOjuiO2O9Ie5DFBLmyO2e1UBojaZLgW1VZqw3bTaaSp1r4vBzDdAnt
R4oemRWThgUnrEcSQ6rdR9h3zJR3VfJYMW+VeFP2HifsW+WdxzTYeQTNUXyr
4nVN0hJyc8LOR8jMoc4O6IJs5ed08uMk8LHCDmTDd7L3qPs7BpibQ70dI/Cu
DgvOzukNc+FEz4/2jDKvSeZOi7QapGNJc7ndS5vvybR+IeqR8axTj7zm9chO
D6v4V5EhL/Hp23PxrOqRceLEiRMnzgmdOTLkXHYiLTsajXLmrs88U87mzs9p
xvla18WRn6rvez/okT4Lh/2pwXXMyCG2JG7kfFWlNxL/kZYoDIn6Yysjh/lS
vK8uF8f7WAPdkdmQc3KmmhOp+7HS/tWw41H1PfqOjwI6HjlbJ/CusrZYTJXu
qLysgd6ofKtBT4fiR+LRhu8MW91o/rS+7H2t9rk+P5X5EbTHLMzMgbycDPYd
iRmp95EyVbnzMdP8mID2iHmrxJKyD0l9j8KP3PeIuTlpwZk5KjdnXHSw46Qe
cE7OxPpYV2qP1MUBWTpKf+TcnFyyWT07Kv2R2VF0RspoRe3RsGZ/4E7PH6NH
jtNZ/W2rRxqOPC16ZOTI03OWcOSVwNcKe4+XgjwdYkc6F5rbLkY9Mk6cOHHi
xFnrGJ3RaY6eHf0xvOhY0l+fz21vpPl4Op3a5/7gBy97jjTZe8R9h/0+8aGG
I41v9tP1ffd9pDZ6pGEly3m847jwftSF4salGTm46wgZOSonJ8jIwexVyVWV
TkfudlQ6ou53bPOj7DvinqPadYTMHJ2XM2XfqvO0CkvqnUfkQPCsokc18LIW
k0B3nEi+quJGysrJp8yG7n7DZoX9GXn00W/V73zPh5rbXM5OkrW7OqTjEfN0
IG81o5xV0h0nzIe470jeVeHLjr1HzsyRrBz2rKq+R8jMuYncHKc9dvMjZa6O
wJ9qdUXmxkJyV8daf1QHM1ehu6MP+48D8q/yPqRoj3T6A/kc1teazevnvv5M
/da3/hf/nt/8Xj9yQs9DteNG42uNHHk6TsCRl2A/ckUW66UOfrxo+dEx5Jnd
j4wTJ06cOHFO6Myxd9Gwoj/zGV6Hfo2leqTTDo+SI99/X6BHwo6j7EPOmBsp
S1VxI3dytPXGkCdb/KgYcs6+Vex4nPjbJqgtou6InFhR/uryPUe97yh5qvQ4
4sQWQyo+DH2rFfhWdc6q2nmcTNX+Yh72PHJXB+47uuuGr6we6X2tafNaKQtH
7zsKQ2a00+j9rZyXY/ceA92RsnJYc1zd10F7j05nLL32SH2P4d5j0WJF9q6O
C9YhQ+3R5eZ43yp1QiYdnR0j3HmEvcdx4GVlxkQPa+E1RWJH0RoHfu/RnqHo
j0v5cSh82Ru4s91Pmu//on72a0/Xb3nLf67dLttR/F5HPfL2PSt8rUEWq9Mj
++Bp7QE7unPJM2T0tcaJEydOnDjrHac1LqzeaNiRNUhgx2lznz1+F7FkjnzZ
57Wuyddq9cgblqGstkjcyNqk3nXkfUfSDsOMnLDXEW4rfSar9HIEGavsU52z
zig7jG12FE1yyvzIfR3gQxXdccqe1Emw7ziB+/nS+1UL7ucIPauhp3Ua9HhM
A79rBf2O7jFOhxR+5IzVIDPH7Dsa7+f15k/rEe9rTY0eadgwLaGrQzJzsow8
q6g/lp49xbOa8L6j9qxSZo5krQob8t4j+FbpsZYlU2BD3H0E7ZFzc8bIkKH2
KI+1TAkMGeauSuejzs0hhrSPMyxIvZDDHPTHzHZ3uNtTuC0Db6tnx0HG+5LC
j/62QaY0Setr7Zm81oYjox4Zzzo5EvJapUdywHxIWuRF1iD7ih/pMXHixIkT
J06c9c2cdUjUJBfczzidSzcjPaaqkCPX6Gu1+5HXLTuV0ylrja7PccadjpSP
s1Rv7OrlqGAnktgU8nJo73HC3IgHMla9vkiPcR5X4krZkZTdxu6ODseIM+54
xH1H7VeFjFXWEiu185gHvKh0R+7wAD70/Jih7pij9uj6OrinA/cdfeaq0iPf
03BkPrP8mFDeai66ZNLSHyVrFfcdybOaKnYM8nIy4knZiRTdUbhy7JnRMaTb
eRR2FKa07Ii5OcSQrdycicrNcZfeuzru0h+BHcm3qjofQ/8qdT5Kj8dglEmG
DmTn2BPsPQo/EjsKS7pdSXdp9Mgkn9fPfO3phiOjHhnPcXCk9rRe9HmsF/0e
JPLlxWuYtxM5Mk6cOHHixFnnCD+S7ui5sYMf6WPtazXv3x6D93WHrTc83HCk
0Ts/U99n81p3RY8kfyp5VT0Llh0MGWbksHdVcWPgWfV5OZiVOsHuRtIXod+R
uJE7HUPfapd3ldlxBpojZauidzXMURWGdHmqFXhW3cetDNZW1qq/Tp7VwuuP
eeU1SGJG3/VY0PFdHT5D1dyWgl/VcJfhyEceAT0S+h4pa5V7HpXuWOq9x9a+
Y6g7Yl+H5OeMeQdS6466r0Pn5pCvtZWbw75VysiRXUjafbQfe24cBf7VIWeu
ysd4Sb5VzswZ5ZCrqnsfnY/V7z+if5XZsDl9r0EGbMk8OQCGHLjeSHO2e+Pm
+zqrn33uXNQj4zmis4ojB51ZrJdAh+zix8iRceLEiRMnzvpnOofeReTGDn6k
x5Ee+crac3a8Hll4f2klrIh7jEs7HVV/B/pVJVO1ZN0R2Q+9qFNhR8pZxU7H
oNextefYYscpZ68iN+r+jkrpjtTzqPcaJWcVPasqM8dzIeqN7gg7ou6YETvm
wo5pjpk4nh0zuZ1ycwx3GV+r0SN/vuHIpPna1MdhdUfu6aCuDuJGYMmQH1XH
I12HHsi05Nwc5ELSGikrh32qqstDZ+bQGQa+Vc7NwZ3HxDHgaNTefewHGTmS
uSr7kAPgR9pjlNxVx4xu9xH8qkPUHwPtcUhe1cwfvxuJu5Dmsu/Y0WTruJPV
WztJ832c2/3It771T+37/te9zvwefvmEnoc9m/yPOnLkaTkhR77WcOS44Uja
g+yDhxW9q/1OdowcGSdOnDhx4hzPEBuKJtnmxumUejTcpeEtM5Kzsy5fq+uP
NBxWone1gxs7uXIqmaqKHclrCrmpE9xjrHS+KuasEmeWgd44aemN6EkVjZG9
qqg9ll5P5B4O8awWeIIMVup3DHs6JA8HsnL8dfGzls6zWgS6o993xCxVzFlt
XfeeVedrvVE/8si3WI8095OGqD2q7cwc2mnkjFWlO4rWKLojMaT7eBRkqyJD
infVcaDeeSTtsZDcHH4s5OYkRZC7ir5V8agSIyI/cm8H7D2i7oidjzpzFfRJ
5VElfpRM1h72QkKOjjk79qTuuuFHc3s/83pkYvNaHUdGPTKedXDk+frSRlJf
vCqdHhdbWazCk5Ej48SJEydOnJMx7GsFTXIK/DijM5NL0SPX7Wt1emQ+ocya
gB3VLqRk69hLz31VuONoM1anupcj2GdU3MhsuVp3VLuO5FGdwI7jBNgSux2L
QHdkfbGqsb+D9h4L2HnE/UjcW8y8V5V3HpErfb6q0x0rzsth3bEQ3TEDzTFV
Was6K8ccw1jXb9T1w1aP/KDVI5OW5jjhrg7RHUF7hN1HzspJJ8KLCTCk2m8U
z+qYbuPbad+xnZuD/RxD6PBQHxuGHK3IXR2Jd3UQ5uYo7TGXvUfyrYJ3tT+S
3BziRtIfmQ9V7qpokqJBhvzYcKLRIO3JgB/dfebjrYYjxw1HPvPcaePIqEee
nqM58rzSI4UhxdfavQsZOTJOnDhx4sQ53unSG5EdKaPV9WosbC6q4Sgz37e+
VsOR5j3B+jiy7WulHNbAq1pBHwfw49JejipkxylkrEJGTikeVex3xIyckB1p
v1EYUvTGVR2OoklC5yM+hjs6kA0lW5X9qpzBCvk4kLOaQg4relbRq2o/9r0c
9NyUj9t5JM+qYbJdr0f+3L/6UD22vla3e0i6o+p67MjM0fuQ/jpl5nimHFEn
R4rs6Hcck710x4L3HqWXY8J6o7ued+iOeZCPo/ceWXf09+ncHNIUC9EdMSMH
M1c5d7XNjmHuan+QaY1yqPmx5/lxp4+aJN3neNLctx19rfGsmSOdr3VUX7za
U10e+2XHyJFx4sSJEyfO8QzrjF3saDN1jB90wQxprk9Ij3zF6JF/7t+3Efcd
9vvERxqONL7Zz/reD9EjK8jHqWDPsSrFv8q7jpCvWnJODmTkgKe1BM2x069a
4q4jdm9ILwc9bsL8OANm7O52zIuAGzk/J9Acwc8qGauB5piLb9V5Vf0pSs2S
nifTQngwg5N6hsyUp1UydUh/lA5Hd5we6TjS7UdWjh+D/g7qexyrfcdJsO8o
fR3c9ZhI5uoIMleRHTEvR2fmYNaq58FE9EjWHVt9j3mHZ7XLt1poXXIoH/fB
v4q5OexfBXak3Jxw9xF5kbTHHvd4+N1Hqy/6Q/zovavuOvDjQLRJrUf+aX16
9Mjoaz09J9QjX60vbYzrC1f77GHdNz9e1SdOnDhx4sSJs75hHdJy41x6NIgb
6djbfX9k6fRIl7Nj3r89Du/rjpIjUY+cSl8H5+MEe4vc6wi9HJyPA/0crEfO
Wl5W4UG98yjdjcCTnJUD3RylsGNOeapLuh2xo6MATVI0R8hXpW7HItAcc2RT
7Hak66I9opbY8qsG+47Eh5yxCv2OlKfqcnQcKxrm2r1+vX74Ye1r5T6OIDOH
/axJyfyI+46ciUNaYwo9j4nczpk5QV6O0h1577GAx2Bfh/ehAkMOwLs6hMyc
MHOV2XIIuTmKHzP2r/ZHwpDymCW5OWGnB+xA9jxz8s4jsOMOs2La0h6JH7fh
482dpPlezuunnz0X9ch4juhojnzt8mv1xYYjL17d3w6kYsjgepw4ceLEiRNn
fUPsaHTGaubP1DEk+12njjEdT87E1/rK99bsazV65K5lKmJAxX0qH2cmftVg
x5G1Sq9HluBPDTXHgjXHGeuOar/R+1cxR0dpjpO25ojdjuGeI+blkCbZ6nek
fFXOzaGcnEp2HHPhRvaqhuwIWmMG+45ZLt7VFLVH3//o+h59xmoGHY98vUuP
nAofqpzVICcnbfMj7TaSXxW7OkbU0+GZMOzqYO8q6o7sWy04j1X6OoqOvUfx
pw7VziPpkoXXHqG3Q+WtQt9jkJtD3DhgPTHUHnPWJimHlTyrfdAee36/kRiS
tccO7yozZN8xpNmZtKeX1lvb4+Z7OQM98snmPb/5PXz0hJ5H7Gu8446/qCNH
npbT3o+85DnywAx5VV+PEydOnDhx4qxviBtZh5ySLjkDPRI8pFPDS5XtBnzl
+y8fi681y2nfEDocYc+xhN3GCfY5Qr4q5uO0uLEUzZEfC55VnbGq+zlYb+zK
WO3wrCpubGWwVrznKN0c01q6OaSjg3Jy6HoKOazEjeRJVfuOxJC078jcKD2P
SV62fKvYtcE5q7DvaBhtt+HIhx/xvR/N6zb8OELPqt93DLNWsY+jK2t1zL5V
l5dD3DhG3dFzpew7gu5ImaujwvY8jhQj5oodBwFTin81yMwZ6MwczM1Re4/A
j+a+ntce6UhujudE8K3SDuQOZ+fozg7xrhJP+sf1cR9SNEjHj83HPTmm92Ns
9Mjnoh4Zz/o5ct/sGHpar7gTJ06cOHHixFnfhFqjMOTMXZrbPF+a/UNzWU5I
jzQc+T/8ewN6X3fYesOXG440ebCfC/RI7OSQ3g7RJlFz7NhzDLiRbuOMnLCj
A7JVJ4obp96n2s7JKQrhRt5vBK5sZeVQR0fHnmMGemTOGTnQ70g5OdjTkQW6
I+w0Ys4q+VWZGy0LEj9OvPZYBnmrwpXoS6VuDsNXi+s36oce/jbokRPeccTr
zI6JZkfJzBFuHHlvalt3nLDWKD2PmJdDuiMxZHfeqnQ9aj0SfatD8q2OCq8l
hpmrwIKYmzPKtG912KU95syO7F0dovYI+iPk5pD26LhR9iFRe2T9see0R3ub
v06a5ObOuPm+z4AjT5Me+YnmnKudP+KJeE7sebz5mTJ/pz/dcORv7s2RV/fB
kJejHhknTpw4ceKsexwvOoYU3RG4kTNsZnzdcJTRI7///e/Vd9+9bj1y13KU
0USRGdUOZEc+TtHyqoJPVbEh7ED6x/Cuo2HCsqp1r2O466j7OXJgRsxhzTqz
cirNj8iOnhf5kvodC8+Nhew+Wm1R5eN4HTIv+bLtVxXdkXodU+9XpWycsOMx
BW+q2nlsjuiRztc6Nt2R3u+aUPeG97RSJg7vO4ZcmXrd0e89joEd2Z/Ku414
+4T3HUeUtwq7j4ORZOZgpqrOXZW+DuZH4kbSF4O+R/GuQm4O5asOujJXRXsU
/THo7OjL7mMP9ccgR0du97ojdUSCd5W0R8ePTpfc6bmz1XDkOJ3Wzzz7lO/9
iHpkPMekRyI/7qFD2hM5Mk6cOHHixFnrEENazbGi47lx6vJ1Sn9Z+V5Gw1Vm
9+3lhiPf/OZ1cSTpkQvLWlYXBGZs6ZGgM2rNUXYcxasa7DuWokeKnqiZMczD
wd4OzFctwK+a8Z7jFHRF+Hw+L4f9qn5HMc8pY7VibkRmJG7EvBzHkNTdIXoj
6o6kR1JuTppNVJdjmopXVXc8AjcyP07A6zqxfLW4fr1+6GHX+5FkU+DH5fuO
Y9hptFmrdBvzYwF5OaQ7oiYJTAl7j6I7guY41hk6w3EXPxZB32MeaI+Zyl1t
5bIOZa+x38rMyQPfKubneHYceg7syd4j8WNvAB+jd7WvfavbvUz5V0l75M/b
S5rHuLO5PWq+bzPI2TlNeuQnLZs4VnkynhN7zL9NmP/PeLbhyH/X5sirHRrk
MnYEhowcGSdOnDhx4qx3yKvK3RkBO7p+Rn8qd5thJqNH/uCHr9R33vkX9Xp8
rZ+t3x/6WvfMVRU/qmiOmLc60xk5Kl/VcaPsO+o9R9IbMRunlbFK3DipIGfV
M6T3ruae/aTjsZSPWXesOEsnRc0x6HZMkR+RIen+vFS6I+qKrDumWndMM9Ij
yzY/hlmr6cTvPJb1sGGu3d0b9cMPfRv0SK8NUtaq6uooJDMnzMvp9Ki63Uf2
wAa648hn4AzHmI3jdx/5vqJTk0Tdsd33mLPOaHNzRhkzZV/xYS5djh2dHU6X
zJgb277VrCM3B7sgxbPag51Hy5AD4sSMdcbtnmiShhvdMR8n7vTE1zpMZ/U5
62v9r/Xp4sioR56Oc4D9yC7/6pUlbBk5Mk6cOHHixFnrlJ4hmRUDdqyYMf3j
KteDeP16XX/ta+fqd7zjv/n3ccSQXznk82jDkeY9h+xHkh6pPKroXVU5OoFX
NdQhYdcxhwwctetYTJdm56gdxwnsOMKuY85e1TBjFfN0xLNKHR2850gZOGGf
Y4a7jr7XEW5X3KiycibMjpixyhk62QTYMNQddccj7zjypbuOeqThyJHJ2LF6
Ye55EfRH6nhM9M4j9jkOx9DVAZmrqueRvKuw9zikvJxxrjyrYXdHW3fU2iP2
PfY5e1XnsLKe2PKuElNmkqcDeiR7VzE3h/YdVW9HBnwZ6o+y4yi5OanVIsXX
athx7PcjhR+3zGmum8uN7XGgRz7VvOf/8hH8Xh/W+bJ9jXfc8Zd11CNPy1mh
R4Z8uMS/ai4vmnNVnzhx4sSJEyfO+qYKeTHgxirQIw2HmW7JccMDf/RHf1j/
zu/8bn3PPQ/De7qj0iM/z3pkmnl+Yz0SclVZc5R+xwK9qsyOsONIzDhpe1VF
e1zOjZYdJ5iFI5pjzruOU9YVu7lRPKvU0UG6onBi1c5a5Q6PUnyuQc8jc2PA
iOhbxW7HxPMiMiTrjonOWuXMHOJKrzUajpw3HPmlh75pfa1Oj/TMmFDXI/hV
x6QvTupWNg7ojrIHWYDWCL7VoKuD8nKwq0P2ICFvdRjqjhlrkcKPmexDom+1
4cIdyFvFzJxWbo7SHaXX0WmOXRmrlKlDXld9tnth7qrXH9VOJPlWSX/07GhP
Ys/2TmrP5lbDkeOGI585jXpk5MjTcTo48lrDkVcCX+sS7ypdv9jBm3HixIkT
J06c9Y3WGkmLnHl2nLnj9yVtdyT3Ns7rz3/hk/V73/sf6ze+8bFDek+4iiM/
V78v0CMnk1CXDPJVve90Atk44S5jDl5Vl68KvY2B7sh7kkXYzVGJ3sheVel1
ZN0Reh3dzqPsOnI/B2WstjyrJfdzpD4vh7Ny/CXlrDJDUscj7S1CVk6qdh0n
gd7oM1Qz0B19x2OSCE9i7uqI2dAdw1eL3V3WI8fN6zKPG44K5VcdkUeVehzH
wpDEmbTzOBrDvqPXHgc+O2egdMdcZeVI/yPmreK+YwF5OVp37I+g73FEfR3k
Rc2X+lZRZyQPKzIk82PgW6XcHGZJ9K5y9qp7nuXCne7c1R3PjbT7aJ6zZXyr
oD9advSfY2snZT1ymMzqc88SR0Y9Mp4j5Mi3NRx5KdAjl/DjRf/xRWBI1CIv
RI6MEydOnDhx1jola44zr0vOZFeSjmVHz5gNPxre2r1e1+cv/qj+p//04/69
wVH7WkmPXFiesv2LtBPJ+4+Ur1pJvippipyNUykm5Bwd6HFs7TqC3zXjfUfP
ipCRgz5V1By5pwOY0+mOYbdjwI55xdwpPR3idRXPqru0miNlruKuIzFnKnxJ
WmMCnlXebwy4kbsdE8hRNdpiqnNWMWuV9Ej2taaV48ZRwZqjysWhvke8z96e
+51H2WFEfZH3HUfat+puh05I0h09S0rXI32csfbo+jpy7uxgbREycYQfs07f
an8AeqTSH6mXYwk/hpk56Ful3kfOzUkhd5VycyQzZ4e0R9Yknf6o2NHzI93W
9rVGPTKeI+TIUI/s4ser2sN6aQlDRo6MEydOnDhx1juV1x2FHec+/1S4cVLO
ORPVaJGGq0xe60vffam+664/9+/b6H3dEXLk+z9cW18r6ZHlTDTJkrgvYEf2
qpIWCd2OyI3oXW2x45SzVTlfFTNyuNexBF4UzZEOcSExJHZziFe1VPzI3JgB
L0K/I/dz8J7jhPs42MdKnlT0qOKuIzFkUqqsHNpfTEifZIYMcnJS3HckPTKv
F7sNRz7k9cjE65GcpUrXofuR9h0T0R5H42X7joXSHdm3yt5V0R+N7jgk3dGz
I+blsO4IvtXBEO4brNAekSU5j7XtXe2Bltjrt3NzlG+1K3eV9hxVbo7v7KCs
HN6BTBw79sW3iqy4HfCj1Sd33GM2rR45rc/Z3o+oR8ZzxBz5tt+qz196teHC
hiMv99v+1SBTJ9yHRIaM+5Fx4sSJEyfOesd6VIkX7f6j2znkLNRqyv2Mk4r2
D8t6vqjrV1/7fv2Od3ysdvmIa+DIlh6JeiJqgTofp4B8nLxAVoTr6FGFHscs
x7ycitmRuJF6HFsZOUpzrFT+jeLGjHYbgRvZrwrcyFk5nheDnFXSHROlOU44
VzXs6OBdSNxzTAKGTKWjg4/nR9Em4eOx7DsOGqaaL0SPHJruyMT7SxO9C8n+
VshWHY4oM0d0x6Fnx3bHY9e+o9YduY/DZ6yK7phpZlR8KH0cPWBEztRReTmh
7giZOX3Zf2RNciAdkIobOXc1yM3xLOl4MlHZqy4vxx3nWU2ZHbdCdgz0R8eP
ib89qTe2Rs33dFY/ZfcjTYbWueY9v/m9fuyEnkfta7zjDvP3UOTI03ECX+tF
z5FX+q39x/BcAm68EDBk1CPjxIkTJ06c9U7ptUbLif6yrKZ8WZZ0Zu7S5LU2
fDSb1/WFi6/U7373XzfvBx73msVR5ux8rn7/+x1HGl4y/EZ9HLzLyHoj7kKu
6OXwDCnZOJCr6i+5xxE1x70ycjj/plReVclZLSEjB3o5iBc7M1ZLyFgtmR3p
PtEcJ1pvzMSz2pWxGmblsKaYgv8U/Kq4Czn2DKg6Ovz9hq3mRo98+JsNR36w
HqSV23scST8H5+V4vVFlrQZZOYNQbwTdsYshOQtnBHmq3PGIuqPfexzQY/IO
7ZHYEfYdveZIt0mfI3Aj5a2ipzXUHyE7R/oevd7Y03uPnLtK3lWvQwo7pp4l
JTeH+HEbtEfmR69BEkNuNpfXoh4Zzzo58t4P1ecvnW/YEXyt+/CvXui4PeqR
ceLEiRMnznqHtMaSj+NF1iQr0iXdMY8xnk+jR56/8P36ne/8q3pteuT7DEfO
G+bxflLwpBaeJ8mvWqCndSL6o3hQvf6Ya62R2BG9qbnvcSR2pM8hGTmysxju
O6peDq8tZpiNA8+zvlXDgYFflTocU8hNVeyIOTnU1UFaYyraI2mNCWiPY2LE
QHMk/6qwY1Fjx6PKWqWMHM7JKSwjzRa79ZceEj1ySHrkWHMjZeWoXJxROy+H
tcoxZOV07DtiHg7nrA4lf5V0R7qvrTkCV4KnlTNXFT+G2mOmPKs74d5jy7ca
9nX4nUe4b4e8q4ofJXPVsWR3bg7z4448xlzf3BE/66ZlyIT1yOG4qs8982TU
I+M5ooN65O86jvR65LIMHWLF83swZZw4ceLEiRNnfUMa46TUp6xm7GN1bCle
V9IjDUe+611/7d8XEPcd9vvErzQcad5zfKF+//v/qHZ6pPhXVY8jaIzMjJiP
QwyZk/Y4Dbix0ryYi9bI2Tjcx1EtzcjJspJ7OIQdl2TkZKg5ep9qJr0cupvD
aZLIipKRQ55Wn7MKu40Jao++m2NMrIg5q2oHUvocx36fcay0xyAnh3JV/XMM
c4ke+e/rgfG1jrOG/zLgwYAbxx0dHaBXEltyP0fQ1UH7jpy3Sh9jV8fAe1v3
2Hfs+T6PPnhZ3W1ed+ziRPKrsu6YtXXHFj9mge6YsV+V+jt0bwf0dZj7dnRu
zvZOqvysvPvo77fMaPYgdxw7bva8Lrk9bj4eNxw5bL5f0/rc008dAkcexd8H
kSNP/0E9UvYjL3hf66odyGV6ZOTIOHHixIkTZ/1DDMlapNccSY/kPcmJnNxz
5GvnX/Ec+YR/r3m0euT7vK814f1I2HP02TiZ6uOYwq4j5KpypyNxZQm7j+Rb
Rc2x9L0cwo5ZwI6UkcOMyXuPkr2quFH1OkpGDvNjJt0cvPeYas9q4ncdXfYq
ZuKUKmuVPamw6ziGnBzhx4K1R3sduHGMHY4qT7Vjz7G5bphrbvXIb3o9ciIa
IvVwjKnvMWe/6hC8q6I7Suej40fqeCyEFdm3msk+JHlWPVdyryNmrkJPR5iZ
0w+8q5SJ0+sTP2aQr9qdl9MDbiTmdBph1urroBwd0R1l/3GrL7ojZ672gB13
wLfac3y5tSMM6fjR65BWexw37OgY0mTrWI5sPr62afTIaf3UM4fBkSFPHqWv
lTjy6Tpy5Ek/Oq/1tUuvNQyo9ci9fKzLTpw4ceLEiRNnfcPaY6BHWmYsXa8G
9zP6jg3DUI4jydf6VXhfd3R65PtIjyRfayH5OKI5+hzVYsraIzMj5+MIM+a0
40j5OGGfY151ao7EibwHSd2PlI1DmiPvPEqfI+06ys4i6o6w40i6o8rIQS+r
ZKnyYxPRIll7JNajjBzFjpCVMyZ9EncdC+7icNrjJGBI6Hb0WTkju2+YNj8j
i/pLX/qG1SONr9XwYj/MzhkJI2KODl8OaecRcnCYHf3uI+qOfNnhWWV+zEB/
DHVH1CMhE2cgvlX0rtJ9SntUuiNoj76jo3PvkT2orq+DsnKU/qh8qlp/JO/q
ts/M2dyR55Bv1eiNW/5y0+uPhh+3vDa5ZfVIk7Mzrc89c5j7kUepTZIeGfcj
T88Rjvxn9/r+SK9HdmmPXbmskSPjxIkTJ06c4x/iRmZFf+Q2n78DHY3G+zmd
GV8r5ew84X2tR7FH1fa1Gj5z7OdYkvRG2nMklsTeDepxVPk40Meh81VLzY0q
axUycqDn0fIj5qui5sjsWKpdR+519Joi9joiN2I3B2eq+pzVJOx2ZN1RdEXu
dkxAkwSvaisrhz2q3q86Fr8qcyNdUjcH+E8NGxqumrEe6XytqEeKfxU7HnPh
xlEB3CiZOJyZ4/mRva3kW8X81IHWHoktwy4P0iPVvuOAdhr1fiNyIzFjr3Pn
0V/uePYkdmztRKJvtc2NW15bVJk5oD1ibg7tPKL2SHxIrLjpdcdN0iIVVyb1
Nc+Ry/XIdXhVo6/1bB/z50Mc+Vv1a5detXqk4chlGTpRj4wTJ06cOHFO3kxA
ayR+dDrk1LFjOfM5NsKVTo+8Uf/o1Zfrf/HPnR65jv1I52udW45KKROHNMa8
UnuQ1OWY59DjiH2OOeXflJCfqvs4uM8xC9lR6466l0PYMFV6o2iM3OsIGTl0
HzIkPddyYkq8SF2P7ZycMftVJSNnxJpj269K+uMIsnKGzInUzUGZOoX0O/q8
Vc5XZYaUjFXDVNOGIx/8kufIBPVI71f1DMk9HSFDjjAbp+1ZRT+r6+HI1M4j
dniEXR3Y4aG7OIQb7fVOtgz2HQekO2bS68i6Y9bSHd3uYwKdHX7vEfoeW12P
HX2P25S56hmS83Iwj5UYcdv5WIkf7e077mPHkUm90Xx8teHIvuFIux/5Z7Xx
ibrf7cf9eQyun4Tzldp5WT9eH9zXGnnzeL4P6Gv9nfrVS681nDiuz4Ov9aB+
1siRceLEiRMnzvqHvKp0rP7ouZE0yKLE61PLaLvX6/ql775U33XXX9RuP+ko
diP1fuR7aT8y8Z7SwNOah9yI+TiYq5qVLa+q6nbs8Ko69qt0L0dHRk6Yk0P3
yWNlh7GVsQrsKNzoeROuY3cjZuRQ5wZ7WceTNjdCP8cw0BaZG70GiZ5V61cF
7RC5UfV0oB45362/5DlyiHok+VUxM2ckuiNlqaqOx5ZnNWfdsY+641D2GoUp
u7s6ZN8xa+Xl7FBeDmuSAT+id5V6OjBzNcxb7dId++JtpQ5H1hr32deBuTnS
BZmwb5X5EbyrpEcSR274Q/uRq3N2Hq8P/9+KDk+PfN3rnvGc8mQ8Bz5fhcuj
O0aLfP3rzc/RMw1H/mH92qXzK/XIyJFx4sSJEyfOyRzixLav1fdpWH70XYyl
62U0fDVf3Ki//8p363vu+Zj/N+b17EfeYD0S8lRz6HPkfFXZd0R25HycXHTF
lJ8r3JihZ5U6OXK/40iPg4wc7uVIwb8K2TmSp+ozcVqapPQ6slc1lUvZdRS9
0R3UHAvmwLHPWeXdyLH0enDGqmXJSeBZnYDmaHyrjhMVQ3JHB3Q7QkaO4UnS
IylnZ9B8DfKk6l3HXGXlDLwOyVok6JGkL6qc1YAPed8Rex+99kg5q+2ujiBv
tR/ojtD/yHk5nKXqM3Os7thmx53e2LMi9HWA7kge1lB7VH0dOyloj2Ffh3R6
CBsKP8o+pL/f+1qJHY0GueEZc2NfvtaQJ0+SHvmP/voTtdPY4jnYWZc2iXrk
73HOzoWOnJ2V50r7xIkTJ06cOHHWNy5TZ6o0SceQlWVI6mU0WajUpWEYqZpe
r1997eX6ne/8a/ve4HWvw/eXh3keazjSvLf5ovW13qhnlruy5jVQxyPvOdoj
vLg0HyenjBzPm8GeY5prnyrl3uheDtIfJV+VcnSYF+FS7TpCr6PzqZbsX+Uu
SNIbaZ8R8lXDzg7WHClfBzJycNeRr4+JHSEfJyGvqs9JHaP/VHYZB5ixit2O
oEWa5xgNz+TsPGhzdj5U98el6IfU0cFdHZS1it0dwI7cy9HhWQ38qjpnNVcd
HT3vU1VZq7DXqPJWUXfEfUfacSR25PspizUJMlcTlZHDvlXFikv6HpkbSXOE
zJygr4Mzc/yeI/MjMKRlxm3hRva1MleOrR7ZH1UrfK0n7RBH3j56pPv79ijO
U3B5lOfJ+vWvN3+nP1ffa/NaXz0YRxI3Rj0yTpw4ceLEOdYhzdHtQDq90TJj
4T7WPY2Ua1PWi13na33jG01O4rl6LXrk+z5c2/3IBLJwgBdTz4RZhvxYqk4O
1hx5N1LvOaY5ceNE7Tmm4FUVbhSfKvNfFuTkgM819KwmXntk/vOMSNyI3Rzo
ZR0loj8yNwa9jqwtclbOhFmSfaxJ6FkVvypmqobdjsNxUXd1Ow4pZ3VYWP6a
znbrBx+k/UjRI0mLZH1y1Parku7IjDjArBzdz9FDbuzSHSFrtbdMe0Td0e86
WpZUnY6YlyNa5jbvOvqPve7ImTmQnYNdj2FmzjZoi86z6hmS8nKYHXVfxxb6
VHfQ1+p1RmBI5McNZsixPZtbSX11Y9j8+U3rc+eePGUcaf4e+pRlE6d5PXVm
j2Gx4/naT8LlYemRv231yAtX9sGRIT9GPTJOnDhx4sQ51rE9jKo/Y8rc6FiS
+HLq+dLx12xxo375+9+tf/InP+bfWxxVjqPO2TG+1lFKWaiw1xjojcSEaZit
armxUj2OxI3czZFKRg5xo8rH4UwczY6sQaLmSNk4yqsacCOwI1+mE+BFx4dj
rx2G2aqkM1JHB+06DlVWDjFjkJEzIu2RdEbtV5UeR9EdJSNHdzvyrmNzadio
mi/qB7weaT+vZ7zB0n1HnbXKPR3kWWWNMWDIMGsVc3KCnUfZcQy6HvvQ09FD
fVEyczBrFTXHHdAdMUd1GTsq3dGzoew+wt7jTqL2GmW30ftWg/tl73EsvlXS
H7eFKYkd7efZcvxozvHqkTfrZQj1yGfrw9Mjnzqkz3Na9Mh16ZWoR/723r7W
ffDjxcvuxIkTJ06cOHHWN+RbdbyImqT3tE6AKT1vGo3P+FrPn/9+/e53/029
Nl/r+z5SXyc9EvYYSZNkvZF1R52tqrscw1xVuo75OKHm2M7H0X2OXZqjdHWM
QVdktmN+RM1RMnKo15H7ORLwrKp9xwnkqU7Ypyp+1ZwZEjXHofKsBl7VUXip
9yFxz5G7N7w31TDY1Ppan69/7j0frPvNa+53aI5d+46coRNwY493Ht1tO8Nu
3ZFyc9ifqm4H3yppjwNhx/3ojnSd9x17Wnfc7spbxbycXqr2HMO8HPasEj9u
S+aq5sfxUt2RtUflW22OZcaxvXRnzHqkuX51c2g58smnu/TIg/x+r2t3Ejny
U81rfc7/fXQ4/suj93je/Hn96+XydJ0n/d/pwpGXrnVw5F78eDk4UY+MEydO
nDhx1jrIi9rDKoc40+iRppvRcFo1u1G/+torfj/yq6AfHi1H2pydsWO6DPyo
oeaYUi5OXkI+zgR2HDHnRhgSNUnMx1Hc2MrHAc0x9bmq3OlYCD+qfNVCc2Oi
dUPacWTtEblxDF5V2nXE7FViR3uKWvJxUHfMve5YKO1RMldRcyTvamH1Rp2z
6rXFkc5YNbxVzeb1Aw+SHjnxemSw04j6IvRwYMYqcSNrj33hxpbuyNmrkrXa
6uro671GxY7BHuQOZ6ymcD3hx0heTrfuiB2Q3NWBnEh9j+xpDTiRezug44PZ
ccy8GOqOrD3uACtuOf1xw2uapEma26/Zj0eWI3ujsn7q6a+u0CMfC653nVX3
HUVe6182r/NTDaM85/Wuw+Sec3B5cs7rXieXBz34/PWfp5q/042u+rWGI3+n
rUfeBD/S7XHixIkTJ06c9Q1qjUVBuTpTydUxfZET7GacWo4qTc7OecORa9Qj
32v0yJnlq5T3FyUfJwnycdLOfBzacZzwnmOaaWZM0iAbJ6OOR+zdgGwc1ByB
HYX9yL/qs1WJHcnHShk544Abx6g3EjvCjqPyq+biW0W90efksK6IGTnsVc2F
LUfCmuRb7ftuR85XHUJWju/l4H4O71XdZj3yG/XPvedDzX0Ty4XOSyodjrIL
GexDBnok64vEjMCToSbZQ78q6o7kRx2IrzTseHQ+VqM5gu7YCzoeYd+RPapB
1qp4VxOVu8r7jr1U93Wgvgh7j1vboktK5ipojDtae2Q9ckvvPdpDOqXnSsuO
W6Pm0p/m+pXNQfPnUdVP2f3IZXmtjwfXT4oe+enmtX6tdjuEN8dX3ecpuHwK
Pg5vO+sHvxf7/T5167zsa31boEciQ+6XH69EPTJOnDhx4sQ5jlF6pM/XId2R
2TGf+o8pr7Wsq+pGw5Hfr9/1LqdHOs3iqHN2PlLfuOH1yMx1cbD3lDTHlewY
dDl6NhyzDkm9HI4dw2wc+7hkovNxwj6OpJCdx1R7VaWbQzo5WuyYSKbqSO04
SoaO+FfFszryeuNIZeT4XkfUHKGbg3cdYQdyOBTPqmJH7uCQXFXMyGGNckR6
ZFpXs4XVI3/u//xQ3Ws4ssf5OMKHkrEKvY9+H3IHslbbu45Bx+MgbeWv0h6k
3Wsc6JxVe39HT4fxqtK+I+uOQVcHelbJo7qN3tXWvmOiM3N6CfDjmBlwC3yr
Le9qR0dHuPeI3Lixqfce0bu6QdxoWLJhR/MxaZYmZ8ftRx5mzs4TcHnYx/wd
YTJaP36EeuTZOUfrg92vbtvWIy1HXu53a5Cr2DG4LU6cOHHixImzvskog5V5
0TGkvd6c3J7KnsxeOrYy+5Gv2d4Pp0euy9dKeuQ4nSj209k4oi9il6P0N7a9
qtLR6D2rlImTkmeV2FEeyzpj0MsxQm6Ejo4R7T1iRk4yAV0xyMhBTZL6OWjH
UXVzFPUA9h3Fr4q8iN0ckrFqWHE4RN1R9zr2oZfDcaNkrkpGDu4vukvDUeW0
4cgHvlH/vNEjm/8my5cNz6FfVWfleD2ROjqoq7HV0UF+1sCvyh2PkqPDOTl9
2Xm0B/JydtjHKuxI+47b0POI3LgFu4+tvFXo6tgghtzR7Mg7j767Q/V1QE9H
qDvy7mPn3qNwo+LHLfKujtTZsAwp9/F+JOuR/90ymvMa3ArrIUsenR75+td/
uvm74jnPKeeO+Dzlz1F/ndN0nobLVedcfeedJpvt6/W9b2848mLDkV2+1i79
sYsnI0fGiRMnTpw4xzK5Z0fhRX8JvYz2esOPdJk2bFRWu/Wr5w1H/s/a+chQ
ezjM87j/t+sv1u997x/WuzdmloeS5jVQH4fk5Eg2DrIjZeNwl6PhPMjH4Ywc
3+Wo8lXRp0qsyJmqBTOt0h3HwI5jZMdCa46J6IPCjbTrmEu3I+Sras+qaIvM
ji1uLGrs5Bh6j6rTHAvJxxkCN5LWOMz4funm2CMjx7PkltcjH3zQ+Vp7zdez
j+lnSzNWd4D/ZL+RsnFSfVsra5W4ETseiRMz5kTeieyFuqP3n4LuuAVaY1fe
6pbyrCasO+K+o2TmUN4qZq4636p0cfh9RcxV3enaeyR9MWFG3NwaQ2ZOwr5V
2nu8tjViVhSuFD3ymvm4OVc2hs2fT1U/+dRp1CM/0zDk1/3e39PxdBzDccfx
XHfoz0X0yLdhzo7RI/fhXV114sSJEydOnDjrG2JIx4yl97KWVnek4xjS56IW
leWzSXXd+lrf/W7DkbQfeRR6A+mRD9T33fcn9fUb04alHK+l7E2lHUfMTcX9
RuhyhE6OJEGtUXo6KD9n5P2qY6U1FqJdYvbqOOhy9NeHY2FP7HEcshbpL5kn
db7qEK+H3DgWRmxxI3U7Dj1Des1RMlYL9qu6vNVMcnLQq+q9rMyalJ06xHxV
0SvJk2rYrJyanJ3nW3pkmJWDGTnS4xhk58B928HOo+w1puBZTYEZU7fvSJ5U
9Kuy7gi+1YAb2/uOifasNpcbft+xrTuOgBnHsO8Inla/+6j0Ruh5XKo7UmfH
tva1bng+tNzoGRJ1R9mH9LeZy013rl4bNn9+h61HHuVBjvx0wyhf897N48/B
EXY6W8foiXR5s1runXd6X+vbf1v0yEv9zuycvTTIyJFx4sSJEyfO8YzlxKIS
ZrQMSXuRwo5Wh/TdkYadpvPr9Yvffal+y1tMvsW5QHs4bD3SceT77/tjy5GG
wRLytabCkpin2tYbJQsHtUbOXKUuR95hBHYMdhzpPsxUbeWqeiak/UbkSdEc
dUbOiDNycs7IwV1H0hx5x9HvNVJWDvZ5CDfSjmPhc1UztevIXlXeb6TboaPD
a4w6YxUzckiLzPh+w1jV1OmRP896pGiCbXakXce0xY07feRGyFPt0V5jJrqj
ymB1Gaucs9pPO7o6EtlxxLwc7HjcCXXHVPYde+19xy1gw/a+Y8K3b8DHXfuO
ig99V8cm9HRQDyRpiRu080ieVdQot4QdrwE78uVmoEeeQo58/es/0/xd8XXP
OHt5K9dxTsrrONxz551yeXPnXP2GNzhf69uNr/VCw5FXvB55QP0xcmScOHHi
xIlzfEMMmRXAjp4XLTfSdc+Upq/RsNd0dqN+8aWX6je96S/XwJHga70+sxzG
+aigNQo7wm5jGmiOiebGMbNi4f2rhWSqEkNyNo7zrLZ3HIN8nET3cfD9yIuh
VzXkwCAjZxjyI2qU1Ono9UbnP4Xr4FsdeG5UuuNQMnKEIXNhyAHsPpL2OHCn
xxplpu63euRM9MidYc5ZNuJn1d2O2OuoPKuDNODDDHJWpb/Dff5E2LEPHY99
8KFCFo58rLNytv2Oo9YdJS+ne9/RfxxkrXLGKuqOuO8Y7ERi3uqmylvVXlbU
HSlvlXYeiSc5kzXQHYkhiR+v2t1Ix5E7DUd+9RRy5I/92GcaRvm637+7Fc45
7PMMXJ7+82M/JpcHPe55Tzccaf4/4/n63nt/V/TIyx16ZOTIOHHixIkT58RO
ytxI7Fhyj0YG7JhxN6PT8Sbl9fpHr1LOzlHvRxo98v76ve/7SMOR04abfJZN
Blqj8qpCTo7KVdVsqBlSsnDGoEmOoZODdx2BG0esORbgWUXtMWfdkbXGMB+H
eDHQHUV7zEV35IycgvmPNEfiR5WTA/mqojei7ijc2FN6Y1ZLtyOyY859HaRB
Yk4O+VENW02ms/p+z5G9QaF7O9DDqnYdyY8KXRyYs8q5OXLcriN0dPQTpVny
viNxYuhb3ZHHiWc14fs3WXekzFX0pY6VbxX3GGnnsWvfMfSuat3R7Ts67yrm
5SRad9widgSuZH0StMdNfz/ojsSOyJDm+uVTrUd+tvm74nm/y3dznHM052m+
1Fqevu0sH/3fKDk7b8ecnVCPjBwZJ06cOHHinOixvlXkxRyZ0XGj40mfsWM1
v6Kezq7X33v5u/VP/dTHa9Ejj+L9JumR99e/1HDk4sbMdtqPPfuRzjhOO7yq
2MGh9hwxVxW8q4necaTL4Vg6PSgLB3NVR3g/643CfJyvCvk4nTuOyq+qezns
beRVRd8q6Y2eG7l/g9jPZ6q2PavAjEOtOfbB19obQq8jdzpm3NnRg17HHmTk
GDYqq7nr/bB6ZMG6Imas0nXyq7J3tYe6Y6BH9hNmxO0O3VHYUTRIZEfhy1Tp
k5KjAxmrITd6rXFzRzoenQ4Jeav70B034fZNzskJdEfIW3W647ilO4omKewo
zwHtEfjRXL8a8KPjyZH3tZb1V8999dRx5MnVI+WETOWuny29cpWGSdos6ZFv
f/vv3hJHXghOnDhx4sSJE2d9k4LWyJeeG40+mXmWZK5s7jOsNZ3fqL/z4kv1
XXcZX+vT9dH7Wo0e+eF6cX1qOWo8Fs3R6Y9hl6NojcSMes9RHhfqjXq/kfJx
oI8DuFF6ORwvjqCPY0TdjNzB4XXFDq+q9qtCLwftNWKfY6A3SrYq7TpCr2PL
p6ozVvvc6Ziz5sjZOWGvY2fGKvVzyB6jYUvDU5PpXPTI5rX3KP9GdXOkoB1C
xmpHtyPvOULO6hbuOnLOqrDjVpCXE/pa9c5jwlmrmyprVfc4Ckt6nvT36Z3G
PXTHbchZpfwc5sIEeh495/HO46itO24DM6IGuSnMyKwIDCm7kiPLkG4/chDo
kYeR13qUR3o/7rzzsw2fPO855ZkTeQxH0aVcf9bf/+yZPe6/kc4zzf9vmD+z
b9Rv/5nfu2mOvBD1yDhx4sSJE+dYJ/N+VubGvBRu9LclZifSXPpj9LxJtVv/
4Effq3/2Z52vdT0c+ZF6d3dWD4fS3SiaI+wiqv5Gn43D7KdzcVhzhGwd7uEY
YyaO9DmydxV6HFf2cUAXx8DfTteFFz07Qq4q+1WHojnSbiNn5EBvh/Bmrnyo
Lc8qdHf0OBtHMnLodtEbU+bDXkenoxzJyDHcZPXIB1CPhIwc5VelnNVUseN2
uOfon8eaI3R0sD65ImuVmdHvQ9K+46ZnSMxRVR2PwI2KKztyVltZq2rf0Xd7
qMwc4UpkxtbOI3R1bHg/67UOZmztPJLm2MGPhh3pvmubI3uuXBs2f45l/dWn
TqMe+bmGUb7h+ez42SmeZTxp/nw8R779YByJ2qP7uO8/7tsTJ06cOHHixFnf
WN+q1xoT0BwtM/ouxoTZ0vU1GnYryoXdj5Tej/XqkaMkl73GVh9H4Ts7/HXP
i9TtqHJVQXMcjcN8HNp3zEV7HIHu2MmOHfk4/vqAnyPX2ac6omxVyVftg2cV
2ZF2HAfIlSP0owZ9joOslZHTG2i90e09ZsKQyI3AjsiPYWcH65HNpeEup0c6
jtxuvs625z7VzUFdj9TPAX7VnZ7eczQsid2OXZqjZK1KPs42s59okbzzuJOo
3BzRHSE3h3RH1iODPg7KWlW6IzAi7Tv6HceNLdEvJS8n1B2h43F7rLiS+jpo
57HlWyXdcRN9q44THVeO/BEtks7ljUHD/GX9JPtanz1FHPnZhlOe937R4/dy
xrPsQM7Oz+ztaw3Z8eKVfoshzzeX56MeGSdOnDhx4qx1Eq87Ei8KP048OzYH
ehfT5hiGmkx26x/+6Hs+Z+fJel15rfPd0rKPYTXubuQ+DvKakgbpdMhx4FXl
7g3ccUzwPszHCfNUJR+HejeIH9HDKvk44mdlnrS7joXSG7nXMdhxlGzVwKsa
cqPq5RBvquw3Zrq/w3Nlr7XriNyYcv9GDzyrzJK054jHcN8gs9xVVLP6iw88
X//sez7o9EjjVd1JuJND8ldXZ6yabo4tZkDIxenSHHsJ7EF6dgTP6hZrkONa
Z+UkrD9Kx+NY7TO2tMcdvfOouNFf30TdETJzkBtZd/QMSVk6G0HHI/Ij647B
3iPqkMqzCpojsqXTI4f+9oYjr/WbP+NJ/dWnnvAc+Zz/N6KvntDzuGXdO+74
q4ZPoh55Os7evtYLAUNeVPpjn9nRPMcyZHNprseJEydOnDhx1jeOIRtmzCes
OXI3o79u2JHvs3mtRo/ctXrku95Fea2PeW3gsPefHoO8VqNHVo7DcLcRvKpj
ZMhE59/wfiPlq6r7Ovo4xiu8qtS3Abk47F9VeaxBvqq/7INXlbNwRqg5ZuxT
7QNXIjuqTg7VywHe1IHwZo+7OoJ8VbXvmKleR+JKZsmg15FuEy+qu264aVLN
6/vvJ18r6ZEpZ6u6zkfaeUz5fsxY3ca9RujmQH7kXcee7Dxucj6r7DyyrriT
+Hwc7OsIc3J0Vo66rnogkR8T7ujYoLzVUHeEvcYN1B7Z0zpmfkSGVLrj5rjV
16H3HkfgW0XdcSzXPTc6fhzac21jWF+5Omj+TMr6iadOnx5pOPKuu75pWeWu
u56L58SeZ+s3vtH8mX2z/pmf+f0WR164Eu4/9oEf3e3nDUdahnT8eOFyr7ne
O+7/O40TJ06cOHFuq7EMabnRX3rNMbU9Gj6fNZNeDdPRaHgrZ440vtZza/C1
PlC/970fqee7lfV+is4Y9jiKV1XvNkIuzhhycUaw29jhVR2M98jHGbW5Ubyq
tOtYaB6kLBzQIgfQ0dHiRurXwN1GZsdMMlYH4E/FjBzWHGm/EfJVB+4IO+LH
okfuoPZIPtQB6op619FocEXp9Mife88H6+1hBswouuMW7TnyriN1cyR61xEz
Vr3WiP2OzIo90Rs3w11Hrz1i1+NmS3cctzVH5McgK2eTezoSvs45OtjNAZk5
G1uiNQo3jmrxn7Yzc5AbQ+8q5uUIL44gY0eY0V33zLjhrl/h60aPHDR/rpjX
enr0SONrjXrk8mP47bhfQ0uPDPYjQ4bU7Oh0R3fMbT3Lj+byvL8eJ06cOHHi
xFnfWF7MSrnMJsKNmWPJMZ3MXRp+KtjX6jhSuO+w3yc+0bw/NDk+99fv/aUP
14tFVQ8Gjt9GrCsWWnP0O5DY5UjcKLk40qlBGuKgU3MMvKpBPg7n5EA2jvap
klc1Y4YcDPV1l7vazsdpa405dG7AXiN4VlFz3An0xh5kpKruxj48NtAbmRsH
oDmyHzXjnNWwm8Mw1KSa1fd7jtxpXp/TFMfQzSGdjdvgV93u8KuyRkmaIXLj
jr7e6UuFjg7WHWkPcifwq4ZZOaQ7Uo4qdHSQdzXch1Q7jexP9Rok8WTHviNn
5nTwY1t3HCvdUXlXt8agNZL+2FzfMGfkL4Ufr2y665cajtxROTunhyOjHrn6
vOENx/8alumRFxuOPA96JHpXWXsk/fGK0x+tBmkvm48vuRMnTpw4ceLEWd8g
O469BpkAM9pLZkt3TMZNXizqH/3o5fpf/su/rZ2vdQ05O+/9sNcjc8i+Ea8q
elmdHpl77bEQr2qX1oh9jqhHct5qzl2O0skhO5KYjTOgPo4wHyfo4+iPdNYq
7jL2MDcVsnH6pD2CV5U9qypjNVOaYw8zcgYZMGTKGauy/0h6o3hdJUPVa479
TBiS2TTh3Byz57jZsE1RTusv3v91yNnxflPyooJflfcelY8VM3Kk3xEzVlW3
I2as7iTc77jlvayYo6OYkXJVwbMqHR66o8P1O0pHB7FjqAleg6ycLk8r82Pg
V1UMuafuCPxIPMn7kEN/H1w23HiZuVH40TLlpuiRO6dUj4wcub/zxjfq6+s/
z9Z33+058h2/X78a6JHnITeH9h4dV/aEH40Gecnfd6nnTtQj48SJEydOnLXO
OANuzCbCjalmR6dJTliPnJS79csvf7e+996/rl1/21HrkQ9YjpwtSstYTh8E
zZH7OCQfJ+zkGJDuSJojZOag5jigvUfYj1R+VezjQM0x2GHk7sZRrjVKw5ac
daPzcYQRKR8HcnOC+2THkfTGFHypqeTgKEZs56uSXklMiLoielVph9HtNbr8
VNp1xE5H8zjDTnk5q7/g9cit5vXq3kbo6Ah2IrcCdqRsVdl1pMdBjyN5VbdF
k9Sa4lhn4qBPVemOep9R7TyC3iia4lj3cwB3UtYqcuaeOatbWnNctu94dXPM
mTlX0bcKuqNjx5H1rdpL0B2vboxApxSuPM0c+YY3fL5hlG95PvpaPEvOXXfp
6/s5B3ns3sex5B13fAv0yJHVFp32qPnxvNcfz7f0R+LHPt8WJ06cOHHixFnf
0M4j5bHS5ThxemSS0JnwpeGyarpbf+vbL9R33vmXtcu5WAdHyn6kZTzlVy14
17G7yzFnr+pgXKgdR85TJbYk7XFY1IPAt6rzcShbFTVH6OPAfFViSuxx7MjH
6Q3F08rcqLJXZYdxB3s5gBl1tqrecWStEvNVeb8xVXojsaPk6CTiXzU5OZ4b
t4A7adfR8FNm8lrvf97pkf3cMqNhNfGpBtk4lKHTS4NexxS4MpFdR85X1Rk5
IVsSK3ZmrO6gLim9jsSOoSZp81R513EkPR2KF/Uu5DVgx06/6hb0O3bpjp4V
hTllD/Ka1x5Jd7T8uCGsaLmROXG4lB+jHhnP+o74Wt/+jt+zeqTxtb7ms1dJ
e7Sa42XxsC7lR7o95rXGiRMnTpw4ax3Di5YdDTcmeOlzUNPgWHbL6nyyqF9+
5aX6He8weuQ69iMfqH8J9Mhhw2kj2HMcjtCfWkhXI3U5drHjSGuSXZoj6Yrs
Vx1mzI2cjdPSHCFTVWXi6Hwc6W7U+Tjc48heVdEZmRn74FXlbg7Zh2SWDNlR
+VSpuzHQHFFv5F5H0hxTvuSMHOprhE5H0iO/+EXHkahH6oPZOInmxd5YtElk
RtXN0ZWV05GRE3Z3KL2R8nKgowO1R9pl3AbPqt9zZN1x2Z7jkpxV1fG4ct+R
PqbnYNbqkLNWKS/nahc/biznxi490uTsPHEKOTLqkevRMG/9PFfffbfXI9/x
+/WPLr5aX/B6pO3xuNwDdlytPxI/0okTJ06cOHHirG/GxJDsX6VTWGZ03YyF
ykI1TJVZjvxu/S/+xd8ARx7F+03UI/+wni8mlrsMryE3DmG/cYD7j+BV5czV
YR54VYn//H4j9TOOiBVzxYuWLdUl5qrCfiMyI2erymPZx8qPgR5H1eEozEj+
VOFDyFeF7Bz0s273gQ17GXdziGcV2VL8qcyOxI/EjH3xoLY6Ofwx/JNNZvUX
7heOdH2OY8ll5X3EFLyqYfeG5kbUHTd2dDdHKyen1fsI2arbyI2QkRP0cih2
xF1H8qkGWTnXkCG39LnawY+oPYruqP2qVzFnFXRHysnhsyne1f2wI90n2uWo
vqR6P/6sPk29H3fd9YWGT75tWeXuu78ez4k9X6vf9Cbz7xPfrt/xjg/Wr154
rb54peHISzs+dzXgxBX6Y3jixIkTJ06cOOubxPCi1xmZF1O6nLjrwJeUfVoe
g6/V6pHzsuEkr/8RJ6rcVdmDxFwc3n8kXvSXrAl29DhSHwcyo+iQuc++CTyq
gZ7YH2qtkXJVVT7OMIX8G82OwoyQveo7ObDnkbmxL7uOeseRMnJS0R778LWY
G9118qrqTo52Lwdm5GC2KuuR7GvN7OMc4zlu3PT7jpSF0/KqbgdcyZrjuMWM
KmNVMSXwImSsbsDnueZzWNmLCvyIPR7XkCu3hRU3urTHrl1HxY4jpS9e2xSW
lP4POkP2qzp2dCx5xeuOrEnS3qNiyg5uDPiRWXPjdPd+RD3y5B7Djsv0yFcv
vlpfvDrs3n281F+pP0aOjBMnTpz/n73zAK+juPY4GDdcAINNCEneo4Ppzca9
917kXuQmufcqyerNvdI7CaSSUBISCAGHZsC994pt9eoOJDnv/M/M7M69kowc
2cb2m/2+8+3V6u7O7MzKnt/+T3Gb2368zWdHVYtRMaXvwyr1GXXtxXz9GTx1
/MT3tHnLJrrpppeptHl2ruPvhV6xnWKv2H9WFl/uAO930u/u+5S+j/mOjs/4
lk7M/JZOwmapzydm+Z9x/IRlx546Tbn7TG6c436OVBPHGFCHw8qnmuf7pvrs
6PuqBvur2jGQXo0Ouz6HYUsvxtHPj2N/tv1UTZxjlu3DGpAf56jvm2rnVNWs
mJnl+7Iq3VHHNWbbvqqBtRw9n9UgX1W7fmO6FcuYYbGl4T5w0NETp+mdd1W+
1nRmfzDjkUzjq6r3GVb9jZJ8Ve14Rkt79HKsZgSyY5r2WzW1OjyG9OIcC6z8
OH6NjiNerKPFj1ZdRzknKKfqkWK0x6LMGBTzaGo7erqjnzNHxT3aemJwfY68
wHhHw4Ol0R3TLM60edPSM6FHpnt65NP8d/sVcyT+rj+5SG2FsO4VV7zi9MiL
2CpVOpMeuUvrkRY7BvPiD/Cj40i3uc1tbnOb2y785mmNYMRCv25Gvq6pkW+Z
1NXIV5pe4bHvaMeurXT//abuxw9z5JIrDhNdQT+Kfdvhe82Hxkf1qJ//xsuH
Y//+GNl5b4rojkE1OfyaHSaf6lEKrPcYmB8n0/NbLY4PC728qsH+rHacoxfr
aFgv2/dTzbT0SE+DtNgx0/JV9XLeGJa0/FWDNUfFk3bNx8BYR5MfR/xaT35L
b2s9Mi3nqOZCU5fD0h4DancYLswvkgfnSDHc6OfBsWs75lssafusBnKjH+fo
+6x6tTk0U9p5VovEOgZxY/BnE+vo+61a3BiQJ8fPtyq+q57mmBvksxpYo8Nw
4JniHYvwY/Dv9PUPatvPHJmRdZI+/sTXI8+Pv/q51yMdR178dvXViiOrVPmS
ypUzHLlbceT+s9cfHUe6zW1uc5vb3PbjbUZjFFYsCGRGX49UmmWuZktoc4XH
v6ftO7fQPfe8RqXNs/PPK/J/NI78ruG//HqOAXlVrfocwXlxAuIcLW0xoCaH
pU8aX1Xoh4YbswPZMVhXzCpBb/RiHeGjGpQfx6vl6GmPxqzaHVmBvqqqRkeB
56uq9sG+qlYtDntv5dHx86vqnDlZvi4pDKl9VcFPhQF6ZKGOScxTfqy29mjV
fPTqOQbnyQmq32HX3/CYMd3WLQ0/+hx3WPNiQI0OO85Rf9c7nlZM3pzgnDhp
gQzpcWFArpxAfvS4Md1oirlezhwvV06az4/BeVZLZEeLFW3NMcDP1XBjmmHH
XGWHuW22A99k87Nx4pLUIytVepc5Zb3mlVXOLkKrXHmVnh88V+uZIxNo117m
yINajzwL7dFxpNvc5ja3uc1tP+5mGNJojYYbDTOqmEPUaVTfwXEw2NHj0CO3
UO3avxSOVDFUH9OZcmLYHNnsivWltHXUotxG3q+k2Gav03cfnqb8t09Swbsn
qfDdU7L37YQ+DjshP9sc6eVdtWs7Bsct5hwtyoy5VjykVY/Di4O08+N49TWs
GMcANjR1Hf3flaQ3Gl708qpaNTkygvLjBNTlKC6/albROMcMjxEDmTEw/6qV
V9Wu55jp51hNs/xQDR+Ci46eOEXvvKM4Mi3rqM+MmQVWrGMxdThsngzKk+PF
N1q1OTz90a7t6DFjflCsY16R+hzB9R0DcuV4OVPPlGPV1hYtv9Y0/3eHLH70
cq0eMeZzX7F5cn5Ad/wm6Gdbp7T58aCtPWpu/OZwnjLhSeXXmgG/1k98jixX
bgX/fX9ykRr65vxaLyXD/AT6te62/Fr/e4Z0HOk2t7nNbW5z24XdcjU7qlqM
/t4wo/Cl7I979RpFjzz2LW3fuVlz5KdnzZGlz8f4MV11FXSHP1NIr2Q69e1J
4SnxHzVxjMXV4tBaYwBHetrh0UDNMfeYl+dG1XI0PGnFQ9r1HXVenMwivqra
39TKeWN+n6XZ0I99LKEeh8mvqs/P8OIcCz1G9Gt2BPqpmvjHjGxfdzQ+qsH5
cYrXHBUrBuiNnq9qga83erlVVT6c4Bw5MLBM4fHT9Lap+5Gt/FqNflgkz2pQ
XUfRJi1t0GbFInUdvbobeUG5cPIC2NLXJjVbpll6ZFDc42GLFb36jsXVdjR5
Vk3Mo9EhLV9WU+PxkJVr9Rs716rU6LDzsBYXC1m8z2owgxqGDGTGPN1ervps
+FHrkfbxA4ecHunsfGuSX1OVKng/YemR31h6pONIt7nNbW5zm9suic1ojj4v
2nqk2R8Ty5V6jdDyCuno0e9ox47N2q+1dHl2Ajnyv8vXevq7E8JQYDmbF4ut
xcFM5nFkg38F5MUJ1hv9fKpH/fw4ns5oM19gXpyiPqqWr2qQ5phl8WWw5qg4
zuRTPerrip7eaPLjFATGOBpN0qvHYeXIMUxo+awWzY9ToDVHU7/R1HPUeVUD
uNHkx7G5UTFdeoZV91H0yMA8O2l8j/j9YeNvGsSMfh7W/KJ6o+W7GpA71ebG
gNw4gfx5uJjaHEVyrFq8GBDnWGz9jjz/dyZfTrrFkF78os6xquMcFfPl+rlS
g/OsnkWuHHvv5VoNYseDRms8nBvw2eNHo0kKS+aIHTiUxc/R8QCOvFT0yMqV
/8x8skFYpUqV1c4uUsP8VK36Nf+7voE5MpF27nEc6Ta3uc1tbnPbpbiZvDpG
a1T74z43WnUz8nRdRvBV4VFbj/yC13KG+0rWDv55RYHFkaXVG/7J6w3EX77H
HJlKp7497umRdu1G89mLV9R5cWyODIxvPEp2/KPRHANyquYWWrUc7ZocRX1V
MwNqcth6pK05+lpjhuWrmqHz4mRqlvS50dccfXYM4kbjq5odGKtYJEeOVZPD
y73q+asWetyYbvhR1+UwmqPvi6oY0o9xNFxp5VdlA/cgPtLokUf4vkwunCL5
VzUbejpjQH2OYhgyPS/QVzWIF/3vWPxn8eKRYvgwOM4x4LOlPXq5Vo0WaXRQ
7asa6K+aG6gVpuUG5Fo1euTZ1HgM9l09aF1f2PGI4sWDh831c/V3cv3Pwo85
3jHDkPhcnB55qXCk0yMvDbP1yP/5n7LpkXut/V7HkW5zm9vc5ja3XdBNsaLW
HPOOeXuwo+FGVZvxmKrNmKd8OwuOfUdbt2+iu+9+jUpbP7KsemTPEKNHHg2o
sWFzo2/qOwF5dozfanHsaNXi8Gtu+PlUPZ/UbP97RXKtZgfqlpk5RwPiFw0v
Zniao58bx7BjUW604xwtzTHbqsnh+aQGsmN6kRjHgiL5VW3tUTGkX5cjLdOv
46hqOurzdI7V4mIcTW5VMEwB/FrfWRWgR9p6YwA/2nGPmi3t+o2+phioPSot
MqiGh50jJ7g2R3Btx7SS4hzzrJhGizWtWMfg+o4BdTg85sv1/VB/IFdOcXlU
Pd/VYo57cY6aDw8G6Iu+9hioOdrcqOygWK7s9zNHpjNHfnwJcqTTIy8NC9Yj
z4Yjg7nRPub0SLe5zW1uc5vbLuwmvqv5Sm/0DLyoj+fI52PCkvJZ65HHTn5H
a9at5zXBS5ojL5QeecLTI7O83KpHvVocdj5V/D7Ar9XERnrsWFhMHccgzVHH
Ntr5c4J9WL3zLc3R0x6zLF/WLD/e0edGkxunQOfJsXxVs4vXHL38OCXkVfX2
Hjf6/qxpJt7RjnXUfqseN2o+TDc+q5mGGws8X9aAWo127Ub9PaNHvqP1yDTR
IxWjGW5MC9YdNQcesZkxiBu9XKol+aoG+awGa47F1ebwYxmtXDkBjKlZz9Id
A2s7+n6r3xzxNcdvgmIdS2LIYH9VmzeLq/EIXjx4xPdVPRjgr6p9Wy090ufH
wM8HvWO5micvbT3SceSlYT5HbiwVR+49AzdeUD1yE9sKZ86cOXPm7DK2jXRW
m683al7M9/XHnGCuzPP1yKMnvqP1GzfQdde9bHHkmfNxlJUjoUeePH2CmUZx
mRe/GJx3NaeY+MiG/wqMWzTcmO1zo8+OVn6c4uIbA+pw2LxoWK74/DiZJsbR
qskRrDemm7ocdn4ckxsnK7CWox/jGJRX1cQ7Zlk+q/r3xj/V6IpejKOlPRrd
Mc2OgyymjmNAnGNmQYDeeEj0SD9f6xH0A8yYZvFgsX6qQfU3iuFGjx+DYxyL
qesYkGPVrr1h+6UG5MjJL+KvamIeA3xWi6nt6OfKySuSK+cH/VWDtccjvnm5
cg77dR69uEeLYwP0yMPFaY/+9w9aPxs9Ej8X1SNR5+9j8Vu/OA19U/UjK1VS
HFmlCjhljTAL9s4uLsO8VKu2isqX30S33JJ0Ro7ceyY98kA27Tng72HnZdvB
dgf9aDWrnDlz5syZswtqt7Jto1JtHkMG65F67//Or7eYzXxVUPgdbdu+ie6t
/dp5j48sV05xZI+eqXTC1iNzLH2xmFocmUF5dvxcqkH1Gu3cODY3ZvtxjV58
Y4Cvqu2jammPVn4cLzdOtsWL2QUBzJhuGNLUaMwM5EXDjHZdDj8/js+PPi8a
rTHfi3E0LOjFOxpmzPTjHdMsf9aAWhwZgQwZnB8nwFdV+6WCSQqOnaa33y6q
RxaXX9Wr62jX7tB+rcZXtUgtx2K48VB6ST6rVpteTh0/f6tXj0PXdDT5cYrl
xqCYRzvHamliHYMZslh/1WJqdPi6Y1CsY5E4x5LY0dcdg4+LFqk5Mo058qNL
Uo/8C3PKRsePF7kZjqzAHPm//1s8RwbrjwFmuFH/bH8+L1vfYv6PdebMmTNn
zi5n60ml2gwnGv/VXC+vzjGPHXOl3qL+HuILmZWOHv9e/FqrVzd65IofjHU8
F/GRJ789LpykcrYe9eo9Zlt+qravqmlP8uwE1duwa3Jk2dzo+atqrTInqE6j
pTMaX1UT2xjAjnZunCyfFzO8+MaCgLocXg6cIL3R81E1tR/t/DiZvo+qpzea
/DjGHzWjoIi/qu+nammPJfmsWjUiz5RX1c+Tw1x2GHU/TtHbRo/kPgb7q9o5
cnxt0tIe0yx+tLgxIL+qrT0G1Oawam8E1OfwmfGQzY8e62mGPBIY1+jX5wjM
s+rrkWfOserl1LH2h44UozsGcGNuQI0OT3cMyLValBttNjzoxUAWZccDZq/b
wn7fN9n8jJ2gj736kV8zR0L3+/QiNfTtK+7nq3T11e8xn2wSVqlWba1Y1apr
vc/OLg7D/FSvvpoqlt9Mt/xvcgBH7i3Gb3VvkOYIZtxjHd97MEv/Pqt0/+md
7fZECf/HOnPmzJkzZ5erPUil2oQX821uPK51x+PCjtm5eq9ramAPrjp6XMVH
VqkCjlyp9cgzawe2HllavQEsWb681iOZI0+cPsFMZdfW0PpiTqB/qvFJNe0p
PVIzYnageXpjjl+bMdBvVeVVNblxfF70uTHATzW70Murmq71x+BajgG8aOmN
SnM0cZCBzKh4z8+hkxbAlfmeNmnnv/F1yCB/Vc2TJqaxiOYYUM8x38+rmm7l
1rFy4gTnzxE98vhJeuudr4QjD3M/jdYXmDvH2hejOZrPh4OY0dYbDwVxo+e3
muazo8mb4+XOMf6s6bl+vKOnPfrxjXaeVTtesaQ4R487g9gxOE5SdMc0nw+D
8+QcDODLXD9nTrH5cgK50edH/3hx7HjAMKQ5frg4v9aLX4809SNtjgQ/2jzp
7OIxjyMrbqb/vUVx5D7myD2aIwP40eiPB4vyo3wftp8/78f+PHHkYyX8H+vM
mTNnzpxdrlabSrX5OqOxY95e2NHUZNR1GZUeWUj5hd9KvlZV92OlaBbnlyP/
Sj1DUpUeqf1Gvbw4ObaPamFAHKNpT/TIIvlUdU5Vi0F9bgyKb7T1SIsTvfhG
6zvpWp9Mt3xVvbw4WYVF6jgaZjTao/JnNflvCj3dMs3yXfV9UE3uGz+/qpdX
1WZLU7ujGP9Umx1tX1WPFU0NR5MXx/JftX1VvTjGjDzhmHzRI7+ku5qo+Mhg
v1bffzVQZwz+HKA3lpQjJz3f4kP/u34sZL4f45heXI7VXC+/jeiOR3J9Rixl
rKOdkzU4N6vhyiI1HgNqcVh1Omx/1cM5xbBjYHxj0Xw6Pj8Wy47Gjvifxa/1
MtMjq1fHfp1Y9err5Gd/7+zHsGrV1vCztZoqVdpMt9yaQjuD/FoD/FYNQx6w
+JF5UbgRP+/PFn40vzsvm+NIZ86cOXP2/81Ky5GWzhhgUpORzezz7FyoBZR/
9DRt27GJ7rvvV8KRV11l2K/kNV8gR5ZunQg2LV/+c97/TfxaT5w+Jqyj8psa
TbEwIC+OYcys4PjIHKUvBjCjqbvh1XEsJLuOY2ZQLQ4/ztGPd1Qxjr6fqseO
nuZoam7Y/qp+HQ7DjulBe/FXtfguPSvfqucYWJfD1HP06jza+W8sXdLPkYMY
yPwi7HjEip30GNJiyWLz42QEsSEbOKjgGHPk21/Rncav1YtJ5O9ZsYkqX46f
7yZQc7R8UA03esd8/1fzHbu242HLB/Ww0RvTiot11MfSfJb0cq/aPJkWeCxA
lwzygz2UZmmJAX6rhtssdjyc6/3OY0lmx4NBfqvmmK0xejx5OMfSJM35OT4/
HtZapfU9xZQ5YnLdQ8yRvGZPy2SOXHHpcCQ0U3BklSp/ZU7ZJJziM0vg/ppr
FE+avbMLb5iLa65Zwxy5hW69JSVAj7T9Vn2WVLqj/H5/lmZHw49Gk4Rllu4/
vbPdiuPINkRvTcx19v/MNsdvpKNLPiB67VOidw//+HkVnTlz5uxcWGcq+v/c
vVSqTfHiMcWLVt0Mjy8tM8fAWvkFSo+8997Xxa8MMYxY1yEnTklmc+SZvmcb
rlmhwhfCkT1CUun4qWPCHWnMLpnZvl9rho4JzDDHchSPeRz54L8oe73SMlFf
Ij2zwNMcsZf6iDhf51WV63EbaMfjRd0G4vzSMo2Pqvb7RD2LDP+62Jd4jM3T
Gnl/2NTD8OpvFOhYwlxp3/ikHtE6mn1d7O1jadYx4Scv16qpX6G/a46ZmMC0
PF9jBIsd8Y+Zc4VZ0nICNEXFZEWP7f8mi/KPnaS34dfaJIEOwdcVuhobmPGI
9jUF1xhfUhOv+I1moEOaNQ2/lXQMe5NbFf07eDhb+uQzIxgpmw4cyvEZUNe4
gNnHcL2Sjpm27PPtY6ZuBnxDDT+CzdAudD5Ti0O0v4BjWg/EuTxu9nWxL+kY
zOPCw6r24z4c9/jROnYo22NQOXZQHUM/TB/3SZxZJj8bx+njf/6T1/xPXVIc
WbUqOHKzZsZgfjHH1nv7a65ZLzzp751dCMNcXHvtGqpcmTny1mTRI/cdzKPd
+7MCdEdff1S212NIix8PKH7Ecws7L1txHDmw9P+HObt8bEqDcbRlzK30n5cb
0X82/4b+85//OHPmzNklbxRezP9zpdQjlf541MvF6uVk9XTIYzqPjWJI5EUF
t+Xmf0tbtm309Mjy5cGQn0qNjpLskyt9rjvT92zDNRVHvk/deyTTiVPHqeDo
d3T85L/EH1fpkoVUeOxbZsx/c79OerGDeQWnvfb+U4XHqgLR6aHf0/Ed/+Jr
fOv5fuK+jp34Xq5heFSuyceOssH31Wh3+XzesRNo+4TiSeaj3LyTcgy+vsbH
NCv3uOQiKjz2neLHjHzRPfFzAR9P58+G8fKOnqbC42jnmGbHfO77KTp67Hse
7+PCfTC0iWviHo9oTQ/n4Nxc/r7U2xBGZM7ndmBg1UOa8fCdwmP/kmse1vpf
du4JPvY9X/uUx5SY43weY7SjdLoc0Ubz+N7zCk+rdsCjzJz4GSY1IzXP5eSf
Ejt26jv645++oDubxMvPmDe0bepOpDPDo51s/p2JR8Q1cwtwzW/lM9gHjJbN
Y4zvpmUe9TTBLO475iMj+5jy7WRuwhhj3jOzjyvGYj6CTy2umcXXMBwGFsUx
9OtweoHHjmgnt+BbGUPDbrg++pOZc8LT+dL0NfF9xY98Te5vTj7a4fs5kq+4
9XAe9/OkHD+UVuCxY6Y+diSj0ONZtIP+YG+Y0rRj2sYxGQ/+nmlbeBD95PHI
4e+iH+ZYWtYxOYb9frlmtrSZnXeax/+4/AyD9puVe0qOgSM/WrHCio+8NDiy
SpX3uM9btN64vlhTeth6T5M0DHntteudXSDDeF933Vq6+uqtdMttKbRjz27a
a+Ijddyjrz1mWdyYHag/Hsi0TB0/L5vjSGeOI505c3YZW1k4MkfHPvq641GP
F2129E3pd3nMkVu32XoktEP8W/t5iRaoR5b8PdtwzYoVV4oe2bffAjp56gS9
/8Gn9M6f/8Zr7XRmoNPMOydo5dfr6M23/kLbd+2nAuZB8Nra9VuL9fn9d/l/
U0b3bCrcCrY5SQcOptOf//IBr50/l/vNKzghPqTv/30F/fm9D4Xt8o+eknY+
W7mK3vzjn2nb9n3ComCojZt30R/++C59vnI1j8tJObZn32F6+9336cOPPtXX
PCXs9977H9N7f/uI1+05/L2TUvtyxScr5bt79x/m752U3EZfrFzDDPYX2srt
4Fww3cbNO6Ttr1dtZN4A75ykXXu+kfv+56dfC0PhGFgObfzlr/8Q3sO5mLtP
PltFv/vDO7SJ+5sL1mOWWbdhO/3+zXfpq683MEueFNbcun0v/fGt9+jTL1Yx
b5yQtvbxGL3DY/T+h/8ULs5mhsc9/PWDFXz87zwXmfJdMLe08/t36cA3afTh
h5vpriaJ9OXqzfR7bnsltwP+yWbW2rH7G277zzzuXwo7ZeUdFy3xvfdX0Fvv
/I3bzJC2wVIrPvmKfs/3jnPAj5nMoyu/Wid9X79xh/Qdx/AZ31v59Ub5Gd/d
tvMAj9F79PePPhc2BXsfOJTFz9DfeX7/wevPdG77hLDwh/wd9GnrjgPST1xj
1ZrN9OvfvUWff7lWODiTr7ll+35u5y/09398Jpyawcd370vjdv7K4/6R8B6O
gRnf//BT+tPb78vv8X7hCHMr7vl33M6mrXukDdz/lzyvv/vDu/TFV+v5+Tsm
3Ltxy2767e/fpg8//kK4G+djXN7i5+Xtv3wovqkZfD/Qcv/+8ef0G/4urom2
4b+8kq/5xm/+JOMOBgcnrt2wg37L7Xzy+Wpu97gc277rG57zv9Ff/vax8OQn
n33m6ZEql01p6/RcaFuh8+woPfKHONLWHhXTGL7ZwJ+V4fOPzVqXs9kceauO
j4QeucfokbbvqrBjps+S0B73F+VHp0c6cxzpzJkzZ/+dlUmPNPyoOdHss3RN
RlOX0bdjotnlFdh65FcXQI/8O7VpG0mzIqOpW88w6tx9EPUIGUibt2yneQuW
UvdewyikTxh1DxlEm7bsooWLnuHvDD5jDOm/rvo35fTOo2l9Y6hn7xFy/pRp
MbRr9z7eR1PHLgOo36Bx1HdAGDPpJlq09EVq074X9R80ltp26MW88Ta98+7f
qH2nAXKsafOONH/BMmazbXy9wTRwyERq3a4nTZ0eTTt37aWRoyfx9cZSx879
aeLkSNqxcw9NnDSD+vQfRb36jeRzhnA7m+nFl9+gTl0H0IDB46hHr6HCJWDC
9p36yPlde4TS0uXPMw9s48+DqWefEdSbzw8fNZE2b91BYSMnUedug6hX35F8
T0O5P1sode5i6srjEcLfbdOuu3DZb3/3tpw/MHQ8NW/ZmV755W+ZZ/9KXbr1
p0FDJ8k9LlryLH29ej1fK1SOoV8Ym63bd9HMyETqwtfsN3AsDRw8mtZv2ErJ
qUv5nnmMBo/nY+E0eeoc+umDU6lj9yF8nyP5HvryfC0TBuzO89d3wGjp66Qp
kcxuu2lY2Dg5F+306TeEuXArzY5Npt58bveQIdxWOM/vHh5nnvOQodJ2x859
ZIzeZSbs3S9Mxr1bzyH01LOvMNuv5T4O1OM7giZNjZS+Dx0xljp0GShj3KlL
b/p6zXqKjU+V+e03aAy16xjCnPkB/eqNP3Bf+nM7Y2SMnn3hNVrx6Vc8L6E0
eNgkatW2O8UlzGWu3EOjxk6T56Bdx94UOTuF29lDI8LHybk9ew+nAYPCpZ0l
y1+gDvwMDAydwOM/kJn/Y27nTWreqisN4r6379iH5s5fSv/8dBW1bd9dnsuu
fD9jJ0yn1es2Uuiw0Xw/4dyHYTzGI2ndxm0UGZ0k94cx6cj389mX6+iV134r
840xxv18/M+v6Y3f/onHe4C007ZDCD359Ev02RdradiISTSY57cdt415/eDD
D3jN/8wlpEe+UmqOVCyjmNH4t153nc+Q+Ozs/BnGv0aNdVSlyja67dZU2rnH
cGSmz5BBcY82Kwb4tDo90pnjSGfOnDkrk5WFI7Nyj+kaGpodDS/a/Jhj6ZM6
HjE3/7TERz700OuyjqtQQf07i5w4JZnNkWf6nm1gSZVn51O66eauFD5mMk2c
msxr6mhZXzdv2Z65YTzzQTKNmxgrnNW4aWte+w+kSdOSS5WT6Pty/6IvHl5L
M4akyHljxk3ndiJo8vRkGjNhNjPJUOrecwANDZvGbSfRuEmxwgtt2nXj/Sj+
OZ7GT46nEaNmUovWXZhLQvi8WJrAx0aNjaKWrXtQi1YdKWx0BJ+fSKPH45qh
1Kx5O2EJ9HPsxBjmAmag0NHMOJPk2Hhup++AMcwfI5lBp/E9x/H5CRQ6fIqw
0agx02nk2Nk0eVqS9Ldj534Uwiw6PHym9B3tgK9btOrAzDORr5lEYyfF8HhN
kDHCd839DB0xlTmmM3Xo1IvvJVHuZ/jImcw0ffk+u3I7UTRxSiKN5HZ6MBNF
RSfLeEyZkUpjxkcJ0/Rm1gxltlLjFkNDho2nOx5oTTc9Pp2/N5evGSfntOB2
uvcYIGOE8cA12zGztmnXhT9Hyj2O4fkFOzVr0V54TfrOY9S732ie847MpOEy
Rug7mKhN+x7Uja+J+0E7g4dN5v4Mp/DRU3hsorhPSTz+s2Tc1LEImoIxGocx
GkpteS5Dh0/m76VIO2C/ho1aU78BI71rDgubzv3ppMcoQY6F85y2bR9Crdt2
k3ueMCWBRo2LEp5r2bqzjCv6jvsB748IH8/HVDvoex9mPLDg8LDJcs0Jeoxa
M+uH9B7GfYmTMRo1NpLHrZs3F7gm+t61xxAejw58zSky7vi7GMAc3qhxK352
RnpjhGemJT+b3XsO4nnU9xM+nXm2Dz83vXgOY/h4gtxP95DhtGjJYrrxJ6+K
1ncxc6Tqm/JrrVbtr8woW0rhp7rB0iLx2Xx/o+yvu26jGH5Wn3989rqczObI
W2+bQzt376J9B3Jpzz7Ld3V/VpDuGKw9ZhVr52VzHOnMcaQzZ84uYyuTHgmG
NP6sOYEaZJalTaqfVc0M6JEFR0/T2g3r6aabXhPfN9TmUBri5yVaoB5Z8vds
w7/dSo/8J919zyCaERnH62JeV4+LpAGh46hz1wGyzp6k+WwIr6c7dunHa+1I
WVefTY7b78p/R3+95x/Ur2W4nAuWAhMMGT5JtChzzdHMTSNGTWd26C4a2/SI
ucIQI0bO4HV6KPXpN5KmzZorXBvO7NKrbxiFsE2dOUfW7yPHRvBafwwzzSDh
AazfR+t22jCTjOL7MOyBa0I3Ap+B2cbKNSOEh6Aloh0cA4v1HTCKmrXs4vUd
x8AXdes3pzBm3CkzUvjaUcwpU7mdnsyb02kqOFD6Pp06dxtIg4dO5H6men3v
0WuIMCKOyXjwGIDhwB/gV7Ay+g5Obd6qi1xLGGd8NIWNnELN2g2nn9WZxXPE
3MR8FjZ6puh7bdqF0MyoBcJsaAc6IvRStINrYqz7Dxoj9ziZWQh8JvM7fKKc
D4YSXuV2cB9g6GHCtSle37tCh+wbLuMOlsJ49O4XLsyKsRw/KU7aCeVxb9Co
jcy14rMoOb9Bo1YU0mc4P3PzuZ3ZMhcYd7xDmDZrjmqHx7UnGJrnHG2P133v
N3C06H54Nidqthw0dIK0jXueNFXN7/DwacyhPYU3ZX4nYDxm8vj2E01W2sYx
7nsf7nuduk3Us4W+8zE8Fw8/Ul+uZfqunqOews3gVfxuWPhU+VsZwjyJfo7V
fe/Wc7D0VT2b8dIO3s+MCB9BN9/8K+2z/smPvn4ryZAjulw5+N6+StWr/405
ZatmwdJyzXptxp/VHFcMWaOGv3d2bgzje/3166lq1e106+3MkXt2+XrkgWB+
DGbFkhnScaSz822OI505c3Y5Wpn0SIsZ/fjIozq3jjKpp+HVWyyUPDTISfPV
qrVUqdKrvIZbZWmIX5Ron1xZaOmRJX/PNrBkhQorJRbqjrsGMrPF8Ro8RfgB
a2hoW1hPYx2MtfFw5qHGTdsJT2K9bdo7VO0IZV6TXSqe/Paqb+mTx76mmNFL
aQyv+dEOmBEsAM5BO2AKrNWxBsdaX7Qp7gd0xp69hwlbGm0KPzdr0ZGm8LmG
H8BIYNMJU+K1BhbL7UxkHuorfCI8xKwA/kM74Duwy4TJCaLZdRG/3iF8bJ7S
q7gdMG3rdj2Er6BDoZ0hIyZToyZthSmm8vnglGFgF7Ap88Z0zST4fccufaVf
09B3zdDgDHAw2kY7YBphsY69aQr32+iE4Ei0jXkRHpoErW4aNW4dSjfXAcPO
U3zIYwQO7MD3OTNqvhojsClzZCfmf5wrY8TXGRg6jho1bavHI1Xawbxi3DAu
ig/jZC5wLvY4NkHzLjgOY4/nYMKURGEs9L2t5siJ0/jYBPUcNW3eQThVPUeK
bRs2bsP3PkJ4d9zEODnWhVm7N3P09Ih5MndqjEKpVZvu0o4ao9kyF7hPzAU4
eIyM0QRq1baHzLXhXbyPaNOup8wFzh+v+RD3A4bGs2WeI/TlifrNvLnA+wz0
/bE6jaTvhkOHhU0VPRN8rZgzVua3NbcNn13pu+ZdtIH3Md788nV69g6jwaGD
mCNf93zWS/ve50Kb8qVfxfvXqFq1vzEHbrV0xtKa0h7h1wrGqVED+02aJTfx
z5u8vbOyG8b1+us3MEfuoNtum6v9WnOZIzNKjHv8IX50HOnMcaQzZ86c/XdW
tvhInxmzNC8KM2YftT6rnzP1Z+RZgV/r5i0bqbbk2VklmqFiv5UlWiBHlvw9
26666gvNkZ/SXcyRM6ISeG2u1vrQcFq06iLrbqyNx09Sa334I4JrZkQu8Nrb
WGMLhQ6eSH/s8HfKu6agVDz5XfnvacUjX9Kk/nESBwcNTNb6otvMEu0Q6/KZ
UQuVXsZrfWh6zZp3pIjoRR53gWUacJ/QR/E9ZH5ATCL4DtcC36HvWP/D9xD3
ptgHzDiL2gnzTRamMH6xWP9DK8QxYTnmoX4DRwkrgCeU5qSYAjwUrsdonNbg
0DbiDSNjlkgfcE2wMvh01mzVd5wvLNZruLCU+Ehy3/v2H0UdOvUR5jK8O4T7
B47EvakxShC/2yZthtDP6jLzzZqveXe2XLNDp766HaVdwgfzceYhnCtjJP6q
E6h+g5YyNlNnKt6Ffte0WQd5XzA9Yr5wtZoLpempMUqS+5G4yD4jvDHCXIDv
wMDgJuNbCs22CV8T3C3cNVmNEcYNOinmcoIeI7QD3+XI2CWe/233kFA5hnbM
/KId8CWuJzol9z1U64TmfjDu4Dv4xYKPpe9T1PyCQTHHs2Yv9PRdMDA40rQj
vsM87uBI8KPRKcGmLdt0E91ZOFQzYys+Bs0ac6meo2iZC1wXTC/+1XydkD7h
FD4qjH7xi197Pus/Ni/+EEdeeeVrVL36+8wo27SmuPG/tA1aM9sUpENuYvYx
+x+fxS5lszny9tvnaj0yR3Nk8XGPpbXzsjmOdOY40pkzZ5exlU2PLNTxkRYv
giHtz+b3OUd1vlZVU2PdhvX0i5//SvTIihWVFgmeLMlsjjzT92yDxqnytX5C
d94NxklSTDE5TnwxmzRrL76SwnLiYzmbHn28EfVhLgEjeRx5/RbR9LAunzZl
Dv2m5buUVSWndPpk+e/oj7f8mSKGz/NYDutyaHr9B48VzjB+qFj7Yw0PzsBa
H+t6cOSjjzUUrhV/Su4nOPcRPgZeMpoT9CPoWjhnRuQ8vqby3wX3gBdwjyoG
LkYYpUfvoXI/huWgJbZhlgMjGTYFb4EZoc+BHwzvYtzgsxkVu1T8LsFT0HGb
NO9As+OWyf0gPhN5YPA90w76Dg0WeiK4RTTSKfHCq2Ak9EP4Diw3diY1bTNU
/FqnRyzQ7BMtrAo/1MiYxVY84mhmpOYyFuJDC+4aNonHqIG6pmi+CfKeoM4T
TeV3wupTVOwg/EWhs+IezRhhLqCl2mPUl9tpz+MJpja+nDgPOZLAf2Yu8Bw1
atJGfHijhBkT5ZpoB6yOMULM5TgZo8FUv2ErmintqPkFr+GdAvRiNUYJwqtg
RtwH2jexodBHEROJ8ydrlgPfYY4johd7ejWeaYzRrNkLlO/xpDhhRXCkembm
y1zg76Fl667SHu5dvc+IFlbGNfF3MWm60pExF+irGSO0g/jKRx+rQ1WqPMmM
tlb0yNL6D1xoU/HTq3mN90uqVq1sHGl8WFVs5Cb5GeyomHKTZsjN3h486ezs
DeN6ww0beL4MR+7UeuTZaY97dX0Qs9/jONKZ40hnzpw5O2srC0ca3dFnxkIv
DlLtbbZUv4ceafxaK1d+jddyq5n1vtC2skSzOfJM37MNLFmp0pdKj7xnMK+r
k3ldrtbL0KHAFGCYiBi11sf6v16DlsJUYCSfI7dKvhasy81av1eP4fTs469R
/rVHSx0/+VndtRQ1dpGwWLuOvSTfp2JGxUPwA23ZuhtFxS2VdTnYFv6Ite99
RBjH+FiCgx56pJ70Ywb0IeY2+GVCE8Qxw0PQppCnFVobuEnxUKxoiT37DJNj
xpdzADMtWA6MYvwuR4yaQY2btJNxgf4HNgVTNGaO7MV8ODt+uc7FEscM21X4
cLbV927MSCHcf68d5iGMLTgQrGt4SMX5hXh9F21r/Cxq2nYY/bzuLL7HRZ5G
2rXHIIlhxfxgLgwDg5HMGIG1wEj31H5IuGqm5iH49ELbRa6aCOZQtAP/TrA2
OBz3aK4JZoLWhjkXrgYDczsYTzCX8T0GayN/Ds4BqxvuAn+DsRRXq3w1mHNw
ZDSP22TN1ZgL8HfE7MUyRji/H5/XtfsgeXcwTY8RnlNwKNhXxojnF/6q7Tr0
lthOYUbt7wotFdcFw6r7UWxar34LmsVzMW2Wz8CP12nsjbvxcW7ctL28qxBm
1GzagtkS7zTUuCuuBgPjumZ+hU2ZP6+55gb+m5vDf4MbJfYZPgEXo+E9U4UK
a/jfoF+JHlmjxjZPU/zv4/fM5w2aIw07GtvMHGT2yhRXOiuNYSxvuGEjc+RO
uu22eVqPzPXjI8+CG+1jTo905jjSmTNnzs7eyqZHBmmOhhezNUt6v1M/Q7OE
Hona6Bs3b6A773iD15uKI+GHeqY1X6AeWdp1IthUceTdzJGRMSmibWG9DG3q
sbqNJVYOLGfWy4/zsUFDxsv63+ZIsBvW1bLWZ36AXyjW1dFRy+nN9h+U2t/1
dMVv6YPHP6XerYeLf6piRqWhgV2gR86OX+ZxF3wcH3iormg+07WPJfpSt14z
0Z9Eh2KmMDFs4D+jD42ZGC0+pNCrTN/BDKgHAp0Qx8BDYBPEE4LlhJG0bopr
NmraTnwYlbalcsNCmwLfRic8KQyM8UCMIPyEYxKfEr0L5+N+wJFoB3GT6Dt4
FRwIRhIfS74HMDD8b3G/s7QuN25iJDVFnp26EXyPi5l9NN8xu3Ts0l/mx2Zg
+GzKGEXMl7xJYKv77n9UzlGab7Joj+BIsB/6BO4C84EN0QdhRj1G4DBwpOr7
POF3tAOfWjCX+LtOTeLnZ4ZwJM4BoykdWemzYCwwo9FioWVC843hcZOcQFMT
ZC7qN2yp52KevBPA81e3XnM5T94JcN/RZ3Ao7s1ol/KeQDOwPb9gbfQfY2R8
nKHZ1mvQQvjZ8DveEzxet4n496r3BIqrEY+L2Fgwo/Hfxdz26hfGz+syrx2T
ZwfaMOYXx/DOolatm/lvbv4lxpEfMKds1zriudLOYDZH+jx0ww1bvL3hSWc/
bBjHmjU38nztpNtvn/+DHLnnDNzo9EhnjiOdOXPmrGxWZj3SsGK2xYuaLyU/
q/ZxlX3WUcmzk513mrZs3UQPP/xr4chKldS6DsxXkgXqkSV/zzZcs1Il5PX/
jO6qHcrr4lRe/ys/Uugu0LDAD0Yzwtq69r0PS27KuKRnvPY2MUfCNxTrauEh
/p5hMRwTf8rJqfR63T9SbuX8UvHkyfKn6N0HPqSUmS/Q1FkqNw3W/vBNBWeY
WD/UgLjt9tpeO5O09njLrXfJPchan3kDeVhRbxL3YHgI2hRy70B3kr5rpgD/
gu/UNedJTCDYBT6S4BajdyEusnGzdpK3JlK0LaV3gRl79w2jWGZGHMN3ob81
atyW4pKfoWncNvqJ+4FvqOk77ge8ivg9aHcwnA+WR9sTdN+ngFMmMc+0HyF6
5KzoJZLTRzROZlOcHx3/pNLq+H5wzXoNmsu54FO0Az3yltvulvuNiFEMjL7f
e98jwocxCU95+XeEI5mpcI9GZ+zB4w6GN33HuKIdaK7gVcN3yI/aTHIeJShf
W2HGOGrCHAnGknb0OwG0A803NulpGSP0Cf6r9z9YR7Rd8J28Jxg+ie646z5h
V+Obiv5BN8VzqrRllfeog2Zge35V/OtQYVjDjNBshVf5Hs1zhHGv80Rj9cxo
P2FwdbMWHYQjZ8ct17mLEkWnR4xkLP9dmHcpiO3sP1Bp9+B3HAO/16z5M+HI
SpU28d/g56X+e73QBn+FihXXMke+Ttdcc6450ubHjVqD3OJxZM2ahiGV1azp
rDQGlqxVaxPP1y66444z65F7fkCP3G3tdzuOdOY40pkzZ87O2sqsRwor+uyY
kR3IjhlZiIlUDIl9WkYB5eSekjw7Dz4IjlwjvqcVKmBt91WJFsiRJX/PNlyz
UqWvuY3P6e57oM/M4fX/Ys/nE/oM1tJKM1J6V526Kn4OnBLIkVNEJzRrfbAY
6sODQY0fKWIou3cIpXdbf0xHqx0vXfxkxe/o43pfUcTohcIu0BSh6U1nvgOn
QNMCZ0BvUtyVqnOEdpS+CFPwuh4+m2AUMKHR/6BxSk2L8Onib2qYIqTPMMkh
g77PiFJMMVjXlUAbogkyUyCOs0nT9pKTxfiRjp8UT01bdBQWi2MeUkyRKIwE
rsa4mZxA3XsNEQ3LjBGYEfUnweloA4baIdCGwUim78LVk2ZT83Zh9PM6Ecw4
mneFXYbI+WBt0Wf5fsDAT/BcyhhZ+uzD4vsb5/Udcw49EjGARvPFnIMNUb8T
2rDRYnv2AkeO8voOfhsUOl60VIw5+i78PmaW1M4UjtR+pOBd8Df8YGNFn1X+
qqh3As0X7yiMPovn6PE6TYTZZIx43JEjCLo0eE/Nb6r0uX3HPnJvYD6TG1Zp
qTOlnzK/UxJFJxStnMfIMCO0VLAgxsIwMMYIeqQZd8PVeLbwvGMujfaI+UFd
TMOmGHfMBfhUniPm90niozydatb6Cf/NzaPKlTeLrwHe5VyMBt/3SpXWUfny
b9C11/6dGWWHcN+519EMV9rHwERb5bNipK3OSmEYt1q1NjNH7i6iR+4pQX8M
tt3FMKTTI505jnTmzJmzs7ey6ZEqv06G2WcV+syo9cfMLIspswu0HskcuRUc
+RvhyMqVlT5wpjXfp+V8jiz9OvFLvrbmyNqhvAaey+t/tV4eYziS1+fiZwjd
hdfb993/mKzDE1KeC+TIEWpdrfSuFGGmELAYr6tNXB1qb6DmAn6OiVhOb7f8
BxVUKV385OkK39Kf7nmPQlqEil5lcsaEMKveced9whmmHeQIuu+Bx4VdxL9z
1hzx2QSjgFeUPqTqM4B74BOJ9b+s9Zkf0HfohNHS94VyP2Dgth17SRtK70pV
sXLN2kv+FNwnchTBBxKcIRyZ/KzOKZoquXcQV4dxA4uBGaGJ9e4b7rWD+wEj
obYhfECNbgrds12n3jL+SvNlHpocTc3bM0fWjWA+WyY5QcE78Cfu1G2g8NkM
rZvimvXqN5dzvTEaNYPuuudB4SrlA6viWh9gJgf7CMvp/LlgbTAVxliNkeI7
5IFF3yVH0QzFd5269BfmkphAbgf1PFF3U8adOdT4I2M8wF2KGdW7B2jDmKN4
HrcZEfOln9AOEeuKZ3CW9Z4AXIz+gU0x7mDt9jxG6Eek1h7hbwoGNu9CTN+7
Sx6l4aKFztDMOHDwONEjMRYYI8XAERIjjGciKnaZp2HDTxf+qXifYXTxho1b
q77z/Ko8Tskyv6iHOVuPEdoezkxbs+Z1/Dc39xLjyA+ZUXZavqbn1qBF+tqj
YdWtwpC1am3Rn7fyZ2dnMozXjTdu5vnaTXcwR+7YfWY9MpgdbW7csz/Qzsvm
ONKZ40hnzpxdxlYWjhStUefRyRBmPBrgw5qp2VFYMqtALD0zj3JyT9KWLRuY
I3/L6821dPXVal0H5ivJPi3n89iZvmcbrnn11au4jS9Ej4yOh36n1vrw36tX
vyXzQ4SnGWG9fC9zJOLLElOf9zmS13jIH4J1+UzNQ/ALlRhBZkvDQ/BH7Ni1
v/wsmiA4ZVQsPXvvK1RY9Vjp/F2vOkWfNVlHcVOflHwoYL7bmSNNO1OEu2bR
rbffI36N4gMbMVdy97Rt30vW90ofUn6G4B74PeJ7Jmcr+g2dUNhFcqQodoHm
ZPqOY8ivgxwwqH8IbcvEUoIz4PMJpjC5S8GQjZq0k3GD3oXze/YaRn36jdR9
XyS8C15FPlF7jKB7CiNNT9a62nyaNCWGmndQHBklDK0YGJotfEGhhc7UmiC0
1PrMXbOZhcxc4J5vv+NeYRswlsl7ej/zN/xNwXIqn1CCsDb8gtFPM0YY974D
R8l9C5vy/aDvmF/kr4nUmuCosVHUvFVXaQcap6kDCd9f8KpqR/n0glfhvwvW
nhm5QM5HvOdDDz8hz2DE7EVyPngVuVAxPt4YMfPBhxWcKbpphKo7qvo+S8+v
YkbohD36DJP3ETP1ewLE4jZo1ErGwmic0LDr1muqx325V/ujecuOktcnNvFp
GSO8E8C5iO1M4PmFho1rIucvckWZMcJ1RoyaRTVrXSd65NVXbxGf9dL+vV5o
gx9E5crrqUKFX9N11/2dGWWHaIfwOT2fpuL8bH9N6GzbhCdr1drm7AyGsbrx
xi3MkXv473uB6JF7mSN3W3rk3gOBfqvBuqP8vL+of+t52RxHOnMc6cyZs8vY
yqpHGg0yQ+uSGZoZMzydskBy65if0zK0HikceeH0yHtqh/JaW3EkmAIaG/z8
sAbHenu6Xv8/9ngjGszr+PjkZwI5MkzpM1gvg5GExfoqFoOfIdbgiCmD1oaf
o2JV3hSVm7U3TZ2YSn9t/2mp/V1PVT5NHzT6jIb3niLsg3W+8VeFvog8m2CK
aO1rC59N5KoBR4BnVP7NBPEBFY5MNGv9FIlthE6I+7EZWDiS+270LuTXQb1F
+MeKH2mEiqVsxpyBOpBGe8R3RY9kS5zzgubIOaLpqVhExcD4HvLeIp+oMJIe
I9Qngc8nmHC20dWmxlKLDsqvNSr+SU83hQbWBRzJ82O0R+QWrdewpeSAUX6x
SuNEnh3hSN13MNIT9VvI+InmG6VqLoK18X2Ph2akaI5U8Y2ROmdrKHMk5hcc
h77LGI0DR3YRXTTainFELiL4ksanPKtrtqSIVo05ShDWXihjhPcRT9RrLvOD
McL5g7gdxIFCXzXPEVgb2iPOwfzimsipJBw5ZpZ+Nv0xCuGxlzHS2vLAIeOl
vki0fl5xHVyzzhPNFEfqvkOfFT0yfJqni+P3zVt2ljGBBj1ztrofzC/u0fRd
dODR4MgadOWV86hKlS3897eSefLri9Lw787VV6/nfyd+fd71yKLa5FbNkIF+
rYoltwoz3XgjmGmbM8swNj/5yRbm/j10x50LAvTIkrTH3Zb2uHu/xZBOj3Tm
ONKZM2fOymRl0iOhNWb7WqOxDJ2XVVkhpfPP6VnKjmTmU1beSfFrfeSR3/J6
8wLpkbWH8Hp3PnPGctHV4BMIPz/oPPA9NLrL/Q8+Lr6TScxDARyJdXXi05qH
5oiehzrzWL8bHoLvK7Q2sAziEeH/Z2pvgFHBU7NnLqF3G39EhRVL5+96vOIJ
WnbDU5QS9aJiF24HzHP3PQ+K36r4d/JaH/oq/FKx5o9OWK5r0CcKR8LvMVYz
I9b66Dd0QtyPYVMwcDvuJ36GjyPuB3GRTZp3lJjIGN0OGEn0yAEjlfbIPIPv
QrdELGXSnBdVnU1mLHAHdEsZI52PNHT4ZNEThZHiVA4bsFh75sgp01N9TXBa
HLXsGE4/qzuLGecpz9cW7ILzofMpBlZaKt4JgLWNT28YsxVy1WA8fAZOpAcf
rif5cpR/psrd27lrf3kOFFcrrQ7vCfoNGi3jZmI20U7nbipXrGkH84uaGKYd
w12iR3I7CanPaWZMFY7EHIG1VW7ZeaIdPvJofdFXIyWX6lzRAlEfFPOi/FXn
i+7ZoXM/4T/jayt6M/dd3oXwXBpmVBw5XDhSnlc+ZxA024atpY9G44TfMjgS
z72JpQSbghmHhU2X80U35ecdeZSQGzZxzvOejzLaGMD36I0RtwN9H3rklVeA
I7dpVlt1UVrlyvj3YYNw5HXXfcgct9OKVzxfttX7DGZUuWOCfVp9/e3GG7eL
/eQngfv/r4Yx+clPtvJ87aU771hA23cF6pEl+a4G65EBDLlP2XnZHEc6cxzp
zJmzy9jKpEdmFfpao6VJpgd8LhATnswsUHpk7ilav3E93XPPr/nf13VaGwBH
rirRbI78hD+Xzgplv+KKQvq6ynbaf+s3tO+Ww7Tnf76hXT/fT2uv3UA7f7aP
jx+hvf/7DR8/SKuqrqHNtbbTgdvSAjgSeSjBmxG6xkHv/mGiR0KzMUyBmDJw
G/Q8k8NG6kp07CM1ImK1ZgRNL6TDMPp9nT/TiaqnSq1PftT0K4qZvFSYAjlc
oRPGia62QJgPtQShR8UYXY2ZD1yLGFDpu9Ye+/QL5/6rPDlROkcpGBi8GyV9
V9oU/GabtuggGpVpx2hTyP+TJNrjQskJhJhJaJLJc18SFsM1UWMS34tLfNrL
ewqOhM9mlDdGC8R/FlobeAb6n+iM0+OpRYeRokdGJyjGAt+BTXE+tNAIzUND
hk+SdwJgUMOmYCv4tSJvTazHwMl0//3KrzVR9x1c3InHCNqcvCeIUdoj5hbx
jZjfSD2/aEf0yPhlnv/tGMORM1Q7KldOMjXj8YDPp7D2bFVfsXPXfjJHYG34
sKJPyHkKv1ZwsdEeR4yaLgwMJozRcaBgPsRX4n7BfLgmGBhaqnoX8rQ3v5KP
l8cJWqhhYGic8E3F+JrndRT3HX6tYEL1nmCBsCnyz6KmZwKfjzHC896wcRtq
2yGE5/dFz0cZbSDuUo3REnm/Ej4mkm6oVYPKXTmfqlbdLu+IqlRZfVEa/t2p
UmUjVar0G+aSfzDL7dLxi+c3V4yK89tqcaXhRuPXul0zpDHw47YAlvz/ahiP
m27aStfXYI68kzly9y7awxy5izkygB2DfFeDtUdhR4shnR7pzHGkM2fOnJ29
lU2PtLmxIJAZtWVkKkvPVBx5JD2f8gtP08qv1vA67nWJT/J9zUrWDmyOvNC2
+YZtsq6GT5/R1fowh6mcpc948YjQkYzWZjSjsRNUDUcwDNbbs6JV3RFoYOCS
1PiX6f2Wn9Hxq0+WLn6SefLduh9SwwdaCTOaOEHk2YRfKtjDaI9gPviQIhcp
tCWlQ80RjRB6JI5F6TyuQ8OmSD/x82ytgY3TuTsRQyjalM4307xlJ+bD0ZTE
TIG28V3UHGzcrAMlz3vZq1EITa8POJL7aJgRvIr4U/wsY8Tno64IGGmq5qZZ
0E2ZI6FH/qKu4sioWJ+RkJsGvqHGtxQ1WYQjoffquQAXooYLxkjiBKOU9oi8
MpgncKhi7WRhbeQpEh7SbArNtt+gsTK/Sp9VDIwcPxgfM0Z4T9CSOXKKcOTT
Xl7api06ie6ptMdFMu6Y8/Ydesm4RUqNkvnCYsiZGq/nAsfwrKGf+BwjbLpQ
dE/EV4LpDGtDbwbXIs4xXs8vmBFjhHy8uEejYcOfGLlq0ceoON8X+oknmsm4
mr5jjJpz3+H7Cy1VtGX+bqOmbaV+peLIxVpvHiFxl+ZdCo6Fj4lSfq3lLi2O
rFHjI2a33ZrzLnTcn9EhbZ9W2691h/DjTTeBpXbwfod8Vvv/XwaW/OlPt9EN
NfbRHXctpG27g/RIoz2W4LvqcaPFj+b4edkcRzpzHOnMmbPL2MrCkTYrBjOj
vfe4MlPFR+bknaK169bTL37xa6pQYT2v5RRDnmnNF15x/4/Gkc/f9xqvq6dp
zUit9cFhffqHaY5cLow0LHyqcJthpFma7+CzCaYzmhE+Y/0PLsFaXWIFpyym
1x96kwpK6e969Kpj9H6jTyk5RnEK8mxCT5w6Y472V0Utw2TR7pCLFH03cY9g
YNS0AHvYDIx+gjGUj+MCL3cnYgjjJR5xIU2ZyRzZqpNoetAeZ4mutkC4qUnz
9pQy/2W5H1wTcZh9+4/2WBucMiQMYzSYomWMlK4GFuuofTaN7/DU6QnUqtNI
+vkTkcxSz4hWZ3xlcU/Q+TwdePgUqtdAaW2K35V+h1qRYDq0j1yoYKS69ZtL
bQpwqMzFtBSZs5HjIjUzLhUtFe8I+g1WeXKidF0L+P6COTE+ioEXyPyiRge0
UnlPoH0+wdUDh4xjZnxBxz3OlTkH6yfPe0n4Dv0EayuOfNaLa8VcgN9xnmLG
hRKriljI6bPmeWM0SevNYGaZ35ileoxQHzRMni0zRoOHT6KGjVsFvPfANevW
ayZ+rzgOpodu3qJlZ4mpxRhhfqE3NwZHMgNL37Umj76jjkucfo7AmyOZI2vB
r/XKBVSt2g75265adc1FaVWqrOL9JubI39L113/ErLZbOO7HivsrjiGhTYId
jR6pPhum2sl7Yz8+411Qjrx+H91550LRIz2O3B+oR5bIjyVok+dlcxzpzHGk
M2fOLmMrW75WozNqM1wZsC9QPKn3RzLyKCv3FG3YtJ4eeOA3dNVV63ktZzjy
3Br0hqpVV/O/4SvpntpDea29kNf/SneBxgYNC7xh8p5gvS3xkSFDmIde8XSX
jl36KvZIeU6YAjUo+vYfKayB9bthF+hI0COxpja5UBGH2b5zX8WRWjOCRgam
gDaHeDPDd+Cubm0H0UftV9GJKqXTJ+EX+7eWn9LUsSkSvwaGidN+hmCoLj0G
SawgfBwNU6Dv0CTht2j6Dr/d9p36ChNLXlo+hrw0okdOTZDzI3RuV9RLRP15
MAXGCN+FHydy8qTyuEV5jBRG/QaM8sYIPIR8RdAT8bMZI+HILn1Fs1O+w4i1
S6SWHUdKvtbYpGcl3hTsEtJ3uJwPnc/wEHLpYi7BVyY2FGyFeilg0zjDwBL/
Wof6Dx6r/W8XyzGlR0ZZzDhPxgc1LYTvdG1HzBd8YMG/ynd4oeRrEo6ckarj
EZUPKzgS9SaT573o6bNoB/VNUnjcZIz4fMQyPvxofXkGozVHombJw482EHaN
lXcPaowQCwlWk2PyHKn3EdBS7flVdV1GyLNlxgjvLKBHYnzNnMMXGhwJDdPk
LQKbIm/QcOZInB+hdVPoke07oO8vK/9bHiNotrhHeR+BfE+RyAek9Mhy5RZS
9eo7+e9vFfPk2ovS8G9DtWqbqXLl3/3oHKmY0fdjVRy5XbRI369TsSP2P/2p
4qqf/nSnZbsue8P933zzDqpZ8wDddedi5dd6IId278s8MzsWoz+6PDvOHEc6
c+bMWdmsTHpkZqGXS0f2mcrSrX2a9mcVLZK/czg9n/IKT9MXX0JnfINZb6Pm
vtWyrjuXhutWq7aGWfVLqn3vMF7vLuL1v2IKaGz1GrWi0eOjPN9D5B594KE6
srZPXfCqznsyT7Qy4+dndDXkK4Wuh3wt0ZopRjBrih4JRtKakdT469JP2DFe
+8UKu4Ajh0+RGEOz/kfunjbtQ8TvMSHyGfpH05WSZ6c0PHns6hP08j1vUMS0
BcpHMnapMB+0P9S0AAObmD74msJwzPjfgiMRoyiMpOM4UVdC9MipiXLvJv6u
ecsuEjsIpsAYgYeUHtlRxs3UugdnI+cpGMfkQoXW1o37BA4z+WKh6SEHzTTN
M6KrzUhSemQdxC2avitf2a49B0uM4WzN9MPCpjAjtRS+Umy6UNgKHAmtDeNu
crvez/OLHKNGV8Mx5H8dNW62zKXhLsSPqnyrz3m5f4Zqv2VwtqnTAc22FXPk
VN2OycPUrGUn0epUO0uETdEO6ptAs1W1LheKD+ojjzXQHKlqhOJ9BHxLcV6s
1rDH8Bih5gjGACwYqTkSbDqa79Wf33ni0wrGgxZqtHI8a4hxjE961rsfxL8+
Ub+58Lnqu/LzBUeOGDlTnk20g7ls3KSdaKnqPYHS5PG8okaJeR8h+YB4HMGR
V111aXHkDTd8xIyyW/hNaX8X2rYXOaa4cof2Z92uPwf7tSo9UnHlFt7Dtl62
hnu8+WbU39xNd941n7bt2hmoR5bEjcFsGXzccaQzx5HOnDlzdtZWNj2yQOuQ
BQGaZJrxYdXsmJal9umZ+aJH5uSfpNVr1vJ64NdUseIGj/nOffzTKvFfK1cO
HDmUmQB+goopwEaogzCG172JOuYL62BwBtb2qQtfVXlYef0vNRhHzRBfSsNd
iA9Umt5zyveQ2QWaJfS/mITlnm/pOGYx8Nlk5pUErRnBB7ILr/+ho4EZhV2Y
76DfqVwmL8n6H5wR3nc6PfWT5yTPTml4srDaMfpbp88pLuopYSjEIiIPC/pu
YvpQFxF8l5j6nKergV3gNwnGkNyfPEZSA6JlR5o4TXNkjGKkFqJHjhamAGdA
UwRvIicPxk1ptguFs/sNHKXHSNWQHMbtdO0RKlwpY6RZG20bnolEPOLMJGrd
eRT9oi78TZ9T9U0knnCE6JEybrpGCPIbYS7BV6Y2C2L/7r3/Uam3GZ+i+g7u
gm4JP19wqM/ag+R9gsfV8FvmuQVH4r4NAw8NU37LsTzfKo5T6c0t23aXvDOY
X1MDBhw4aOh4iRcV7mLeBfMhBhVaN8YI1+zZe7hoj4mpL3gcCZ9S1ALBM6Vi
cjVrgyO5b8a/WvTm7gM9TV2YEWPUF3pkOCXzPRrtETGkDaFHQhvWdVChpcLP
F76yCclmjFKoRcsuFMbPu8RxgiNnL6BGTdsLA6fqvmPc8Z4AeWDlOYpXvtDg
SPi1XnXVIrrmml3MaauZJ9ddlIZ3TNWrb+F/J35P11//MXPanoAcqT+eBeZp
tfXIQB9P8OMe/ryOWXgI/1s6mipVGss2Ru8vP6tYcQzf6xgqf9VY+sX/dKYd
e/b5emRxjFhMPp2S7LxsjiOdOY505szZZWxl1SMNQypeLNC8qPeaHZUemS+x
kUfScykz5wRt2ryBHnvsd1S+/AZZayo98lzHP60W3QF65D33DuO1NnNk4rOy
/lcc2VJ4I8njyAX0wEN1qUevYTRn4Wue7tKpaz9e208X3dJoj+Aj5CKNT3le
57VZJKzZldf1+E6cztmCnKqo1wB2lHi1uKUSw9i5+wDR0ZINR+p4QolBY440
9eL7Dx4ncX5zY16mFS1WlZonj1Y/Tm+3/Af17jqCwsdGKM7QTNGPGRh9T5jz
vGbgRaK3op+m7xiPCbqWIGLmwKGmRgj8WvsNGkMpC14R7RDfRQ5X+MDOWfCa
+DhijESP5LaEI7X2aDhSND09RmAxYSTmGfHPhK42K5ladR5NPwdHJj8v/qqi
gcH3t2eo+ItK3lK+n6Fh06h+o1YUm/w0X1PNBfKoIs8OfDZVDKpipLr1VHwk
xlhx5BzhSMViRntcIOMDv1bct2FTxL927jZItGaT2xWabau20CPnqrw2MSr/
LfTIwUPGK2bU+mwXnvP2nZnFeNww5+hnzz7D6ZHH6ov2Z+psYi6QuwfniT4b
u0RyHoFDwaNxeoymik/uQHmG4YNqmFFqm4oe+aJcE8w4dMRkatC4tYyvyeeL
cX8C8ZHgd9136LOiR46eKWMcKX1fSI2bQo/sI3qz0eTB2oOHTPTepcyU3LvR
VLNmDf67XkjXXruLOW018+S6i9KqV1/D+y3878Tv6YYbPmYu2yMM92PnJA3k
RuiO27R/q9Edt3uxkTffvJc/o0ZuT7ZZ2mZany83m6ktgu+9K+1kjty9nzly
b2bpYiEdRzpzHOnMmTNn58zKwpEeM4rlK2bM0AZuFHZUtT7SM9T3DqflUVb2
Sdq4aQM98sjvqUKFjaILgPvOvd/aGtEdypf/imrfN5y5aQmv/5/1cpSAPRB3
JrFy2n/vQebInr2HehyJ+nmdtR4pa/14w5GjlW8oc4aKV1ss34EeCRaRXKh8
TbAYYv+w5hdNEPlIwC68/oeOBr9Ho4GBu9q27yXxcziGdT145s677pNzwavx
05+mD+p8SifKlc7fNa9yPv2u0Z8pJfkl6dcMaKmeHvmCrkXCDBw+QzTBGOFI
VSNkgq4BgVyzSXOeV3FxzGUtWneRGEPwkPhnxiwSboJfK8YNvAo2BWfA/zVB
9x0sB0bq3nOw/Byn/W/BYp27DJDYP+VbyszIHNm60yj6xRMRFJ/8vGi88M/s
xWPUjc+XcdOMBL4zsX9GB0YtkTvvulf6m2AYmD/jPQHyqJq+Q1+FZissBmYE
Y2lGQt0OYW39ngCaLZgT823mHH1v3aa7tANdztQSRS4iaHWGGWfNXiDvGJAL
CZotxgjnI5bx4ccaMAe+6OXZhX58d+2HxAdZGJj7qVh7gDwnErMZu8zTUsHA
Ei+qGRjvI/As4R2Fee8B7bthkzYe0ystNU7pkZHzdDvK57pFK+iRsxRrxyn/
2ybN2knf5yxQfTfvCeDXKs+m5kjk3q1VCxy5iK67brdmtfUXpVWvvpb3W5kj
/0DXX7+CeWyv1gB3/Oim9MbA2Mhgf1YVEwk98mtepw5ktorRFm19vtwsmq68
EvcXRz/7WU/asXsv82Ku0iNLiHt0HOnsYjDHkc6cObscrWx6ZL6woeFHxYyK
F8GNYpk+a4pfa3oeZebYHLlBNAsVq7TmnBquibVi+fJf0r33DuP17mJe//N6
OXqJxIE1gF8rr3u9GDZe6z/wYB0K6TWM5i56zatVgfX7CMk78qLoLmAKcCRi
JMEZsbquJHwBu4pf61OqDgOv/8GRnbQeaXxLoZFB10JMouHIGZpdRI+c/7Ks
/7Guh5535133C/PFaXZBTF7d2xvRh098Qd9W/K5UPFlw3TF6t8sKioxYQv0G
jZb8N0lznvfi74aPmiG8i76LBsZjNHFqgtT4mDQ9KSCOsyVzxoBBY1QsJHMG
+iR6ZIsONJc5EtohrtlnwEhpSzGwyv2DGNLu0CPBkUnPao6Ml5oYwjPgSB4P
6JHGrzU+BbxrGClc9MyU+S95cZzDeRxRGxF8FZukcruCCzFu0Dih1YHpwXoP
PvyEsI/oasxiYMuu8GsdF+3pzWBTvCOQuh087jFaewQD4z0B5sHohBOmxFOr
tt35Oqqd2XqMkPMUWp3hSFwTzNehM7MYcyTGCM8cYhkfeayhaIfCkdwOcgSB
I6G/Sl7auKXCfJ1Ej1wgrB3FrA0NtGs3xcCYH6OlIjYS+YTxbBkGRo6gRo3b
CC+aOce4P9GgBc3g/ibqOirQI1EPE/U3kyUf0DJhziZN23Pfe6v51RwJv+XB
Qyd67wlmSl7ZGKp143X8d72YOXIPc9pauvbaDRelQZO89tptwpHQI2+6aa8w
24+dk7So7fRy6iiOxH6Xp0cqjhzAbBWrLcb6fLlZDHMk7i9eOHLnnj3MgDk+
R56F7bb2ux1HOnMc6cyZM2dnbWXSIzMKLM0x0IfV1ykLfL7MUHpkRvZJ2rB5
PT366O+pYsWNvJ5bo2OV1p5TwzWxVqxQQemRSXOWUHzSc17O1PoNW0vOSjBJ
VMxSWQc/IHrkcJq3+JcqTycf69ytv9RglLV+AnS1RdSfOQqMJ4ykmSJs9EzJ
ayO6oY6FnDgFemR/iZ9LEs1oufgRIq5taPg0YUbje9inX7jkMklZ8LKs/9FP
6H7wz0Q7hl3GTIym+x94TPSoRdGv0xf119N35b8vFU/mX3uUXqz3axrYfzwl
ztVsysyIvCrIJwTek9ys3DZyETVr0VniCsX/Nlbl5ARnoF/gITASajvCFxI5
W+ct+qVoh4h7lJynA8dQEnTPJMXVYLFuPYeodnR+1PE8Rp14jBXPPCe62oyI
FGrTZbTokYZThF2Yj3A+ctWIb6n4m04XPRJ8ZXLiYl7vrv2waJyGgaEDP/p4
I9GBEeen5mKecCn8YBPnmvcEC0WvhR6Jc6Xv0Ju574jNjEtmjkzR7wmmJFDr
dj2EUaUdne8Vvr9gLGFGrc926TGQx7i3vKPAnINtQ/qO4L+DBuJDavx8Eb9Z
r2FLmWuT2wn+0fBhxXOSkKJiIUXX5udIaeovenGPiI1EniCMERgYbeOeoUdi
fE2eHlyznuiR84Whxeear9mydRcKGxOh8gFp/9vGzdqLHqn6rnyu+w5Qfq3g
57jEp3V9kljmyBpUsbziyGuvXcv7DRelXXvtOt6DI99kjlzBnLZXOA2+oxej
2WxpcrTefPM+/nkVr1MHMVslaIu3Pl9uFs8ciftLYo4MYY7cyyyYWyqO3B1k
Nks6PdKZ40hnzpw5O3srmx5pa46BeuSRDGVpen8Ex/g7h9KUHom6H4888gdm
vE3CfFWrgvvWnVPDNatXXy9+rfcyRybOWSqxdmBGybnC7DGWmUxqHkr+zEX0
4ENPUEjvYYojEecXtUhyq4aNniFr/RitGYlf68BRwg5KV1sivoDgDHzHMBJq
Zki9BuiRWu+aLhrYQNEjU7T2KH6CWo9ETJ34gfI1oZ3d/8DjwhPGDxTM81id
xkqvEjZdRjGjl9Bbt71Xap7MrppL7/X4nOITVOxgmOiR/Skm6Wmld8UuUTXp
4dfKzG3nA1J65Dias0j5sIJJkJulafNONHfxr/j+nxQOlRhDcKSMkeo7fH+7
hYQKm8UnPyd9nyB65ADvfqR+JTiy8xjmyFkULxz6lMTpwZcS52OMTMwl2BTv
BMC/Kk/PEskhc9/9j4nemKj7Dk24XsNW4jeKXLPgu+nCkYOFxcRvWfv59hM9
0rC24i5oqdAu46Tv6j2BcGTb7nIdMxfIIdvC82vVPqw8v109PfKXFM1jhPND
tB4JH1IwPY7BfxbxjWgjTupKLhftELmZUAfT6Nqelgo9ct6LXq1Jo0emznvF
0x7xrDVq0lb7YSsu9vTIqAWq79rPt0UrpUem8hiBV/FOALVBUb8G7wnQd4wR
3hPgHpEXFtdUNVxixa+1QoUlVKPGXs1qGy9Ku/ba9bzfzv9OvEk1a/6TuWxf
MbU0Li4z/qw337zL40jER5YrN5jZKlFbgvX5crME5kjcXzJzZC+tR5bMkcHc
GKxDOj3SmeNIZ86cOfvvrex6pMWKNkNm+mZrkofTlR65cfMGevTRP1wgPfJr
4UjokXEpLwgzTp6RIr6QokciVi5uKc2MXkgPPlyXevYZRvOX/MrLnwkdKGzU
TFnrx+rajEaPBF8pdlnKa++ZErtnWEwYaUoide7Sz9MjEV8JDQz+kfDHhN+j
iVfrMyCcORI5MV+VY2AfxBeifgXaMRoYdKTb77hPfHPFL5a/B+ZDfGPihKdp
Tb1t9K+r/l0qnsy9oYD+0O0DGjkygjp27Sc8kJD6rLA28rQ2Fz0yRRga94Nc
RC21HjkXPMRjBPYBb6JmIvhbNFseI+QiQj4esJjUGOQxxjh2hx6Z/LRXZ2PC
5ATqwqwNnklK1f6ZkanUWjgSNUuY5TTfgV269wyVcVOxkCq2E3OJfqt6j0uF
CzFuYFPbJ1f5tY73/DOhr2LO4I8JTc9wl+iRzJEy7prfUVOxCzMn2hD/W3Ak
jzv0yGm6nWidyxQ5bQcPM3qkqpPZrcdA6tCpr4wbmA/9RE6cRx5vKFwbD9bm
Y9A9JS8s35/kkBU9Eqw9UHKnwpda3kfIc4S+K99sU4sE/qZ9+o+SdxRxiYoZ
EUPaSPTIF1Q7iN1lBq7HHAnuBQtK7p6Zc2V+lR75ivQd7wRQGxS5Zucu/qWX
Dwi+v7hHNUYq9+6YiXHCkRUrLqEbbtjLnLaOeXLjRWnXXbee99v534k/cp/B
kfs1p/34dRJLsptvNv0zvq57tR4ZKmylLMn6fLlZEnMk7i+VObJ3sXpkcey4
pxgdcpe13+U40pnjSGfOnDk7aysLRx4phhnNz7Yv6xHJ06rsUFouc+QJ2rhp
PT32GDhyk/i+IS/Ouc/HuFY0h4oVVzFHDmNOWEoJ0COhTc1IpQYNW0s9BYlh
i13m65F94Nf6uqzV4b8n8ZESL/ay0tV4Xd2POQqaZNKcl3S82jIKHzOLWUH5
tUruT+G7BMnTM43X5ybvCfwIu3YfLP6YKZqH0HZfZqS2HXtLLpNY0aaWSc7Q
u+55QBjF5DJFrNxd9zxEU4TvXhJtCnmDEN8ItsC6fuHU1+jLR9fT9+VKp09m
XptDix5lhkx4VueVXSZ5Wpu17MJjlezl/kH8HfweB4SOVdoUHwMPITcLcu2A
v8HA4FBwJHgTNTZMjlHEmXYPCRU2MzUTwTOSizRygdYjmRmj5mi/1khmnxe1
/+0i0dm6hwzhMXrZyyuLazZs3Fr6nZCicuJCj7zr7gfEV9bkxMXYPPxofQod
NknyAXlz0TPUi5OVPLvw2WT+RXyk6IT6PcGIUcqvFfNg/E0xv63a9ZScOMm6
Fgl0U4xH6NBJng9rBPNut56DqKNoer+SZwQc2rvfCHr0sQbi3xynY2pHjo2S
5xDPRKL2hRbW7jZQ65EvCIdO13qkvAtBLGQSfFgX8zVHCm8La0tM7RLxoYYe
aZ4jeR8xJV44EuNu6qhAjwRH4lmGlqriOKFHdlB9X/wr7XOtntfBfI9J+j2B
qgUap/xahSP3aVbbdFEafFtr1NjpceTNN+/3tL5LwYwe+dOfgiOHMlvN1TbH
+ny52RzmSNzffObIPgF6ZHG6Y3G2qwQ7L5vjSGeOI505c3YZ27nSI01eVrP3
2BHH0gvE8PPhI3mUk3eSvvpqDd1442+patUtmvnWnYd8jOskn0ZF6JH3Duf1
7jLJ2QJmRF5K+LWO4zX4nPmviv8e1sEPPQy/1uGKhxKUjgTGQeyj6Ds6zg98
B7/NZK1HggnCx0QwkwwWFlFxfuC7ROFQrM+N7yF8Q5GPB/UnjK42S+s77Tr2
Eg0LuiDOFz3yrvulHcNI8Ee8/c77xDfX+MXiM/RIo79hrQ8+CGs/lVbWXkv/
Lld6ffLtXisoOna5qknf0uiRL9NsnTO1RZuuNHDwOPFhRduiRzJ7oEYIxg0+
qPCLhaYH3RYspnTCZaJHIr4RmpipXwkttRMzEmpagDklpi8qlTlS65GpL4ne
NWu2irnE+WAcFQupcgQhPhJxg0bjHMvzavRIu7YK8vHCV3gu4jh1zcNuiI+c
EOPpzcpvmTlyCPTIl7SP8lIKY17tZuuR8WBtpUciJjJJapEsl9yszVt3FsYS
7RHcxfMLBu3YpY/SbDFG3CfUMXkUeiTPo2kHfqpgYDB7kn73AF5F3ZCZzJZJ
mrXBxd3EJzdG65HPaNZWeiR0beWTu5SGhU2nRo3bSq4o9T5iqadHIodvkuja
y6VmCd4ThI+OYFZXeiTemzRt3l58cvF+xdQ86av1yGSt2eLYWPFrvY4qVVpK
NWvuZ07bQNdfv/miNGiS11+P2iR/4j5/wkx2QGt+uy8JU33dr/PsDGO2WiB8
dcUV8/T+crR5zJG4v0XMkf2K9Wu1eXJXCfxYHF+el81xpDPHkc6cObuMrUx6
pPBigac1HknXDKm5UZgyXeuRmjGhR4Ijv/hyNTPeb3kNt1liqFTuxPXn1HBN
aA6VKq6i2veN4DX5Ul7/v6hzXabq+MhYYTnxYY1ZxBxZV/TIBUt5vSw60mLx
MZT8lfNfUbGQvAYfYPTIeS957ILvgElEa9O+hxOnJkmeHqzPhVM03yEfz4iR
02StHqfzvSL/K2q9z12g1v+45qChE+m+Bx4XdkjQbApGQnwkdC9cEyyG2hyd
OmvfUO2fCX9FxBKiLsQzM9+k9Y9uLzVPZtXKpVe7/JFatOwquqfSI+FvupA5
oxvf/3jR1dC26JHMHk1Fj3xdOBrHEGOIcQJfJTC7QJ+FrtstZKg/RnxN5PMB
q6PGCpgEHDkzcg617TJW9MiEOcpv0uSAVXrkqzpGcYn4gTZs3EriBlUOmmVS
JwPxkdAbjZYKn836DVvRqLGRcr5oeuBIZn88Bylab44Qv+XRNCh0gvCzmV/k
WoJ2CYZM0DVcJk5LojZte9L0KMWryEHj6ZHMWPMWvqZzMy3mZ0PpkfN53JCX
BnOJeE9wJJ5BjBHYFO8jUK8R7zakBiSPEZhP9MjZC3U+oKeFXdEfE+MrzAif
3P4jFUfyNeONT66nR/Jc6Loh4Hfxa529QNcsVT7X0CNHjokUVo+Rvi9ljtR6
JOZX597F8w9t17B2ZKyvR1autIzZbD9z2ga64YbNF6Vdf/1G3u/ifyf+RDfe
+AlzyQHR+X72s92XhKm+7td65AhhK8WSsIWXqS1gjsT9LRGO3LFnNzNgLu2y
9Mgz6Y7Bv3Mc6cxxpDNnzpz991ZWPRL86DFjhsWSlh4JOwwtMj2PvmGOTM8+
Tus3rRO/1sqVtwhHnl89chXde/9wZoJllJii4vymzJhDDRq1obGT4qSen4oD
Wyzxc4hZm7/0DYpJUjlTUaMjbJTKXxmn1+D9B42T2D/RCVOVNjUyQI9ELORy
8Q3tLHrkPOEU+B6C9aBNIW9L6sJXdZ5Oo0f2EZ9LFU+4XHK93HPvw8ITxg8U
fq3IvYM8K5KTk9f60A6hRwrPiH/mM8Kr3XsNkVqKKfNeEXZbMO4V+uLWNfSf
K/9TKp48UPUb+mWXtyTnSnSC9muFHhk6jubDxxFxfnzvyM3SrGVHGTfRUnmM
RI8crPVIzcDIRYo+YRzBfdDVoOmB1YWBpVbFM9qvVemRifAd1noX+AjnQ7PF
NeA/ixxB4EhwqZmLccwztVE7A+OhNVsw0uN1m4gODH9TqVXBzAfWBpsnz9c+
rPBbHqT0SMyZYdMRRo+EX+sclTN1ouiRPUXrTNE1LcF60PTAWBJPKDmTFguv
Yo7gG4oxAlf3Eo5sILGI8ToPKziyafOOMl6JWo8UjuQxQi5Z+FJDEzSxndAj
U2V+VZ5dsHZvcCSPkdEeh42cRg2ZI3G9eK1rix5Zv4X4yqq+q1zCeE8QzhyJ
5zBW5wNq2qyj+E3Phx4pPtdGj5wksbNyTW573KR44chKwpEHNKttuSjt+us3
Uc2aqHH51iXt16r0yDBmq8UWby26TG0hcyTubylzZP9i/VpL4sQzHXcc6cxx
pDNnzpydvZVJj0zPt+If85TfqnBjHu/zhBvFrM+HjuRQVt4J+vLr1bwO+h1V
q7ZVOPJca5HBeuR99w3ntfpyXv8r/z3okQ0atxbemLNA1TxEzcQHH66n9Mgl
b3h14Tvz+h38I/qOXoNDZwMnYf2dmKL4DnX/uunYvySddxR8J7URoUfOV76H
qCWPWDnkGUXOU/EJjFa1IqFHzln0S8mpg/oX8J+98+4HhA0TU03ungSpjQjf
XOUX+6Rohh269Bd2TIEemfy0MFKPkKHiJ5kKv8kUxUjo+7QuibT1kb2l5smM
n+XSGwP+InlHWzFHDhgyTrQpMBLGExoWak0u0HokfDbBYmgLYwQWw3iEj5ol
fUJflP/tk6LpiR45W+mRqp7HXGrbWemRSXNfFg1NaW2jlB656FXJ9yo1KUfO
lPhI0SPnqLmAvogxAvcaRsJnzC80XmG5hKflGPL2jJkYo3Ld6DHCuMP/NVn3
HXynfHIHC6sKA8c/KXGpbdr3lHGXGi6Jqm6IyrMz2WNG8C7qiwiLLfmV6Kui
R/YNkzw7mJ8EHWeL+br7ngfFPxZ6qIwRWLvbIImZFA0a7wki5gvXiqYufrHP
CK/C9xfvJPBcJ8gYLZVY3EZN24h2aFgb13xC9MhFqtZkvMrdI3rk2AhmbZPv
ydcjzfwKa/PzGjp0sp5f1Q7ey9S68QaqXHkZ3XjjQeY1sNrWi9KgSdaqtYc5
8m3+ecUlzJFf8jo1XNhKseRi0esuT1vMHIn7Wy4cuYM50uiRxWmPwZ9Lipl0
HOnMcaQzZ86cnb2VhSPBh0e0zmhYURgy3c+rY+uS+I74teafoM+/XM2M9wde
w22VnI7Ix3Hu68OtlxioypVW0733j1B6ZKrJJ5JKDRu1Ef9HybnCa2hogg9p
PXLh0jd4vfyU6DtYvyNeLMX4HvJav3+o1iOhV6WqXCjQkbpDj4TWNlfVCJk0
PVkYCetz5Tf5tPhvQo9E/k+s1eO1Xyvy0rTv2EdyiYIJwF3gsLuYKUQXgwaW
oGpA3F37QWFh+MXCbxL5Z1G3A9dO0XokOATa3SjokeLjqDQjxDZCJ8T3npn8
B9paew/954rS8eSRmzJp9iPJ4vMJH1YwHxirRRvk2eks42a01P5Sg3GsZuDn
RZ9VeuRQ8YNErB76jhhSaG2zoqy+R81Vfq11I5TfpK5piZqFPfh88HeC1tqU
HtlGuBQ6MJhx7CSVZ0fGQ+uR4OpHkGdn+GSlpSYqbVjpkbFSU9JwF+Ijxa91
vpnfZdL3bvBr5XsRBpb3BEkqPlL6/rLcT4TokZ1Fj5ScOuBq7jvO7dCln/b9
fUb62UfrkZhHVc+DOXJcFN3/4OMS6ygcaWm2eK+RNE/pkTPkfUSo5IqS+dUM
jDECb88VPVK998A7i8ZN2lLynJe8uiEY93oNm4t+qsboKbmm8WudI5qtyvcE
fRT1RfF+JV7nA+rLz2uo6JEvyzsO+BiPE7/WW/hv7ulLRo+85pq3dL7Wi7/u
R2ANEJWv9Sc/+Upz5HLNkrBll6ktZY7E/T3FHDnA48idmiODtcczcaPjSGeO
I505c+asbFZWPdKwZCAzap7MMIyp/VrT8uibIypf6/qN6+jRR96kq6/eKswH
P1T4oJ5LwzVRJ65SxdVUW3MkfALFx3Gm8msdz+telVPzKYmLe/ChesKRC5b9
WjQ96F2duyuORN4SE6OIGvVgDXCGyjHq65HgwiTNSOCMTt2UXys0I2hTyGsC
XQt+rWDGOF3zEHpku059JA8qGAmcAv9RcKRaq7/g5Te94677JOcs/DvBq8ip
2rlrP8+PE2t9cFkP+LVCjzScEau0VOhtKcJIiimSej9JK3+6mujKYp6H4vxd
rz9Eb4WtEM02mtnH0yN53OJ0LGQ/zZEp81/SPqxPCmujT6JHzn1BWA6+v114
jBF7maLzloIj20h8ZAQz+ctS0yNS+2xCjxTW1nGLyIEkeiTPg+G7cRNjJc8O
2BGMFRP/lGiPDz9aj9lnsmipEkPKDIXrSXzkfDVGUbqui/JrfcXjrjCJjxxM
idyu5AOCHjk9mdrAr3W24tVYXZ9E/Fo1r8bpWjHGr1U4Ur8n6N3fio+co+YX
uWPxngA5nkydTNRgwXOo2PIleY5M/KvSI1/x6s/A31T0yIWvefmAUBulUdO2
yj8amq3kmk1S8ZHRC+XZhO6J/LYtWnWTnLHIRYR3KfBRbtqiAzMwtNQ3tK+s
iY+cLPOL5yhKatLEMkfeSpUrP0M33njgotcja9bcw/9OvH3J1I8sniOhR44U
tlIsCXvyMrXlzJG4v2eYIwfS9j27mRcD9cj/hiEdRzpzHOnMmTNnZ29lzrNj
aY2H0/1YSKVT8j5Nf05Tnw8dzqX0zOO0YdN6qlMHHLmFatRYr2uCn089Mkz8
WpMkL81yqeeo9Mg40V1ULYOl9NDDiiMXgod0jQ8wDvgHmpGKUVzGfDdWOBLs
YNhl1NgI6hoyRBgh2eiR04weOV9YAcwI/03oSNAjwYzgoUipkzGa2nfuLXlQ
EU8IjRS8Ch9HrNV9Roqjx+o0EgYSNmUWQ07VTtAjtS6Gtb74tfYaKlyCnCni
N8k8AzYdMHCs9EcYWMfkwf/2+bF/pD33HCoVS8IO/SKDXgt9W2ImwZGiR0q+
mOXCYug/YitV35+SXEToE3Q/48M6EWPUXdW0SNUxqBGz51Hbrtqvdd4rqhaJ
1sDgFwvGMewyQuuR0IC9eMLJ8ZKfCFwtNTqhtfF4PWz0SO2fCeZDHZIxUv9F
+5Zq1h40dIL0R2mcT6o8SlqPNDVcJotfa4iMtVdnI3oxtWzVlYYMm+wxIzRB
+M92gqanxwhsCz3ykccaUerCVzzWxvsI5NkBU4rGmfS00iN7KD1S6s8kq/hX
FR8Zq/IOifa4RBgSmiTGSBiY51f0SOZI0YY1r4Lf6zdsKWOQskAxMGIupe4H
9wGxnSZnkqdHLv211uSXyvxiLDG/Up+EeXPcZK1HVn6aOXI/s9pGZrQtF6WB
cWvVUnok/FpVLcbtvN9xSZjq6x7myJW8Th0tbKVYEvb0ZWpPMUfi/p5jjhwU
4Nd6ttzoONKZ40hnzpw5K5uVXY80OXR8Ay8abjxsPps8O0eYI7OUHvn4429S
lSpbJaejquV2ruuMbxDftcqV19B90CPnPymxdmAx5O78P/bOA6yrM9v6k2aq
mklRk0yfJCYxxZLExJhm74rYQWx0EBsdsUsXFUGlqVhRBOy9ix2w9zRbmmZa
Mnfm3in722u95/whTuZ+zlXvCPfM8+xH/QfOec8+B+b9nbX23tQjR4wly3Hm
ofLDa43ekh59hkgqOHKymZnQlf1ao8hi3Ovrvhwz6rGPBmeY2QwZ9AKyPlL3
2UYzmsl5HJ27eXJ/Dj1zfNws+gipRyr/YAbEhEoc2cHWI60eNPCg2noke3dO
NIyEPjvwyrLfjPIutMmOXT3or6Q2pccEH3TvMZh6ZIK1dqNHmrVDp7PnBqIe
DryL74tLypEsn+Vy+pcf3TBPnqp9RkIbxipHLub1gIf6edq6pzkPWM4n0HAk
zmPPaxweZvRI+HDjrBrU6NgkaYc+O29GWZpvlukR6mH67JCR2OtmuqVHtqFG
iMC5hw4fLy++1JD54DxO9IDV4zfU+ztQ2SfF4jtocS5Nz/KWgvn6ad69Bobw
s8kJpmcS9EiwIPQ89gOaYN4TtG7vTu03wZqzgVmRRo8cbvqbsu/QdPbyhR4J
b6jJUQbnYUKPxH203xOAI8Ft0DttLzRqSDErMmq00SihPYIju1q+1nhoj2BG
6Nr9/KhJ4v0I+Y69ZsPJppMspoc/ehh9rS3IpnhmbK9syzbd9FmO4XNoGDhN
3mvRUTp1MQxs13HiPYoX9ci5PCY+G8o+O7+0OPITZbUjymjH78gwjGv6tT7+
+HblMmh7p6nzVYUwa/1I8wyODCRbGZZEzK6mMUs5EteXoxzp9d/2a3U40ok7
KRyOdMIJJ6pj3FR9pMWHVz7/flRw42/lUiW+vKSfX1CO/BwcST2yUDnyFGuo
4D+99XPGj3JO3AMPlBk9MmmGTE409YRhkQnSTNlj6PBx9B5iDx09Js3okb29
ZcqMJdbMBKNH+kCP1L069+Dj4TcNMXokOIM9RtPpBYRHEnt87v8nKt8pR2J+
ZDj1yHnsFwPNELqWN+sjF1i62jTu/dt36sP9u5mtOJO8yvpI3aubuRKm5wp6
yKA+MtHq0zMqIk7P08/Sxebx+9HvBczmHxyrazfaI2rdqEd6BZGBbV0N+lPn
rp70j4Lb6MkNi5Pg18Pko59duGGe/PwXVyXPZzW5q6+tR6bMseaTzCSPd+85
mPqi7WFFLyIwUmRsivF3Ts40fXa6Gl8rvaXKbuhVg95G1CP1npGRxpt5K+DI
yYnZrtkq0JnZZ0eZnayNmZSV9EhbE6Qe6T7Q9FuycsR+vNAjBw4z7wmsPqy2
Hom1oEcpdeDQOPbZwT11zbS09MjK58E7CpwHHDll+kLeczwzrI98o7kkpuS5
ZkUGhsDX+hrvHxl48kz28+nS3ctiPqM9mudooKnxBTPGG67Gc9SnXwBnV5rn
dQafNaNHWvecnlzokS3IpgmcNWNqd9GvFc8yfi7MbNQZ9LWatS823m6XHjnc
/AxYMzqHUo/8leVrrTp65GOPbVMuA5OdIp9VhTBrPa9/7tF9apCyVbbFkois
ahqZypG4vjkWR55zONKJKhEORzrhhBPVMW5aj/z8H/XIS9bnlyx2vFSJJ116
pHLkm2/87+iRDz5QSo6MT4a+M4+cgZkZYA/0rEm2e2oqP0CPxGz41PR80yN0
7HQyDn2tqfNce31PrxDOGARnxCUZdvEPjjYcqdxgz/Or0COTyTMTyC5T2GfT
2z/MMCO1HKNHtuvcm+vB/h+cYtdHkvl4HjMDAl7XUGVheg91ndAjwauR0YbF
0EOWjNTL0iNtBta9Pur+PPoH0afrYuDA6Ep6pPHKoh8s5nmAV5cEbZRPf3nl
hnny019cloltpnL9Faw906qPHERNi/5bMJLmCL2MbObD/AvokbavdbKld5n+
N/78fvRBpZZq9VE1HJlj7oXyEO7r8/VflciYVNZSmnrCVGnUpJnRI9OMrgZW
s+sjwVKo2YSuBv6lr9Vae+zEDIsjvehzNX7TDL4naNu+B2teE6xaV6NHdjXn
gX5ncRf8s0bTW0zmA6v36ucnjV5vzu+dXOk5eu+D9qy5NV7oWfTPdu0O1p5q
WDs+k+8MoI+iR6rNjHiGe3sEkCWTUivYFM8a9Ej4o01vVlO7S1+rHtPWteED
ph4ZbHFknJlP8kGLjuTI1LQlhunHox9vAK8RWiaOiXsRPKJCjzTzI6tGn52q
zJFPPrlH2SpY2Sq3Em9lV9PI0mvF9c1Vjhzg6JFOVJlwONIJJ5yojnFTemRl
vfHzCmY0DFlp7oc984N9dq7JF1/9UcqPllOPfPhho0eC+7Cvu5WBY6KXxgMP
lkkDqz5ysnIk5kJiTp7xtY5z1crZvtZefb1lqnLkeMu/17W7J/kHPEJNcLzl
a/UM5J7enuHor3vvbsok0NNMrdws9r/p4uZBX6vdGwZeyq6WHpls6WrY/6O/
Kfvs6HrIkbomz4FWfWSK4Uicx6VHhieQpyr0SA+yBZgAeiR9rT0Hi//QWIsz
csgz/XXt1An168xMDF17UIzRI8F3Vm+XkWHx8mFrcKTNq7Mku3+BnKp99sb9
rvXOSV7wGovvMuifpa813pzHsPYkeofBfGRtaKmjk6WdcuRPlCPjlO8mW3wH
1nbTawJ/k5HGQY+0fK16DrvXDfXI+q8wB9RsJ1XokWAf6Gq2Hon1BA8f47q/
YCTkx2vQMGqMccy76RGE2R2TlKP4nmBiBt8T2PWRhiMtPbK1qY+cYvtA9f5C
j0R9JGpvwWLIMWZ0NCZHznO9jwD3N3njXX4PuXrSbBk+ajJ7/KKvb8X9TeHz
FmT1ipqYaN5HoIa0t+YJ98xojzNYi0uOVP61+9cOD7X0yFiTo7Hw+UancK4L
ngf8XLAWcgL0SPha+8iUGYtdXlk8/wOGjCR/x1kcOZQc+Su5//6qVR/52GNb
LW3vpP55qkqEWes5vZYS3acGU6Or4K2cahrZypG4vnk3x5H4+uvitvzP4Ugn
HI50wgknqnHcDEfaOmOF3ng9O/6W7GhzJuLi5Qpf61tvFSlHnuZ+Dj5UeFBv
ZeCY0B0efLDc6JEp6bqHziOfQctDj0/se6EZjeOsiukuPXJq+lKjI1l6JHyt
qMmbbDEF+K4fNb151gzHmRW+Vt170ycInTAsjnok6s6SrL4nYBfs/zH3EHt1
o6uZWRPtO5r5gqYHzSzxtHytOIfdUwd6ZINXmrB3TxI1o9nUDDt27UdWIlMo
p6Dfpzv0yJBYnhtrB4t5kiODyD2GgU1NXiflSKwvweoXM8rSI6HdJk0z54F2
1apNN0loky6f//LqDfPkx/UvS45vIefbG19rFn2k8E2CxaC1YV4GWI61kNQj
gy2OzGPN5uixRrMF94G/yS6ct2L7WnNdvW7MbJTXyHdJZGDTU6dhY6NHTklb
Yng1NpX3DN5Q5M3oapavVTkSzGb3MjV65EByFHVCPQ/uL/RIHNv0TDJ9ZVu2
6cLzoM7W7nWD80CPxLmhe0KP7NPXjz2TcG4ysB4T9Z49+/i6zoMcsT5SORIz
Tu0cGT1S1x4yltdoal3TONcRvX9xz+IsT663f4S8+1479sSJt+ZcjggzeiTY
1K6FjLD0SLwTQQ3pRPZ7gh5pfK2pM8zacR74WqlHTjHvUthLeLjta4Ue+Qm9
BniXcycG3l/Z9ZGPPbZFueycrvkE+awqhFnrWb2G3cpWQ8lWRpPMtZiyOkau
Xit4cr5y5MCb48jKfzp6pBMORzrhhBNO/Mtxc3rkdXqj5WO97IoKlrz0hYkL
V67Jl1e/kwOHSuWF+st1D3eGmoXxvx27pWH2icfloYfK2GcnLiVDGcnsl8Oi
LF/r8PHUh2zN6LVGTaVnX2+ZlrHM8pumkXGgRcEnaO/BwWKo/8M+P3GKqS3z
Vxbr3mMAj5WYamYuGD2yv4RFp7j8qpHo7QI90j+cHBlHvptOn2yHjr0lBYyU
bGY7sD6y/qtkuwSr/g7M8+bbH3KeIvhhYkImOdLWI8m7yhSopeveC/1aR/Pr
sHbs//sPDHbpkWA58Iw/fa3QI7NcNZfwyraw9EiwLblLmaNVWzc9RohMnZEv
SwdslM+f+vqGefLEz85KZItJ5BOcB/os6jDBSGQxi4diYpNdvtb4KVh7rqVH
+pNDk6cu5PXYdYvkSGVN+jMng7UnyiuvvsE+O8kWa0fEVvhaU3Xt5l6kst4S
c0LAUvEWDyE/nsqRYDYcc6zlycV9w/dx7ZON3ty2XQ96cqkto5fRGEuP9B5O
7oKWChYjR3btS01vsjUDskKPnM97DH0WDPfuB+2pPfM50lwNA2u7ebmYDyxn
zywJDhnD9wlkxnGmhhS8DY60n1efAEuP1H/zeiYZLdX2tWLteF6Rr1Zt3Ohr
hZY6yert+sGHHdkPGPecPl/Uv3oZX6v9LoX9jSxf6/33z6oSvtbHHzd65I9/
vEXXe4465ZNPnqwSYdZ6Vq9ht3JViEZeJd6aW01jjnIkOHmBcuSgf40jK+uP
17Oko0c64XCkE0444cS/HDfbZ8fmRnpaK/GiiW8sPfIb/RqNK9/IxctX5epv
/ii7Sg5IzZoFupc7W4khb7XecIx7rYceKqevFfWR6GsDfSc0KknZoy33vakz
Frt6lKDPTq8+PjJ95jJyScy4GS5fK/baiVNMfaXdrxV78qSpedz/Y3489vXY
99tMgRpDzI+HHmnrjNTA3I0eCS0UfWjY2wV6ZKfe1IESrLo41DJSj9Tz2HyH
GRDwbILvwMDY64MjO4Mjo6e4mMKlRw6N5WdYO/b/8LWiHyl6sySlGkaCj7EL
++xkkuWQIxwTPIQZKSkWU0RbemR/Xde09KWm34zyTmyjyXKu5sc3zJMfPX9R
8kLXMkfUIzE/UjmSOdK1R49JlnZdjB4JxkpU3mUNqYelRyJHnJ2Z7vK1xiXm
Wmw62/K1vswcYO1GB57i0iPhW8bawWW2rxX3DMeEjxPvCahHan6SUs39hSYN
HXmSHos5ipvtqo8EA6dYfmRypOZooLc5T5ylcdp6JBgW9xzvCXpzfmRzsr/t
LQ1SLnzxxYZ8D8C1J2SxL6zxtU5z5Qi+VnKkMjA+A8tRj/Q0eiRYG/ccPGr3
a+V7D+s5cumROA+1R6Nxtmpt9Eg8W8gR+PCDFp2oR+J6zByVdJceCdYG28If
PXTkBHmizq+kRo2Z+rP3ifLZkVvuM7h1fgW8vzJ6ZFXnyLvuCqFGV8Fb86pp
zNVrBScvVI4c/M858pN/wo6VmPKc9fm5j79k3Jb/ORzphMORTjjhRDWOm/K1
fm7rkL+pqIf83NRBkhstdiRfXjFx4dI1+eLr7+RQWam88kqh7uHgy7IZ8lbr
Dejvf1I58rBypK+yWbrurU29WqitR44crzyU76r5oq+1t7ekzSow+t3YCj0S
7JI81cwIoa+VMxjzdA++gNoUWKw7OFKPnzLdMIXhyP6c0YDPoAeBI+lr1b39
lLRFhl2UV8GRHTr3ITvY7AKeee7FV+kdTJ5mGDhk1AR6NuE3nZpufIZgSs6P
VI5M1vOAU8AH7r2GsP8nvhfsg/NAS4Tehv0/rgdeSluPBEuksC4uU0ZZeiTO
g/4qZOBKeuS0jKWuekRwU4uWXWTtkL1yre5vb4wn7xI50+BTSRmQQ62NLGbl
KGaM8bU+oxwJ9gerj7bqI6FH4utwPZxJaftala2M9pjJfi+oK8Ux7fcEkbYe
OXiETNe1x1v3gnrk8LG8vzyPpUf2t/RIO0esj6Sv1cpRfCbvb9sOFkfqvYT2
CO9pizZdLV5dyj40OKbNkfgs0dJNMaOjiXIkrgX3CHyHeZ+Y6wJ/bKpVj8he
RO5e/AzXjrXbeiR6BOGZwTFxHpsjMV8Ex8V7AvQisvXIJKs3k61Hgnvt9xER
lh4JbZ3MmJzLfj8ftESfnT685/b7CHh/B6I+Up9VrN2eSfNknV/L/fdnKON8
rD+Dh2+5z+DW+RXguT2rv4MKlSM3k8ngX4BftCqEWSv8HLuUrYZRo6vgrbxq
GvP0WsHJi35YjyQbfn2d7gh2/H4tJLixMkOec/RIJxyOdMIJJ5z4l+Nmfa2X
bF78/Bv+/dIV++8V7Ii4qJ+hV+uFy4YjD5Iji67jyNusR6ZksFfm+PjZxtfa
vA15Y3rGMlNbBl9r47eVI4fIjNnLjb5DX6uX4Ujdv4MZob9Bj7P1yCns/Tmb
NYZuPQbx+PgMfU9cHBmVQo8j+C7S2v+DI6fqZ9CHYqx6sw6de3NPD3YZD45U
Xn3+ReNrBT+ghw/67NgciX395KQKPRK+RDAF/KpRo6e69Eh8L/b6xtdq+uxA
Q8LnmE/iHxQlXeBrVUZiHxgwkkuPTHTpd9TayJFDZfrMAlOPOCFd2bKbfNii
M3OZrMdd1nujXK79xQ3x5N819j9dKtO9F/LcOCZ8re1QH/lmlHKP4ffR1iwR
6IfIL++FsouPxZHQ/cxMjdkydOQ4ciRYi6ytjBRVydeKtSOnkaNtPXKslaP5
nInhMcDiSOQobSF1Ql9bj9Rj8f5aejP1yJhU42FljqYZPRK8OnMZfZ8xuvZu
lq91akY+3xNQj/Qw9ZH2vcB7AhdHjp3mek9g65GG+RYxR+Gos3UfQF+reWby
ONu0r+VrxXOAHKGvFGouWR9pPUfQUm2OjFLunWr5byOjLY4MjuGzlQCtfDz6
7HRijyDcX6wdemRfr0ByJJ5f5B0/F5X77FSF+sjHHzd65KOPbtbfFWf5+b+7
/8+N9wnCWs/odYAjh1Ojq+Ct+dU08vRawcmLLT3yh+Z+fPWDXtZzH1vc+Iky
pMWPrv/u6JFOOBzphBNOOPEvx83pkYYbyYmVwvVvsCN6tFoBtvxMOfLrb/4o
O3fD17qcfS7AkWY2+K3fZ8H/9fDDh6VBAx9lq5mSmpbPXqEuX+vw8dQeJ1nz
715t9Jb06OMt6ZmF1F1ixk+XLtQjI7kvx34ZGpjnwBAyDfbQU2csNnqk3a9V
j2/2/znsw2L0yGSyGNnF9rX6R1ALTbZ0QuqRnXqzfi6F2tRs8VBeAw9hLejZ
gv0/+mw+y/mRCbr2ZRKn58HfMbcjYnQKNSx8faStRwbHkjPAD2ACaInwtUK7
S52xyFXbST1SWSJV125qOw1HoifRtJlLyWnwVbayOHLGrOXG56v5gNf1w5ad
mMvkaWYep2f/YJnx3hy5Vvd3N8yTH716SXLCVki0zZFNoQODh+a7+rWC+5AL
+17YeiQ0OqM9ZlpzP15hrsnamiPUpYIjB3iPkLTZZu2sIQVHDhvHekDkKLaS
rzWJOVrMHPkpR4L/cSxwF5i7Qo+cQj6cnGw4EvkYOGQ485GYOo/vCWw9Ermk
9jgJ9ZH+1CN5L5QPwZFBw8bISw0a8TjT9WvxHGHGZjf3/sw/zo33BOyzAz0y
ZCwZ1sXalh45xcoR9GIfq89OgvUcTfieHjnNeh+RY3yten/xToQMrOdhn52W
nahHpil/U5N36ZEjqG9i7ThPCH2tv65CHHnW4shNZDLolOZ30Z0fZq2n9Tp2
Why5yNIkF1hMWR1jgV4reDJfOXLI/1+P/LiCH89/XMGP5yxf6zlLkzzr6JFO
OBzphBNOOPEvx81wJJnxc5sXLQ2yEjO69Ej780p65IHSUnnhhULdv6FH4vHb
UpeEY2LGWs1HjrBfa0JKhu71l9GXaPrstKUPLz1zOf1+0Opea/S29OzrIxlZ
xdR3XHpkQBT35djDY79s9MgA7qGx1wd3kSPhe4zP4mfgrsq+VnwG7oxy9WsN
52fY67NHaH/UR/bhOWymYH1k/Vf5fdMy8jlzAtpZs+atOackTff60DhtPTJS
OYBsqpyCOYbgSOiRPKbyEBjJ9rXCxzktYwm9lH7W3A8cH2uaaNVctmzdhbon
eAgMbDiym3JWCFkbPlDMhYT+9kHLzuQz6GXwgaInLOZHJqcukI1e++Wbx39/
Yzx519/l6MunxbflRHnmzWhJ0bwjH2Bto0cOJjeB39knV/kO2jJmoyBHuL/D
2GfnTeZjhq7drhdt1MTM/eDaNaeRYyr0SOQHXA2tzcPiSJOjfL4ncOmReiz4
YqETsl+r5Wudznsxt0KP1PNA14bGafdrRY0htNApvL+zlPcsX6ver2nppocs
5n7Agwr/9PRZy+jXHY7ZKJavFedG3iOs+kj4WlGrCg62ObJ3vwBeD+47eNX2
tWKOCa5nAvsbTZK3m5l+rXwfkZzr6rOD9wpYO++vPjN4R9BB147PcB7UTOL+
DlBWBgPjmRtn9cl9skpx5LlqwJE7lK1GKFstqcRbi6ppLNRrBScvszjS0iMr
a4uWvnje4kX+/ZMKdrzez3rWitvyP4cjnXA40gknnKjGcbP1keTHKxX86GLI
6/5emSOvfPkt50c2a1ZMX2udOsct7fDW1w/VUZ6s+chhafCKL/XItFnLqbuE
RiXIO++1ZX3kTGVGMAVYrqFyZI8+PjIrZyXZBXVg3ehrjSS7zND9NuoWqelB
j9Q9dIZyKPjLP2g0fa1gAbAptJwRlh6JGR3Q76B30dfacyBnw4MDwQ/Y/9PX
2qk3+7CQTfU49vxI6Eg4N7QwsO+rDZuSTTOyirh21kdCj1QOABOAsez6SMyP
xD4fn4OR+g8IIQNgLemzC6hxoj4SvlbwI9aOHFXWI21mxDFbW3okzm2YsUKP
BGeAU8CmHl6B4uk1VNe3QD9XlovPlbmtlsnnj3x1wzy5QjlkXsxa5sPmSDfl
vqnW9Yxj3WKFHonzIEfgmRdebEhfq60tkyMbN5MBg4fLzOxi8pBdHwkNEBoy
csw+Sl7gyBByJPKBe+FbSY/ku4ekOXxP0KaDmR+ZbnEX9cjW3fQ8I/TZKOK9
gFeWvtbOfcjk08lys6W3h780fqM5uR9rx3OEelbMuYT+mq45xnM0nHrkADIf
vg55x3OEtQfq2sGwOCbOY+uRrudV74WPn+FIzHox58mmHvkW536k8nqgm0ZE
Jxs9Uq8VeZuStpDHhB7ZoXM/foZnCYxr65HQznHteO+B/kZ1nvyV1CBHVp36
yNq1N+rfT9+WvtG3b/1Y6yn58Y+3K1uNpEZXwVuLq2ks0msFJxcoR3rLmfNn
lQuvufRIaI+VNcfK/Gh7Ws9WYsezlXTJ2/I/hyOdcDjSCSecqMZxsxz5z5jx
+rD/Ozjy86++k7IjZfJW02LqkXXqnLjNeuRRV33kzKwVRr+LNHpk8MhxMjt3
pTLVgkr1kd6SOWeV2ZezX6uX+AREkl1mZhdxX25zJHyPs3NXUJtin52emB+Z
pRxaTA1xpO7/O7Nfa5IyRSH1ITNrYgBnw4NrZ8xeZnFkAOdH4jw2m3pY/VrR
7wXnhmaE+sjnrX6tmVi77uPBfPC1Qk/Cnn76zHwXRwYEjyaHZWQVmn6t0CP7
Gz0S64Q2BT3ScGQWz4McjSBHdiNHGu5a6OqzA51xVvYK5mgc9EjlTfRiAVuC
ScbHGY7keZQjcR7wF/ySPXsMkZW9tsvv6nx3wzx57o2LMnXYfOlj6ZHMkV4P
ND1XfaRyJNaJP8Ez9LWOTtVzr6AmiLkfDZu8IwOUfWbnriLvRtPXamYw2jni
fFBLjwRrz9a1wyvrp+chRybl8nqgz45w6ZEp+mwV8esr9EjDq2Rgqz6yY+e+
5DjcI+S9l4fla9V7gbyjRpG+1pcb8zi4v3hPAC9zN3cv1jLiPHj3QF9rT+Nr
5TE179CbDUf60588M7uQ98LWIxNT5vEzzOPEMe35kbN0nSlT55s+O+TIaK4d
ejWemQ9bmn6tvL+69rEWRyKX9nOE9xEuPbJG1dIjqzZHQo8cRY3OaJJLLKas
jrFErxU8WWg48h/0yEp1j7Z/Fb7W6/ixsq/V0SOdcDjSCSeccOJ/FreKI3+I
Gf+hZvLzb+SzS8qRXypHHi2Tt5uu0P3bec7URl/VJ588dUsDx6xT57Ry5DF5
+WWjR2bmruYMCfZrfc/M/ciZt4Z+RsyVMHrkEMnWz9ItvmO/1oAI1pBlzlkp
4ybNNhzpGchasex5q6nfwdcKjyTqL7PmrmJNn0uPjE4mz4ApMN+CeqRvOLkF
+/pYiyPbdewt02YuU3ZZQc3InvsBJs1Sto1PyWUNmt1nJydP167sMjJCzwM9
MjqF+irY1Pa1QieFdpepvEs9clAIGQD1nlinYSTb15otmXNXUr+DZ9PWI/F1
U9MXk2Nat+1OvS5rzmrqmdAEwU3oxQL2IJuithO+VuiRyJF+P7yl4Ej0/oG+
l5OzWjb12i+/qXVjfte/3f032fHrvRLYzroXej3Q9HwDI+hrhacU60Rv26HD
rH6tMan62WpLB06VRq83E6/Bw3U9aySNOTIzNuENhTaMdwKYX0Ff68Bh1Cyx
dvA19Uh3o0fiPNDv8J6gXQczPxLvI+AlNb2IulH3BAeCu6Dp4XvhDU3PLGKO
JsbbeuQ7XB+OiWMHDouVl199nb5l3F88R8NCJ1KPRM0rno20WUvJrt3pax1D
hsQxx1h6ZG+PANZr4nlF3yH22Xnf1EfiM2i3I8ImSjOLI3FuvCfAewj0UfLV
+4R3KTP0PPS1tujIXsJ4hnkearbG14q1I0fg4qEjxkmdur+WB+7H3I+PlXEO
s9/VnRiYSQI9smZN9I3eoJ+dsuaUHK0SYdZ6Uh59FHpkKDW6Ct5aWk0jX68V
nFz0fT3yoy8qeujYNY+V6iCvZ8jr/+7okU7c7hjlcKQTTjhRDePmfa2VPK1X
rH9X5kf739af9LV+9Z2UHymXt94yemTdusaHCp68lYFj1q17SmrVPGp8rakz
lRnXcf+PmYjNMPdj+HiZs2A9GQl6JPyE7r29JXf+euWxQnopu7kZPRK1atjX
w79n65HQAufq9xtGirF8rVn6/Wt1X76A8xow0yI0Kln32qvpM6Qeqbw5xC+M
TEB2sXyt7Tv1ou8xe55hl/5Wnx2wGI4JnRAc+YJyJDTVuQvN2o0e2Y/9fMAz
YFMwR3f0aw0eTT8ieBezGYweGch+Kzim8eTGSKdunuzpgs+ggY0Ij3PpkfgM
2lTk6Gn0taKfaU7eWp4HtZDQsOB9nKnXk0WmmM0aTFOHuUDm6PdDS4Vf0l2v
faKdozRl4BEJktFojvy29o3x5F/v+pucevtTyZ+yhbzqG2D0SPRFnaNrgg8U
eqTdrzV3/jp6lNFnpzH0yEHDJDdvHTVf5qjnYHpD4ck1Ocqw9MgQ5miOfv+k
+GzOj4QeiXvNHE3N43sCmyPxbEDjjLL67HgNHsH3EdAZY1kfOUA6KovNzEaO
VpLfwZGNXm9OpscxceygkIq5H7i/4LThoyYZX6tyPPKbnllgfK2ay8CQMeR3
8CH7qHr6S59+/uRiPq96Hh9rfiTeR+TMXyNxKXMr6ZGpPDfepcArbftasfaM
LMPA0CPbd+pLHTdLz4M+uf36G1/rFCtHpr+RcmSdZ+X+B8CRHynrlP/beeuf
cxgY9ww5smbNDfrvU/r76AjnSlaFMGs9KbVrb7M4cnkl3lpWTWOpXis4uVg5
0kfOnDsj5z++SmY8/8n3++b8EDOe+wE98t/ha73nnt1O/B+LUe8oRwY5HOmE
E05Ur7glfXYq99O5cl2N5JVKjHn5N9Qjr0CPPFymHLlC90HnpV49w31gvlsZ
OGa9eqelVq1j5MjE1Fm6L9+ojDSPWh70yGDd9+Yt3kR/JvQfcGSPXkNk3qKN
umcu1v1/GusjffwjqflgXw8vJXRC6JGoU5u/ZJPRI4PQZ2cQNb28xRup76CX
SZdu0COTlFfX8RgR3P8PJEdC8wEXGF9rkLTv2Jv61ZwFa9k7Ff5R6JHow5K3
aAMZib5W/Sw0IkHPvZkeR3JkV9RHJlNfhRczcrRVHxkcQw0JLGf32cG54A2d
p8cE0/kFm36tkxNz9TwbjScXvtZW3WRURKLMW7iBWqqpj+zOdeUqP+M8qI9s
jT47LTrxesAk4ycbjrR1TxyTHBkUTbZ15Ug5kj1kNMcxUdNkz6Dj8ofH/nhj
+uS9f5NDTU9KpFcCORIaKq4HejN05vr1zfxInHuasjZ04EbKkV6Dh/H+zlK+
Q32kGziSLFZEHoq1fa16j1ELiHVSj1RehaYI3yzuBTgS7wnadnCn7olnAzmK
Zo66UfcEw/I50vuLe465Lqi9zVXeZX1kPz+yLVhsnpUjrAUciecR9zcVOQqd
5KqPxBqhY0fGpJCBA4aNZd7BwLF2n52+fjIDz6s+c9AJbV8reuLMW7Se7yOG
63Nk5n5Mlbl6PVPplU0hA6PmdM789cyR8bV2lg6d+lDHBZuOsfrs4BrxfcgR
NGbM0alT91l54IGqVB9ZRD0STPboo4ep81WFMGs9YXHkKHo9K3iroJrGMr1W
cPIKefoZXzl9/qwy4DWrbw4Y8csf9K7+EE86HOmEw5FOOOGEEzcXN61HXvlH
PfJCJT3yAnrraFy8jB4738inF6/K5S++pR759tsrdS/0EZkPPlR4UG9l4Jh1
656R2jWPy0vKkUlTZ8uCJVvpE0Qv0qbNWkiI7qUX5m9lfVn0OMORqI/E/j3b
4jvs370DIliXNn/JRu7/yWIegexlsrhgG/flYLFuPQaRORYt3cr+KpX1SOy1
Z+UUkTmgIw32DaXmA76E5gO2a9ehF2vQ8vQ88Dj2t3yt0D0X5G8mu0CPfOmV
JtQeFy7bKmnKLvTPoj4yOoX6KtjUro/0CxpNrQrnt32tmP0H5lm4dAtrO9mv
VTkSehg+g4Y4IqxCj8S5qYGNSbV8rUHkHuQIPVOhYb3/YUdyBhgL7IKvAUvC
64ljgoHhDSVH6rUt0rVDS2UPGc0R+BprzJy9Ula33SrfPHBj+uRf7v6rFD21
WmbHLtd1bmGfXVuPhN64UD9DvSh6tzZ+/R36TRfo/c2as8LMj9QcBQ2NpS7M
HNl65IAQ9q/BOnEvbF8r/LO4HtTUjlC+a2vpkXifgOcI+l4r+lqH8b1FjvKd
q19rp96SmbuKObL1yMavN2PdLNaJ5wj9dV9++XX2fVq0bBsZGO8OUB+J6+Fz
pGyK+kg8RwHKnXiOwLFGjwyUXv382eNnQf4mvifw9o90cSTOA+Yepmtv1rwl
9VPkDc8RnqnW1twP3F88N6Pha23VSdorA0PHnafnYS+i/vC1DmP/WD5HCdky
FH126j7Hfq1Gj7yzfa2PPXbW0iPX6+8iaHuHqfNVhTBrPaEMvNXSI4sq8dby
ahoFeq3g5JXyjHKk7Ws9+/E/8uN/x4wORzrhcKQTTjjhxM3HzeqRNj9eqBxk
RvMnNEiEzZa2HllaXiZvvlms+7iP/lf1yMUFO3XPvkhGRiToHrqVDFUmW1yw
XWYr37n0yN5DyJbYL0Obgh6JWY8zc4olf/l27v+hR0L3AQcVrNhNjdP2tcID
ubRwp+G7UMORYVFJZDF4WyMsP+JgnzB6Q8Ef0Anpa+3Ym1rTYmUXaFPQ/cBD
6GWyRM8Nr2zIiAny4ksNOQMzX88zK7uQPXG6sJ+P4VUwBbQr955Gj0SNIHjX
zCwxeiQ4cmnRTvZcQV8VcqTyUv7yHfSBjgifTI6EHgmWgvZIPbJNd/paoeOS
KSbNInt88GEn8gy+lj2C0GdHORLzMHEeMDB61aA+cmJCjiwr2sX6u2GjJrEG
FfoaGAd6avToZOnaeaTE/myV/LH2n2/M73rP3+R82ysye2Ih53jUf8HMj1yi
9xf+TNQTgiO9Bg0j54PfoyzvLzRAaHrMkV6P0SND6A0tKN4l8Xov4G0GC6K2
EPcX7wnQ8xS+Vqx90dJt1H1xTluPtHNk9MgBrDHEeRYtM9xFPVLXBI5E3pGj
wJDR1CNH6/PIHM1eZvTI7gO4XjBfbt4ay9eqax86hrrnwqWb6Vs2eqQ/30fg
ecV5UB/ZXDkSfaHyC7ezrnd46ET9GWjBY+K6kaOwqBTeS199HvBcUsOmr9Xo
kTjPImXGcZNnGo7Ua8RzhHXiOQpmfeSzUqNGhjz++MeWZnbsjgzjCz0jjzxi
OBLa3qOPlpN9q0KYtR5XntxicWTx/ymOrNAjr8oZiyNvRHd0ONIJhyOdcMIJ
J25N3AxHkhOvfGNxo9EcL9rsCA3yB/TIzy5dla+ufSc7d+/XfWaR8t7HUq8u
GPI0me9WBljyqafO6D7ruHKkDzlyWfEeelhRH9kcvtbh4/Sz3axHjB43zdRH
KlcsKdhh9uUTzNwPH79w6lWFK/dYfVSD6WsFR65Yu5/7f+y9MYcB+k/hqj30
sNqeTfhooS3BZxhOP6LRI+EdXLJ8G3mVfXY69KK/EuyCfqDQ9NB3FDVyhStL
yC7ss6NsiX6thav2KpesYE8c6JHgVbAYdCjwTI9e3tSW4EUE746xOBKaFbS2
Iv1+MJJvUJTla82R5StKNEdLdO1x7J8zMjxReWQncwSfKPRI+FUXKostVDYG
U4A93m/RkZyxTNc+OTGLawevQo8sXr2POjDmcBo9MpvnnqnsYvcijYieQuYj
A8cmSftuQ+WpJhEyJ2uDlA8+L3+oeWN+17/c91fZ2mifNH+uBVmrQO9vpqXf
gdmgx+J6wElgKDdrxib4FTlCvSc4EoFa1eI1+8iOWDvrI5Pn8jmAxjmcemRP
HtvOUdRo42vtP3gYdW1wF3RCcGT7Tr2p2Zoc5Sjv+RqOTF/CZwa6M/VI+lrT
pEjzhjpd6JFd3QcaLlbehDfV6JGDJSAklr7j/MIdep4MS4/0kwx9jpbrM4Me
sN6oj9TnHfxYoJ/BKzts1ASjR+oxlyoH4vkOt+Z++Oi14nmdv3ijmfvRqjPX
PlfPg3cC48GRnkFkcvRwQo7w3iNI+b1O3eepRz7+eFWoj4QeWaQsCT0STFZG
PqsKYdZ6TGrV2qxsFUavZwVvFVbTWK7XCk5eJU894yenlCPPWnrkzTCkw5FO
OBzphBNOOPGvx83qkYYlKzRJmx1dLHn5msWUiGvKkV/LF19/K3v2HZSf/2Il
a6jq1TtlceSZWxo45lNPnbU4Er7WWcozB6iBjYyIl3febUf9BHv1OfPXGD2y
keHIpUW7qf/Fjk8zvla/COpIK9cekIkJlh5pzehbs7GUcyUq99lZqWyJ2jJw
BvTIUcp32KuDXcJjTH3kYJ9Q6lUFK3ZRR4Ie2a5jT+7nsS9PmDLHVR+JGkOc
G7WQZjbia+TIlWsPsi4O2iH0yNDIZLIY9CXwgXvvIdQawXc4pkuPVNbA/n/V
uoPKq3PImuTIpFxyMXIEvyn1SOXI5cpN0Kbgq2zVrju1KHATcmQ4spu892EH
mbNgg+ZzLznR+FqDmKPV6w/RB1rha9UcrTtALZWeze4DyNfgK/LdaMORT78e
wZ5Hy1fulgmxs2Rx42L5/f1/uCGe/NNdf5bdTctkfV4p/bfIe+MmzXj9BcrK
0HzBxfC1Bg4dzbpO5AhzTGxfK3yqazYcItNTj9RnAUyJtVMnHDXJ9NnRY4PZ
UNcaRT2yKxkLWjf4LpYcOVA6dOqlTL+OXI2aWuiRjXRNqMNctf4g9WbMj2yA
Pjv6PK7Sc0PjDBmpOeoxgFo2coT3BPAwu/UYLP66djxHOL/RIwOpR6K3Ku5l
XGKuDNHnt/l77ehXxrOJ9x/wdIMj4e0F04OB8R6itd5fXCu0bjCw8bV21mez
l55ns37tHvboNXqk4cjVuk54coOHjZMn64AjZ1URX6vps/Pww+v19wQ8ouX0
i1aFMGs9ruvfYnHkykq8VVRNo1CvFZy8Wp5WjjR65DcuX+v/hB8djnTC4Ugn
nHDCif9Z3BxH2gxZSY9UVqxgx2vfC/RqhR55+Ys/SNnhUnn77WL53+izUxu+
1pd9JHnqbN3vlnOex6hwS49UJgPjQCdEf0zokdB4wE3gO9ZHdveSIf7h1JHW
biojA2EuRB9Pf+7/N247yv2/n61HJmTz69BfhTpSd8OR4CvsyzGbA183SDkS
mk+xfj5mguHIth16cZ4G9uWoJwRHPlf/Fc6fwDGhgQ21+rWiD86aTeVkYDNf
xJMcAM6AZgRGMnpkDGvdwENjJ5l+rX37B1AvXb/5MPvS0Nfa1ZM9ZHAezPOA
ZxN6pOHVA/RnRth6pK51WXEJdVPb1/r+Bx31PJu4dmhg4Ix+/YPp2dyw5Qjn
k4BPjK81W9ZtLufsDuir1COVI5kj8F1MorTvavRIsMuKtftcOerd1U/29zwl
/1n7Lzfmd63xNzne9mOZMDyD2h/eAeDdwVLlu0jWkKKnbSx10NXMkaVH6tch
Rxu2HmGPX3ibUR8JpsTaMzILOI+jnaVHrtAczV20nn1hqUcOCqHWDY1zNH2t
g+hbBmvjmTN6pPG1os8rjjklDXrkaFefHTtH0A5xbtxT5AgMjJ5K1CN17dCG
i5UP8Z4AvtZeffwkU58j3EvUvGLtzd9vS117HZ6j9CUybKTFkZoDrAeaNTkS
eqR/JLkUHtjR49MMR+qzuSB/q6xShkavKbvPDvpCrd9ymO89gr+nR56vAnrk
aeWw5cqR68hktWqV6Z/lVSLMWo/p+qFHhlOjq+Ct4moaRXqt4OQ1ypH+rj47
lWd8OBzpxJ0YDkc64YQT1TFujiN/mBcrPvvme2Fz5JdXv5VdJfuV8wrlyScx
P/L4LZ/58Q9zP172luRpmcozx7n/hx7Z/L029LWuU5aCfw/1hA2bvM15gsXK
BEWr97j0SPRWRf+aTduOKUcaPbKPRwDr57btOkU/ImbusT5SGWrz9uPW/n+i
y9cKvQk6IbyD2P8P8h5FzQf7cnvuR7v2PVkzyX05fK3QI59/mfMncO405cgQ
S49Ev9ZN246TgaEd2hwJTQ0MAO2qR29v+m3BGeu3lHNeA/imj7IGZs9v3nGc
5/G16iPjk+fyPOipAy2VvlY9z5qNZewxhGO2adddWSVIClftM9rUxJlkS+iR
qN3D2m09El8H/+yWnSfppcSsR1w7GArnxgwJ00MGemQyOQ56qq1H1mscrmvf
ppxz0FVDCu0SOdq85phs7XBAvn3guxviyf+s8V8y56n5EtgnSu/FIVmufBdh
6ZH+waNZv4q1mz47wcw9NL0tO0+wLw31SD03/o612zkiR2pe1mqOUJtqWNtN
n5Fh9B3zORqXxlmPRtPbpPxeLnGJ2S49EjnCMdG/Fr7Wlxo0Zp+dzTtOcEYI
WVu/PyI2lWtH3SOeIzAw9Mj8op3Mnd1np2dfX+qeeMcxOTlHvP3C5R193vkc
bT/GGS44pvG1TuX7BGipYZHJ1CPBncVr9pOBY8aZfq1tde2Ll+8gh9p6ZP9B
w+jD3qLrhB4ZpD9PdevVV47MUEY7p6xWJuiLeieGYdxTymEFypFryWS1apXS
L1oVwqz1qK5/k7JVBDW6Ct5aUU2jWK8VnLxWOTLA4Ugnqkw4HOmEE05Ux7h5
PfIfefH7ce0HOXL3ngNSr16hPPHEOXLkk0+evOXxxBOYSan7xEeOykuveEvK
9Czd755iTd7IiDhp/m5bekQ3KfMtzN8k0bHQI9/i3nz1hjL6/1wc6RvG/T+Y
Av1YoVf17ufPmYO79p3j/h+aHvq1Tk7Ike27T3H/D87o0t302Vm7qZz6Dvyb
bnqOgT4jqVet3VhqaW1B7P2J/i9gisRKeiT8rNt2neT8yaEjjB4ZFpVIhsWs
C84Xoa81ibwKzYp6pHKkT0A0/aeblR/GTrDqI5WB4Z/dpuvEbHr6Wrt6kim3
7j7JXj/DXHpkIjU51ItGxKSSM/oqz61Yd5A5GjvR1Ee++2F7WbhsOzkFemQ/
6pGB9Ibu2HOG8wnJYnrt0Mi2l5ym35SeTc1xhHIRmB5aahT0SLdgeapJuLLL
Tv28jByJ83Z195JczRHuBXu7DBkj2T/Lkz8/+J835ne978/yUZ8vZdWSA9QR
jR4ZI4uU8TdtP8rrwf318BpKLzPWDj0SGp2bnjs5NU+2lZySDMuTC/ZHD58N
W4+autQYS48cEEKNEh5Ylx6pzDl/yRa9F0e5dtQxNmzcTNJmLWc+0AMK9wJz
TMZNmqX35zT7vaK3EjgS9ZHrrRyFRZn3EX7KkfDpQnu0++z06uPLuSxbkaNk
S4/U5x3a8FZ9jqBrD7N9rXpM/AxAb8bzYzgynLyK9wRYewtLj4TfG88CNFvU
yOJZwnOEtePZCR5WNfXIhx5ay35cNWuWUuerCmHWelQeecTmyDWVeGtlNY0V
eq3g5HXKkUGuPjsORzpxp4fDkU444UR1jJvnyOuZ8Zqpj7T663wvlCM/tXyt
5UfK5O23iqRW7bPkyCeeOE798FYGjgldsuYjR4yvdVqm7svPsu8o+pvavlZo
Zeh1Ez1mqrzW6G3u99dsLNc4RJ0QjDPYN5wcuaPkjKW1GT1yRmaB7Dn4Mff/
pg8LODJbdu09R59gZT1y/ZYj1MCMHjmIeiT2/9iXm7kfgdJGOQO1jOA79O6h
HqkcOXVGvuzYe0YyMpdL8HBLj4xMkO17zsqCJZs4X6SzciSYD/Waq9YfoC5G
PVLXhV6g4FAwEud+ePpzpgMYGLMiUbeI+ZOoldyp3IT5JMMsPTI0PIFsiByF
W3pkP88gWbXukOWVnUVueveDDmQxcAoYycMzkCyJXjW7959n7x5fZTFcO+ow
ce7c+WvIxUaPTJGNymLQUiNdemSYLCncJZu2HXH5Wrt0H8AZimAXMlJAhLzd
vLXMiF8mn3lflT8/9F83xJP/9fBfZfP7e8XLLUj8g0azlhFrHwfPpua9n0bm
3JVScuAjzhLBeVAfmTR1vuzce5a+ZZceqewIDXpxwVYyJfVIZdEVaw/yPcFo
6pGDqEdCszU5yqWvFXokWBv5gE6I/rqvNmzKZw+foS516Mjx7PED3RM5Qs+l
cOVId3Ckfj182NAeTZ8df+nZ24fvI8DA0AmhR+J5R5+mnfrM4H2E0SNbUY/c
uuMkn6NRUYmsfwV3rt5QSgaO0bVDj0TtLjhyy47jJkf9TZ8dcOTufeclSZ+j
oOFjlCPrS437Z93RHPnjH1dw5COPLJcHH1yjXAYmO0Q+qwph1npEHn54o7JV
JDW6Ct5aVU1jpV4rOHm9cmSwo0c6UWXC4UgnnHCiOsbNcuQ/sOJ1DPk9X+sV
06/18pffStmRUmnatEhq1jqjzGfmgoP7bmXgmODJRx4+LC818JYU5cide89z
buBImyOHj6Pms7Roh/G1Nm7GufTrNh+hD9SeHwlfK2YOligPoT8KGKGPhz/r
5w6UX+D+3Ccwmnt9zEYEe2Afj7066yOV7zZuO0aPI7RJ916DZKByJPb/0AnH
0LMZIG3a95Q5C9cph55lb81+lfTI3XrMmdmFnNFn+1p36XpQTwjm6+LmQV6F
pgeWxJxKcqSyG+ZU4Jh2n50+lh65VxkY+39olvS1pswl88GTO3zUZGkBPVJz
Be0PGli4HrONpUdCs4U/c6zVr/W999vTkwrGAt8ZPTJImWW57Cv9lJ5czJ+w
fa3g77kL1krICKNHhilfQ4dFDxroke3chkrdxuGSX1QiW3ceZ68ao0cOoMcY
jBWfkis+/uHKQ631/i7k2udMXyVrmm6T399zY/14vrvvj7Kq6RYpzCvh2sez
PjKYvlzokft17eijBD2ym/tA5e75vL/ok0s9EhwZncL3Eai5RJ1n6zZu4qF5
Xrn+kGzYctjM/ehh9Eh4jHEe9OvpRV/r29QjkQ/kCPWRDV5uIqPHppkcLVxP
LzN9rZp/5GjFmn2aryTja1UGhv6Me8QcKUf26qMcqd+HfBiODOPzjt65+Az1
r9Di7X6tYHLMIsHzA4/yEOVO6OdrNx7SdcyQD+Br7dBLClbskR36tePjZvNd
AnyteB+x79AnfF4Dh8VavlajRz76aBn72dyZgbkZp6RWrQJ56KHVVZojf/Qj
hyMdjnTiTg6HI51wwonqGDc19+OfeFkvXPd3Oz6z9cgv/yClh0vlzTeL5JGa
p5X5TP/Exx8/fksDx3xCOfLhh8rlxZeGKGdk6f7/E/alHBkex74jqOfaufcc
e+rQ16p7emiKG7YeowaGujbjaw2ljrRX98vQI8mR9LUWSOnRy9SRfANNfSR6
yOw79Cl9guAM+FpHRiaw1g39M8Ps+sghI7n/h/Y4dqLdZ6cHZyvsOfAx2QW6
2HPPvyxT0/PJYugBa/q1viqjdM+/9+Anym7blCMnS9dunuyJA30TfGfXR/r4
R3G+X4kec6xyBvyWfT2MHnmg7DPu/6FHdurmQW8irjFr7irOdaSvNTxBtitr
o1YOsznAkX08A2Wt8io0sLGTM4yv9YP27OG6RxkLWhuYD7V6YJaDhy9yzqA3
9EjUkCqL79dzY36F6bMzgPrall0nqYFFRidIe7cQqdsojLNawC7wtfYBR2o+
kSMwMPuo+kdIs3day5TpC5l3zALFPMg3nn9Htr9zQP764N9uUJ/8i1zw+Ubi
x2azj5LRI1dx7eg16+Nn6ZHK3bgXeI7gyYVOBy0VLLa8eBe1SVuPRF0pvLLQ
m7u7Gz0SvZVKDpzn2smRjY0eifcRhiNj2GcHzx5ylLdog9FslSPDNf/QMlFT
Sz1SOdIvMIY1scyR5Wvt2cdX5ur3ge/Qr8nbF/WRbdk7F2uHt7tCj5zCnwE8
R3h+4Gsdol8Pny6eI/As5n6AI1ETu1v5fVzcLL2/QeKprAzWPqhrpx6pea9b
7wV5oMYs/fm7c/VIBGZbQo+8//5CuffetRaT2Rx56I6PRx45qH8eVgbeYOmR
6yrx1upqGqv0WsHJG5Qjhzoc6USVCYcjnXDCieoYt0OP/Oy6v7vi8jfyiXLk
JeqRZdL0jULdC51SjjT7OuiHtzJwTOiSDz9UJi808FbOyJL9pRclR/f/6EWK
viOY+wG+gk8QeiQ8hm49B+ne/wQ1MFuPHOwTRh0J++UKPdJP0jML5ciJLzmT
EixGPVI5EuyB/b9Lj1TmA4vBb2r2/9AjR7APKnyGY6z5kdAj8xZtIj+A7zxc
emQ+jwlGCrb1SGXT/WUXOFcC8ye6uPVXPjYe1I3KwOGjU8RdOdI7IIr+WfCD
PT+yT78AsmKZMjB7BAVGSqeu/VgrifPYdYutrD47u/adV4YoIS9Rj/QIkPVb
jlIDGzMpndyEOfeYbQL9Li45h9dj6iOXS/mxK8pIypEBkZx/Ac320JFL7G8E
LjZ6ZBJZDP1iImISpYPbUKnXKJzssmvfWWq2fS1fK/rPgrsSp8wh35Ej0xZx
7Zm5RcozsVJfWRve3oObL8qp7hfYZ+dGePKPD/1JFjdZIYP6jeRMFawdOTJ6
pBd9rYcOX5KcvNXso2r0yCnURwtX7eY8DnKkV7By2BFy3+hxRo/ErEnMf0SO
0NPI7rODnqd4H4Ecwdfa4BXokdM1R5fZ3wheZvpalVHhVYXeHBZp9Ej0d1q5
7iD5Dr5WaM09+vjQh32w/KIkps61+uy05fsI5Ai6dgVHpsqeg5+wdhfPVJv2
Ro9EzeTGrUckZtx09mvFs1m0ej/5HbNeWB85aJjrOUJegqhHKkdSjzx3x+uR
tWqdlmefXSI//3mRPPjgEbKZiUN3fDz8MNZ5WP/coFwVRY2ugrfWVNNYrRwJ
Tt6oHDnM4Ugnqkw4HOmEE05Ux7hZPbIyN9q8iBkglf9uB/796UVTH1l6uEze
fBP99k/qfvOINcvtVtdAHSFPPqQc+SI4Mi1b9+VXuP8fGWbrkWNl36HP6DdF
nRjmfsC7uGXXKWWaU6xrAzsM8g1l/Rz2y5Mr6ZHoVXn89FXObQCLYa8Pz2bZ
sc/ZuxOMZPtawRmoJ6SvtedgGTBkJOctoLZsjNWLtHW7HpxdD04Bu2Cv/uzz
LyunLpXy41dYkzdUmaL+C6/qMeOlVDljWdFOzp/o0t2TfWi37jxJ7yOYw+iR
kZxzAQa2fa29PfxZv3nkxBfKqwtYQ9m5i4dyWZ6u/Qp7u9h6JDgSnFEMT250
iqVH+rNXrNFSMzi7/t332nMWyCHllPikXHIk+rWmZxXK0VNfsSYPdXemPjJH
Dh//gn1pgodPcPla4bmEhmf0yKHUI4vXHKR+F2vXR7p5MUelyqGo58Qx4WtN
VY7E2lH/Cj2yvrI2OPJA2UXN0Q4ZN3yGzKk3X/50759viCf/cP+3crDXaTl+
6GtqndA94anFDMbDxz9nbecwS4+ElxU5Ql8azOOArxXPCLzM6LmE2Rm47nbt
eyiv7VKWu2D5Wn2pR2ZY7yOQI78gM/cDzx5yhB5QQ0eMc3EkcoS+Q+izZOuR
yBm8tq5+rcqR8GGDTRNSK+oj8ZyCi6Fro3ePXR+J9xHwduN9R+t2bjLYN4w+
3c07jlGPbNGyExkYfYP2l33KuR+2HgnWPnryS81LnnIk+uzUkxo1plGPvFM5
0miR5XLffackICBDPDxylE3Q+3S//k46UIkn79ww6yzX32/gx2hqdBW8tbaa
xhrlSHDyJocjnahS4XCkE044UR3jZjjS1hjJiJV48cKV77OjS5/Uf39q1UfC
1/rGG+iTeEL3c4e5r7s9e8Wj8uCDpfS1TpmerZzxpeQqP40InSxNm7Vg3dmB
8ouyYo3pb4pZfpgDsa3krOzcc5oz/MA4g3zNjI5y5Qf0Y0X9HHqkYEb8qXPf
cB6f0SMHyCRlKOyryZGV9Ejs89FzJTQyWdx7DBKvwSNd+3/TZydI2rR3p38W
PGTrkc/Xf5XzRY7oMVGTFzRsHPUq8Gi5cgZmOIYo83V1608PKvQq6ITQxciR
fhHc/4O7wBmmPtJPOWitHFO+g3/W6JEekpQ6Tw4rW2aTI40eCV7dV/oZcwQt
FRzZ2zOAnLFDc4QesPS1vt9Olq/cS9Y2emSgnifQsPaZq5xXD54BT6F+8tip
r6m1ufrsKEfCU4u+oxHR8dLOLUTqNAyVlesOUQNDjSH0yM7d+rtyBM+mj8WR
qFHF2lH3GQCOVNZGL1KwFHKE2r8mb7wrAX0i5XKf38rf7r8xv+tff/w32dm5
XAK8Y/ReDiDfHz35FZ8jsBg5cvQU2a85AmvbeiS8sfAyI0cx1CMHUrtEj97S
o5ckLsXqs9OomczMKpJjp79WjqzQI3G9yBHmkQytpEciR+uVI0MtPRJ9glHP
u/fQx675MT37eHNWKXiXvlZr7ge8xeBV3JMQPWazd4weefDwJc3RTr4zaGP5
WreXnGG/15gxth7Zgz1coWeil2w/r0BeI56j47r2ZOqRY6VuvTrKkVPJkbVr
l/Ln8E6L2rXx+6ZM13lSfH1nSu/eOconh5XL9unvpAPU+u70MOss199vNkdu
rMRb66pprLU4ebM89cwIhyOdqDLhcKQTTjhRHeOm9MhKrGjzY+W/X7hej7x0
jXrkpS/+YHytTdEn8Th1AczVRv/EWxmPPorarCPy4AOH5MUXh0hqmnLkUXDk
anLk27qHhl4I71+xxZGNmrxDzsEeGvt/lx7pE8o+M9AEjR4ZLH36+cnsnBVy
8uw3Mi19scvXCj0SzEdf64iKPjsl+z+iHhlKPXIQ9UgwEzhy9ASbI3vIwqVg
pMsV9ZH1XyFHgk0zc4vJkS81aEQuAkdSjxw5SbooX6G+DT1c0FMTHlR3S49c
seYAfaSYC2Hrkeh5Cp0wZVqe+AZESkflyMSpeVx79tzV1NpsX6thpL1kJKNH
giONZuvSI5UjMS8R3IZ+rbge1OplZFkcyfpIW4+cQ4Y1vtYKPRL1nmDriBhL
j2wYxl41ew4iR2nG1+rmRa0Nutr39Ehleawdmq3RI1+RKL2npUeuKLvtJHc1
eb052Wf3vo9kd+Fp2dW0VP7znhubF/K7h/4gWa8tlGnJS8iR0LWHuvRIw5FF
lmZr10duUo6EVxeaHq4bmh6YFkwfryzdG3okODK7mMyYNitfOTJaXlKOhEYN
tkQfVfQVdnM39ZHgSMxwHKXX093iSMwCQU8eo0cGUI+EDxscmZgylz7VZpYe
iRzNzCq0+uxUcCSeI7yHIEfq16MXMLzd0WOnsz6yTTt3vRel/HlBv1ZwJPRI
9BfGOlkfSY78qdS4b7r+DJ7Tn+tD/Dm808L8vimT++474eLIH/3I5kijSd7p
YdZZpn+Cr2Ko0VXw1vpqGuuU98GSW+TpZ0YqR55xONKJKhEORzrhhBPVMW6J
r/U6DfLCpev+bsVnGp9euCqff/WtlOw9IM88k6/7thP0vpn93a3WHMqpSz7w
wEHqkeDI0qNf6P4f9ZFx9Pmhz86BwxfZ74a+1kbG17q95Kzla4Ue2V8G+oay
Fyf4bnJilnh6DSUDzNb9/4kz12Qq+uwEWBwJz+aJL9hDxuVrDU9kv1Xja01k
jSA4EnVu6AEba/lawZHU2lhvllfha50FPRJam6mPNL7WBHIk/IjQDjH3A8wH
PRI9YOGvhB7pTY7cT79p7AS7X6s/daQj9CPOZ09Xw5HzuXbUkLr67FCP/FSK
VlXiSP3+LTtOyvbdJ8mRLcmRbWX5qj1kpMmJubweeCyhtUGvwsxCw5Gao+Q5
ZLH5Sza46iOhR6K/EOZNhMPX2i2YvlbMqdxz4DxrVft5Go5cmL+Z9wLe0CFW
v1b0kMHaM9lnJ9bokcqRqDFEjqDf4j1BP69g1nsyR6OniHeXEbL5tRL5a40b
0ye/q/UfcjnqD5Kbs4Y1hm2t+kjkiDWklfXI7cddzxGu29YjwfTQbHv39WGP
YHAkmB56oV8Q9MjG1BaPgLWXbORzCq3b9s+u3VRaSY+MUa4sN7o2nyN/cuQi
fY7I2lOMr7XZe21kmt4D5GhW9nLja33H+FrBhsv0+cb7DqwdvtZtJWf4PiJG
GRh6ZFvokesOyYGyC6yPpK91QIjk2Lr21Dy+46hT9wm5794U/Rk8J7VqHeLP
4Z0WtWrh902p3HvvCfHzmyl9+lRtjrzrrhhqdHfdtc6K9dU01snddxuOfOZp
o0ee/djhSCfu/HA40gknnKiOcdN65KVK3HjpB+IH9Mgvrn4nO3bv173cEo3j
9L7Vrl12G/aKZeTJ++8/oBw5mPWRpUc+Z+0f9EjMeg+mr/WCFCv/UI9s/DZZ
cNvuM6aujXpkf+qR6Gdj6iOzqEei1+YsiyOhR/oERrGnJhgKdW3zFm6o8LWG
J5IXV284+D09cs2GMvZHiR2fZvXZ6aGMtIUshrmOmNGHfq3QI+nZzCmm5mP6
7CSyDhPrGsY+O56mt2qJ4UiXr1UZsXitqY8cMx56JBjYX/f/6+hxBK+CI+Fr
xTnh3c2eu1JClE1ZHxkeRw0MtX/hleojN+88wRyNcXFkOylcuVcZ6aLEJdp6
ZKBkQGsDR2Ys5YwO29d6xPb+Uo/0oh6JXq/ssxMVb/TIxmHsIVNy4BzvRV/P
Cj3S9oYOsX2taYu5drA2ObL+qxIRm0pmA0eCuxpDj/Qayv6khrVTDIsFRcv6
+aXyVc9v5a/33BhPfvv4f0h+q9XSqX1f4zcFR66s4Mh+lh65zXqOwJFgTvQi
AtNjhibmc2DuBzRbcHVaRj65EL5W3CvkCJot7jn0SHAvdEfM48D1oO8v1k6O
3H+edZj9KumR8P5i7scQ9mttbdXZfs5+rdQjLV8rfgaQo5Gufq1hnIeDHH2P
I9cfYg8ozAzFewJPL+XIvLVk4CSLI+vWe1Luu2+K/uyd1Z/Bg9bP9p0V5ncD
OPK4+PpmKEdmK5uUK5ftlQcfNCx5p4dZZ6k88MBay9e6uRJvbaimsV45Enrr
VkuPPOfokU5UiXA40gknnKiOcVMc+U+Z8dr3/37pGv80HPm16bNTXqbMtlT3
QEe5n6tVq/Q27BVLqXMajhwiKS6OXCXDwZHNDUdiX1y0uoT76UaNKjhy266T
pj5SOXCQdyj7bIJd0I/VY2AQ9ciZOabPDmrzKuuR5eRIM/eva/f+1HnQHwX9
WqGLoXfngMEjqb2h/07suO/rkWAf9L/EDMPnnnuZtYXwKKI/CnoDuTjy6BVZ
WrjdzBdxM+eBjxI9W8NiwJFDqEcWr9lPVoBehbkfvaBH6v4fbEo9UtfO+sgp
86hhZc9bSa+sXR8JDaxQc2T32UG/VtT+IUeYWWJ8re1ZH4n6ucmJOZX0SKO1
gZFsXys5Us/NmRbDx7t8rSWWZhtBPRJ9dkJlxdpDykjnJGa8mftBjrRYG3qk
t0uPVI5Urp5lzf2w9UisB71IR0VZHNk/WHbuO895HOExZnYGZrZAk8YclNTQ
PNlcf5f85e6/3hBPfvXgVSnssFn27f1Mr3+3hEdZeqTy6sbt6EV00sWRbcCR
6LOj9wKzUXr39aUemZFZRGas0CObsK8QOB+sDQ3arfsAXe8UK0elvP9udn0k
/NHQtVFD6mn6tTJHR41mO9gvjPWRdp+djCwzhxTzI1FDavr+bpeR4YmGI/1C
9d4qR247Sl/rhy078dkE06PX7Fj2aw2gHol+Q9S1U+dKIPRIiyNr1z4rNWse
JLPdaVGzZhnfX91zzzHx8angyIce2qu/k/Ypo+2/48Oss1R/v6219MitlXhr
YzWNDcqR8Lduk2eeCXXqI52oMuFwpBNOOFEd41bURxputNjx0rV//Ow6PfLK
V9/K3gMH5Ve/WqL7tqP0vpkovaWBGWvgyRo19lt6ZJYcOmwYaXjYZJevFT1k
4EesrEdu1T00+p66fK0+ypEF26m12Xpkb0uPhNY2LX0R5zTCE4v6SezV5y5a
J0NHjrPqI83sjNXrjB7pZumRq5SZUM9IHcniyPn5m8k+1CPBkc+/Qr5Abeas
nEIJHlbhay1Vjsxfvp3zJzpb8yOhf2GuI3yiqI8cYvVrBSONUc5w6ZHz1lCb
Srb0yI7o15o6jxqWmR85UVq2hh4Zb2ajQI+MsjkykJ7NbbtOcNZEq7bdOPej
YOUeFyP1tfRI9HQ5chKezSXkSFw7fK3UbBet5+wVsLrdrxU9bMOj46V9V6NH
Fq89KCX7zipHVuiR7GkL3TMJemSYmfsxw+rXml0ogUONHglGwnryl2+rpEcG
UY/EbBTokd17DSKLFSpH4p0C5pjATzy0+2g5994l+fs9P/Az8gPx53p/kbLA
cxIZmerytW7adow5wvuI7j0GUI/ML9pJpgdr91KOfK2x0SPB9PD++lt6JHy8
yNF8ZW1wJDRb9mu1NNvQiCQyOda+dmOZ5s5otv08jK91odXTlpqtr/G1Tk1f
Qk19ZuZyvkN5+x0zPxI/A2Rt6JGWr3XrrlNk7egx01x65Eq9F/tKP5FxkzKM
HjnA6JFG154rQSHjpK7la61d+4z+DB645T/Xt+Z3QylrN++995j4+qYrR2ZV
WY40euRoZaxtylg2b22qprFRrxF9abfL0z8Jox55/tOqyJElTvwfC4cjnXDC
ieoYN8eR167TIq/9sB5ZKaBHfnn1W9m+C96sRfLII0epWdyuOd3YM9533z6X
r/Vg+WV6NqFHvtWsJffSew99Sh0pQvfTDRu/RW8q9tBbrf0/9Uhw5HLDkZMS
MpVFgslis9Bn89RX1CMxp7Eb+rUmZHOvPnfhOnoHzVzHRLIL9chIqz6SeuQh
2aUcCT2yr82RSza55rr38zK+VnBkmTWvIShkrLzUoLHyaCJr//JdeqQHtUNw
5CZwpDJfj15DxNsvUopX7SMjQePqP8DiSN3/g01xHh9Lj0yYkkcNK5O+1gnS
ok1XGREeJyUHzYxNsF6bdm7ss4P5gsgReve0amP1a11Rooz0GVmaeqRHAHu6
QK+alrGkwteaNIcMm7dwvaVH9qdOixkoqzYcNL7WbkOlDud+HNDPz5Lp0f+1
SzcvMxuRszNylE3D2C8Gcz+w9lngyJDRLj0SzLYEjKQc2eh1Ux+5Y89ZzkYk
a1PTi2KPIPTKgU8XmiXuB2pIT6/7Wo6/eV7+dveN+V2v/fi3kvTKdOnff5ie
4yh7noLv3HoajoQeCaYHA/fs4ysN6WstpN6MOaTwqTZ4uYk+E2kmR4s30C/q
5j6AvlbORtEcjeJzZNaOOlvkyOiR/tKjtw/7vB6y+vkMgR75rtEj8WxmZBYw
77YeidpOvI/AO4M2lq8V/XjB2kaPBEe6s1Z1n/68jJ00k7WqHgMw92MNGRjv
IAIx96Pek3LvPcmczfjII/tvy8/2zf9uOETP7T33HLU4Enokag33KJcZb+ud
Hmadh+T++zELY7Ty1Xay1t13IzZX09ik9wx9aXfIM8+EVWE98t/PNU44HOmE
E044cbNx83rk9eyIP6+6uPEz/ftn/PdV6pGfXPxKLn/xe91Ho4fqEt0DHaZm
cbvmq2HPeO+9e8mRKdOzlBMucnbG8NBJ0vTtD1mbt+fAJ+znST0Svlb3QexF
Si3G5WsdJYsLtpHFJsRnkkUws2Gmtf9PTVtIPbKru+nXivmP8PuZ+khP1zwO
9IWlHmn5WlfpvtyeL2jrkWAkaD7Ylxs9sgH7o4AJMrKWs1YOnIF+PeDNxcu2
Go7s5sH6NnAL5kIYPXIwfa3okcO+sMoZZmaJP/f/4OJEzM4AR3bpx3Oi5wp6
nkLjpB6pbAq+Y89TeDatPjuYjbhRcwSvLPyvzd9vLwXFJcoZnyhLZymHBbj6
tYKBp6KGFL5W5XQwFLSyOQvWUmuDZouZItBmV6zZZ3FksNRtHCpFq/fLDqtX
DY5Hjlyykf5K9IWlr5V65GLmA7V/lfvsQGtbvGwL8964SXO+A0ANKbyg8Om6
Wyy2fOUe1meCtfE1qO+E95c9jzQvUX2TZMvPdypP/v2GePLLml/LsYiLsnnL
MaNHWr7W/OU7OccErN2Lvta3JD2ziAyMOlt/cKQ19wO+5bkL1hk9srsX9VO8
d1ixdj99rfBHw5OL9xE7Skx/YTC+ex8farb7yas55MJ3LD0SOZoxe5keE3pk
C3Ik1oMcgSNbW3M/4Ftev7mceuQH4Ej0a4U2jDmVE40e6WHNj4TfG/18AkLG
ss/O3Xc8Rx60OPKI+PjYemSpclmJ/k4yLHmnh1nnQalRY7XyY6xeyw6y1j33
ILZU09isv8/Rl3an/OQn4ezX6uiRTlSFcDjSCSecqI5x03rkP7BjBTeav9s8
af7bJxe/lkuf/45zP15/PV/3BOXkyNsx+7uCI/coRw6ir3XPgU9lZnahjKCv
tR09orv3fyRLlBEjYlJ1T298rfBsgjOidA/dzc302Vm0bBu1oPFxs+lZRH1k
RnYRPaioMQSLoc4PHAl9J3vuKtZHmrrFBNYSFqwwcwxxDq8hIznXkb1MwEg2
Ry7ZxPOgP0o/iyPRHwXHTJu1VPf/YzlTEsdEb5f5izcYX2tXT/bzgZeSumd0
Emdhwte6fGWJizNsXytme6B/TnxKrumz0xl65Dx+Bj4Gm7Zo1VXZwjAwchSm
rAffI1hlw5ajsk55FWzaqk1X5nNZ0W7Zte8sWbsv6yMDlJEK2eNzirI2fa09
BpEjof1lz1tFnunq5sVjQ0uFphkeZXyt9ZqEyXJl4C07TL8XsCl8rWBt1AOC
xTj34x2jR4JhMYMxcOgYqV//FXIkesAuUO4cRV/rO+KpjAi9GTkCu9LXquxW
sGI3Z72A3zBvBRwJ7y/Wac8XAe9mxxTLtTbfyd/vujGe/OPTf5aCbhulu7uZ
+4E6W+RoorJ2L32G0CM4XfO9nzlaYOZHvmw4EnlDXyjUMnZ1N/WRzNEq3ZdE
JoibsinqKVG3uJm9VaezBxL0SOjaJQdMjlDvCD1yakY+72/azHwZOmIcNXnk
CO8J0M/H5Wv1C6PevHr9QfZz/bBFJ/paUWfLHHFOjfG1giMN0+cqv4+TJ+s8
LvfcnaQ/e6f0Z3DfbXlHdPO/Gw7y987ddx/+nh754IN7lM+Mt/VOD7POQ8qR
mKc4Rq9lp/LkFv0TsbWahmHJH/1olzzzTCT1SIcjnagK4XCkE044UR3j5jjy
qktztPmxMjd+5vKzXnV9Zvrs/F5KD5dKo0ZLlPHKqFncjl77OCb2jPfcYzgy
ZXq27Nx7XtJnF8jw0DhppvtqePugTWGORKRy5GvQI3sOkg1bj8qqdQckWvfQ
YIfBypGY64geNuMmz7Z8rUaPhJbDGkNypJdMTsomB2bmrrB8rZ70IGKfj9kh
oREVvtbiNfuM5jN2mu7/A6V1O3eZt2gjz4N9ue1rnZaez76u8IZCj6z/Avrs
JHD/P2/hOjJfp26eeuwEWb/lsDXrMYlaG3ytmDWBWYAxypGeypG9+vpLlu7/
UVOHnjc+ARFGj5ySJ7v0s/TMAs6P/LB1V2qp25S7FuZvosbZpl036eMRIGs3
lSuLHaQnF/WR8LXmF+4kL4O1ja81kBoqdL6UaQs4o6Ob1WcHuha0Yfpau/en
ZxZzJtA3NNzWI5uEK9/t0ftRbjFSoHTWr0WOwMVgMcORLWXK9EXM0XTNEesj
X3iVvZOgccJjbPTIZqZuURmpePUe5ogsFhjN+Yk4P1jbY0AQfZtgJPAqvKE+
Fkei/xHu7+JxG6Ws/okb5smLta7I5EapsnjZDvbemRCXaTiy8VuSkbmc80VT
ps2nHvkSOTKNDJw1Z6VLs41Q5sNzxFmP9LWa+kjw3YYt5by/8LW69/Ima4P/
kSPqkc3b6HO0hH2doHuGjIQe2ZI52qE/A8jRqPB4epQH+4brc3SEz5FLj1QG
BtNvVqZHnS05cmAIa2l3k+lz+GxCj7zn7uQ7nCMPXMeRRo986KESZbM9ypN7
7/gw6zyoPGnrkbvIWvfcg9hWTWOr/n/GFr1Xu+UnP4l09Egnqkw4HOmEE05U
x7gZjvzMxZCVmdH67FLF5/CzsseOfv7xha/l4ue/k0PlZdKwYb7+fi3lXvN2
9NrHMbFfvPvuEnnhxcG6R8/SPfBpSZu51MWR0MI2bz9BLoEu81qjZtTL1m4s
l6JV+3QPrRzpNkAG+YTJgiVbZNO24zKeM9jBYn66/y/Uvfo55a955Miu3Y0e
CTaFnxN79c7dTB/VdbovX7R0K/+OfjzgSDDSynWHlJFsjuwpcxasl416nsnW
7Ixnn3tFpipHovcPfImolXu+fkPTm3X3GdY5Yu5Hp67mPKiVAzeCy7r39CZH
LlW+W7/lKDkDHNWrb4DyySply9P0PfoEREpHS4+EVge9KmTkJPmwFeojE2Tj
1mOaow08Jnqzok4RMyDgl4WvtaWyR/P32svigh1k8PFxs9gTB1+XPns553GC
tYf4Rei1D1LWnsMcYbakYW0vekxRT7hw6TaJiI6Tdl2DqUfmF+5m7x3mSPm1
s34tcoR7MUF5dYhfuPJQa0mZvlCv5xRrVQOGjqFmi3uKOZc5eWvYZ6dR4+as
6QMjIUfgYrce6NcaQ51w3eYjplcN6iM9g5SRVjPHmNHhrWvv3G2AJKXOV1Y+
w+cIvmjv5sPlyEtnlCd/4GfpB+J3P/lOjsRekIm69p7os6PPHHKE/qjIEeZ+
vNTgdV3HDOW7s+zlRD3SzYuaOfK7eJnpG4RnFV+P2k6To+nMkXsvX+XCDeTl
ifGZ5MJmypGYsYn7C20Y/G7rkZv0ZwC6J/TIlhZHYiZNgeYIHPl+iy7Spn1P
WbaiRNZtOsx73teqj8zMXckZIZMSsy098gn9mUtSXjvJvjX/7jmL/+wdU82a
+3Sd5eTI3r3BkYf0d8Zuyy9658f994N5D0iNGqv0OsYoX+3WP7fpn4jt1TS2
yX33bdV7VSLP/DTqe3rkWYcjnbiDw+FIJ5xwojrGzftaKzyrhhevVnDjxWvK
jdf4//Of6N8/QS/XK1/J5S9/L0dOHJTXX18kd911SPd1e+jTeuihW9+H4uGH
9+s5SuTlV/orZ8zSvfpRmTE7X0aETZL3PvhAWSlW99BHlBHXKsekSuPXX1fG
6q978lJZtW6nRIxOEzf3vsoZIyRv0Sbdg5fJ2ImZun/2V9YYLDMyC2T3/hPK
FnM5p9G9Vz9ljkz9uuOSOWeZMt9E/ayHhEXFKbsckkXLNsnI8CTp0dtT9+oh
5Lu1GzG7EnznKx06dyMXbt1ZKpMScsVzgJ8y8AvUj7bvPkpGCho2Rl56+UX2
NN22+4TMXbBKmWCS8lkv/SyOOmrxmm0yMiJVevbxEv/gUHLHpu0HlQkwPzJA
Y5DMzlkhO/cckQnxueIfFMbvh064Q8+DfizDQico13ZUtpik7FImeYvXSWhE
irRt35nrKl67X1au3cljtmnfUVq0akUG3KJrHzcpSzy8fPXrvGXGrALZtfc4
5wui3wuuPS4pW9d+XFkWtYwTlHf7ag4S2Xc0v3AjNdtO7n5Sr3G4LClUvtu0
lzny1Bx17+mhzLPW3ItJ2crAo+Td9z+klrd99xHN0RLlyNHKYvUlemyKcuRR
5gh5f+PNN2TAkEBqqUWrt+m1TeF6AkMi6FvevENzNDaD19d/kJ/Mzl2hLHeU
s1zAqz1692IN6c69x/SeLNUcjec9i4hJkj1zTsqFJl/K32+AJRFfPHVNkt6f
rmt6U5/JAj3mUWqdfkFR8uprr8iYidNkx54TyrKF7IOKHEXFJtNvvaxokz7D
SeLOtUfqv3fpNe3R/z5D8+6jjDdA5sxfpzku473w8dccfdBS+XERc5QybZGE
DB8r77z7vn5Pil73Ycmdv0qPifrIzvq8j6LWjBxFxEyXFm3aSqcu3Tj7csuO
A8qrGby/yOWsnGJdp+YoAXpkrNSt92P9mUvSn72T1M0eeuiAFf/+mYv4fWD+
vo8Mhh6tfn7KxH2z6GutUcPwGTyjd3qYtR5UroIeOVYZC/vV7Yx7791RTWO7
Xu82vVd75Cc/iZZT6LOj//9yppIeedYKhyOduJPC4UgnnHCiOsbN65EVmiP0
xk8vG3ZEXP7yqnx57ar8/o/QIFEbeVXKjlzT/9//vWzcckZ+8YtC3ReUsueg
ecd+O3xf+7n3wMzq+JR5kpt3QuKTl0jw8CRlSy/xDUiR5SvLJTVtg4yfnCC/
/nVHZZIQ9nqZnn5AeSde2nQIkS5uk8lRmbknlbWmSp9+kdK6bZQyUrEy6BkZ
NzlHAofGyActR0jshIWyct0xGTdxhTJJlLzRNFr31zNk7sKDkp65UUaPmywf
tAhWvhzLWfEzsw7pMROkY5dQadrMh/15suYc1z3/DGXacHmyznvKLktlYf4J
SZ46j37Tek+1UlZKU148JolT1igLjJX3PwzR/f9MzudInLJPJsZPkHYdQ6Vn
33hlM5wHWmq8smW0vP/BJJmZXaAseUqmpiufeaFWzl9zNF/mLTwuaTPnS/Cw
SdK4iZfmKk2WFBzSz9ZJ7PgEafbuQGnf0fhNp2fs13Mly9vvDJL6L3goi22W
WdnKjKlTlbnCpU27GGWkIj2m0T1Ry/dhy1HKNoukePUJXU+Rckqs5i1EWWkW
+8UkTtktE+JipVmLMfJM0zDlqK26zoPKconSvtNIeV9zl5O3mjlKnjZVeW+c
vNjAXXO0SOYtOiGpM+Zqvicoz7SQkJEZsqz4sKRMX6X3JV5+9euumufR7AGb
PHWP5miirnGk9PZI0mvcotdzXPk9UdceoXwYJbPnrNFrOk0N2jcwSl5/M5ba
c9acU5KRmaf3YLJ+Nkh5NF0W5JdK+uzVku6nnPlYqfLkjfldj9f4WFYH7JU5
eaf0GrL0mOPl6afbS1hUtiwtPKGcXyTh0WP0mRkmISMyqV8npu7UHI5T5hsq
/fpPluUrduv9PSwTE+Klq1uo5mg0/bCZOSf0OZqmXDlWXnnNXaZMX6x8eUIZ
OFeGjojXn4GeMmxUul5juX62UqLHxCtbDtJnZKLmbZ8yeYk+m4nS+I0B+iz4
05c9ZfoxSUiBFhohnbrGSuacVZK3EB7jdF17vNSq9VPdN8Upsx3Rn78d7IEK
XfLfzZDGo2AY8r77Dsgzz2wn3w4enCHdu+fqekvkiSe2sC+X0fvu7KhRo4Sz
cW098r779rh46777dlbT2KHXu105cq/89Kcx3/O1Xs+PP8ST/x1f3pb/ORzp
hMORTjjhRDWOm+XIT62Al/VTsOSlq3Lt91/Lb/7wtRw/9Y2s2/g7GRn6R9l3
6Bv5i3wpx09fk6lpf5TB3n+Wp+rt0z3BJd0LYQZaiYslb20/w330QdWpGyqe
A8qlXYffiF/gFmnRaq80bNJVmbFY3mn+W6n/4gXdP5+RHz+mTPJSnLRqe1V+
/vPf6H8vk1/+aoO4uc+Qzl0/k5//4k/6dYfk2edKlTOS9ZjH5bnn/yQvvXxS
9+kn9L9Nl0HeO+S9D76Vn/7skjRrflB+9vN1ut/eLt26f6Vfc0H346f062fq
sZfKBx9+Ib9+9hv9vsPKYculUZORyn5X9Jx/UC4sk2ef3ydPPe2uzHpCGrz8
rTLLCWnY6Kxej7eucZU0ffu3upZL0vStE/Lyq3niMaBAWrb+Wv/773QNB+VX
z26UPh4ZygVXdD1/Ulbcp19/UL+2SIb4npJXX/udcl2pXnOJvPHmZOXD0/Jc
/W913cf1s1PKGYHyYatN0uT13+j3fKbnOS8vvDRJGjaeqlxzVX7xq2v651Hl
2kV6HUOlc7fLer3f6rlL9d8HlNmSpXffk3rO/9DrPi4NXjmu1zVFBgwu0bV/
Jz/7xWfy5lvH5dWGuTJwSIF06PRb+clPfyPN390rT/xkk9R5LVo8vD6RBg2u
6tqPyvP18+WNt6ZrPi7KL35pcvTKa/vk+Rc8lalOaw6/1a/D8U4rf3vp2jbJ
62/8Rq/lU2n2zjnlhDF6bTM1R9fk6We+4f199rk10sdztnRz/1zq1MH93a9r
36//TtBzn9cc/Flea3RUr79Mz7NM1/7/2DsP8KqKrQ0HRbyKei2ov2K7CtKr
0muoISEhCekkIQFSIQnpvXdCIPQO9n4t16siKCBKrxYs9KJ07L3c9a9vzeyT
k5BAgIQSN8+zHuCQs2f2mjmHefe3ylbq3uNrHvsj3jcf8r9l81qs5zG/5vXb
w2u0m7k2mXzbvkCrb/u1xvrkjmv/otgW+3hNPmUGDpY9067DD7wP91KXbp/w
teeS/5hX+d7hoxO8bzfRQ81f4DlOo5EeJ3jP/MSMv5b/bTXP9Rn+jPHc23/N
PtjKfn+P5xRPQ4bt5Pv9nnr3/ZDX43N+bSz7YCV14Lm377iHfbeb35PN11nM
fjjOa3mc98dH7MtF/LOpzKhH6OZbfuR7x976gFlyEu+v3fQwfwYe6bKZ57ub
WW0AXdMwnT/bx5hpDvDn8COpB3P99e9L/qF6zqPiDy62qXHX8rw20EMPLScn
p2dp/PhpFBAwkwYPfpxuu83gyA8ue7v22vf59/Xs59f4nJol9cRQsxWs1bDh
e/XUcH+KI++5J5U+ryKu9Vz1yC9MjjTN5EjTTDPNtPOyC+HIfVZ65D7p6XGC
Dh8/TtGxPzEH/M7/3//F/9+TWODYX2jRY9/TvIXfU0bWz3TTTX/wmf0H/n79
StcdfF/n+9R2/tBauqrBCvrXQxHMKNv5tb+YsX6Rc3C79rNo6LB36ZZbfrPM
s0GDX/gcvs/yd8MebHaY7+fXCq+BQ+6449sKr/3z5p/4PH+swmvXXfcbNb3n
a742WY1DPM43/Of/Wf3s/5jHdvO58I8K77/pnwfp1lu/q/DaNY1O8fiHK7zW
6No/mDu/qnRNzP0oXXd9xbk3vecUNW78W4Wfve22X3j+P1T4uX/84xjP6Ugl
f/zI799f6bX/Me/uYx/9XuH1e+49Trfe9n2F12699Qfmx+OVxvmDeRzj/FU+
p0Yf0w2tcuiqRhX9dtfd3/G++a3C+//5z31sP1Z47dp/HOefPVrhtQYNfmKe
Pnja+j7E63vttRXnfu99J+m2JhX9fvsd39Ett/7E1yn3W+PGvJfv/KbSNb/j
9Tkgf+7E9lYNWRK2jm34td9R06YVfXTd9b8xNx6psGbwR7PmR3nPVPRH03tP
0T+uq7iPbr7lJ7rhhoo++sc/jjCznqg09x943Q5Veu1Pfm3/aXsTnHnzLRX3
jE0D7PXDld7/F1111ffMAYekJqrxrOfi16ZRvzdqtI7uvPM98vdfRNnZGZSV
lUmuro+xf1aLrqdiWy+95lgzPfI19m0hz3utsJbS7VbXU3uP73cV76d1dO+9
aZIfuZs5cqcR17qnIkvWxIyfr5NfJkeaZnKkaaaZVo+tNuJaRZM8dEIMLDl3
/g8UG/8zDRr8Oz344F98dvsfBYX8QjNm/0hTp/9Aufk/0403/Y/PPr/z9+sR
OdPh2bo6F9WeNWr0vuLIq96l++6bSI7On/BrxBzwB9kO3EotWi2hYQ7vMxP9
LufxW2/9lW6+eRf17beROnY+pRjhBubOOw5Ql27badCQvfJaw2vAE0eZe3aQ
s+sOZjp1nr/lVrDD5zTC9UN68KFf5LXGjX/n1z6jPv128nt+47mQ2B137qXO
XT6jtu0Vf1x//Z88j4PU6ZGt1H/AAcs4d/7fEbrrrg/JiefesCGPI+/9lsfa
wfezmef2m4xz882/8M/uYi7eSm3antLX/B+/to/n/hENsVPXxNhNbj9Crdt+
zK+Xc8oNN35N997/KfUfuE98hGve+X/fMEt9QQ4jttDttysf3dbkZ7mm7cCN
PI6a+403/UVNmuylDp02MZ8f0JyLeR6mlq0+oeEjPrUwz21NoKUpH91992/6
/b/SnXftosF2H/KcvlZMjPc3fZfu6ppKD2hf2mCNbvuKHm7xGXXvqdj2mmvA
xEeZ3T8me8cd8nO4xzv/72v+2U/YR1uYc/5QY9/2M/vtcxo0dCNfQ/H/DTf8
yT+7l3r2+pD69lfsBD/ffsdX1LL1Dhrh8jmvoZr7zbd8I+P06XdQxsBr1133
E7//C+rXfxdfX/no9tt/lGsOGLyJ94jiUDw3cWhylNb+89sa8+Tnt/5Izjeo
ZzE33/wz8/xOsrPfTu06qGted91fshbden7M63vI4uMmtx/itfmEOj96wvLa
zTef4vfzPG33W3yE5yB33f05OThtkX3eQPbGT3zve3gfbRBNXD3H+JPXbTd1
67GJTfHhtddifb+ktu0+4ffvlHXAde+482ue14f8M9v57z/r/YU9+r181hs2
3KWfGxnPey5+30VwbMOG63j/raTAwAXMkZnCkR4ei+nGG1eJrofvosvdrrkG
35mI23+VoEfiexSs1ajRavnuq5+2mvfPe7yn1tM996UrPXLvSfpi91H+vVxj
3GUw5R5TjzTt8jCTI00zzbT6aLWWH2kV13rqe8S1HqOT356gD3d8Te++9428
/tNveGZ8kh576meKiv6e2WMtf78e5LPPev2suXbPHOpMtYbPsMvp7ntiaVzI
NhrpcZTGhS7nc/JGZhYHPpe/TKPHnGCu2UwePh/z2WQcdemayz97jP/tCxo1
ei11fmQJuYwspjFBe/i8/hX5+K/i8/QyZrtE/rlP+Fon+Sy9mmwHrWdGiefr
rSK/0SeZizaTk8tqat1mDrl7LyOvUcfI02cD9e73KXXvlURDhs3n9x/h63xG
bp4bqFffefRotwgKCj1EDo4HyC/gfera4w3mpP7850+YWY+Qp/f7ZD98K79m
T8OdXicfv+PCAS5uG6lH7zz++3M8/pfUp+8u8vZbTY90WcJjTqKgsIPMwYfJ
g+fR+dGl1LPPHB5nL7/3AM/rA2bAFdRvwDh+76cyjo/vaho4eDPzmg85uS6j
Uf7H2HcbydntY+rafSK/fwqNDT7Gc/mU/AM3M3OVMJePk7kPsTtIfoGr+efe
4HtLpsCgHWQ3DO9fzYy8jobax/I4a/heTvLPbuRrbKCevbPJf+yzFDr+GPvl
C/LwWkHN2rxEt3dOIf8x+2mk+6c0bPiH9GjXWdSrTyqv4Zd8//t5Xu/zNd+m
9h1H8r3vYH8f5vt+n6+7iXl1MP99Gbl7HeP13chr8BHd/0Ag+3kmr+UxGjDo
c37PWt4Hc9lHZfzaQZ7HV+Tt+w517PwGuXokUHD4F+TqdoJc3d/ldXuPOb+E
7/tjchxxhHx5fTo/up2v58/39gF5+Rwlz1Eb+N92ULfuIdS772wKGHtMngF4
+25h/pxOXbtFU87wY7Tp9p9rzJOf3vwDJfbAs4h03gcv05jg47zndvCYGH8m
+2ASRUYfYY4+xPeKub/C6zOV1+Igj72X9/UG3ldL+XVvvt9d5DTiK37ParJz
2ML7w43nu4Lv7yjvwfW8jz7m+wnnvbKAfEcfkXH8eH0fbpFN7TvE8349zHv/
AH8uVlLnLq/yHFLZH7t4LY7z+5cxp25nZn6YOTWFz/t7mHE+5s8g8p9Xs61i
e69WYw7OPUZhjcSEXn31WnrggeXk6vocRUZOoeDgGeTo+BTdcgv6Snygv0Mu
PSvWnCOz5c/l36GXfn51Y4hbWc0cuYHuvS+DPt9ppUcyM+7SJn/eW8mMf7dm
TTM/0jSTI00zzTTTzttqiyPBkEb/SKPODuzQkRN05MQJi165eftJ2v7J9/TR
jm3Ups2TpGokrq+TWCzEeOHs0aDBMrqraQJl5D5DTz73NhWVzqXQCbOobbsx
fJ6eSc+++DaVzXqSElKm0f0PelNf20R66oV3aM6Clyk1s5h5I5McnafQjDn/
pceffouy8ycxWxQy7+RRwaTX+f3LKa9oOgWOK6L+AzMoIfUFqdlSXLqYouOz
mFNKKThsIY/9Js2c+zTFJ5fyeTuJ2aZE1YtZ8hqlZk1mTspiTorkufxHekLm
FU+R+j533DmEsvL+Tc+8sJTnPouvNY3uvHMEn9/n0/OvvENTpj9BkTFFwhnj
QhbT488spZnz/k3J6QU0yC6XOWIqzVn4Ni164g3KzC0gZ2bivv1n0rTZz0kN
2vxJU5gvSpkZ4yg9+1l66vm3qaRsNo8zndkjmLllAT39wltSeyc6fjrfTxjz
RQaP8zZf92VKz5nCr0VTqzbjaN7ipbTkyTcpp6CE+bOAmZF9VPKa1KktmDSd
+bGYbAdmUlLai/TsS8upZKqq99LPNo3XZDE98exyntfzlJqRTd37Taa7Hk1k
/7xKCx57jdLER5nMyEk8l1fZR2/xOKXMxlOoVWtPysh5np5+fikVT2FODC5j
Hw3nay7icd6W2juxidPogX/5MbcW0DO8PujZmJSOPhc5zNLTae7Ct2jR42+w
r4t4bQqZsXN5fm+IP/KKpvLcC5i7plBO4ZPSb3TytNkUEj6NHu0ygcIjFvPP
wUeP08S4WbyOQcx1Weyjt2juon9Lj8bBQ1Ooe48JvK9ep8Xso0Vhz9BHt+2v
MU9uu3kvlY1cyvtoOU2f8zwlphbQgMFpsnbzFi+XPo6Zefk8bj7vhRLp27kE
PiqcwsxeQm3a+vDefYHniX00nffKLGrTbhSFRy5kfyylqTMXU1TsdOrRG/0n
S/ge36LZ81/kz8AU6tQ5iu99Iu+ht6WHSmZeMfNnAX8uCmhy2ev8s29TbtFk
CgyaTTfc2II/c7nMa9v4zL/CErNeHpNZu3EH52qKI9cIR9522/s0ZsxMqbNz
++2r6I47lsm/IT7icjelzUGDfIW5HRy5gf9s8NaaemoqL9TGZiPdd2+m6JG7
9zNH7j1arkEabLinklXWKytxZp38MjnSNJMjTTPNtHpsdaFHlv9Z9/s4qP+s
+34cPo7+kZupfXtwJM48q+okr0dxJM4c7/J52Zf5YgYtfOxNyi9eRDEJuXzW
7s/n5jTpszd52pPMNqXU6dFOzF3+8tqMuc/za1PJZaQ7hYyPZjZ7kRYsAc/M
JN/RQeTjP5ZKmeEWPwn2mMvcFS+9GfKKZ8trhZMXS39BFzcXik/JZxb6r/Sk
QP949AcJCo2UngmzF/xbevj5+I1ldnGm6Twuam1m5M6RPhctWrXks/pjwoG5
hQv4mmnMTS2Ze/OYpd6WfhqRMbnMnCP5OgU8x9el/2NcUgm5efpQWES8jDFv
0Sv879PILzCYfAMCmT+fYW56ndlxNoWOj2V2cue5z6XFPA56jkTHZdGgocP4
OjnCV+jPmJAyiYbYOUhPDPQnmTn3RUrJnE6D7eyYaYbwGK8y07xK6Vmz5H58
A4KEc3HN7Px57KNYufe84jnCm8pHWdJzJCmtiNfnv9LbJC6xiOxdxlFT5sgZ
zMRzFpb7CO9H70ZwE9YiOHyi9P0oLl3E8/wv+2ghTYhKppatWlBKRjGP85b0
ZYxPLmIWeoQCxoXLa+Kj5BK+njeN55+fPf/fMvfk9GnSr8QvIJSZ/im5JtZi
XGgs+9OduXuB9NSAjybGZdIwByc1d/io7Cnmu2JmRnsZZ/6S/7KPXpC5u7p5
0fARrrwWL8tapOfMYn4dTSEtQ+hQ86M15snDLU/Sc7HLpFfoSHc197mLjH1U
xj4KZBvNrPkC7wX2UfZMnvtE6ms7kPfKYuHA7IIFvPfTqWfvvpScMYnv8U32
0RN8zXxecwfpFYP7Aa8mp08l20GDeO4u0k9z7qKXxUejeP+j70fZTOWj9OxZ
7PdUuvP//smfuQLhyEaN3rvk3Hh6vPsHwmA424FHQkKmkbf3PEL/SPRgVHGh
l1p3O3c9UuVKGvd56fM368Y+kOcSWLd772OO3P25RY/cte9o1RpkZT3S0Csr
cWad/DI50jSTI00zzbR6bLXHkZXthJVGqfVI/n3PAfQA+Y42b9tC7do9QegD
hvqCqDNY27X9VO1CxEC9w0wRQAUls/gM/Bqf/+fz+b9A+rKjbzr4btKUx6XH
e/sO3ZkFx8hrZTOflfO/o7Of9GVHT0Xob+hT7+03gTx9QplNnxCeQV8I9I8c
4RpAWflzRWNEL8bI2Bw+f/vKmX/OwleZqZ6S/vEjXEdT4Lg40Q1naM7A9YYO
c5e+hGCNzNxZ5O07npo/3I6KJj8mjIae8uOjMunhFh0oJr5QmAB9KKJi8phB
R8m18V7MPZ4ZCX3qg8NTmAdeFE5KzpjKjMFzHxUuXIhrZuSCMxL5/T7MF/OY
pdhHxfOZTfOo/0Anio4vkNfQ2xDXHDjYWeaFfg9ls56l1MxpzBnO1Le/A82a
/7KMgz71XjwGetVPgo/4/dnsl3EhicyMgcKU8FthySJh7eHsY1wbPS1Lpz1N
CcmFNMRpAt3dJYnHeNHCYvARfDx1Jq/FAmax7OnS17FHr8HMd4ssPgqPyGC/
tWd+nyzsU1y6RHzToVMvZtsoXt/X+Rrso5QSnk8Ac1Mac+ULPPeXxUdefH8+
/hHso6flmlgLjOPkMppyixaIP/KLF7CP0GNzpJo77y3Fq5NpwCAn5tAoXvPX
aBrvGzyPwJoPc/Dk9f63+CgjZya5ewZTx869+H1P0usJH9C+f31VY5787MG9
lNA/V+Y+c95LwvTJGVPIwzuU3L1CtI9eZh/NoMCgOOrVZyj7e4ncT07BXPZ7
NnXvMYASUkrlfrCPYpnfB/D6juO9jNfgI3BkX1vEgHvy3npVxkrNLCMvnzDx
JdhZnh3wOOERmXT7HbfyZy6fz/xbdZ+GS51TV9GgZ+F7AbG2yLMLDp5Onp7z
5c/IvWvYUMXYX+6m5rmOv+de4T/n8P1sJBW3e2nyTi+OoZfTB9J3+L77s5Qe
ue+E4kiw4r7Khter4MsqrE5+mRxpmsmRpplmWj22uuPI003pk8fp0BFw5GZq
2/Zx0SPR3/Gqq1YK99Wm4ZrgSRub5dSq9Wg+Q8+kWfNeEc4AG4Ejx0dmyHm5
iDkjMa2UObIbjfQIFEYC80GjdHQexfwTL2dqaJKpWdOYI8czJ4Xw2ftxYUtw
RlAYONKfOXKOvKY4I5s50kfO52CHkrInKC65mJxc/SiAOXIG8x1YLCl9Cl+P
OdLBTTRLMEGGcGQYM2NbKpy8RJggu2AOTZiYSS1atKOYBOY7YTHEI+aQwwhv
uTbiNUt57vHJ6PE3WvraT5v1PI/1vIzj48d8x2NNLnuSZvPP4vwvHMnvz2GO
xDi5hXPlmraDHCmaxwGzgcWgRw4cMoJG+YVbuBhMYcvc1I9ZA4wBLk5jvsP9
+DBHGj7KyptNY0MTyNktQJgSWiy0PeiRjs6+cu1Z8BHzakJyAQ0ZEU53P5oo
PIQY3OT0UmaXEHJmHpsy4xnxEZgefNezN3Nk8ULR5MBIYbyu8Jviu1eEV8GR
HTv1YL6LlDUvnfak+Mh55GgKYxYrg4947uAmb76/UaPHKx8tUMw3lvcA1hea
sPLRPIpkFhsy1JV5VPF7kfiohDnSkfwCo/i1V3iuT1MyM/CIkX40bLiHrDnW
An738BpHnR7pIYyOcbLyZlHpiIW0/fqPasyTO+7fSS8mvKt4ldfXg33k4R3M
46r9Ch+NCY6j3n0HUwHvFexD7NEJPPduPQdQYmqprC98FJtYSAMHj+C9nCiv
QadHTG6//vY8d0+axfcIjTKFWduTx/ENjOQ9rXyENQ9jfr/jjlv4M5d32XJk
eb0WxZEhIbxXvRRHIjbCiItQuuTla6p2KWq0vszfd4gj3kSoYaTqGK2rl4Z7
Q52kBg020333ZdNnu3bquNYjlZjRih2rYkuxiq/XyS+TI00zOdI000yrx3Yx
OXLvl4ojDx7+lrZs30Lt20OPxHP1Fcx8K/i7dmWtGq6JfmOKIwOEI6EFQTuc
GJ8v7DE+KoPmCs8sZI6cTB06diVXjzFaW3qCX5tCTiN8aWxwgrALzurQ37z9
w4WTJk15TM7q4IxgPns7u/hRdt4cYTlwBjQfR6dREss6c+5LWhcrZh7xo8Bx
sRJ7OGWG4lUw0hB7xZHgJnAGeKY5MyM4EowGFhvPHPnww+0V3zEjgZ8iY3PJ
wclbuGgGXxNzxziuzGwh4SlUxixWJtoSc6Q/MzDzKZgWP4vzP7hhuJMP5fCc
cT/wURRf01brkeA7cAa4bNAQZ7kGGGkyXyOFOXLAYEdhDdyjaJTM2l6+IcKs
xdpHYO1xzHwuzG3ZzHrI38stmk8RE7PZx6OYHUuEDYtKHxOOHOoURk0fTWL/
PMc+eVrrkcyRI/0l9hU+wlqMC47ntRwkeiTGgY/CI9LZR+1EbwTfgenB2B06
dxeOBANPmvqYsCW4NGx8ujwnKJv1jPgI/D7Kf4LyEbMl1mJscLysG/Rs8REz
fYShR/I4WB/4KIHXYOBgJ2Es6LMSM80M7MwMascsBm0YawG+c7fiSGMfhYxP
oVZtO9OiUf+mow+eqjFP7mt1mKaPe4o8RgUznzJHTn9aYnfTeC3GQI/sO0Se
OeB+sBaiRzJHJjBHYn3ho5gE5Is6yzMRzB0x0+BqPCMY5uBBM/nn4Hu8huco
0Fxl7nxNrEU48/vtdyo9slGjLfKM6NL3iqiuf8R70j8Cca2KIzeIHqkY8lJz
bk3riK1jH7/C33c5zFebNWuhT+b6emm4N/T/vOqqLXQv9MjdyI88pfIjT+NE
gysrm6lHmmZypGmmmWZabdjF1SNPCEd+efR7Wr9pEzVt+phwJPpyNGjwrnBf
bRquCZ60sVmm9MhJM5kD+QydN4smxuVRj16DRI/EGRpsAF2mPXPkSPcxwkii
UaYaemQClfK5HNpSSgZy0MLIc1SoMBLYEpwRFJpo0SOh2YCVEPdo6JFgxoJJ
iyTG1cnFnwKCYkUnLCl7XMbx5HP5kGHukrcIBgBn+Ige2U7yCDEOYlAnTMwQ
towB34FXi+aJdmjv6CPsiJ8r0nGcLsyRwcwlYKTSaYpXhYH5ujj/G8wXFJpA
Do7eEteK3MNMZjHhyEGOzBb5zB4vSqwrrgm9yps5EjG54GKVPwc90l4YCeNI
3CP7BzwGLgTzgZGgezq7jZbYX4wjPmKecXL2ER0PNXYQDxyflE9DHMPpni6J
7PdnmcWeEB9BZ4N+WDrjaeF6MOzYkDjhyDzmafgTjBQWmSY+AtNh7tBXwfLQ
I/0Do2TNi9inYEvwXdiEdPG78pHShhH/O2nqk+IjQ/d0cvUV9sU8wauY+yA7
VxkH64t9FC96pJPokWBLxIviecQIFz/mSA8q4/cqH00jN88g5sievI8e57k/
K/HAIeHJ1Jo5EmsFLn9qzH9p312HasSS/2PbeM82SrDLlfsBf2Mt8Myid58h
okcaawEdWPTIlMnaR/Os9MgkeQ0+gj/6Qo9ETO6cl3Qu8RTZ/2ByYx9hLRDX
eofEteYx42yWZ0RK37vcbBWpPoRrrTiyoh55uZvKKUfN65f5z7nMWVuYI9eL
XXfdhnppuLfrr1/H3+9bJa61XI8EPx7XVpX+WJUeWdHq5JfJkaaZHGmaaabV
Y7uYHLlf65GHj/9Aq95HfYgFEtfaoMEKbStr1WxswJM4K77NHOlP+ZNmCJPg
DD0xPk/0yPCoTDn/IxYyKXUytZO41jHCSOAZvOakORJ5YIhzTMmcKvGaOEeD
kcAzhqbnBI5kvoDeZHDGcCdvik0olNfyoIslFQlTBI6LEe1R4kVTlR451N5d
8hahg6UiD5PHAUfi/I8YUsxd5Ue2k2sac4+KyRUOhB4JZhQWAyMhrjU8RbgU
uXtgMTCwcCSzS6mOS8X92SM/kvkOehPGkbjWgU7Cq2BTsBiuP2CwE19jvDBj
IXNxcobWI20dmFFeoBK+LlgbuYxePH/4CDwj8bM8DvREjCM+yp+t41pHCX9B
N4W+Cj1ysFM4Ne2SxL54WnTfBF4LpUeOFh9hLTA2YjaxlvAt7hNzFz1ScyTm
nsPjxTG/d+io9MgZzGcFkxYyr06iEYhrjUgTX5SI/sZr4RsqeiRyO1Xs7jSJ
a0U8ck7hfPFRJjM94pYH27nIOLgf8RHfB/zmFxgp/oBGCb+PYAYFi2F9oPOl
8DXdPaFH9qIivj+Mg32kOLKTsJrwKmJQJ2ZTbvcp9NX/HashT/6PdrU7SI/H
vSExqIYeCc1WnlHwWkRMNDiyRHJ/oa/GJBYIA49jjhSmZx8lM8/2tR0mca24
H6wFXhM9MjBC4pbhO6x5+IQMuv12cGQuM85mPj+tqPW859qxVcKSyM8OCSlj
jpwn2uQ116yU1y/9/GqW/41el1df/W+e89+PI++/L5s+3bmzCj3yeBVWVXyr
GddqmsmRpplmmmkXYpdCj0R+5MYtm6lZsyV8dluttcMVks9Ym4Zr4qxl6JF5
xdP5/P6U8ExUXL5oWNAjcYbGWV3yI9uruFbksOUXz5fXHEf4SH4kaqFAfwS7
IN4UmhXiTZEfhtjBoLAEiXvMzJ0jepPEDsZkyftjEovkNWiHscyR0LXGBMXK
a2C+xJRS8vQOJrth7mocZksVG6r0SOiYk6c+Ief/8RMzJGYTfAd2yWYWQz0f
eycvimOewTWhi0GbdGFmQ5wk5lhUCm1psmicXlonBDel8v2oOjve4gfoTWAx
MJLtAEeKZl+BlXP438CmKj9yvGh/8BE4BXpkX1t7msqvFTHzpjJrQ18FR8JH
k8VH03Vs6Ghm7HIfgZGG67hW8Eguc1p8cj4NQVxr12T2xROii2EtPL1DhPsQ
twudLyV9qvAd1hI6IcbB+iLfsXmLtqJxCvPxeOD39p26Cd8Z2iH8pfTIVHlv
8eTHJAbVexTiWsdX9FFIHDmCIwvmUakeBzWCBtu5Co9i7tnio0k6PzJSmBHx
ovI8wgU9RzxFJ8T9gN/dvMaKHlko4zwhPgrWca3gWTX3WTQ+KoucnH35OqX0
atAqOnL3iZrFuzYg2tFiN6W6TaKefYYIoxvPKCYwv3fvYSt8Dq0dTB+dUEgD
Byk9EnmpeUULJM63j+RHekgOKbRxzM3TJ5j8mclRAwqaOnRp5EeqOju5zDib
JNagtvOea8dWSsyt4siKeqTS+S693lhTPfKqq17m3/OZr7ZaeOv66zfWS8O9
NW68nhpevY3uuz9H65GnrPTI0/lwZ7VsWdHq5JfJkaaZHGmaaabVY7s0ca3f
0frNm+i++xZrjqzruNa3FUcWTeMz7+NS4zMqTuuREelyhsZZHefp9h1UXCvY
Mqdwrrw23NlHdDQwBXguRWqehglHQt8xmE/iWl38KSNvtmh9GToHDXmH4Eho
UNAOEdfqCD2SORIxgeAM6JEeokd6SA1Y6EBpWo9EfCbO/+Am8OoE0SPbUnR8
vuhymDuYz8HRS9gRYyNGEb0zwEjgEsRNCq8irtU3XOJNoXGC8SQ2FHGtzKHg
LYwDRoqMzab+A4bTROZIcCj0VcS1ih7JjCVsyeNAh7Id6Ej9BjiwL5+R2jl4
zcsnVHi7wPBR5nTxIzgw08pHEww9kvkLPkJsbYIlrjWJ5wm/L1BxrV4qrhU8
j/sB4xh6JOaCeN70rOmiLzaXOjuTZO4YB37v0EnpkahBI2uBXFUXVWenWK8v
YlANPRI+Kpq8RJgPDAwWhJaK8RGDGjmROXKoi/Ao1hI+Ej2SuRqMBX+Ai+F3
0SMdPaUGLNY81UqPLDTG4fW1jmvF3DMlljlTahEl8n6E36CvLnJ9ifbcvL9m
+mSD/9Hy21fQ3JgXxUfYWxLXCo7k+YJhwfQxzJEDdJ0dcL7o9NAj+w0jOwdP
8Rt0XxXXGiK+NHyEtQiXOjvgyBzmnI38OXyHajvvuXZshcTcIh7CWo9s1Ejp
kZc+7vbspjTVNexj6JGTmK+2WXirceNN9dJwbzfcsIGuabid7n8glz49jSOr
s+p0yOOaNU2ONM3kSNNMM820c7VLG9c6X/IjGzR4R86b4MnaNFwX50Ubm6XC
kbnMkQWT1Bla8iN7D6KwyHTFGTkzJb6vXfuuEtcKzQjaEnLHHEeMonHBidIz
Aed/ow4L4jbzixZI3CI4IyhE5UeCWcBn6dD0JmbRcEdv5shC4VBoPtDFnDRH
ghnBfOADD59giWvFz0EHkno+o1S9VpzdwU3gyPFSi7Sd8B3YBTmTUcyR9sNV
vVac6XH+B1MihhRxrXgN18Q43hLXqhi4QOJSp4reau/kzSwxW5gG40TF5Agf
RrOvwKHgDNEjB42QuFbwEHwk+ZH8c/1tmSPLlOaKa4Iz4Kd8PXcwElgMHJgp
PlosPkJ8JfRIsJjy0RyKTyqgwY5hdE/XJMqbtES0wwReCw/vIOFQsJBai6k0
lv0IPRI6YaH4aLrWI9sJ94L5sL7wBzjSd3Sk8DfmHqtZOywiXeYDP4vuOUpz
ZPEimTu4eEyIqrOTnTdXfhYxqHhOIHok+wUcqnxUrkciFho5oHhOMELrkdCb
oZ3imm7CkT1lHQpKFso+Cg5LotZtOsv9wu+Y+wT4iFk7IbVE1lLNvVDmvtDu
OTpx5zc15skdnfbQlIjH5ZpdUWcnucTiI4lrHaziWjFP7FdwtaFHThZNfb7o
oh5SrzXK4iOwpbUeefXVG/Vnu3bjDGrHVujvhvc1R87VPYhWiE4JRrvcTWmq
OKO+JHGtjRtv1wz5N+DIa5gj788VPXIXc+QXexULnrup95lxraaZHGmaaaaZ
du52qeJaUWfngQcW8dntPWFIdd6sO45sCT2ycDqzh4onjIrNo569BooeifMy
9DfoMu07dBGOhI4EbQl6pKOT0iOFM3CGljosYcJJqO2CWq/QKMeFJggrZPJ5
HBqNinvMEp0vNqFA2BLaIc7/iFEMDIoR9sgRziiRuFbU2QEngMVE02OeAQ+h
Z6GMg1omkaoWKfgO2pToYsx8wxx5HOYmcCBYTPIwXUeLvoWxodeBlcGQXsJ3
i4SbhMWClR6ZwfNTzDddcjv7DxwuuaSYZwaPAxZD/hzqsIKR4KMkvnf0mew3
wJ5KoGEVzhXWBmcgrjWvaKFl7tAOnYW1Z8s40IYnRGWJj8FfykfM2on5NGh4
KN3bNZnfu9jC2u4GR05eYlkL5P6BI9GTEuOAv0MnlOuRRaKvThdm7IC41oAI
KtFzN3JV8fNYM2McaKmI3cX1LLzKcwf/w7fgPoyDmNxB0CP5OpgTWAwxrrbs
N9+ASIuOmyh5tr6KI8ueUDpuepnsNXAk7hGaM9Y8OEzpkVgrY+7IiVW9USar
9eVrou+Lk4uvzB3xuC95L6ejTU7WiCf/uuovWtd6G43spPqtiI7L+xU1gG0R
1xqaKNow1gLMCD1SOLLsKeF1xEdjv0KPVD5aKHpx6IQMaqL1yKuv3sCfweW1
HmdQO6a+IxAPERIyVeuRa4UhVdzre5e9Iff76qsNPbKA+epDC2/dcMPmemm4
txtv3EiNGn3E/3/k0ec10CN31iCm1dQjTTM50jTTTDPt3O2S9f34cAu1a4d6
rTgL4TxX93Gt0CPzilRcKmqRQo8Mj0wTzQcaFjiyHeJaPQJFa4POh9dQJwcc
Ce4x4vy8wWLMGuA7pS2VcyT0yHwdlwrNBzof9EhwKDgDPAOmQL1WnN/BJUpr
C5a+H4aeKBzJvNeMeQg9C6EnYpywKFWvFb1LiiTWdYboYvaOnlJLBoyTmat4
1VnnR4KRhFd5HGic4FMwMGIu0XMQOYYOWo80eCYiBnGtjqJ7Yk7CYsyRtoMd
pX8m+Bs+wvuhR6JXPfgMWpnEPfL9QPsEq4L5krWmZ+iRykfThJFEj+Rrw8fw
H+q1Kj0ymd+/SGl6vBYS18ocCl+ipg3WIjA4lnr2GiT3Z/FRRCqzdlu5JtgU
a4G6REZcq6FBy1qIHpkqfkPMKnwEPdLHf4LFR+BI5LM6OvsJW6m41DKJyR08
xFn8XqifHUAT7g89Utcyxf3gOcEI51Fk7+ApNWAxDjTbkZ5jLXqksY+Cw7Ue
yexZINrwdNGgEfsLtsTP4prR8YXClsjtxD1Kjm9KKc3svpiO3Fizejx/NviT
NrX/mOYmviTjxPCewnMCxLUaWigYuE9/O6k1a9Eodc0jaK5YX9EomS2h6yo9
Mps/e+v5M7is1p8P1Y6pZ1d4jhUcXEaenvOuWD2yQYOXmKsmM199ZOGtG2/c
Ui8N93bTTeiT+THd/698+mznTtrDHIm+HbuZBau1vdqsXttl9buZH2mayZGm
mWaaaedul0qP3Lx9M7Vps0Q48mLpkTmFZWwLhWei4nKl7wfOvWAxaEvoJd+2
fRdydR8juguYAP0Sh49gjgxOkDhQiXVFbVWJaw2hPOY7aEvQ38Ca0IcQq2nE
pU6IzhSOjE4skPM/rgm+c3QZJfVaRX9jdsM47l5BNHSYu/AIaueAXTyZ+Zoz
D+XwOT1XchGnKj1S4lrzhKcQL4r4WfvhXqKLgQMNRnJ29RM9EmNLvGiyoUeG
yPlfcfEU6Z2BOj0ZObMU8/HYkcxItgOGi3ZboGNdcX3RI33DhYcy+H5QuxN5
lP36O9CkKU8KZyEWEnG6iGuFL3L03KHpIfYXHInxUbMUdYPQGwU6HuaeLrpn
nnDkvV2TmFEWqrzD5Enk4RkkHKp8NEd4ZkxQDPXsPVDqjcJHWN9QZqvmLdpI
XKuhHSJHtX3H7uQbECF8h7VAv0RDjwTXyjiiR4ZInZ1cPXf4KFD0SF/JITXi
UiN4fZUeqfgdPopPLhI90m90hLAY9gM0P7wXNU9RAxb3D/5282CO7NxDxobO
h30EhmvdupPkWeYjTjdT5cQivho8aqyv0iN57hFKS4XfwdroSenlFUKve62m
U7d9W2N9ckvHHZQbOlNqzY4LTZL6OVgLxOT21nqkrC+4GKztrfIjjfVN5LnB
jwZHXnXVeqlxhec5l58t1xy5isLDp5KPz1zJlWzY8F3Jm7z0+Zs164979dXo
m/Qic2Q+c9bHzFlbxG68cWu9NNzbTTdtZo78hDmygD5HvdZ9p2jnHvSAPF69
VaFBWrPkbpMjTTM50jTTTDPtnO2icqTWI8GR0CPbtIEeiTPRch3/9k6tGq6p
tM63hCNzC8qYNaC/MSPFao7kcy9YDEyA3g1tO6Bea6DoLtBnwJYOTj6i1+H8
rmIUS7WmFyw8Aa1MND3UInX2ZbaaKRqWcAbzHfpxoA4muAnaIc7/0JaQHyn6
G3L3mO+gRyI/UvTEvFlK0/PRca18PTCfqmWSLmwJTVUxEsbJFo6EXohzvcGr
YCToW5i7watgSOiRYCTRDvl+MHfU6cFcDC7G3PsPdBDmRgwsWCyOrzlgoKPU
GRIdN3u63Hu/AY7SP9LQ34xej/AT5p6t5w5NT2oRMa8KF/Pcx0dlCKtDxxMf
QdNLzJW4VuiROczqknfIa4G6NOBQ+A33A54Bj0OPRE9KjJPC44SMT6VmWo80
9FXRIzt2Y76LlF4VolHCR7xmIbwP8sRHs4TfLHokfFQwR8fPaj2Sx1XMN1X0
5oFDXITZ8X7xEY8JrgZjiV6MmGneW1hze2YxvIbYZ1zTiGvFe6FR4rWgUCM/
UnE11hd6JOo9YW7wEWoJoc6SowvmniocCp9iHDfPsRL/K889cubS805v0rGb
albf9c+r/6TX7nmTEkYVqjxZXl/RI/va0TAHD6mdi3HAjHhO4As9Ep8Bnjty
iUPHl+uRDRqsk1gAG5t3LlNbLnqkt3cZDR8+36JHKp3v0uuNNdUjr7rqJR3X
+hE1brxZzODJ+ma4txtv3MTc/DE98EC+xLWekx5pZbusfofVyS+TI00zOdI0
00yrx3YhHLlPs2FNDXGtexDXCj2SObJt28cseiTOdbWtOeCaeGZfrkdOZQ5U
jBQZk0vdEdcq8YyLJcYQjNUO+ZHugVL/BjpfArMN6uSgDg3O7xLHmaby55Af
CeYCW0KTg6YHfQgMJ9zE14SOBJ0PPTrAnBI7yDzjNMJX+Ad8Jrpn0iTRI5Ef
ifM/eA68i3HAQ+CWLKlpUyq1SFu26ijxpnmakRBfCa0LNUkxp3QZp0BiNqFH
ghkztC6GeXtqvlPa4WTJW0RcazozsMEzyP1T9VpztXZYJryEWqSowwq9CtyE
ujTIowRHiv7G94N4U6VHhkq/RcmjTJ8iMajOrqNFo8M4mPv4yEypaYt+KPAR
cjPjEqBHhtK9XZKF/cFd0CPd2Ee4p3wd2wmeAd/hmQB6icCwvqETUqh587Yy
39wild+INWjfqavohCrWdZqwpWh6zJ0YW3wE3dMnRGrS5uq5g4uhe4oeyeMK
f/M445kjjfxIeXZg+Gigims1YmoVR6r+kYVa51McGUidOveUOSoflVIw9Mg2
nWQ/GrGu4czaDtBsef3A32nCkQUSH425y7MDvib+3c1rnNQjytdcDNYeExhL
xc2m0rc3/1Ajnvzjqj9pS4/PqCR6scTS9ulnJ3pkka7lK7onj4F7NPYRtNIw
ix6ZxZ89xZHQ/S43Uxy5TPIjGzSYz3N9jpS2d2VokdZ6ZIMGL0rfj8aNP6Tr
r98kZvBkfTPc2w03bKRrGn5I99+fR5/vZo48cErq5Ozef7yinYkrq7A6+WVy
pGkmR5pmmmn12C6ZHmkV13ox9MgWzJHZBVOktyMYB3VpevQaKEyG8zY4AzGQ
bTs8Sq7MkYqRyoTvUH9mbEiCnOlxhga7gMXASdAIJUYRnMGsCX0IZ3zFM1OZ
MzJpmOiR+cJ3uKZFjxwbLTVo0nROnYf3OIlrldjO7BmW3grQHlFDRsZJMziy
A02MzVPswuNESFyrh/T6AMMqRiqQ+qKo/4mfU3G6k4RNoUdiPip3DxwZS/aO
3vIzwjM8DmoEgQ8R15or+Y1TJc8TtUjROwT1a8GB6I3Yf4ADc6SD+A33r2ri
qLhW9PEQ5tM1cVD7B7wGH4GRxmtGQo4hfjZFdE/okSF0T9cU5md+f/Z0Xoti
YSTU2ckvWqjjRUuUHtl7kMzb8FGIcGQb8UeOzm9EDZl2HbuR72jVz0PWAjmG
UqsmVfG38KqqeTSKWTnHmDuvL8bBuqm5Ky7Gc4JBWo80YnfjkgrFb+BVNc40
4Ugnfi9yDOG3dPFRqfQqFY4sXCDj4BkFaty0Yo7EfhRtGD6CHsmsjecAWF9c
U/RIviaY2VjfONFsx0psK/ZWhvZRwNgY6tVnCOXmzKP/jFhJ39z0fY31yXWP
bCPnHt7MwO4WLjbisMGRho+glYaOt+bItfIMR8WQXn6mGPc9/n0B//4cz3c1
1UX/oboyNVfM+QVq2DCPGWs7XXfdRjGDJ+ub4d4aN95ADa/+kO7T9Vor65GW
uNXKXHkWq5NfJkeaZnKkaaaZVo/tQjjyAHPhudo+cOThb2mrRY9ceZH0SH/K
yZ/C512VU4caMtCwkM8FLQfMht4NbTt0IRf3ANGMFBMUS37jGOZI4QzhSK1H
eodoRpopmp7U83RWHJkpGiX0yAyJN0VNHGEk5i7oSOjhEDAuWuVRIr5S65FD
h7mJxohrqN4KwZoj5+p4QsWRzR9uIyxs1IBBfCW0LsRpIr5T8gF1/lxQeLKw
FGIUcT9e0CN9QtT5X/qdKD0S8wTTZgrzlUrPQvSEhHarYl2nipZqyxzpo/tP
wkeiR9oOp7629oq/mWFxTQ++H9S1zWLuSZc4zlKJ5XVy8Rc/io8QpxuZLrWM
oOkZGmVsQg4NHB5KTbskM7PNFe4Ca7t7jRWOzNOsDXYJYL7r0XugxAKrujCl
zDMp4jf4Q9UXnaL0yA7dJD8yX/cBFaZ3GSUcifVRTD9J1hb5kRYf8ZoHCEci
bnmWhVcVRzqLX1Ts7lQZE1yNurDSbxTPI6BHMisPE45crNd3smjfHR/pKetj
jDNO9MjOws3ZVrHMDiO85TrQpXFN7CnUJxKOLFBaN557uLGPoEfm6vhm+Gj0
mGjmyMGyN7CPkhOn0jMDXqMj19asHs+vV/1GL//rvzQj4zlZX+ieGMOXWRnP
OIS/+bWQ8FSr/MgrQ4+0sYEe+SxdqXok8iPBkdddt43+8Y8NYgZP1jfDvV1/
/Xq+523MkTmiR+4+cEr6d+zar8zUI027HM3kyLq1v/76y2KXei6mmfZ3skvR
P/LLI9/Rpq2bqXmzxcKRShtYXif5T4on3xKOhB6ZkaNqTYLBuvccRGESz7hA
tDJwTDvU2XELEN1FYl0TiyRvEPmROTqeEPoOOAOaFc7l6fr8D01POJJ5TWlL
U0RHsuf3R8cVWGp0RsflS82U0WNjVBynzqlDL0HkR+ZrjpQ+hjwO+lcgjlL0
Nx7H6GmB/EijNgt0TzsHD6kbk605Q/QqV1/RI4WRUCcHjMRsivw/MIqKUZws
fDfM0VPGVRplqcRs9mM+jIzNUePwfFAjFDVkoEeiVwVYLEH0SMS1DhO/if4m
cY/jJK4V80HPEGGxoBjRSJEnChbDNceDkRy9FQNDxxWdMJcGOSg9EnVtVI0f
5SPkR2LNjHjRQPZj916DpJeIxAMz0yOWFxxp8F2SzB0c2ZVGjZ4g8cTQcZWm
5yv7IEd0XMXa4Hf0yMyW9Z1hycMc7qzqKBlMDy1V8iMxTr7KkwWbopemNa+C
gZHfCNY3NEr4Q/TIR3pYnlHAb0GhCUqP5Hsz4mdRVxh6JDRKpeOWSZ0lzB25
oKJ1ax+NFD0yyBJHjdxb/zETmSMHUaZlH5VQGO/NXt0G0SuD3qEfbvypZvGu
1/xJa7pvpayJ0y16pPhItO5i6VV65emR8694PfLqq3OZsbbQtdeuFzN4sr4Z
7u2669bxPW+le+/Ppi/2fEF7DpykXfuOWvhx13lanfwyOdI0kyNrxcCHv//+
O/3888/07bff0ldffUW7du2i7du30+rVq+nNN9+kl19+mZYuXUpr166ljz/+
mPbu3UtHjx6l77//nn755Rf6448/TM407ZIZ9h724E8//URff/01ffnll/T5
55/T5s2bacWKFbJ/YW+88QatWbOGPv30Uzpw4ACdPHmSfvjhB/r111/pzz//
vOz28IXpkSeUHTpR/ucz2H7+uX0Hj9GR4z/Qex+sp0aN5kqdC/QGUHUda/uc
uExrnW9Sy1ajmfmm8Hl3lpzV0SdD4lrBkYXz5UyP3ELFkYF81l8ifIZ4RYfh
XqI1Sjyhrr0DFvPwCaJsPtMb539wJGIk8TPgDLAL8tqEI5lX5Pwv7JInTBAw
NrpCTh20NuiRubrWK+Zk6JFZehzkqqHPA14DCxuMBJ5BzKRisdlaa0MdFlVn
J0drlKjDg1qk4EjoWpa5gyP5PtNl7kqjhNYGPTIKemS+ZjHpL+go8apgJDAO
GAs/17e/vfgNjCO1VbUeaXAGeBMsBg6E7peha81Aa5McUj335HT2R3wODXQI
ljo70JAlTpd9NNJjrNQOyitUeZTQ36Dr9ug5UHxujAOeaYb8yIRC1Q8jtVTW
oH1H5kjdzwPrixxTpUemSD0dg8WgtSEH1NpHWC+sb7qeO9YHWurAwc5aB1Yx
07iPfqizI7y6UOfeFsuzA+iR+bo2Eq6JGOqOnXsIp6OvCnyJXFwV11psiTFG
XWHkr+I6iM2WON3YXLlmaHiKJdYVOaaoAQvext5SMaiTLHpkpt5H0ChxzW7d
+kvsb17WAvrPkBX0XeOa5U/+2ug3ernVGxTmlSSsi+cC0E+vFD1SaZL4zlmt
41qfvcI5MocZC/Vn1vLvsHX11NYyT67hNdtM996XRTt376S9B07RbsmPvDCr
k18mR5pmcuRZz9bWjPjNN9/Q4cOHhRG3bdsmjPjaa6/x72to7bpN9O6K1fTq
a2/Q3HmLKCe3kELDIvmM5kwdOnahB/7VnB55tAe5jvSiyKhYKiicTIsWPUH/
eX0prVz1Aa1bv5k2bd5OGzZspg8++IA+/PBD2rNnj7Dmd999V4E1L7ezummX
r2GvgO9+++03+vHHH4X7Dh48SJ999hlt2sR79t136YM162jzlg9lDy5bvope
+vdrNGs2n2PTsiggMIhsBwyh++5vJta2XWdycfWghKQ0mlo2k5597iV6863l
9N7qtbR+w1a+1np65ZVXaOXKlbRlyxbauXOnfGYM1rzYz0suiCMPnV9c6+Fj
39Oa9RupSZMFkh9p6JG1f05EzmV5vdasvFLmF5XHhThQFdeqtByc33GeRn4k
4lqhGYFxcC5HX8YxIXGSpyf9QcBI3sFiYAfoj2BLidl09pWfMeJfxzNnoPc8
tKMsHcc5UeuRAWMnSjwiuAs9KXD2HzJspPT4AFtCM/LwDtEcOVvGSZActBQV
18osLHUydXylxLUyN6l4UaW1OTn7SR8JqWMqeYdFonGijkx23lwLZwSOi5X7
FAbORq2ZEtFSwUOR0bm69k6pxIYi9w91WPOLFslr+Fnob32hR5bo2re6tiry
MLNET5wufIc8PXAg/p4uGmWpaG2iRyYUWeYeE58t+ZHo+5GRM0e4SxjJcww5
ufqV67jMVfBjj14DhO2kNir7LYTZGT6KSSwQ32FsrEE7xLX6jxeOxPoqH/lK
j00VL6p6m6BPJfRImXu2ZjEex1H3dTHYcnxEho5rLRBGw/2IHslcjZhPGSdd
ad2Ia7VzUHoznifAby5uAdShU0/xr5F3iD6kD7dsL9ysavwoDRo+wv1m6txM
5Mc6OvvIfjDigbG+I9lH0ApzCsq1bv/AKOrZezBl5c62rDlq4nTrZst+LdR1
cvgzEFVIMx6eT99eX7P8yV+u+ZXe77eV8hMWyNzgx9vvuOWK0yNtbJ7Tf679
+Pq6MjVXzPl54chGjTbRNdesFZZs1GhdPTUwsuLI++7LpC/27KI9B76WOjt7
9h+v3vZpk79X/bN18svkSNNMjrSctXHOhg6zf/9+YTiw3IYNm2jHpztp+/ZP
aM2aDfTGm2/T4iVPUG5eEYWETqChdsP5bP2Q5L4gLgy15fFc39rGGMZnMMNw
HsNza8OQl4JnwTAvnyBmzxE0fkIUFRWX0pNPPktvLV1Oa9ZuoG3bP6ZPdnzB
c1tD69ato48++oigax4/flxY1+TLv68Zzzvw3AF7Apr3+vXrafXq92XPgBPf
e2+NMOLMWXOZETPJf/RY6t2nP5/V9P617OH40/ev7OG48v0bFFNpD6v9i1ob
dze9n8/dgyhwTBBlZefRkiVP0jvvrqING7fwZ2uHzGfr1u3CsdA18ZnDsxIw
Zm375cL0yFPMkjW3/cyd+w6coEOHv6ct27dQq1aLdX7kMs2RdalH+lNmPnNk
lqr7qThyoMQEIuYTTACOadO+C5/tR4tmBD6DzuTAHIg1t5zV+Vzu6R0krIHz
txHrChYDH6ZojsRrYCT0no+OzVfn/zR1/oceCY3I6B+B+EvokUPs3CRXTrHY
ZBkDPJSpWUxy0CakWPTIrDyV7yl6pL2HXCdTx9SCm1BfFL0AhZEylO4JjdNT
M3CqjnXFdyz0SPzdqMeDa6J2ToTVOOAuxLCiByUYCdyEOfUbYE99+g9TtW/T
lf6G/hPIwxQGlpw6lcuIuFZr1g6PSBPNFr7O1PV4ouOylR7ZJZnSmX1SMlXe
IfRI5FeqmjZqLeBHrKVwpF4LaLCocxudUGipJSoc2V7FteZKTmypig3Vmp5R
90e0Ya1H4r3Gs4MAHgd1bcCqaZb1hR45Qur1oB8I7gc6MGrXYpw8PQ5YDb1N
hvEa5WstNF70yADRI7O0Fgr+xnfJI137yPVV/OxkyYlF3WBofobWjbhm5Eci
hldimfXcESsLhs/WfVWgs/sxR4oeyf5N07mm6DvZtXv/cr+zjxDDjJ6hoWNT
6J1h6+nH63+uEU/+1uh3erfHOpo4Npua3HE/f+by+LP3gebIZZelqbmt4t/n
sT1LSpsEo624IkzNFXN+gX2dzQy5kRo2RO+SNcKT9dPWMEtiX22ie+/NVHrk
/lOql8e+ExVtv9XvNbA6+WVypGl/Y460Pnfv3r2XNm3eRi+8+Iqce11HelLr
Nh2kRh5qyxmG56gWC7G2+PJzeIXzeFVn8epYMtrCknguLDbGsCh53mpYq9Yd
qVPnLuTmzmeTuEQqnTJVzui7d++hU6dO1cl53LTL06DxQe/75JMdzIrbqayM
z3+JKeTt40ddu/WkFi3bV7+HQ8+wh4NPfy5yGktWfhZitYct+1jvYX/sYat9
PHSYC/Xpa0ujA8aK7vnaa2/QB2vWCldC968t3f1i1tnZr/VIxLWuXoNcl3kS
11rOkHWoR7byYyaYzEyg6qhETMyU/EjEP4IPwUKIR2zb7lFyGRkg+XPCBIkF
wjhjg+JU3w2wS7LKnwNroLaLwRl4duCo9UilvynOGKb1SKM2C/4sca3MJVm6
jgrGlvzIYW4WtoReJRzZvK0wijFOiK4hAz0yU+tV0D2HOrhL3KnqGTJF+nWA
e6BH4v3Cq6JHBgvfKUZSLBbIexN6pjF34UjRI+0pIjpH92osEY5ETwvpC8mM
BNZFjiK4qW8/e/GbMBJq4mg9Egxs1CyVZymuqhaRoVFCF0NN3NhENXdwZExc
Fg2wD5G41nTmphRdKxZsCj1TfCR1kIq0HjlQepao3MxJFMQc+RD0yPgC1fsi
WXEk8iONfh5gYFkLremJj8BiSUWS2+njHy76XbnuyRw5onzu2DNh7PcBQ5yV
38Fi7I8YsDbz9yg9TpJ+HgGORA6roVHCH9AjO3buLnswVdfjwfdH1+624m9V
k3ayxDLDR1gr6MWJBkc6MUeGpWite6qO/R0jtXZEg85QOq6hR4JBjX0Ev3fp
3k/2uPSe5PGiYnKoP6+vEcedHj+d/tt/FX17zXc14smfrv2FihtPpZttpvBn
8H357Knc58vR3tbfP8iPRFzre/K9ge+MK8HUXDHn59kymSE3yHkVPSXBk/XT
PmCWxL7ayByZQTv37KK9B76WuNbK+uLufZW0yLNYnfwyOdK0vyFHgrGQkwjN
ZseOz2nBwiUUl5AhtRqsDWcTi4VaW0I1Z/H4M57FK7NkoLVVwZJVnsMDrS1S
agDg3IGcGJz74hPS6PnnX2Km+FRiYnGfiGm81D43rfbMyGNEHi6Ya926DTRr
9jzyDwiSPYf8JORHnbaHw86DJavQ2E97FlJh/8ZU2L+V93DFfcz7V+9hZRF8
fren0aPH0Cuv/of37z7hY8TiXsgeviCO/OrUOZjmyEMn6DBzJOJab711nq6z
U/f5kS1a+vM5X3Mkn8VRi1TpkUrLwbkaWl7bdo9InR2ltZVIjCI4ELmP0KvQ
01FxRpDk/4EdjPN/gNRhGSUaUFqWqjUDHQlxrVHMdIa2hPM/ct2w9tbxoqiP
MsRupNS/VCymamJCV8sA82WoPiTBkvvXRnp9GHyHHEM7e3dhmAxdGxVjQmtD
/U9LvCjfI9gU8bKZkkdZplksWu4Tf0/NVHpVOHNkX+ahyImKVzEOYnIR1wo+
lPpEiAcGR/Znjuw/jPImqXjROIlBhR4ZKvVvjJql0A5HuFixNuJ0mZEQU4u5
pet6q9HMkdAjm3ZNklhk+AOsBkZCHKrULNLchOeI3XsNkBw9g5Hw+W7WvLVw
L/wO5pvIfkdcq9RhZb4Dn6GnCXwUIhw5y8L06JuBWkLwb7nuOVHWNzV7ukXH
xfpCj5yoxxHWZh+Bv9FfJEfn3uLe8OwAdZQMjRLzxDML0SO1Xoxx8L2CuFa8
x+jbgR6Rotnyv4OX4SPo0eiXEhyebKl9i/e4uo+RZxJGXSf4yJ+/Q3pILaKZ
lnHg967dlB6J1zFOpHDkcN7vSn9PkLzhIhrUawQtavkU/dT4lxrx5Dc2v1Bm
gwPMk+9cct2xZnrkM/rPtf88q+7yO5frOYMjs/isuk7yJa++GvZ+PbXVzJJg
/w10z73p9MXeXbTn4NdSJ2fPgRO0m22PYfutfhe2PHHG2Nc6+WVypGl/A440
8sNw7kZe44aNm+Sc6usXyGfoeIkPOs0sLFk9T57pLF41T1aj6VSKETwXTce/
0jkc+Sr4v93NI4BcXN3o5Zdfow0bNko9FOSnmUx55Rq0c8RdHzx4iD79bCc9
8+wL1K1bT8k3q27/lu/hpGqeiZyfxn6mOO0qWXJMJW29MksGWu/hCWL+gRGi
Uy5dupx2fPoZHTp0SHKUz1WnvOC41nMwpUeeoENHvtd9PxZLbNZVV72tc5Vq
+5z4Nl8bPPkGtWzpx0wwmc/Qqh4n+nF07zmQgscnCx9CPwMzKj1ytPTew7ka
fAedLpDXVPXymCL9AaFXIQctU7QyremJXuUj2lm55pPK7/cQdjTqraJuDXLd
UENTarOkqlqiyP0bjLjWAlX3E5wCnhGOtBpH1SJtQxOis2R85NRBFwNHgrVU
vGipcBP0yHGhiZZYV8R5CgN7B8trKVp/G83fq3YWjlQ5dajDAj5EH8kMrelF
xeUxZzhInR7FYiXys+j5gbhW+A1amdQNZeZD/8tMrSeCgbHH0YskVY8Tr+sG
IaYWczPq5ETHZjJHBokeCY5MSles7eoRKLWDhJHSFDfBj1jLdOZIw0f47DZj
H02MVxon1jdKOFLpkTkFKicWawG+gy5t1Ng1tGEv5ki8lqw1vdH8mcT6gn/V
+hYLRw4Y5KQ5cqZojNA4+2o9EvG3olHyujiIHukmvSKFI3mezrzXOnbqIZpt
su4zg+8Q1NnBPIwYY3Cu/XBvyX804oEjY7JF4wwJSxbeNdbXxT2Q3D3Gqr2l
NWh8f0CPNLRdXAcx3V2hR2LP5Kh4b2jciGvFHPB++AjvR+/JofZuVJzzGC3r
u4Z+vramPPk7Zdjsphts3tV9Ni4nWyr52UZcq9Im35HvpCvD3tFzfkE4Evmo
yJeERgmerJ/2Hp/JsWbr6J570pQeefBr1btjv2JGS6zqAavfa2B18svkSNPq
MUdCswE74fy5c9deevqZ5yXvsPOjveT5ZtVW3Vm8al2nSn2yurN4ZW0yqOoY
V0t8YOU41zNpOvoc7mt1Dsf/8TDURgkcM45efe11+mLnbslFM5ny8jfj+Qf0
ONSq2bbtQ8nNjYiKP8P+rbSPa6ixn2n/nv5M5HRdsuo9bM2TE09nSatnIf7W
HKn38CjDeA+PcPGiyMhoeufdlbR33wE6duy4hSnP5se60CP3a6vq36BHfnn0
O9qyfSu1bq048qLoka18RY9MyVB1P8dHIq51gEXLwfkd2lWbto/w2d5fx2yW
8Lk8XzRsfB8ZnAH9xmAx6DiG5iN65IhRUm/U0N9CI1KFz6B7GTmTUbE5kjPu
Hxit41JLRecDdyE/EnVDDRYDz4AZEctoxFyK1vaw0iMxPrQ25BhC6wI3pUld
18lqHOYefAereFHFYh7Mpp7I7UQfQWh6CcxI0COZdzF3iXXl+8E1Ea86YWK2
ZrFJEisr+ZHMh7nMYngN9w4tsm+/YaK14X7wmpv7WOmzKbyaPtVS7wV6InJI
4SP0pECtVNEjeW5gQamJE5NJA+xVfmQa7j1N1Vsd6a71SGjDaarHBj4vKq51
uu75WSSf1YeatxFtEPV8wGzI/UM9Xh+/cInZjNdrAb7DPkjXMbVgceSqevuF
qvXVLCZ6JK8vGNJa0xsweIQaJ9vwUZ7wt4//BM2rStce7uQlrI86SugdiXm6
8F5DXGuWEVPL4+D7ArkZ4EjVz5LHGZ8s/Wdi5TVV1xU9UBUDJyutW/c2gZ4O
LThLP/cAW+IZKvJQsI+MPEqwKfIj8R7sTfQUieC1xnMC0d/zZ+u84ULq2Wcw
2Q1zl/pGYNiUqCn0XNtX6adGNcufPME8mWCzk3lyRS3FpNZuXOuVrkfa2GTw
n9eQqlu2Sniyftoq/k5fyfe5lprek0o79+q4Vq1HWtvuCnrk2a1OfpkcaVo9
4khDp8D58tixY5IruPydd2lidJzUtsP/RWezs53Fa6zrnEmfrKmmU0nXORNL
nu0cjufTOFv4+AZTQOAYWrbsHdq1a7fU7kQdWLM+z+VjBjueOvU1HTj4Jb27
YiUNHjyUnF19a7SHQyrv4dNYshY09hrn/MbUOOe3oiZ5+vMQ2b/aSkqm0po1
6+irrw6LRosaWdXt4QvqH1mJGatjR4vpuNYvj6o6O61bL+LzwApdZ6euOdKP
OaGEmWCanMURs9mtx0AK4fUG5+BMjx6PiGuFRoS8NjAB2AU1NrF+xlkdeXxu
XkqPBHtY4it5HR2cRsnfDc4IY0YCn0XG5AojxUvsYLYwAdbZqJOJOjzoATHY
bqTqU5E2WcXPMs+AGcEoRo977MuHmreWGq2GjoRcN7thbsIzRm4mct0ceT7j
QhJ1nwrFGZg34mWNPEpoepiLnYOnsIyqx1Mo1+zb34EiorJkHOij0PREj0S9
V3Akswfm2YcZsk9/OxXrKnGcKk8PtWEzxEeqhwq0Q/TZgMan+oOoGp/2jh7i
a5V3CL7LINthSo9MzVI9IcFn6MmC9xu9PMCe+H7HMwG811gLsPNDzVoLnytG
KpKYTaVHhqucWOhvMTnCYsFhycJYSZpXwWHofZmeozVK6J78OXTgn03RHIlx
kFdpO2iEGidrhkX3RC/NUbr/JHRcXBMatJ29W3l9YJ6TRY/EMwr4iMfBXnu4
RTvlj2zFwPi+EtbmMVN1XVfoxIiPlrnr9cU8sI/c2PeZumcIGNYvYAJz5EC9
j9SzEPi9S7d+EgstvAqdnq+J5wSBQUp/N+K9e/UeLHqkaNCpJYpXeYwgr3ha
MWAD/fKPX8+JJ6+zeeci6I3nokc+zd8ZK+vke6ju6s0u03MGR+awof7MSm2r
6qkhDwLPItbQ3U1TaBfiWvd/LXGpezU/7jVsfzV/rsbq5JfJkabVA47EuRss
hPPkkaPH6fX/vkne3qNo0BBHyQ06zc7pLF4DXaeGZ/FqNZ0ansPPrOnU/ByO
vmiwR7v0oMioicIpR44cFaY0egBe6jX9uxl8Dt+j5tO+ffvpxRf/Tcmp2VXv
3/PdwzXW2BPOoLFX8SzkHOpHnTnn9/RnIb5Wz0Iqs6Ts41FjKC0tgzZu2ky7
d++ukilrS4/cX0mLrM72MkceAkd+uJXatLm4ca0Z2ZP4rK4YCXVpLHokswKY
YKLokY+SM/rcC0cW82t5fH72kHVLz52pGYlZzFP16MO53Dj/B0CvYs7A3w3t
EHltw5hDoXsZ/SOgIyHXzT9woqoBk6JqwIC7Bg911Yyk8tLAqw893FbO+UYc
p6FHouZsuj7/IzYU53zM16j7qeIefWgs71FLvChzhrswcLCwocEZiiM9hDGU
LsYcGZGq9chMyzhShwV6JDiSGQmvGXokWNKIdZU8Pb4f5KVn8HuTNEeibihq
yEITM+I4EVMqtYiYTVKlligYOIMGaI5MyZwu/hAfMSNBjzTqC4G1/AKi5JlA
WuZ0CyPhc4kcUrwHfImxEbPZtn0X8vYLs+TERgjT+2g9UsWLwkeIMfbiz5Bi
S6Xp+fM4WF/otYZ2CC0Vca1Repw40T1zxR+jdP9J0Sh5nvbMkdCMswt1fWCe
J3ppdujUXWvdqh4Pvge69bAVfjRijDE/xP6KHpmlYqbBkfbMkXj2ZfT8jOZ5
oHYPcm1V/Vj17AD/5yE/Ml2vBdZH6ZF95fmJ4SNo3La2DjRmXKzMCc8OoM8i
JnYoetJofVVpw4HyDBbXzIqbSe90X0u/XvNbjXjysM2vFGnzGfOkoQteCntL
Mxf62D6jOQXzeecKseV6zuDIXDbUn1mhbWU9NdU3E8zctGky7bLU2VH5j3ut
NUZrLfLAcVOPNM3kyHMwo9YIdJsTJ07QunXrKSe3QP7fqJlVdT5PqfKcXt1Z
/LS8sxrGu1ZmySprl5yXpnMe53A21JPwHR1G0dExtHXrVjp+/IT0okc+3qVe
5/psRr1gxBgfPnyE1q3fQK6uI/lsFnoB+9jq9eo09jPpkzXS2GuS8xtznjm/
lZ+FaG3d39DVw5Vh//qF6T0cyuf2UXR94xsoOyeHPvzoI6kvhWdL4PML4ciD
zIWGHbD6/Uxm6JFbLXGtiNGCLrD0As+EVdlSzZP/pZat0PePOTKtTM7Q4cKR
A/UZfJacz8Ecrds+QiNGqnqgOL/jNeiRAeBInd8I7gJDunsGScyloVepuEdv
xZHp5bGDdlqPVP0W1PkfeiT4R9WAKZFeINCRBtm5WmraIK4RPAAeAoMa42Av
4jXRI7XWBl1syDB34RkjNzNC589hTxo97nE/YGDokenZ5bGuYFrUewWrqjjO
QonZ7NvfnsZHZWm9CiyWI7VIVd8Q5sjEYvlZ5Eb2BkcWzNecUUAj3ZQeKeyi
GQn7FzmbGCNZ1yzCZw8+Amup2qhg4HRLXKviyBKJDUbMJmqmGj02wDOGHon3
Gj7CZxB1dlBrSDFSoeLIdo+SD38ukBOL9Y2IzhadMCgsWcUDpyoWg57nCT1S
Xpsi94NaNQ6S/1qmubhQvktshSNzhWPhI6VH2qv+k8yRcTrWFfVWUY9XxdRO
kvc7u/pRx47dyuOOeW/hO6DTIz3l33FP2Ef4blK1iArK15eZD2yK7yIjZhr7
CPm9eCahenkoLsZ3BOJa0/RaYM3hd+iRyu+KI/HMQOmRMYojEe+dkC9xragB
laNjmQ3d08dvgiUfF+NEjc6mqdfPoh9szoUnP79E+qS1Hnmlc2Qm/V04UuWG
MkfenUQ79+5kRjwlPSH3HjhuZWDK46YeadplY1cKRxo5Y+g1t3btWgoNDSM3
dz85Y1RlNT+PV3M+rypO8HzP4lXmTJ5BlzyXOq41PYdbc6TVORwsqSxEemLG
xsbRypWrzquuiWk128Oo+7R06VLy8vKWHNbq9vD57+M60thPY8nTc36rrON6
tpzfCrq6fhZSRb5vVdp6+f4NlXjEMePG06RJJVLPtrb0SGuWPJPtZ478ijly
myWu9eLokS1a+vEZehKf1afKWRy5f2APrB80J7AHzvpt2nWW/EjFkcxNzAfI
acM6GT0DRYvxGCtaYXrW9HJNL1Drkfz3ZJ1HCa0NGhR4xdCWcP53ED0yUuU3
Il6UOVPiWocqjozXOXWIr4T2iFqkUo+HXwvSuX/oy2HoSKiZAj0yKjZf5x0W
67hHH9mLaTqmFiyGnhAeMvcZ5SzG35FgOXCYkXeIz0mffuDIzHK9KiZHapF6
SF/IOfIafrZvPzv+WTsV64pYSMQ98v1Aj8R7kzR/Gxwp42gWw+dNOJI5BPmr
yNOLjE63xLWiNhL0VfAZ4lpRMzUzp1zH9bNwZJmKS+Vx8LkDR0IbhD6L9YXf
24keqfpCKm5SLBYcmqTzDhWLIQ8T3/dpRs0i0T0jVFwrGNjiI+bIgU4yN4P5
ECsLPdIYx3geAQ0aca3CkRIvWmDRI1WdWtV7En1Im7doJ+9JzSyzxDJDs0Wf
SiNmGswHNsX3k+SVJqu5OzNru/L+zLD4KJ98+f846JFqLVTsLt73aNe+8mfE
6sJH0jN0gAN/F6nnJuB8/LvSI90s8cASY2xwZFa5Xgy/39bkfmpiM4UKbA4y
T/55Djz5GTW6qPqktR75tP7zMrr0eZs1tWV6zs+xpbGtpvIaPCvqqal+J2Bm
0SP3VZcfedzq95pZnfwyOdK0K5AjUTcnIjKSz0OdyMU9QOJuxM5wDj9Xq/FZ
/Bzq8dToHH6ePUHKz+GVNEnrXMmzaJLW53D8f4xaoLm5ucLsJkfWnkGD/Oqr
r8jFxYU6duoqZ86627/n9kzkNH29Jnv4QnJ+q4zTLt/D1jHaFfawZR+XPwsp
fx4SInt40BBnanzDjbWiR1ZkyZPaqu79IXrkke9omyWu9eLokQ+3RN+/Yq0t
5UvuX/eetrxuSaKnQG8CC4geyWd7nJdxfkc8KjgQ6yEspvsQIu4R/RHBHuW6
WJRoW+AOQxdTWpsbs0WWnNXBpjj/2w/3En1L8g4RC8nsgXjEwUNHig5kcAZ0
JTBjmhHbyfNEvmOzZm3kzA8dKUbzKmoTY24GZxh61ZiQOEtMLe5xpMw9yDJ3
cAb2FXhZ5p6ufITPCngo3BgnAZpeFvWDHsl8aHAkfIfcyN59FUeCYfEa/v/x
9A6y6Hy4H3znDh/hK/GnUrNIx+milhEYSPU7ZH9MTCNbu3HCkcmZRpxujlwT
PTozdJ1acDGu2b3HAGFQI44Tn7uHmrUSPk8VRiqQ3L+27R8lL/5cQM804jix
FvgsG3mH0BYRk4saQWlG3R+wGH/Whjv6SEyroenhO8N2kKPMDfwuvBqdLUyN
z54ap1hq54IDh9qPVDpukvIRate279hdtGHoxfA79lrL1h1F34M/sL74flE1
bQt0bmax8D00Svxbmq7rivV1HhkgHJyhY6bhI+RqQn+HLxLT1P2gx6bokXrP
GDp9/wH28p2EvYl8TKxLT/4/D/sLc0e8Le7HRce1qucrqofKWN5rTW5/gD9z
+YT+kU343D/FZj/9bPNXjXjygM0vFGzzKfPkxdAnrfXIpzSnvH0Rxq0te1vP
+e/KkUm0e+9u2nfwG8WMB0/SXoudqGTHq3itotXJL5MjTbuCOBIxrI899hi1
79BJ4pFqZikV7XxZstqz+Onn8erjXa3yzs54Dj+/Oq5VaZIVzuH+VjV39Dnc
+wzncJyjEJPUrFlzWrlypfj/Uu+BK93Aj88+9wKfszPOYQ+nnvezkjPpk+er
sVuz5Ln2BKkyTruK2lHWfSVrqklaPw/xHKX2L+zCOPKktlNWv1dvB7QeeUT6
R26iG2+cZ3V2q4vzG66p9chW6PtXpDgyLl/yCbv3sJWeGAZHIva0dZvOcrZH
PKLEQjJHQkPC2qRqFjNyGd08xgp7qLw0lacHzgDLGLUzsVegE4ItjNos6DkC
JvAbHWXJO0S8qItbIA2CHglGSlI1ftALsNnDrXXOo+IM7K1mWo9M1ToS9i96
hoAjknXNUkOvQi9AvB/XxD266dzOVN2/EfcDpsU8wRii6fH94HMAPsQ4hl4F
7hI9kvkQWpvScfOZm4ZSbzYjZ9LI00OvSqPuj+Qy8vct+jViDOhi4Dt8hux0
bxTUi41JBAOnUX/okV2YIzNUjw1ooWAk1Ew16sfiPaghg2cCqN2ToNcCnzOJ
a9V8h9hM+KNNuy7yXS45sTx3YXpHL94HSXKPxjWhtaG3Saql7k+efMZQ1wac
nWil6dkOdJT3GCyGtUbtWnz+EFsqGiU4kscZMsxNenwY9YHRS7NDp26KxfQz
itHCkR3kz6rnZ4HsUzvJIc0XPVTl+Kp9hO+bVB0zjft1dh0t+6bcR3kS796j
5yDZB4Z2CL936dZXmBC+A6PimojJDdD6uzxL4Z9FPdzBdq46HrhI6ee8vsgB
lfWVnNZc8XuT2+/nz1wen/fBNW/K5/Au5rVz58kddaxPWuuRVzJHomdJKpX3
LbmSepece68TVWNoNXNkIu3exxx54BuJW9134GQlq+q16q1OfpkcadoVwpGf
ffYZTZ+16BzP3hdgNTyLnz1W8PSzeGVNp8raJeep6VSODTwtV7Km53DNkaj7
ryyIppTNpI8++uiS74Ur0aDnIoY1amL8Rd/DZ4t3PZ9eIWfL+T2X2jsVc36r
6Yt6phrEFfZw5WchIRfGkV+eEkMdVvXnk2e1/QePC0e+v2YDXfePOfocVPd6
ZIuWvnyGLmbOKJUzNNa+W88Bcj7HORgsBE2pjeiRfnJexvkdOYaI58NapOo6
KoozxtBIYbFpFVgMnAGuVBql5shh7hJjitoy0JagI0JH8uWfhyZo1IBReqSr
xLoanAFeBTOmZpaPgz314EOtpL8jXsf5H3sU+WvgRCM3UxiJ54M9Z8TU4h5x
TdSBVXl2JcIR2EeGHmlwBvY/eChcOLJM7kc40taB+TBI9K7o+EJhxj59h4oJ
fycpDQucgf4o5XPPl30KDjTGgaaHNYDma8w9RnTCVOZIpUeiNhI4EnWDkPsH
DkVNHKPuD54FQo/Ee41x8Jl6UPTIHPE7fDme/SF6JH8GwFiiUUZlWvRIFQ+s
dU+3QHneYvhIND3hSC/RUQ0dF+/rP8hJ3oPx4SPEyio9MlyPUyj/jnFQq8aI
qYWPUXOoQ8fuFj3R4MiHW7TXXD1V+yhBNFvcR7Ku64RaUdhH8J/1+qIGLPps
Gr0nwXf4HgALVt5HXbr1sYyDa4ejZyj0yLExosXCR9gfSo90tcxdfMTj+PiO
t+RrYv3wnFfpkXlkY8WRhp0vTza0cJMZ11p9XOvfjCPvZo7cu4v2Hfxa4lLP
pjeaeqRpJkeebqiVMWfOHEpIzpN4FJMjLx1H4mweFh5NCxcuNHMmz8EQFxwe
Hk4Ojm5aVzQ58krhyANffS12en2d6uJaVZ2dr3SdnVatFupzAc5zS+vA3uJr
47z4OrVoMYo5oUhxZKziSOiRY7WWg3M1mBF6JDQinJeFm5jv0NNx9JhoHZda
bNGroOsZGpaRpwdtC+d0VdNGccYQezdhOkNbwvkfMY7Q5lKzy+tk4vw/aKiL
jnUtsuSgPdSsje6RoeqbgDMQjwh+k1qi8fnyXYpzPuJwjZqlile9ZI8ZMbW4
HzX3cZbzP+4Hewi8DD5ScZy5sr9RPycMHMnjQwvDfaA3Imq+Ko4skJ/t3U/F
tSodV9WaET1Sc6ThI+xP5JDKOFo7RByKoUcatUQjIlPI1m4sNWWOTEwv03PP
ktxV1KBFPqDBTcj9Q31TvNfgYvx/gbWEX+F3jA1/tGn3iOLI7Jkyd8NH+Lwm
Z5TpWkLZErPp6RNazkh8TXyuECcMLdVgMXzeoUfCrwaLwUd9+9vxOGFWHJkt
aw49MkNiXVU+LmJ023fopp9RGPpqpORO4GcM3RPfIyqHNM8SMw3ms2e2HMv/
pvIo1fqi3jBqqVq0bvYRPv89eg5QfU11rqlwZNe+moGnaI5MkzpKxnMT0el5
T/XoPVB60iiOLNS8GiA5oOKjJMXf+C5TemSu9PtTHHn6Z/Mu5p/ZNgfptxry
5C6bn8jf5iPmybdr8fsBc8NzLDzPutI5EnrkKqt/u9Q1gOqutpB6NvgeNW2a
QLv27aa9B75RtVoPnLwgq5NfJkeadplyJHLINm7cSMOHO/J5KKnas3JYNVY7
Z/Ez1Tk5y1n8THmTZ6q9U0Wu5LnVcK3mHF6jHLPTz+HWHKlq6Y/jM5In9ezZ
U2qYmDVdqzfEAW/ZsoWy88pkv+AcfHH3b+qZY7XP1HOyyrzJpNNZspraUdX2
A6lBvm+F2NZz7GVz+rOQC9QjD58SO3CYWbIGJnGtX56kIyd+pPWbNtPtTRDX
+q7Vua4u9Uj0ayhkJpgs+gzyCbt1HyBrgnMwcuJwBm/dVsW1Ih4RjANtaSif
n7EGKfqsDo3L1T1AdD05l+uegb5Sh8Wbz+mTyzUf3gfgM1zHqF+D8z96SuLn
y2vAZDJ3MUcOcdHxhEWWfomIz0zWHIlxsF9atGwvMYg4/xu8inM+ONKo+zM+
Kp0cmF0CeZ8ZMbVgMcwbdWCNPErcD5gWmqBi4BIZB9eErgbds5zFMqU3otE7
E2OD23r3HUq92IQz+H6itC6Gej7CwJq/sS9Rq8YYZ6LBSDw23pOk44EnMEca
eiRqI4FdkN84wnW0cKh1Lw98b+OZAN5r+AifJei4uF/lo1x51op6rdj/KpY5
X2l67CPknKboXh4RWhv24O95w0fQ2nw0R4KB47WPsL6ob4q4ZKyv4SP4rXwc
9TwCeiI0Y/C3+Ijfr/TIbhY9Ea/h8415QgPFPcHH2KeKtfMtPgLzDXPwFP9Z
1ndilujp2DfiI+HvHPke6N5roNyj8lGOzB1xrZGx5XMP42sirnW0cOQ08RH4
sDtzrdLKZymdPlppw7iuJR83uiJHKj3yjTN+Ru9jHjh3nvyYrqoVfbK+6ZF/
N46MV3GtB7+Reqv7Dp68IKuTXyZHmnYZcuSxY8fotf8s5f8zUBstVs691Z69
+f8E1JOo7jx+vlbjs3i1PHl6j4VqWbJyrlmN+4FEV6lLVn8OPz9NUumSQXKu
AkeO9AgUPWNscDS9+ebbdPz48UvObJebIQ67bNpMikuEjp525mcgdbCH61yf
PGvtqOr6gcSeoR/I6c9CztbLxlqTLN/H5c9CYBfCkYeYCw/p3MdDNTDRLQ+d
oGMnf6LVazbSNdfMpnKOfOsCzoM14chRfN4t4PNuiZyLsYZdmT2QO4hzMM7v
OIO3kvxIXzkv41yNuEfUF8G5Wp3VlbYEznCrxGJgeUOPNPLSsP7QM6FRGdoh
9rQdMwXWKcWoAcP/buiROP/HaM5AXRnU2UnRvRYxd+ydBx9syfs2zcJ32G84
5+PfVW5mvnCToUcqLbRQeFb0SP6uMvIoDU3PjnkXeW6iV/FreDbSu+8w/syk
i9aH+wG7ovaOu/TOnCGMAybp1Wco9e4zROdMFoiPoIshrjUlvczCSNiX0BOF
xbRGOY7XAKwNJjTySsdHJFN/rUcmGBwpPvKXuNhU3csDnIhrduvRX/gqLln5
CJ8dxP6Cd/A6xoY/lB4ZIvHEmLuFxaBHah0XPhKO9AnRdX9UvxOlR3qJXpug
eVVxpNIjMXdo3dA4wdXeVryKvYVnB9CMRaPUdZ0cnX2ofceuwmxx+hkFPt/N
H24r96E4Mk/W3NAjE3RdJ3wv2okeGS/PGYz1dWKOxL5JNWrs8tyUHjlQrbn2
Ed6Heq3gv0TtI3wXotcLeqGCbSXem9+PmNghduVzF22Y1xfXNWojYRw8w23S
ROVH2oge+QbVRBu8jxlosc2X9IfN/2rEkztsfiAPm+3MkxeiT9Y3PdKY/5V0
D+d+zyrGZBU1vSee9uzfTfsPfcMceIJ/P3lBVie/TI407TLjyGXLllHx5Jn8
fZ999rN3XVgtncXPFO961nP4efYDqUqTrOocXlVsoNTbqdQHxLpWibUmqWpY
KPMPnEBZ2fm0YsWKS85ul4P9+uuvEvfrP3ocn0fPwo8T6mgPW+3jutDYK+qS
1dSOqqYfSJVx2mfQJM/cy6Zm9YcvTI9UOuOhGuqRB7UeefjYD7Rl21Zq3nyB
Phu8pa0u4lpxpnqdHm6BOpuKI3HexVqBPcaIVjdVztUThCM7kZOzquMCnQ3a
EuqLwO8Giym9SvXoM/rRGywGbQt8ZOhiWPPBzEhgC+kfoTUfMAHWysg7xL/j
XA49MlU4skBpeswzDzVrLWPH6XHGBMfKa7gO2NTgmcF2LsJvRv1Y/DtiKdFT
Pjl9ioVXkfuH7ycjjxL348t7Bbl7xtxxHeTdKT2yfBzod32YM/B+6KZgS8yp
d98hwpKooyrcxNeELuauedXwEfbhcCdvK9b+f/beBMyuos77b51553nmfWbm
nf+AywiKQIAkAkJIQva909k6SSedTifpPZ3uTqc7a2cnGwHEBXQEcQFFcRxH
RxYVQQEBRZFFEcIiKEv2fd8gIFP/+vyq6txz7z333nO3dBJvP089HQ59T9Wp
qlO3PvX9LesNI+FDCgNLTNrrNUcuU0NKGgxHrrzZ6qtrJJYueqaLL8SYsU73
7jNUPutYm/eFeK3wG/F80Nxgxk9d2kPsVa+xtsymjwyLOb3YMT3rur+PaPvo
0qm27ebsgM8NHTZO2sH4Ol51eqTzveWe5CFFM14lNrVG54OJsWt1WjfMxvts
9MhrPW2YNUI0W/1vFz+WNYt5xFmIs5mmHvR09Eh/H1Xq957cKJwHOPtmPter
10DD7yu/YDlyhdEj9XwXW2bsvfX/J9Yr5xRo0MZ213BkZVWrzx93rXznnv2h
Tyhj1xrvH5mqdCl6IgOefCFDffJMirOzQuU3ZtmpUn5h43s/ps45p0O9vvEv
6q0t+yVnJCyZTcnLT4EjC+UU4Ehy6aFpLVu2TC1aslZslZLa/+Vr753BXjyt
mJgJWDLaRjBkXj6/ppNiHx6kSYbbh0d8zGJtWx1Hss+cNqNJ1dQ1qVWrVkm+
Scazs3nuZBeeefPmzerO7/xQ771Wi45+0s9A4ubvNSnPQzLNc5PK5zebfCCx
vr6pctkk1yRzw5FhC7wJR+If+fyG523ej4etf2S+OJLf90v+yBWrr9f73c/J
vhjehz3of/bB7KXhlG7drxSftVXCSOtFf8MW0XDkzV6sGfQq4UirYQln1M6R
mJzYcEa0w8Xy+da5a7z4NbL/10wgeuTqLwoTUA+MNHzkRNEoTfxYw6vYtUqO
DMszzJHzL7hE5iR61Vzr60asV57D2dQyz/GfIx+h0UINi0nb4Uh3z/lG00M3
RavqsNpSY8tiiZ3Du4JehW0njDRI7FpnCiOJjqvb2X9QsS4jPUYSvUrzDH6Y
4vNodVzmIBwIQ7o+Yv6XjDIxbYWb0AnblqlBo+DIZZqbbpK8isT7gZHGkMPR
8jd6MT56nAnAV66PGK8LLuwqXEW/Uw/90f2yq/RabeLn0PbZwmJTpP+WWR1X
mF5z5JTpswxbikZpND2nNzs/SubPEPwj56+z9awXO2D0SL4bRNNbZGxdGXNY
DP5eIHGd1omN7uVXXB3RuoVX54i/KQzot9MtGTtFbLJdLg/WptGWI53WTdvR
0xljEz/W9BHvep++w/WY3+TpuKzDPXsPtP1u+qjZ5nqp0d+V8D91w4fEMRox
qsxq0NdZpq/W32+zPX9NrtXrNerssz+u37lrfXat6b+7XYp+nZE++YGCHnma
PUM2euQi9cZbr6uNmw9IbNaNm/dmVfLyU+DIQulkjjxy5Ii65557VK/eV+v9
aIfsYxP7j8XvlVtt6ey9eOp8fQlsXPO2D0+g56SwDYzTJKc3+2LuRGxb/Zok
e032glOm1un9xDXqmWd+/zeVI4QzkLvvvketv+FLkkMvqf9jwBzL/xxOpLFH
5xIJZ6+d4iwkMB9IerF3os5CUuaySa1JZmXXatkwbBG7VqtH/vGFP6pu3b5p
9wYP2PJgjssDHkderDly+SrNkUs+J/tixqQ3euQsw1jtwpGrVbdPXSE5S9nr
s69Gf2PvX1M/39urt9mYOMRsdXvoNmtfif4HHwnPWBtU9EwYyGlLzCdybMCd
y1cbu1T4bOLkas2REywjXe/FlUFXczzDNcb/U5f1lPZyT8ertLPd40hjo4jW
xlxytq7wKvFRyFPvtV2zFnkh0COl7csMW7LWEjunZc5Kw0gLDIuRC4T8mdhi
io6r6+w3ED3ScKRoWPjpaZ6BN109zr4SH0PDkcZelDHAdph+dTk2Zs9ZqgaX
GLvWxctv8mKJTtAciQ8qjOS4ibioV/cZKs/t7FJNzNPLhG1gJOqmP/B/9Thy
odHfSsZUSP+R80TqEY6skfNB52vqND3Gd7HUY3iV8R1s9UjHYtJHui8qZzR5
vMr4w5EjR5V5WiifHzthurrs071lHji/Q97LcdaH1NkdM4bOh9SxJesRDFwv
HHmTdx5RqvudMfb3ERos8YmXWY6kvfT7Vb0GyliZebTO5HoZOlq+I+V8RXT6
NRKjRxh47S2e7S5MX6m/CyP+uGtkjTr7LKNHFn3gcXn3snmHuxT9Sn2/aLt6
PyRPPld0SJUW/UHzZJj7w7jY1WNfX9AjT4/i0yM1R76+8Q311paDkjPyrS37
sip5+SlwZKF0IkeSQ+LOb39ffw+sE05JZ//d6pVVCco1IUriz4XfiwfZuiba
hyeyDUygSQbtw5Pm5Uu8D89Gk6yc0Rxg2+qK4Uhi502ypallobr99m+Jj2Bn
M14+y3vvvad+9atfqaVLV6oFHev0PEkWPycRP2Yzf5N/PhN9PZG2HuT3mzx2
VII4xElYMkiTjOiSMRwZpEnG+fuanKjZ5Y/cn3bBD2XbTsOR3bvfocz5cj45
kj3VT9RFl5D37zq93/2s6DOzZi8R9qhv7JB9MPtq9vrdumuO1Ht7bEvRhpgv
6Hzsq729+rw1liPrfZyxRnSkMcKRN3oaJbYSxaJHrrb2otfKXMKOk5y1xu9w
vcxJ0SOLJ1qN0rKYvnZBl+5ePVxjzD99ZR/DXcs/5/EMvpXwrOMMp1cxf5wW
Cq+KTa5mYBML1Oz/mRewHHzkfBG5Z//Bo1Szfgcci/GuDtLXJleYWLX41tEO
OLLfgJHCGaJh6XuOn1Qla6AwrG07LAYHontKHy2kjxaKf2S7fR7R9OYs0RzZ
oM7tvUz/rWn7bN12tLaxmkONX6jRKJnPnAkQq9VxMRx5SbdP237/vPQL7y15
XVirYSxvLND0mjusvajpI/qdc0F/H+HvOGassVuWtlsWGzxsrPx/6jF9tNLT
I109nEdwdsCZgmNLPj9uwjTxj/Rr3TAfPqSmHqN78v6LD6m+l8R1RTvU6w1s
yZrhbKZpO3o6eqS/j/ieIhaR5FqxzIe9c8/eA6S/JD+n7iPWL/wja2S+32za
rv8WBi22NteOi+HIqTNmezFlucb369lnO44M7x+ZqnQv+k2GPBlWjzzdOXK5
ym/MslOl/NzarzyqOXKhemPT62rjtoMSBxxbl2xKXn4KHFkoJ5kjyRWBVnXX
XXepa6/7guy/09FuZru989w8lUT78KR+k2H34cvi9Zx09+GzYm1cE8RwtZpk
fPzWGB+zgH240ySjOTJek3S6pHCkLo4jyalWU9+qFnUsVz/4wQ86nffyUQ4c
OKDWrFmjJkycIjp6OjbYUQx4suZvKpZMy2cyRU6b5kjJNHZUxNd3foAmOTdQ
k0wUN+rk6pH7I3rkBjjS6JH5tWtl74F/5Ay9L16v97s3ipbCWPS+eojR6vTe
Gu5hbnTtfqUaN3GG3ut/2TCBnhfFms/oY+NDZmLN4BvGXt3liWyzLIb+x97f
+aVx/5GaQ7F1dH6HzBWYYobmzmXWXpRzFrQ27FrZ/xt7QuMPiC+kq4e2Mw/O
O/9imWvoSOz/WfeG630+dTp7UdGrxlTI2ufazvM4BnZ+lKLp6XUN3u2wbYcd
mI/wEPeReuYbewJygaBHCiOh46JXDSgWPdLZujr7yskVjR5n8DycXaBH0kaj
Ua6VuY3tL/+/Y7mJ+9miOXJQSb06p9dSfc3oq7QdRiIn5nIb94f3mnte3Wew
9K8bi2o9Xp+84BJpB9e5N+8ruUCmWr9HxpdrJcJii42O6zF9taznaJRO52PN
F715+We9swPeU/JkGI78nDxP85yVYuMr9YjvrTmPoB5Y33Ck0fnIR4keaeKl
Gq2b7xOek/u5PuK9J38M3O3Gl/WG3KRuDoudrm77uAlVMsYmTq3pI76fYEGT
s9OMOf2OHsn4cU/aI7leBo+W/oP/RafXz05eFfHdFR33WnkexrdSM6/Lpck1
vlPP8uxa4cjs9MjY0r3oiYx4MrkeCUd+18dhnc1K4ZnKtBmOXKZMPNN8raWn
SnnQnjv+UnPkfPXmxtfVpm2H1MbNe9SmLXuzKnn5KXBkoZxkjnzzzTdVZeU0
1dLaofezK0JrN7PzufcO3I/nfh8er+fE7sMTcGSqXAqN8b6SQfvw6jjbwFTx
W1viYrcm85P0OHJKnew/x+n9w4iRY1VFRYVw15mUb3LBwkVqzNjJarrup/TO
QHwaYl7nb67mcJC/ZOb5bIL9fRd65yHhNMmAuFFxuWxac8KRW3fsS6tsIU/I
tj1qx278I/9o80dyrp5vu9afqosuJkao5siOz4huQr/30uxB36K1sa9m/Lta
PRLbUriJuTBCs12EI9d7epVjMZebkP5E/0OrMvno18i4FQtHXuP5HTJHsCFl
PAxHXitzbLxmh2HFE9Qyy5GwCZrPhRd28/JRUo/4/nXpJrlLDCMZXqWdfMZw
xjpPr2K+OJtavj+k7eX1URolbUcrIx+FyXG5WuYhbMi67Oph3uO7Vy6+oV80
Oq5uUz/Nkf0GFgt/O/0N+2DRI319xHo5Zlyl2M46e1FhpNGThP9cH7W0LlaD
R9arj/Vepv/W5KlwfTS2tNJypOEm7smZAJ91tru8B/QR7eA6/UJ/dLv0SlVR
OUs+z/jKWOg+mjlrsZfLg3vS75wJun5nzhBbjfiopp4bPBYjnyb/37CY7SPN
kSZOz83eeQR6IhzpNEqe13BkLxPr1fbR9KpWdVXPAfI3Ln4N+qpotvpezqaW
NQa2ZOydfTPnEaUTZqgJmiNdbCTq5vsJPZK/c7F88WXsCUfOW+1xpOR6GTLK
m+9Gp19lOdL47jrbXcZ3qu57vz8unzs7jxzp58l7i3aq/w3BkpTfFR1QxUXP
xNzHz5Gnsx6JfyR6ZD59BE6VwprOuD0iHPnGxjfUxq0HJW/Hxi37sip5+Slw
ZKGcRI7885//rL7whZvVsOHjZD+ZTvyck8qQud6Hz0nhYxYqv3vYvJLxHBmk
SabKKRmtScbmk4xw5BS/bWtFvRT2nnAk+xT2bUOHj1E33PAZtXPnzk7nv2wK
sXT27N2n7rjzBxKntkb3ZdgzEG8On6z5m2wOJ/T5DRd7J/4sJHxeyVQxiBPl
Ra1JFIM4hCZ5MvVIONLpkS+8+Ed16aV3KOPvkm+O/Im6+BLy/l2r97smfyN2
jL37DJE+ZR8MezDu3bp/WuKJYlvKvrrFciR96vbqzk+PuKeehqXnFDab2EjC
R0bnw19socQnaRGONH6Hsv/XTMA4YEsp3KTnEn5twpHOntDaDmLX6vbq1MOY
E2eHuUX+d4lvop/DcaTLE0k9ozRn1DUsiNjU6udxeer9+hvrGPFeFwoDW87Q
827AwBKZ147FmN8DB5fIWgYjiY6r/7bvgBHCkivF1nWdXCOnBbzp4sKIpqfX
SWIR0cZIH80XLVR4RrhJM/DsDjWouE70yIVL9ecXrhM/TRgJjvR03LZrZO3l
TIA2uj6q0uN1fpeu8m/T9tXyXuIfydpMH7fZsYDPYGanFwuvwpF6/fb8NdtX
ST2jxlZE2j53tcyfQUPHSD1clz7Sa0J/zdR8F7h6uOfIMZMNi1mNks8Tt+dy
9EgX61XXw3sKAwub0h/6now5cZDm6r5ZaNmS9aRE37NOj5N/fLGJnTC5xsSP
tX1EW4hFRE4X6SNdD+sIvEo7TNuNTo/eLPPdciTrInbDI/DdXf1FmVtSj2Z6
2Nrz+9XXOI/19Mii3Nm1JipXFj2peXJXWjw5RHjyTLNrXWav/cyWB87Q8jO9
pnM28bDmyHnqzU1vGD0STXHrvqxKXn4KHFkoJ4kjN27cqL73Xz/U6/1SOSPk
nDk8P8YzJN8LmZRTbx++NIkmGa/npMrvnlDPidMkw+WUJMZAZVWsJulsW30x
d6xtq6dLlhtNEtsj4jlMmlKt/vsHP1Tbtm3rdB7MtLz44otq8eKlNj5Nevk7
Ep2B5H8Opxl7J0TsqFRxo2LzooaOQRx0FpKDXDbZ6ZEH0ipbth+QWDs79xxV
zz73nDr33K/nee/zM2sz+1N10SXELblW8rgzJ+nn3po90HnYgzMfGOOu3a4Q
/z20NvbVjO9wzXZVtXM9X0Q+LzExJ9eZXIs+FsOOlNiihmdWy1gVl0yUuWS0
pTUyD/BFZA0Rv0PRsJaLLeOwEeNFB4qwWJUwBb53jjMY24u7XS5tc/t/5gXt
pM5F1qYWzsR+ljli/N8Mr0qeer0OubY7TQ/dFAY2nHGNzDdyeTTNXi75Abk3
/yb2zmTxDb1ZuInP9x0wXHPkCNHa4IxWsa+cLn6Yzl+T52GNHD2uUuw1RX+b
a/RVfFDRDsWmVviuQw0cqTmy5zJ97XMSo4vn5Z5jSqcKIxGjhzFj7WUs6Qs3
FpyhnH/hJcJ/XKdu+oO8LqzLfH7OPKO/YVNbr9830XFtH6F78neOz3jGCt12
xpf7OV5lfAcPHSvjImNBH+k1oJ/jSF0PHMg9GfMR1m653ep82MlednlvtXRF
xC6VeUEcJcbQ+DKulu+oYhuLSGym9T0lN6lm4LrGRVHjS4wezgpcnFr6iO8j
/IH5O2cjTL/36DVA2sE9+c2aNGjIKFk75HyF8dWf58wF313Xdmx30SMrdZ9E
/H5Xytrzb2efq9+5dTmJsxO2XFn027T0yceK9mmefEqdOXrkMvvf99vyszO0
3K/X9J/K859zbrt6a/MbavP2g5oD9+jvlr1Zlbz8FDiyUE4CRx48eFDdc9/P
1JLl14fefyfTH6P21fNSlGz34lnswxOxZKo8ILH78FA+ZmnoOYE+ZkH7cJ+P
mT+fpNMkY/NJRvtJGo4sE440pbFprvrZA78QG9fOZsJ0y8svv6xuufWruq9a
vZjCoTX0ZPM41fzNdh5nEjsqIUuuSDiHY3NKhuLIuLhRsTlR50uJzwMSGzcq
/jzEHzcqKz1yx/60ylZdNunv6937jqsnnnxWr623KmOLla/zc8eRP1FdLiFG
6Do1b6FZZ+nT3lcbjoQfGHPG8JKunxabc+LfwE2M5zC992df7TjS6FVVamJ5
bYQz0MWwe9ScgVblfPeEkUaWyXxxfoey/x81SdYOiQEj9pXLRWsbOnyCx5bG
vnKGuvDCrlE8wxjiU8e/3f6f5xgmHLnK891zvFqj2yD2opZXaTtnWYttPnrH
YrAcbZ9v7V/RUvsNGqnvsyyKxQZqjjQ2vTdJH9GOPv2Hi4/k8tXG1pX3Bp4R
Xo1hMWIRebyq7ymMZGPaEo+nFU2vZZEaBEf2WiaxkUwMmOWGI8dN9eL+MGas
u8KRui+c7e6MmnZ1wQVdvT7id6N+B7t37yE6I4zFGiGa3ujJ8h1hbGod08+Q
WGnEtDHju1LWdHNO8BmPV/kOIS6NNxbtpo+wBza8amymORsuHj1J/F+NRmn4
m2e5VHPkkpWf9+rh+6RHzwHSFqcN46/I5/ncQmtTy/rB+DJOEZva5RKHCNtl
4ztr+mjKtEbVu+9QyUnjbIRrZ85TV/XqL21mPKiHtQj/SHduwpi0WI4cNnKC
vBfia9q6QnJfTp3WHOWPy3tyluPIIjjyp3l6t4PLlUW/UQ8W7Q7FkoYn92ue
/LE6/TlyqTIa609tuf8MLT/Va/pP5NnPOXdOtB65zWqLsb9PQT3y7//+N4Xy
N1Y68sCR+MMR05J4JLUNrZE4JCm1mxQMGXbvnYu9eAj71tD78AQ+ZunpOYl8
zMLrOUE+Zon24UH5JGM5Mtq2tSHKtpW4iRM9lqzRe9wV6oEHH1YnTpzodDYM
W3bs2KH++4f36L3n6uhYOmlq6GmfgeR0DgfM47ZE2nqifCArUmuSqc5CQuSy
8Z+FROWTTJTLpjZ5Lpus9Mjt+9MqEmtn6161Y89R9fvn/qDOO8/pkSfDP7JS
74vX6v2uybsHl/fSe2PHWIwtY9e126dlH47dJPOCcUTno+/8/m9wBhzpaViW
xcjxR25Apy2xtgwvmWg4cvENyvlmYsdpONLYpTJHxk2cLnok+3/hjDbjg4Ye
6XweuQ9je94nL5L54xiJOSB6pG6zi53D3MJmk5wl2NRKHBX9PGhtnGE5X0Se
h3ULu1bDwMZGkfkFDzFnXT38e8DgEi/GEPXxt336D1P9+o/wdFzeEXRd1jxY
zMUxZV3EhxRedH3EfCWWEfFYF9g+mtW8UA0srhW71vmLb/RiwHBPYhmZPlor
Y0bbOROgjY6LiYV7vuZv/s098Rukv9AjWY/5vNPfYHrmg/NFNLyqObJipnCX
0/nQ9IhrA3PNs8zH+JJvkfubeq6Rd72/ZuopXj1Go4SVRwhH3mT7yORlwT/S
z3z4lRNbiXsxHvxmzI3t7xovNqrJTTpJxsnZvzK+xDEaXwZHfs7rI76LsGs1
eURMPawZ2LX665HYSkNG6fneLvNDxlf/LZw+XGyub7I2wsslD2jF9Gaf3+9y
WW/OOvtD+p1bo4xd68nRI2NLn6LfaZ7ckwZP7tSfeVadvnF2lthn/4ktPz1D
y0/0mv5jefaPnTvb6pGHhQM3b7VxwbdmVvLyU+DIQskjRx46dEjdcccdqqKy
Vs5ok+2/43IYhGbINTnbiyfcjyfSdNLehye2DQz0MQvMJxnsYxak50Rz5Pxo
LSehnpNIk4y3bY3NJzk50La1VvZzZT6WbGqeq77zne90Oh+GKceOHVM/uud+
tWLVZ2Nismaho+d5Diebx5n4+yY6D4nPZRPiLCQw/nBADhA/R8Zp6olzogad
hZxMu1aK2LXuPqqee/6P6sILv6Eidq351SPJ+9GxbI3e764XLQUeFz1S9xv8
wDgyZuSKGDO+UhjJMMEyYTvWAef/xvgS03WisJjxRWyxLIYdKTqb4xnGA3ag
TpcD0eWUZM3osPaizAuYcejwUo8t+TwaJRzpYqs4zecCzUiN+jPCLtSjn4N2
MpdNXBijLZWMKpc2EPvH2HEuE40TBnZ5IoXF9LqF/a3Xdl0P8woeYo7CfS36
vebfxJDBpgL2cTru1f2wax0uehX2qaKLwZFTGjy/UMNijWrUuKnSF6aPDCON
GDlJ+ma+1d9mNS9QA0bUqY/1WqavYcdp+giNk1g3fv5mre3dZ5DJm+FYrHqO
Ov+CrmJrSV30Jf3hOJLPCzcJ00+S+WDsRbHdXSqxlohJ69jSsRhxi7y2w2L1
hiOFVzuMzTTvdf+BIyR35hI0PatRwnyw2BLRQg1/w9SXXd4zKo4R+UXIfUn7
TPyalTLm2B3TPuff2NC0SK6hRZvxNW3nHGT8pGovTi1rEM98dZ8hXj4anod1
QjhSt4N7Op1+4OBRMt9hUxlf/be99LsyXGyub/J0acaXmLQdjr/1NXTgs87+
f/qdW6U6Q4+MLX2KnkxLn4Q9+xQ9rTpfa0xXj1xi19H7bPnxGVru02v6vQpm
Psdy5Jbth8Tvnu+WqLJ1X/y1JCUvPwWOLJQ8cSS2rA8/8kvV0rpQr/FLE+6/
U+VASKzfrJHSZn/nnSfbM9iHx7FkPnzMMtFzgmOVxMXcCbJtjYrb2hRn2xod
u7XO0yQjumSN2NTNapqjHn/8ceG0zmbFoIKWTvnyl7+s94cr4nN65OQMZHXM
/M3dPM5UW08nhmt6OVFjNckEOVEbY21bFwRo6pYj6+NjD0edheSAI7dpLkyr
7Nyvtujv6z37j6vf/O5ZvbbeqiIcmU//SM2RF1uOnH+t+PjRd716D5K+gh8Y
O8ana7fL9T58qtgZMsaM09Di8fLuYzfp/N8klsmkWi/XonAGdo+jp4jOZvzs
Vkq8KeKTEHvFxbRkLGEKciYskr36KpkL3HPoiFLPnpA2sVcnpo6fZ1iT0CNZ
6xwjMe5D9T5f2GOR8W9kDuH7Vy3PaGKwNgqvYpNbp/f/n/F0PtYrYolK222s
V+YUeSFpG4zE8zA/ib1TJnaxpo+Y8336DpdYO44zmkUXq5S4sF4f6b8r1+sh
PoHCq7aPqoWRyuT7D5vaFvqjaYHRI3su1X8LIxntUPTIsSb3xhzLlqyxnAkY
jjS2ndOqWtUnz79E3k/qoi/pr65dP60mVdSLTS/18Y5RN/PB+CKuknkgvp0V
M722M+bYuRLbFU53OUPo24FDxsj9DYutkD7CP9LPq7STerBrxSa3de41Ni/L
FHXp5b0ieTd0PXyXXHhRd7mX9If+zfwjXhPPPN/quMwjrtXoNcDYpZr+IB4u
caBcfCGeh7b07ms023arufIdh39ki+XIZtHpF4n/K+sEzw7ns4b1unqQ0cpX
mrZLPXp8iX3r+ohrfM5w5GrVmXpkkD6JT2R6PPmUSl8f7Cw9crHt63ttue8M
LffqNf0exdp+7rktauOW19XmHYeFAyWW27b9kd9plrz8FDiyUPLAkeSHfO65
F9SqNTequNzsIbWbVAzZFlCy2osH7MlD2QZmpOmE2YcvicsDksrHLLyeExyr
JFjPmS0l2LbVz5ExfpJTom1bnS7pWLKiskHNX7BUvfDCBnX8+PFO58bYgg/n
vffeq6qqG6WvgjgyTB7IVGcgiedvFnN4XgYsmTB2VII57LfPDh1/OGRO1FRn
IQF5bJLlRM2KI3ceSKuYWDv71K69x9Qzv/+D+shHvqryGxvifhsL9seqy0XE
CF0tsUAZC/oLny/6Cv5gvWFNuaTrZRLHBa2NWCKMzTDNdtP1/tj5kLEWEdOV
mJjiizjPxAKFI9Ej8T8zOt8KVa37HXbg/vhMMmcYR3QkciawB5e4P3rcx06Y
poYOH+fZE/IZbFDRplxeRK6x9qCrmXuulznHWMOR3H+ezUfZIPVYjrRaKM+D
xsl642K4MCexncCPk/u5fPS828RgpW0RFuuQ3Ih8HhYTHVf3B7kJ8ZF0Oq7Y
oGrOKNPrnPC3tYVkDSTmKSzk+oh5iWYrbRdu0v0xa74aMMLYtc5bdIOwC23H
ZpPPGx3X8De+A716D7b5Fw0Xw5HEuXX9zvtIv8NsrNGGkUwfoYXyHhl7UaMn
YrPJWm36yOi40vbRRm9uszlDeL/QI+kbqUf/5r0l5hAc6mymaTucjg8rMWBZ
Z5psHtFLL+spmp7REw3TY+uKna/RPZfLO8uc4Zmdf6PLKcNc9sZXt504Rswb
dGCZr/oaz4Ie6fnO6nr4bruqZ3/b9vXSR6wtAy1HmvOVlTI/OHPhPMVp0NJH
+j2Zotvq+Jtr0z2OPDX0yNhCbJ10eZKYsJ2fNzE4l6LJGflfunQoY896jy33
nqHlHr2m361Y2885t1lz5Btqy45DEidnyzaTW8r7nWbJy0+BIwslxxyJP+SG
F19RX771m5H9ZwxHht5/B9r/BTNk4j35qbMPT8WRsT5msfvwVD5mQT6SwXrO
3Cg9J5VdYFTsVsuRaJLRsVsTxNspd5pkXZQmKXH5K+rV9TfcpP7ylzfUu+++
2+ns6GfIJ574rWqft8TLcRp8DpJs/iaew+nN3+w0ypzYtwbGIU6REzVQk0yd
EzUhR86M58i4s5CAfJIzsuRI4uZs3ZlG0X+/eftetWP3EfXCS8/bvB8/t/nA
8q1HEiNUz7t5Jl8C7zu2evQP/MD4MA7EQR1t7SYZQ8YCPqOvPP83tEOJiVkt
9p4Sr2W20cXwn5PcgFZbqrIcydjDd+KbKfv/MlkrFoq96EoZb+45ZHip1SiN
5kNMnEu6Xq4W2NyC3Iczq8uvuFrmnsQ3oR79HNjEci9nUyu8OmqSrGWe/5t+
HrQ21pkFS66PsJhuO+10bed5qh1H6rbBGTwP8xCfybLyGmEk6qZNffoOEx9J
OEN03NlLrR5Z52ll9DE+h6PHGs3W2VzCLDCWazvs0tA4T3Nkjdi1zl0EI62U
dX2sZqRR+vOuj3ge/BDRI9FhnUbJugx/0w5p+2z01QXqyqv6yVjiq9psx4K6
sQ11erEwvfh21pu4P9JHS4ULickjbbc2tYwvdqD0DXlIvD7qX+zZxTZbHZc4
RtiGikYpfWTyslx6WS/hWnNGsVTOI1w+Dud3KBw5qky+X11MG77HijX74//q
H1/OQcghI7GR7NkBZ5fk2PR8Z/XzVNW1qR5XDRCW556MBesJHDndznf+H/GJ
eur+dVq5sRFe4umRxqfV2FFPq55jOfIaXR6zbNPZMT7ji+HJvaFYkhiw5BYx
PNnZPpGJ9MhFyuh1P7Ll7jO0/Eiv6f+jmFfnao58a/ObEf/IbfuzKnn5KXBk
oeSYIx977DG1/vrPR/Fj7B48aUyQsPvv+TEl1xplHvbhiX3MAvKAtMTEvkzp
Y5aGnpMw5mV7oF1gxL412kcyEUcG27bWxWmSsCRl+fJr1NNPPy12pJ3NkGij
zz77nLr+M19KeA7inYWkpUEmYMgUczgrnkxqo51t7KgQOVFjbbRD5ESNOwuJ
y4c6LzAfalXMeUiuOFJ0xjRtW7dY/8gXXnxedet2uzp5euRUzQSM8RrpZ/qo
Z+9B0h/wA2NBv6NHjrZ6F+NF38NnvOfoXUZbMpwxoazG83lkDMXucXS52Gs6
5oPb0aC4v7MXNblAJun1oVk+LxqWHlv82uDIhVYrExYbN1V98vyLvb06bcf3
7xPnddHzYJGwqWhLuh54F2ZxPoJ1lpHIpej5v+nnGSv5BWuj2IN1CT2y3bVd
Pw9zhxisfAbOoB7qHDCoWNYp2EfmtH42ckr07Tfc8Leu2+hiU2VNM/Wskr9j
7SPm6dxF13paKPNQ9Ej9OcNNuj9mzvX0yPaF8N0KWcdhpBIbM9U9D2yK3aXL
LQIjsRZj+8u7x3hQN22/WDM5bUIjbbJjQd28P04v5r3DR5Y12vUR/T5pSoP4
m1KPi/XK98GgwaNtPdfK8/CeEnMIDl0o9azw7GeHjZhg+Fv6yMSKvfTynpGY
sroevjcuuLCb9K20Xf/G7oWx5G8cW/LejyiZKHPZP76cg8CRck/JcbNYngX9
fYGNkUs9zM0re/aXe7VLPUulHwYMKpH5ji0z/M1Y8q4wN13bG/Q9mZtowbwX
Ymer666satUc+S/KcOSpp0dGl/s1T/5B/a5o52nKk36OXKiMDvlDW/7nDC0/
1Gv6DxTMfO65TWrjljfV1h1HhAPJK7Vlm8kvlUnJy0+BIwslhxz53HPPqVWr
r1VVNbMTcmSi/XcYP8iEDJmCKTPei+dyHx7kK5lsHx5Kk4yPuRNKz0kUq6Qu
wC4wYdzWpqgcIEEc6WxbOa+flECTpAwaXKLWrl2vNmzY0KkM+de//lXdc889
au68xXb+uhJei8yYIUOci2Q6h5Pp6mnlA7E8GRx/OECTTDcnalC8qMb4s5C4
mFF1fj/J6LOQbDly+46DavvO9ApxW3ftOaY2vPiC6t79DtkPnQw98sKLKzUT
MIYmXip9A3vwPsMFsn5oToEz2IdjZ+iYYMgw7Fpbo/zssNkklonTsBoti8EF
kj/R8gx9TGwV/i37f2tTi45EjBL24GJz2bhI7jl42DjR7xyLwU3E1PG0Ml03
aw0+k8yHdstI1MM+H/3I+b8Jr+p6GHdn/8rziE3upFpzT8tNtJ38gHxW/Cj1
8zBX4CE+A8/wDOSYQI80Nr2fkT6i78gp0cdxpNVx4fGJk+uEXVz8GXwT8TGE
S+fMXeVph9TN50zeS90fM9tVf/TI3stU24L1YttJH422eiRc3WL5m/UUbZl7
ShwjXXfl9GbpI943xoM2ojl27X6FrLvokcJNsJiuu7Z+vtWLja0rWltZRZ2v
jxZL28nXKPUIiy2WfidPBuPaPt+MBd8v+IrCndTD/yM/Jbw6rHi80Sj1s5pY
scaudaGNlzSzuUPOHi+6+FLxMWU8WCMYc8kfo/+m3ca04ftqOHqkfsf944vd
Lz6wxnfWMCzP3KuP0WzdPKLtPTRHSh/pezI+nEOhR2IXLOcr+v/xt3DkUOHI
G63m2iHji7/r/EUuRo/myBmzNUd+WJl4raeuHmkKjEveoa+o4qJHNE8eSosn
uxf9Vp06HLnActZ/2/KDM7T8t17Ted67jX/k1rfU1p2H1WZsU9PMQxVb8vJT
4MhCyQFHYstKboSbv/QV/V28KrkWmSwXQrZ777T34iH25bnchyfwMYvNA5Jc
z0ngY5aGnpOKI8Pm//DHbpX8H7ZEbFvrPU0yKuaOX5O0PDm9qlF96T9uVZs3
b+40jnzyySdVy+w22RMnPQeJOQtJdQaS9jlIRnM4+VlIsthR4eMQx2rriXOi
JvSTDJETNeosxJ8P1c+RAZpkXD7UXHDkzgNq+670ytYd+EceVRteel5z5O3K
2LWeHD1yfgdjtEr6kvcZny+YGi5gveB6l0suFU0RrY3xoK8HDx+npun33Nh2
RnSx8WXVJg7KHMNivNdwQZvN/Wi0w1bJu8e/DRMs9WK4cs40r2O9zAnGEJvN
IZojxc7WshixSdEj/XqT40jOFKjL1WM4crm8B+z/YSPRI4WVrzVsqZ9H8guW
1RhfRMtiaHrYtfJeuRg9zA/sWuuFV9eKLSMs1n+A5khsejX7NFodF60LH0mn
4/J5eIZ1zeujZqOLlYwtF/51Po+GkYwPKfU3tuj+aGhTA4Ybu9a2+euFqWg7
GliJjZnaLGy5UNZSzgRgXcdIMDr9hk0m9+QabeecQGx69ecZX8NiE+U3eqLx
o1wovEpbGR/HSKzTxC1q9+rpkH4nLg3j6saCevr1H270zI7rrRa6UFgZ21DR
KOkjYsWWTFLdP9XDMJ/1reR7Ao5kDKU/4GL93TJcfEhXeHbHvN8wcHV9u7VL
Nf0xWjhyhvC7Y0vOKrFrdTldGmzbe/TsJ/eSPtL1cE/iKKF/yvmKbjt/Szye
wUPHCAMbXXqhnLegRwrDtq0QzqedZ531Mf3OrVWngx5p/Atv0+W7CiYrLnpW
8+TBUDz5ftH/qv8q2tGJPPlz2364ca79/Z+2fO8MLf+p13TG6oeiR27aojly
xyGxc/FyTNlcxenmpcrLT4EjCyVLjoQh9+zZq7717e+rhYuvjbMFTKZFJs+D
kCVDhrB5DaXzpIx/mcY+PIFtYGo9J6SPWVI9J3U+9+pkHBkQayeaI2dFcWS5
30fSp0vGaZKWI9mzzWyaq75x+53q8OHDMq9OFj9S12uvvaauWa33FE0LfVpk
fJ6P2JisJ20Op5jHSbkyD7GjUmuSCc5CUuZEjT4L8ceM8uewCbJtrU7gI5mV
Xeuug2rbznTKAYmlt3PPMWvXSt4P9MJ85c7+qdU671MXdqnQLMb6co30If3Q
s9cgsSuAC+hf+hAbQ95NbBwZC/p2iOZI7PVkry7akuEZcvTNs75qjA16VfHo
yTLnjD2hYT7OXhhPrgu76HFBR2JdgO/EX1PXjQY2ZNhYYUZTzyKJiYN/ZLvN
UdlgeZU4Lm6eil+abh96EXPM2aUyB7ClNKy8zuNVbDbRUp2fHft/8nPAOXOk
7UaTo2/69h8h/OZYjHybxCKdUFYlOTqomzYRC7RP36HC3zwPn4f3WMt4xmZr
28kah08gTO1sLtGwqJv2Od+92vo5okeeozlyDjF2W5fKOg0jjbS5VYzmulDW
z569B5r8K+IXulD6/bLLe0md9Dt2mMx//CP5fzx7o+2j4ZrzGRNjL7pMvhc4
J+C+2N86P0rW6JGjJwkv+pkePZJ70XfCq/RR/xHCnbST/yf2s3oeDBs+Xnwu
hS11H/E8Pa7q7+mJro8G63lAX3hcrL9X4Ej+xvTREpMvpbhMnqvd2r9SD3ot
+S/nd6z3dGnOJ9EjXb4S6uZ7i7ppC/ekj7jnANEjTR8xvny+r+ZidGyjURrN
dZTVI808MmcUfO+ddfZH1emmRxYV3aWMtmdiro4vek49V3Q4LZ7sUvSE6jyO
bFcm3s5dtnz3DC136TX9OwoN9txzZ6rNW99U23ceFg70/Ce2Z1by8lPgyELJ
giPxZ9u4caP6+tdv9/aVcf5kAVpk2vpN0v332jwx5cnYh4fQc0L6mKWj5ySK
VRJkFxgca6clhiOjNcl4H8n6+DwgniZZG8WS06ub1M033yz69snwlyS+z65d
u9RtX7tDzV+0Jm4OJ/PtzQ1Drs35HG4LmsMhtPXQczhELptZmeZEjcn/EZcP
NaFta3tczKic6JGaI9MpcCfnxLv2oEe+cJL0SH7/WF140VS9V18u/oO897D0
Vb0Gis4I07Au1Fm7R+LQsF92TIBGyPvt7dVFizF6pF8H4j0eOXqyzCdjH9kh
ftPYMjKGzDGxqdXjgF8bWo7Yi+KvqevhnvADTOE4A7bsclH3iFYme/Um/Tyf
Ev4z+3/DM+iRzC8XO8fkZZwoMTSdFsrzYD9LXoi51s+OOUTb8eOkjbSdeljX
4CH0NWEx/TzMKfRInn2e9JGZl736DBGORGtzOi48g/2s6yP+jjUOvuRddVqo
0dqMD6mJ16L7o65VDRherT7WS1+bR78vkbbDLtiWSh+huc40bUePdHlR4EjW
XXwM6W/uSV/SH5+6tIec4zkNmmtwfrV+Lqfz8S6Jb6dua/vCdR6vsjYXj+Kc
YG2k7Xp8sQNtlHpWyzX6CLtW/p52Oh0XDkSPFC20eYmMH/Pl8k/3tlq3mVvE
80E3pS0mv0eHfJ+YPKTLxdeU5+J95p58L/nHF72X/Jf+PuK7hFhELl8J9TA3
sWulLfRRgz1fGTioRNjenK8slvmB3fAIyS9qdFz6iHGcrL/LPHttfU048iw4
krwfjyqT8y/X50O5KjAueYdutYwCkz2oXDzUD+hieDKcvet7mie/VbRV8+Sv
VX7iswYVZ9c6T/1t6ZE/EI7ctO0t/b1ySG3ZsS+iQ2ZY8vJT4MhCyYIjt2zZ
ou745p16DzI6SmtLyJFJ99/p2gCuDSi503kSsWTn7cOT+5ilo+ck5chYH8mk
sXaCOXLK1CDb1kSaZDRHknPu45+4QN357W+r3bt355Uh8Yd844031PXXE49y
pY8hU+vpifJBJozHms95nAZHZjOHZweehQTkAQmZEzX6LMRq67OC7LOT27ZG
NPW5MWch2XPkjp0H0yrYwW7bvl/tFv/I51XXrt+we6F86pH8vk+zWIVmh+Vi
l0pf8c5i18pv5gT9SDxPtD/4B46st0wweOhYzQuzo+wWR1sfNL8OxLvLO8qc
cT6P2CcMHTFBxs7kju8wuQD1/p+4PGIv2mT8NbnnoKFjROMULdRqPudf2NXb
q1MP6wlsyb+5p7MnxLeSueRi50isWM1I6Iqihdr4QmNsXgjqnmX3/6w9/C33
QzuEHVjT0KHoF94N6mEe9R9YLJ/Hn9Cda8AZkldi8Q2ehkVOCzjS9RF/x5qG
nsg7F+HiZqmbddzEa9H9UTtb9R+hObLnMn0N373F0nZi9BQT68anJ9Lv+O+5
GKrUzVp73icvlr7lnvQlbe/a7Qo5p0OfZUzoI/Ii8v/mOL1YvzujxLez1vbR
UukDabse3zlz13htp9+JS8P7OVvGwtRDv5l6rpXnEftZ/Yxo23JGIX20UOZB
d822Jl7SUplbaMOcZ9AWk99jkdjpwtp8D7bYvJfMI+5ZVdNm2m7Hl34fN2Fa
RHPV6wHfIeRGcb6V1EPb0SNdH9F21oQBA0dKblNzvtIh/dmjJ3ato8VO19i/
mnpgcs9eWz8j33dn/ZvjyNNXj/SXD6SpT0Z4Mt/6pF+PnK7LDbpcZ8v1Z2i5
Tq/pPN+NmiNnqM1bN2mOtHpkmnmoYktefgocWSgZcuS+ffvUnXd+W38XNkb2
33Ni4pI4+85YLTJrG8DInrs9cB+ePVOG1iQzYsnUHBkUcyeVj1l4PSc45mWQ
njPdF2/Hz5HsHV28nTiOjPKRTK5JxsZvhSUpo0aPU7/4xUPq2LFjeePITZs2
qVu/cpvqcvGnpC9S6ukJYwpn6geZaO5mOYfnZ86SwfM3YA6nymUzO4ucqKnO
QgLyoQZypC3Z6ZGZ+UfuPXBcPfXM79U//uMtdj90EvTILlPU3AXEFl0u7zc2
fdhC8t4y5vQb/XVx18skNzz7esceg4QjW2TeyB66wfAMLNXmxSeZL+8qepXL
n8iYsAbAKYyZ7NWtvSh2nHAk8xGeYWzgyMFDxopOOFPsbA2L4QvZ5tObyLXw
SX2NfwsjST3Naohup2OPhqZFYjeBXsX6xPx2+pvRUqukbj+LDde8K21vNbGA
WMuwa4VDWqWehTJ/sKkdXzZD2unmHxxHrB30KrER1p/BBnSCXre8GC767/hv
YhG5PCDCxbaPmPcuX0l1bYvqN7xa4rW2SGykDok7y9ig4UkfNZvnYb3kTMDl
X6Fu1ljitdIW7kndzHt0PmmT5kPDTW2SF5HniujFc41v5+S6qD7icy6H4yxP
f2tS/QeN8urh+4R7EXPIcajTQsn5gWaMTmj6yMSKRSM1cYyMzscaT05K1hQX
35cxx8+WepttH4nvrR4zvovoT+YM9QhHjp8u/O58Hml7T9Fs13jMx5y5skc/
+Zy0Xc5X5ujnKZHcpnO885X5olviHylt53n0PdGF+Q5zZxRcm1KpOfKsj6jT
T4+EI6P1yNiCPllR9Lx6uehIWjz5CfETzacmia8n8XHnKOMn2W5/n4mlXa/p
PN98zZGVasvWLWLXil2qxH3LouTlp8CRhZIhR953332qvqFZzi4TapH++JYJ
dZzMGLI9oOSaJ3Om6STwlUycByScnhO7D4/kAMmtnjMjiiNnx3BkrI9kUC7J
+mhd0p8HpDyYI9n/rly5SmIA50uLvOee+/Q+anqMTXYwR8b59mblB7k2cB7n
lCnzZN+aWJMMdxaSKv5wQo5sjOfI+LOQufGaepYcuWP3wfSK+FPu1xz5tnr6
939Q//qvt6r865HGP/KCiyr0vprYosukT3hXYR90RsaW9513/aJLLhPOQcuh
T6vr2vSefoy813PEbtHs1eEZYpmYPbTRZ3hP4QzJDdhiWKxiut7/a3ZgnHh/
uOc0G3sHm0DmnPPXHD3G6JGwh9urwwPdP3Wll6uBelgn8PPjv5lX8AjnVeiR
cs36PBJjFr2K+ozdotHfRsGRmoGFLS03sc7AJC7fCPUQ87RPvxFi8ykspuuB
u8iNOE4/O+106yZ9iR6JXyl183li0mA/KyzWbHQ+/hv+aLV5QPgs+RKxqWWd
5r0RXq1uVv2GVamP9dTPI7GRNBfTdt3v5MRkTZB4SfoabWdNdPlXaoRnGkVb
Zn2nPxwXY8s83fZHndjuzhG7Y/rf6cXcU3w7J9VG9RFr7whdt8RQ8vS3WRKX
hjEUm2n9/vFekUuTmLY8O/WI7lk8XvRI5pbRuufLeQIc6ZiPdjI2XHc5RGut
vuo0W9HUabv1veUZpO0yj9qlf8lL02b7iPcef1ZhbXwrLfOhcaJHMi9cH02v
atXPM0q+u1rlfGWBjOWV+u94D6TtPI++J/GoiDsu/N1k7Gz5jotw5OmkR37H
/hsmezBp+aDw5B9D8+SJovfVbUWbNE8+lvLe6ZWf+35z78d9v8/U8phe0zmf
+K3myAVq87Y31fZdR8UuNZnWuL2gRxbKacKR+KydOHFCrVt3vf7OmhWz/06d
ay87G8A1CRky50yZh3148pySYfScBD5mKfSculg9J2HMyxQcWZ0pR8bokiE4
ktKv/2B1yy23qnfeeSfnHIn/5fd/cK/VgxP49vrPQWJ9e3PMkOHmb/pzONOz
kFDzONVZSIKcqIn9JAPOQlLlQ/X7SNbPjdPUq7LkyJ27DqVV4MjtOw6oPfuO
qxfFP/Lrsm/7wAfYa/5ERXgyV+Un+t78vlf0yLZ5ms2blko/GKYYIO8oZ1k1
tn+I18r5H/t6+pA+GjR0tPm7duNnRx8SKwaWcntowxk1kiu+xeYGpO+nTGuU
vI6GZ0zOPxd7h/deeGamsSfEnhYdivkpLIa2pPfq5P0gR4arh7VD7AR0+5hT
jmeGDB0nc8XFVhG9SrML9Rm7RaNRik3uhCrDlo7FdNv5W5dvhHrgDOwz+Tdr
MvVNtzFc8SGlnW6eoXURs1V03JlGx4X3iOczx2pl9DE6KJzu8oBIH01tFD1S
eEbyImperWoSjvz3XktV05yIzSVaW3HJZK+PeB7aTswkZ89L3fQtOq70O31U
P094GhtS7Dx4djMWrVI398FelPGFA0eJTW5NpI/0mOMTSvzbFhuLl+cRjhw0
SuqRnI66HtpJLk0+zxrjtFDmAXGUmFuidRPjR7M78VpNLKAOy/R1oovznps8
MfNMXhar2ZLTUc4j9LgyZnBkxC61TWI94Vc7R3xaDX+jH2PX2mrnEc9D2zmP
oB+9PqpqES7mXIL1jvGlTeiRnHGgm1I3trScE0wqb/DOKOg3NPazziLvxyp1
pumRseWDRb9IS580PLk5D/rkg6rzY9+erPIz66vwsObIuWrL9rfUjt1HDSum
8M1P5b+fl58CRxZKmhzpYlt+9vNfMfvGFHFJgm1aM82FELD/XmBLWnvxkHty
jyWD8ylkmg8kLz5m6eg5CWNexug5NcH5Pyo929aWOB/JSC7Jxqw58ooefdXi
xcvUq6++mlOG5CzkFw89olav/Wy0TXYCjkzrHCSH8zfcHE4xj9ONHZUqflSU
tp4sJ+qyeF09VpMM4Mi4OZyKIxtiOTL6LCR7jjyYZjmkOXK/2nfgbfXMs39Q
//zPt6iT5R954YXlejw1i89aIu8u8S/RsHg/GS/XJxdpjoR/mB/0Hdw0eMgY
sb1kfF2MHviOWKqzfToQWht6JP6FjmdgpKHDx8u4MOaMCWsD7IKWw7wRHUiv
H2htxP5kDhottF3a8snzL4qKg8La8YnzLpR/M6eqrf5GjB7mxyzLHjABnDJN
1xexWzT1jJO2R7iJNQU9UnI/Clu2yXqFHsmaJ/XUzRXuchxJO2V+6f9PX8KR
fv6GqdHB/PyNTyn80TxnZRQXDxMf0kXSduHVqlmq/zD8I/U70Yq96HzhQBjU
2Jau9vREWPUqXX+LjTNbVdcmPgLnnddFnpl7Ujefh88YN/pTNFfGYnipjLPR
QhfIv8W3c3J1pI/0nEEnLB45Sd7tmVbno9/xj3T1MBbkzMCulfkgvFo/X74n
iLEzeNgYWZeELevaRYeFbZ0uzViw7l/QpZu5Z8tSj4td3F+j486zvrfj5bn8
48ucEY60mit1o53D+iZuj6mHtsORwsC0Xdcj/p4DR8rYs5bBuoylcKSccayV
8eWenLeUldfLWij6tx4LYgSddfaHlLGz/KW8e7k/H8pVgXGxq2cdSp8j/TxZ
U7RB/aXoWFo8+e+iHeaCIf+WygPWxuQRzZHz1NZtb+rvlSPyvbJDs6S/bPf9
DlPy8lPgyEJJgyPZfx87dlx98Uu3qrkLrpF9Y8q4JAF78MxyIcTswRckKbnc
k6fQdNLLyxfsY5ZqHx7KxyyGI738H7Oy4MiEeSRTc2Ssj2QmHMkepap6lvrq
174hcy9X8VuPHDmivnHH96LPQcJqkb45kIkvZCBDhpy/4efw2qj5m43PbxhN
MigPSCBHhsqJGsyR/jkcFzPKzuGaPHDkjt2H0iwm98e+g28b/8j/e4vdG+Rf
j7ygS7ketw7dV4uFE+DCnr0GyrsJ97lzoYsu+pTEpWQOVAt7zFaDBo8RbY44
pvTtdNlDTxab0xbLllwTjtSc4fK0C/PpfTW5HhgPxlfsCfW6AD/wvjNPnA6E
LeWAwaMMe8hevU2YiTyIrb44KPDnhV26S/uYL4wn6wn+a8JiLSa3IJwBrxIz
hWfknqxRkqd+wnTrz2fisqK1wbvMR+EMXQ/rFBzJWicspuuplNg7xWI3STtd
PiTsRYm1w3tYYzU52o7+6PG3fh4YDh9SyQNi+Zv1jz7i+dBxYZdpMxpVv6FV
wpGNs3XbZ86Tuul3NEHRyqwmRx1wrMvPMaN2jnAkOi5MSn/wDNNmzFYXX3KZ
MDDvKm1nLIYOKxUGMjbChlfxwRyv11x/H9F26m62sWfd+MJdfI62C6/SR5oj
5dmph/MItGH9jPjaOv4W30zNlt2s3bJjWHTMS7p9WtXPXGjjJbXJmMParAF+
u1QYmPr84zuyxHAkc6bWsiXj3dOydr3lb84zr9Acyd+w3jAW9Af+kdjOsHbx
PIwlvDlwcInXdt4Lxpd+dgzLGYNw5FmOI89sPTK2/H2aPHm86K/q5qKNOeLJ
v5XyoM0J/EtPj9yZQI/c4fsdpuTlp8CRhZIGR6JFbt++Qy1d8RnZR0Q4MkGO
BF+uPf8ePBMbwNAMGXI/HtofLWoPnqPYO8lit6aj5wTGvUyt5yT0kQzYh3sc
WRPMkbGxdnLNkZS16z6r9u/fLz6NueDIJ554Ql173U3hOTJBbJ2s5nCYeZxi
/oa24Y5iyfS19TDzN3gOJ8uJmpojA/OhxtlnJ+DIuhzpkXsOpl2279qv9uw/
rl58+QXVtevXVf7zRxo98oILy/X4kNtjkbyn7MF79hwg+2X6n/eXd/bSS3vK
O8d4CTfpawOHjFYVlU0+27/ZoouNnTDN+JXNNOyBXgVnMI4e8+l3Gz7jc4wn
92Q9gAl4z5kTRgdqVqNGl0sOCWdnSz3ExOmqmcLFWzHaUpW6uu8wmSOO+Yjx
SVxZYTG0UJiAGJ+6HtiAeebYskT0yOmeTxz1oBvCnJJvxHITnAEPcX/q4jc6
LnokuUNmi47bJp/nGjawhi3nSn+MGFkmbTX8HeEZdCzmvusj1j14iudzcWYr
pzeo/ti19tRreMtyaftUzcMl+rPc1/SR0RMnTKyWMwHP3lMzDnFEL728l8x1
+l3ODvRYX9Gjn6y/TcLFbSbGj7BYq+0jc8+SUeXC1v4+giOHl0z08nPwPIwv
eiR/w3cMzyPxifoOl/ngtG6ukd8T1o/00WzpC3wPpY9El56jxo2fIb6IZizM
+Eo8XWv7K3apVi+WcwJ97yarhTK+6JHMG3dGgY0MNtj4RzZbzZXn4TsIPpS2
N9vzFT1nsGtFR2eNMuPboufbUH3PCrmn0y2dHukYlmvMQ6NHrlR/K3pkEE82
Fb2kNhW9nRZPni3c3dmcdqoXP0e2qy07Nqode44Zu9Xdh7IqeflJyJG/LZS/
sdLRvz0lR5KHAX+1tnnXRPbgIXIkJOTInDDkOluy34+3nwr78NZE+/DkPmah
9JwUMS+D9JwIRwbF2mnxfCQrpvs50ucj6ePIyRly5MzGNvXNb35Tvf3221nb
s3IWsnCR3k9UmT1zJucgURyZ9RwOMX8znse585dM6e+bgiNTz+ElgWchcflQ
k/hI+nNJ5oojd+nv3nQLdkZ79x1TL72y4aT6R56vObKljX5ZKPtqYrvAHryH
6Eju3b3o4stUMT5wetymCxM0q0GDR+t99Sxr+9fu7aHHjp/u+cShdWE7SPxN
ydkh3DTb6EjDTF4Jxs7ofMTemSB+ek1W54P5YFN87ZwORHucHim+lQ2GCVgn
iEVKTBTmhPCMvobWxTxosPVIjE/NGbCBsY9sl7WoxMZhETvbemMfOV63Hc5x
bRfOqJgp9pn0A2so9YhepZlxTOlUaecMa4uBfyI5HHkveB7Yw3DkDOGMGsti
aLhwjsuVwmdZ85xma9repvuj3nDkVUv13Df9XjGtWXRC+hjuEh9O3R50v6t6
DvDi9lAP6yZ9xN/wnsjZgX528n7Ag7yHMhZ6Hgy1mp6zIeWeokfq+zbZswPG
HFtgnsnlmOQzxEjrr7mLdwvGc30Ef5t6Vhi2RPccPs7EYdVrhBtfxgf/SI/5
4GK9rpP70txzkTAusWOZM3Cl+CJavZjPw/ZOl+YZmTP4wLLmyPPo/2/0yEHm
eRzz6e+dK67qK/VSD/Npivh7jpT3gueEa2lnj6sGeDFk0Xa5J/Xgywm/cw/m
1iThyH/V79wKdXrpkeHj7IQt/5AmTx7RPHlD0RuaJ3+ZszacecXZtRo9cqvV
I8WGNQ3tsfP1yM7nmkI5tTgSLejFF19UV/boJd9jEY5MkCOhPXGOhLA2gMn1
m3VJSq60yiBfyRywZKyPWWwekGT78AQ+Zkn1nJAxL4P0nOSxdiIcOTURR0Zp
kplxJDrApy69XO3cuTMrTZL4UPhaXnv9F6VfU3Jkwjwfq3PMkBnM39A23Llj
ydYUHBl7FhKfEzWZbeuSJPbZ4Xwko2MPu7OQ9iz1yEPpFc59dx3w9Mhu3b6m
TNzEH9vykxyXH1tGvUedf0G57n9ihphcDWht2PkJR+p+NbGxWlSXiy7Ve/NS
GS/eZ95Z4Uj93jZa+0jZq4+arMaWTvOxpdmrwzgu7ib3431Gj2TNECaoNjoQ
TMA7LTaXli3RwLApbBLGaZPPk7fjE+ddJNcc43DPT5zXRew8HSOxZpAzhLXL
+Kq1qvLKmeI/B0fORAvV94QT8I+EI8XO1rIluiHtZH4ZzmiWdQmOnCb1dEh7
6A/WHPQu2uRsMOA4OIX5L7qlbid9AUd6Wpm+Rr3EyXF5DeFv1jk0QeKX1ltu
qqist/6RS/S1pR7zleh+p0+MVtYu18T3r9dAEx/IanKskXAk/Y5mL+d5uh8u
uvhSNVozMG1ympxwpG4H4yZ+g9PM+KIn+vmb8R1eXOblmISlWLPR71w99AX1
wJFovrSTseAa9rNo2zDwdKtbDh02TnXrfoVlPjOPmFfokZwRGC5usfF0Tbwm
b3zFr3S8tI05LGcHuj+KNetiu+xprvraON3v9BFxhKvrTJ7HyTbuL/PK5cLk
nsxBxp7ndD7/6LjkDZXzFVhZfx6mpl0yj9DZ9RxGnzzr7P+nTj89MvccWeDJ
fHLkI4Yjd7yldu05Kt8raccPjyl5+SlwZKGE5EjsCh//1W88e8vYPXg6ufYy
sgGcH2b/ncV+fEH+9+Hh9JzYfXhYH7MlgTEvg/fh86WE48hIvJ24WDtVsT6S
s2Ji7STgyCnpcSSlprZVPf74r8S3MVMtcs/evWrFimt0Xy8NtMv2cp6m0NNT
c2RYO9Ycz9/AORw/fzOfw6sSnIUE5ERNkMcmMCdqc2z84WCO9M5CGhP5SM4L
0NSz48hdew6nVXbqwrnv3v1vqxdPsh6JXWtTKzFDTGxTtDY0NN49+pN3FM3x
sst7S74G+hpO411Fh+Fdjdj+zVIjNQvBROIT5/bqwpFlcj/6m3vyDsMprBNu
ry4xU0ZMED84+M7xDPka+g8cqeeB0YGE+TQP4Ctn4vYYm1i0wyuuNDoSY8wa
g7aJXStsRrxUo5UZv0Pu0yC65RypR/TI0kqZVybeyizRzmhng811yPPAGX36
DpM203bqoT/QI9G70BTlvExfxz+SAiMJB+rPk7sCDW+W+N61SdvHjqsU/z2J
sWN9RVnfhqLZ6udh7lZqpptSUSt6JBxZN2uxaLvSR5rv8C3lPWHdLdftGT+h
Suo2cXtMHFL645JLLpPxcnk86Y8emnc5Q2CM3FiQ05F/c036Xf9/2gifNrq2
V84SLXWEfiYXH6hCxrdOxoy/cXk86SM4UlhdtO4WuUb/EkeJd39atekjtG9i
ps2y84h2jh47VZWMqZB+c2cHrP+cCdTacyLuKePrzgmaOjy2HKHbTuxf10fU
PVY4cpDnB8k1xreH5ki+z1wfib+n5ki+i2baPmJ+cJ6AXas8j66HzxeXTJSx
c31E3ZMmOz1ypTJ2oveq3J8P5arAuNhKflnl0q41UfmHoofU3KI/qe1F76TF
k/8q7epse9JTpUTbtW7buVHt2ntMODDtc82YkpefAkcWSgiOZA/+1FNPq3nz
OwI5MlFckoQ2rTlkyLmhmTLk3jyP+/BUHJlqH57cxywLu8CEek4kB19QrJ1p
cRwZ8ZNMnvsjfY6cWFalKiunqzfffDOjeDtokW+9tUnPlzWGZxxHJrNpTcCQ
YedxZlp6jtgyE/vWlLr6qpSaZKqzkFDxh6POQjrifSTjYkYl4EhbsuHI3XsP
pVV27UWTPKD2HTgudq3dusGRxHE/GXrkZN2vc/W7SgzVmbJfJsYn7xx9x14Z
Vrik66dlb0+fV4huOVMNGjxKcj3S7+iJU4RnJgmLOZ84s1c3nOFik06xPIPO
B5/UzTTMR52wEP53Tufj/Yfv0PqcDkSb4FLyV8Cbwk2aceBP4nmiXUmOSr2u
sD7AkaxRsKTRygxn0LZ6q1u6esZonhP9rcawB1obepnkBrSxPGnn1ZofaDNz
SvgbvUq3EU6RPrLrWk/Lkawbhj0addsnCEc6/ubamHHTpH9NvhHD3zwPeiR9
ZnJuNqvyKTWiR/77VYtVbWOHx01omTyT6SPjnwhXw4f++ECsi/Qba7LkqLRr
brfuVwpTMW7Clvhm6rp5RnQ+00eGV0tt202/zxSdkJipLsYO92R8sWvlb2pk
LEwf4R8p86N5sdy7fKrlyEGj5D0X22qxbx4vcXaM/6nhM7Re9NAGnx8kz4NO
Lt9HDb55JOM7y9OlTR9NEs25sWWxZ588TreF+e5/nknl6JF95b9rbe4YPj9w
4Cj5DuKe7jsLvRkGZm1yuiXjKGchnFHUmLEweqTjyIIeGVT+UXjyldA8eaDo
XbW66C+WJztbD+zs4rNrPadNbd+xSe3ec1xige/afTirkpefAkcWSgiOPHbs
mHrkl7+2++8QHDk3XY4MG4skmh9jS0735qFYMst8ICl8zILzSQb4mKWj58xM
FvMyVs+J5OALirUTibcTzJFTEub+SJ8jXXn++Rczyie5ZcsWdee371Ktup8j
HLkiWksPpUWuCdDUU5yBpDgHycv8XRCrq8fbaWcaOyr0WUionKjBHOnN4aaO
+LOQgJhRCX0ks+XIPYfTLk6PfMmza2Xfln898pMXTNJ92Kbf0TaJBULBDpN3
jHedd5F386KLLlVDho2T/hbNRr+X2LXyWzQ5y3xw5Bi934cD3f59nOYMbDld
PBzuabQ2438nPmSwpcRMmSC2pLAL6wLv/UjhyBE+9pgpHHne+RcbhrXcNKGs
RmKR8jnuCaOwPuAfyZgaPdFoZUN1PdynzuqJrDGjhCOneuzBNdEj9XPXNizw
4gNhP4sOJfU0mHrw6e7fv1jyK9ImlxdX9Eh8FPX8rbC6Fn2BhmfabvoItiKm
rYuxI30ksWJL5UzO5DBBC61W/YdWq4/2xIYUHbdJ2olOiC7HeyB2w7rfxmsG
JhdoJD7QTLFJdT6k3LN8aoO0Cf/I0fbZhQPF7rhUnlE0OWurWmzj8fr5jP8m
PpLLN8I11mfitVKv5DCpnGn9Sod5fez4jHrQ+nif3fgy17pavdnp0mi9sL74
LNq4qvhq8tzuLHNKpZlHcCT/32mh0nbdR/J5qydyzdi1DvB8OLmGzyV2rV7b
YUvdn/jowsecSbm4cD2u6m/OOJqX2PnaYDhSjx3rD9o98wV/yYh/5OmkR35b
GV/Jn6mTlQvxHzXDzk+TJ9cU/Vnz5MMnrY2nXnH5Ix8p6JGFclqVZBz561//
Wq2/7nPe/jui5ayI2n/H5dqLytmeyKY1jAYZvQcPYsi8MGUo+9Y0dMl8+pi1
JObIIB/JUHqOL3dCUKydiJ9ks+ebE8WRSWK2ZsqRK1eu1iz5QlqapOSL/MUv
1GWXXSF9QD82B3FkWD19XhoMmUSHzM/89c3jOBvtXOUDCZMTNTFHBtq2xuax
SZcjRcOI19Srs+TIXVZjDFt2+/TIl/+0QV166cnSI+9V558/SfcXPmmt8n7x
nhG/kneLfplUUS9aiovnWSPsYTQ57Fr5bTQ5yzM2Jqbw2QzjswhnYMtp4m6a
GCy8q0Ot3SSMZ9iyVnQttDruaXimVnz/+vYfoeqbFlkOrJV7Xn5Fb5svUDOB
ZTFsKSUHSbVjy2rRI2fImmTqKbM+dfz/WquV8ewlo6cIq7DeiU2srgeOhGlc
PFpZgzQTYNeK7Sht53nQ7/pr1iUmEHOOe1MXNpNogo6/6SN8CdH+jD2vYRzs
WmFjF8uHa8SKFc1Wr6EmD4heF8urVD+rR1bX634X7a9O+sjZ3/I89CUcSX5D
+gOdz7S9Vl3+6d7yfJI3gz7SY9F/wEjhcf9YwPlwWU1DhPPRI2m74+8yO77D
xLbUxNgp48xPr8vos5wbUs8ke0ZB7Fr6mGd3fEa8JXwPYWDqY87wN8Te9TMs
/Dnc10dOcxXNtrZdbKTpo4lR4zvPY0s4kvbXz1rknSfQdjjf2VbLO6DHHY6k
jhnSdvMODBhcIvdmzsj3kvjJDpM5z+ddH2HXCt9iR21sq2t0fxT0yEz0ySVF
r6o9RScK+mQ6euTH29X2XZvU7n3HhQN37T2cVcnLT4EjCyUER86bN09yUkVz
ZGqb1tQcmT5DevvvhTEl52wZTtNJax+ewMcsNq97NvvwKD0nyi4wyLY1hF2g
jyNjY+2E5Ug5J5+aKGar2Q+F5UjKw4/8Ki2OPHTokOjps6wW5vT0II6M1SKT
c2RYDTKJlp7GHM50/qaKHZW2nXaInKjx+SRjc6KGPAuJ4cjAmFExHFmTQ47c
ve9weoXv6z0H1cHD76jnX3heffjDxEk8OXF2PnlBme4bYnbOlveJ9w09kneG
fmDfzPtIHBbiarIWuDMd7Pn47bQ/uAu9Cj+2WmvvORHmK50u9qrEMTF7df3u
ltWI/x1rAPt/c0/DkeQNIbYM7z/1oxPCH3U+9sBOFl3NMF+TrAfOZpO/Yd2h
beznh8CR9kxLuBh70REmT6XTm6SeMeXid8n8gD3oD+xaxS7Wxnrh7+CMqzU/
0FfSduHvBuEmOIVnh6W4LwyJzybrK4xDm9AjyWNYa/mb53YcyXystHw23uqR
rJnob2XlaKFVqv9wzZE9lohP6xTbRyNHlQvvCn9bG18Y66qr+tvcIKbtokee
d5H8N+sy/cZzoEeS94T3AmaCfWBYWNnfRyNtHKU6+Nv20VjLkcb31dTDfftp
pjf1mLGg7/GPxLaUPnbziGeE/9GgGfNJ1qa2a3dzhjfFcjFM3+Wi7nJPx/Sl
Vo8kVpKnJ4o98HgZE559sj07GKn7l5i4tfaMgnuiR/boNSBiB62fh/G8skdf
mavSR+W1cg3bW75jOHOaZMcXH87efYbIeuN0WPRINPVa20d8ZuKk01WP7DyO
dOWfMuTJfxIdtbP5rhM48lzNkTs36u+VY2rn7oP6u+VQViUvPwWOLJQUHLlp
0yb11a9/R/Z8wRzp0yGD7AEDbVoz23+3J9p/B5WsuTLIvjWTfXimek5AXvdU
PmZh9ZxEPpIxek40Rwb5SEZzJHtAF28nNmZrRJfMniNvv+M7auPGjaE58kc/
+pGqrpkZx5GeXXaqc5AUHJl6DifQ0rOcv+nO4Zz5S8adhVyT4Cwkg5yosT6S
TfE+kkEcyVlIbR44cs/eI+mVfUckZuvho++qp599Tv2f//Mlu2+7z5Yf57jc
Z7XOe9V556Pv4JPWLO+J0yPhL95f3rEysVEskffO8RnXBg0eI3ts3nkYwXEG
LGbYcqbwzFjRIyd4OSLdewv38N/TbT4K2IW/G6M5hbGAZ/g8fIMdKWMGG/BZ
tMful/bwYqNwTbSlXgO9HBPckzUBDnTrD9qd6J42T6VoZRWmnlGjpwjjGHvP
mfJZWGzQkLFR/nhwZJ++w+V8i/sKe6BHahaCIZhLZZaleEbYBYbmb+Bq4obC
kcYm1tj4jrW2v9Tt+kgYWH+e9dLk7KhTkyfPUAOGVauPXoXvXbvwDM9OPo7B
w8bKfDY6bJXE2enRs5/MZ+cbyd+ST4P/RivkuemP3lcPkfbhhyCcP8nEQaJ9
Tk+kTeSplLb7+kjOCYaPN/XotnPNcSTPIm3X9aBH9us/Qo9nucwPx2cwaL+B
xfJuyvPoz2J/eqUwsG8e6XphNrjUxSEqLZsh5xEmz+lsz1aFe3rjS7/rv0WP
NOMz39Nh0VbRI2vEbrhR2F048qp+8r3EPd07MHDwqMh7UV7rxXAizg7z1V8P
zOvmEZ8pm1yv/r9/+xf9zi1XhiPvycN7natyr2WT/1CnAkdmypP8HX//t8GT
0Ry5Y9cm/b1yXDiQc8psSl5+ChxZKCk4cv369aquodXjSM/eMmYP7s+1F5Yj
09Eg4xny2piSD7bMch+eCz0npI/ZrDT0nIQ+kgH7cI8jA2PtzI6L2ZqaI2N9
JOsitq0hOXJE8Wj15S9/ORRDknPy7nsfiJyDxHBktnp6RnM4al6mMYdDsuXc
oDkc2k47gzkckBM14VlICF9fv6Yelw/V48h421a/n6TzkcyaI/cdTqs4PXL/
wXfUiy9vUBdf9FVl9Mh8c+Q96rxPYm9KzM5G0arEP1KzGDFWeVe5RtyRy6/o
I3zI+yw8AkcOGSP7e8eWxHMtwQcNFoMt9TvLvtzZPfpjvUy0dq3oXawDwh6T
jB6J/SJ/y56cv4Xt0P8Yn4lWdxw9pkLsXTzbTFsP9rcuD4dZD6rUoKFjZM0x
8T31NeGMCXIv4SbWEVsP/OLYg7aXahYbrD/v/AtLpT/q1NV9hskaRF1wgjDS
gGLJvQHbUjfXrtbc0+vqwRIDxvEIWiq2v66PhGfGTRPbXxffc7xdt4YMKxW/
StNHmsUmV6kBw6vVR3p06GdqE/bGL5TcKLTT8HedjBsMDIs5v07aCR/id8h/
s+7KNd0mxpz2MeZmLSUOaqk8g2Flw+ScE9D2SB9VqVLd786PM8JNtaLPTpHx
bZLnmVxu7FphXj7veFM4Uv8t76CcMehCPZdfcbU5o5hiOJ/cnDwjHGfiKlV7
rO3yYIr2xz0118r4Ws6fIGcck2R86Hen98LA+DhWW/tkM761ojMyNyUOcJkZ
c3w43XvhxrdX78FyfiBzU76LDEfyd14f6XFAj/zov39Iv3fXWC67Nw/vdS45
Ej3y1OJIP0+iN6I7FngygCM/3qZ27t4s/vZ8t3BOmU3Jy0+BIwslAUeSp+/A
gQPqhhtvkf1dgSMLHHmqcCTf5bd85XZ1+PDhlBz5+OOPq+tuuCmeI+cUOLLA
kal/Mvmu5tz44OET6vkNL6iPfvQr6uTYtd4rHFld1yg2k7AHnDFY8yHvFjZ5
5HhAi2KvPaKkTN5j3qVJ1q6Vz5h9tdEY8dODxQwH1grHlY6fJraHEZ+2Kk+P
5L959w3P1Kjh+u/gVbdXl3vq+5HT0rCHYUtsZ3v3GezZHQrPTJghnMLe38WU
GW/9I13eCcNSNTa/SLXR5MoMN8GR8IvjplJ7T3iZNUvi7uhnR1vCdw9upi7Y
o8yyKfqWY0thD80Y/QeN9Lhpgn0e2ubqoY3okXwerjXsUSV8iC2xWxfHT6wW
/0jsWj/aY7Hmy1Z9PzNmtJscjDAWddAm2t7D+vk5G98J+h5wLfd0zEd/wEIy
5tMibAnD8jl5HsZXt7OkxNj+0k7H+diGDtHtdHalpcJNNcKGjC9tl3lUXi96
ZPGoMonzM176zdi1Xt13qDCjW8exMe5v4/Q4m2WpR5ixReak6aNqL66sf3zh
SPqBtrvxdblR5CyEeTTRzE18SJ0OO37CDBNnp0c/sUN2sXzcnKFfpvrYst+A
kVI/GqnrN+yT0U4j74DutzFTVW19jWbJ21TkjKizeTGVHtk5cXbCFuLqrC76
c9o8+Y/i+9n57c9XnJ1zPl7QIwvl9CmxHHnw4EF12223qXkLVpl9nt+vLMAm
MJYj43MlRPas6dgBhmPIRCX9fXk4+9b0coHk1C4wgY9k/D48miPjYu2EtAtM
xZGxuT8icVsz4MjJ5gx4guPJBBxJaZg5W91+++0pObKighgPQ2I4Mti/N7xd
dgBDBsZMTWWTnYM5nHIerw09h3PJkUF5bJpaE+SxiYs9HDkLSZsj42LtzM2K
I/fuP5xWMZrkQXXk2Lvqmd87u9aTpUeyr0bPqxPuYL8MLzpfyVLZV5vYm7AA
vneOE9gv807CJMIolpGwWzT79yrZ6+NjiOY01foXsleHkWACPu9nS2w74TnJ
bz9xhry3+A6iU7JeOHZAs+yj2cNpmY4jaafE0tH3haXgJmM/O8vjM48j9X0c
wzrdE/9O2jm+zOh5/D0caWLX1Nj+MHF2uL/0kfSH0RnHlk71+JtrxIBBA6uU
tpt+ox7q89qu7yO5M/TfTdP9Jjat9tmdbanhM80u2LXCkVd2qPLKZvt3pt/h
etZW6XPbdhipwup0RqOsUr01R5bbuLNuLNHaeGbD36ZuuMusw41ev1MPMXAq
vT4y4+tYTvwyJxi2hSOdXyT95jiSMeZvS722235342vPI7B1pZ7Y8TW+q7Xe
M5pckbNMjFpvfMfLZ6bYsfA4Ul8XLp4YaTu2v443SydOl3MC+HuSjTvl5iF+
unzvGF3ajC/1oJO6/KU8j4yvrk+ex373jBo9VTXPnqXOOYdYzPfb96+z/SBP
D//IVIW4OmvT0CeJAzuv6BWJ49PZbS/okarAkX/jxc+R72uOfOutt9R5550n
tkOJODIqNkk2HJlkDx7sTxaWI9PYl6fah+dSk4zNw5eOnpPARzKpnhMUa8fb
h6fiyEjc1uCYrak4Mj6PZHTM1sw4kv3FqtU3qHfffTdhzJ3XXntNlU+plL1n
Qo6M0iIz5Mi0GTKb+ZvFHE6mSWZzFhIXezgcR8afhcRr6ok4MthHcn6App4d
R2aqRx44fEJteGmD+uQn0SM5W77XlvtyXO7Vew5+360+/olS/X4SG7RW9sHl
ElOzWPb+7MvZZ8McMIqLLcI1fAON/d4MeX+5BidwjTwbhmdmyHcB+/V+A0q8
fI7wgMQ3HVgi7225cMZ0yQuBL+IwzWOw3OQK44M2tnS65J8X9rCsyz3Jw+C0
P/d+Dxw8RtojzDfRMDD3dH7Wrm6uoavxt+MmGH0VThg8rFRVVhnGmWjXDWxY
K6zfH+2EE6/s0V9sFyXvhe0j7FKFtdHfpD/0PXW7pY/QLS2Tw8A8D20vtX2E
TS595GwzS63mi97FekfbuU9FRY3qN7RKfbQHHGn6fXJ5vTBSb82202tmy7WJ
VreV/oDFLPPx7AMGjZbzAIlHO9H0x+Ch42R9dWcHk2x809KJsHZj1PgOkXwt
LR6Dct++mhm9tk+YIblEe/YeLGu0tF0/31S9vl999RA5E+DZ0Rdpu8nnMUWY
0fXRuPEzpB7Hq04/pJ0RLjZ/26ffCO/7wYyvnq/6GblvxfRZUfN1gJ7HxAx2
fUTbL/t0bzNf7dkBbf/UpVfJWYSwtr4n4wuDUi+xgNz40m74for0kWkP9aKX
+5+nRHNkXUOtx5EFPTI/+uQNRa+rI0V/Dc2Tc4tePkP0yYge+XHNkbv2bJL4
33v2HUr7XDO25OWnwJGFEsCRh393h3rooYfVZZf1kL0Gezy/PaDsweeEj3EZ
a9MaVoPMXMPJYj+eyL41BEemlVMyI45MHPMyjiOT7MMT5U6I13PiOXJG0twf
8Rw5xceR5RXxMVtdvB1/7o+JITiSMntOh3r00Uclv2kQR86YMUPvYaYKU4Tj
SP/8DcmRKRgy9+cg4Zky15pk1DyO5cgEmmQojoyNGRV1FrI4PtbOrMQcGX8W
kqUeue9oemX/UckheeDQCfXqay+pT3Vnr/lTy3r58KNye9h71cfOGal5qlSz
jdHZ+vbXLDN1hr6G/eJUo0UO0hxWXqlGlJTqUi7v3+ChmgWm16vGpnbNjaXC
GCNGTlZTNDMs6lihhgyfINoMDEgs0bXrPiPcNmbcNGGCQUPGqWUr1ur3vUE+
x+cHDi5VdfUt+p5z1Ui9P//8F/5D/t+oMWWqqWWuGjikVN730WOnaQbV3FJZ
pa+Nk/0/3DFYt2PmzGbNoePV2PFW8xw6Xi1YtFyvKZqLRpm2D9L3aW3r0HNm
rv7MeBPrpXiSmja9Ua1cdZ3ck/WEtg7Tz7HymnX6uSfLs6BBXd23WM1qapV6
uadh4jH688Qfmi734p5Dhk1Q40o1H02rkf4ok1ie6Hnlak77Is2sxvZyjH4e
2HL5ijU2Hup0q9dOUCtWXitsQz3E2RlZMlHi7Jx96QI1csw0G5toslxvm9th
2i6sOk1Yefac+VK309T69B2hausaRTMePbZSnofxnVrJWE2RepgH9EtVzSz9
rsxRQ0dMtPFwsEdtUnPnLzFjMalWeAn97ZrV18lzE1OJWLx9+49SHUtWSR8x
lvRR3wGjpZ7KGY3SJniPeUR+EmxFuKdhrgo1eMgoVV3TIHk+jd3vdNGQZza2
mPMLXQ92vrSpY/FK4eSR+nPMI8a3rX2xmlHdpPvYxOWlL6dW1qsFHdeo/vp5
y2wf9R8wSs1bsCSqj/oNGKP7bYE816gxU+XZ+UxVNTlWZkS9A2Vllfo7qko/
e5n0G2PB38xp75D3gnlEP9NPX77li+rDH4bN0CPzcT6Uq3KPMtxIW+9UJgfI
/fbaqV/Ozpgnf97pbc+83G9zAj+szv34HKtHHpecUun668eWvPwUOLJQAjhy
yy9uUp/73Of19/54NaN2TlSsVo8jo2K1xsckTZ8jkzBkEh1nXq734ifLxyyZ
npPULnBZTuwC/X6SyfScKl/+j7jcH9VBMVubVXDuD58mGcCRZRlw5PSqWeqG
G25Q+/fvD+TInj17SjwG+sTPkUH+vYG+kQn0dE9T73SGTMKTKWy0U9tnB+ey
Sde2NfYsJFQ+1BiOjJvDAbGHE/pI1mfHkfv2H0m77NmLf+S76pVXX1Rdu35V
mTxu+dpr3qs++EHs176nyiatUT/4nx+qoZppsBm8ZtV6tf/gUfXDH90n5ymD
NZfAJ29u3Kp+9esn9Z65RuJW1s9sVb9/boNcnzN3sb42Ur9f09Qjjz6hDh15
W113w836nmNU8cgJ6o5v/ac6/vYJ9Z3v/kDeraHDxqo1625U+w4cUY89/qSa
MHG6/nyxampeoF77y1vqL69v0ky1Vj344INq3vyl+p6/Vlu379YMsEL/3Vhp
13e/9wNp53XXf178CsnZd9MXb1VHjp1Q37zzu3o/P04z5GjNN9drPj+m2/6U
qphar59xhGpuma/+8sYmKa1ti0XXnKKf67FfPanveUStXnuj5MYkNunXvn6X
Onb8hLr9ju/qesZqlinVbHednNP//BePqlLdFvJBwA1vvLlFPfHbp/W9akUP
q61rVk8/80f11qatep7Ok/i22KXe++OfyefXXfd5NXT4WN0nE6Vvjr/9rvr2
Xf+tRmvGG6T7eL3+/wcPv60eeuQJzWZVMj6LNDPd9d2fqy69V6imOZpVBo0Q
Pfehh5+Q/ly2fLUwNu266z9/qPvjHc0vXxOfV/rohhtvkvH59l3fl1yX+F8u
Xb5G9+8ePRa/FQYarJ+9efZ8teHFV2U8WloX6ecp1v1Xp574zTMyX69Zc6No
g6PGTFZ3fuf70ke3fe3bYudJWb3menVIt/1nDzysGbBc7tkye5Huo63q+Rde
UdOnN+g+LtGMXa9+re+5cfMOGf8BA0frPqpS/3P3T3QfHdFcv17aOFrX85Xb
vqnbfkJ97Rt3ar7X46vn0bW6jw4deUf94uFfyRkG40t7N23ZqV565XX9nrfr
vhypGbJO/eqJp8TOb/GSa2R84OZvfft70vYvfuk2aWPxyInqc1+4VXLw/M/d
P9ZjUyaa7kLNn1u27Va/fEyPxSQTe6lxVrv6o36WV//8pmponCNjVjmtQT38
yK/1Pn6/2L5g7zuieLy6+54H1PMbnlP/9E83KmODeE+e3u1cciRxdk4fPTK2
nF30iLq56C11PE2e/Afhyc5vf2Z65ENWj9yi14O3hQN5j7IpefkpcGShBHDk
n360VjU0NKpavQdjPxfNkSuCY+wkYcg5MbkScqFDzktScsWTmeg5oTXJOI6M
95FMxZGJ80gGc2RDCLvARLkT4nN/zJYSxJGhc39gazTFz5G1aXEk+6vJkyer
HTt2RPEjdq7Yu159dR85hzZ22dEc6ffvTZizJvAcJBFHJpjDCWPqJJ/H+WHJ
oDkcb9+ajCOjNcn0fSTjOTIgh41fU2/OgCMbcseRe/V+fu+BoynLPt+/+b4/
eORd9afXXlLdusGRP7GaRX7sWv/u7+DI76qKiut0i/9XM9UW9adX31DH3/mr
Zqlj6tjb76ktW3dprn1DHTl6Qnjm6PH39P7kgN6f/0Xt18942F4/fPQdfe01
tW3HHvHx5Ln4/Gt6f/3mW1v0Pv090VyPv/1XzVTbZN/NNf7uqP777Tv3qpde
fk24w5R3NFdsE4785S8flfsfOHhcftPGzVt3qrffeV/ayT3hztc1wx3T/zZ1
/1X49tXX3pA2Ujdt37lrv3pR18PnaLcpx+V5duzaZ9t+TP8t4/CmbsN2qYfP
c8839LPQ9uMnTN1H9TPCty+98mdpG/fjHq6P9kkfvSvXDxw6rl7+01+kj7iX
tF33NX30lm7rUemjI/ra+9JH1O/vS/oIrntfj9ZDDz+vug27Tu0/dFz6Hd9a
/oZ78ryvvPq65qgdci/3ecfNb5/4X6+PYLdXbT20j7HYsXOftBNGh89M24/J
M8JG3F/GzddH3EvG9x36aKtmz43Sb1LP8b9KH72sPw/jm/nyrtjbMRbwNPc6
cOht4duX//S67SPTx7QNlmU83fjSVzA717kn/Wb6aJ/0B89Cof379d8zt/bq
+riXu+crup7Nen4f942v6yOew/URPEp/UI/0ka6bucK1A/pezFUKbM0zMseO
HtNjIfPoPemjNzU7v6dR5ndP/Vb9y798VmEzat7tzrZfTWbXCpucXnaticq/
F/0yLZ7cVHRcNRW9eJrxpOPIh4Ujd+/dLPG/eTf22e+aTEtefgocWSgBHPn0
txapHlf1kr2afw/eHMCRrWE5Mt39dwoN0iuL8rQXD61Jht+HZxKrJHTMy0A9
J4AjA3Lw1YXlyJhYO86+NX2ObIjnyPL0OZIz44997GPiy+vnyPfee09iDQ8Z
Mlz8nbw53Bqc8yM9jvTFGs7SHjt/c/ja5Jpk6JyoKc5DUp2FtKXmyMBcqH5N
PQlHxmnqM+M19Zqs9cijthzx/TZlbwI9cu/eQ3o/ekK9+uqLmiNvU4Yj0QXu
URE/yVyVe9QHP8h+8T9Vefk69c6JY3rPoTlN77v3ap6V9sC1et98RDjM+sro
awdkH35C9ud790V8aByL+D8PW8EGcu2AuXZIOOJE1N/BKcJM0j/mfhtefFk4
kvLcc897/0+Y9pDx+/HqOfKOMIP/ntTj2i56r2u7Zpi99m/22rN6/g6+cGf3
e6TthnnQid3npe26Hq65vzvg+sjej2swBNcY+z2+ergnPLxnr61nL2239di2
c+2g7SN/e2j7wUPvqHfefU/d/7Nn1MWDr1V7Dx23nHxEdDZ/22nXbl87D9k+
ctd2S9s1u9l69th4T45F3ef2eG1/N66P+OwB3dbd9hq/abu/HtdHhh0jtnLs
Tw9bTo6u54TMxdi2uz5y19ALue6/Ztr+rqejmP8XXU+4Pjoc0/YTUW0P6iN5
ngTziGuHjryrnn4Gjvyc7PsLemTn8ORtRZvUiaL3z0CejObIXXu3qH2aI/fs
D3emmazk5afAkYUSwJGPf6VVnXX2h2VPFsuRns6QjW9kqlgkYfbfi1xZb4vv
Wq54MpQmGZIjZQ9u/O7yEvMyHbvAsDEvoziyPTFHRsXaiXBkRZ45cszYqapk
VJnatm17VKwdcka+8cYbamTJWPH78ceJCsr5kTBnTTKOzNk5SOr5m9kcTuLr
G+IsJFTMnVQ+krG+vlG2rUk4siUxRwbGHo7hyNocciRanSlHfb+TF8NDRo+M
2LXmjyP/7u8MR06Zcq068Z6N67ff7If3HbTlwJHIeXbSa0fttSPR1w7EXHOf
P5D6nhtefMXjSAr6ZMp66MuAelwfe/Xs91876rG9/9q+mGv7fdf2xVzbG3vt
gGHefd48OBK5tj/62r6Ya3J9v70ec40coyc0Rz7wwLPqkiHr1V7NJ+hsjp+9
MwnLMfHXYv7OXo+cdxwNvBZ9z6BrkfOS+M9Hru3172k9zktwzV1PcC3l5zOp
x5ak9exPvx5Y9fDR99RTTz+p/vmfTzeOPP38I1OVTxQ9mhFP/r3ltVOzRPwj
RY/cs1mvG2/HrQ2ZlLz8FDiyUGI48v07+qtHb2lRH/rQR/PIkUE6SboMuT6g
5HIvnuE+fF6SfXiqWCWxMS8D9JyTypH10RwZidnaGpP/I4gjY2O2NgbGbI3E
bU2fIynTZjSpzZu3SL5Tx5GHDh1SDz30kBpXOlnq98eJisTYScyRoWIN50pL
TzaPczSH086Jmk7sVrsGpM+RIX0kE3HkrHhN3a+r50yP9LjpmO938sL+9dCR
99Srf35ZdZc4OyfHrrW8fL169z00tqOWr46dEuWpp56J4shHH31MtLrYv9sX
8++E5aDvd16Lf9yzL/t9/0bvO6HXrAcf/L3mSKNHOpYNc1aRvPjPPnJfHGd7
HBrCnu5MKbDkkWN/VU8/86S1a0U7ulvl/nwoV+VuZbjxS+pM0iNjyyeKHlPf
Ktqi3iv631A8+ZeiY6qm6AXNkw92etsT65HGP3LP3i3qwMF3crI25OWnwJGF
EsORJ77eRz3y5WZ1YZdusj/z2wQGc2QyhlyTwDcy85g60RpOspLtPjycj1la
+/B0Y15G7cNDxLwMaxeYKNbOzLAcGZtH0nIktq0z4jkyKt5ObMxWG28nU46s
nD5LPffH59Xx48c9jsRfkvg7pRMqJBaQ3783KHdkLjgyOy09XywZLpdNJnGj
onPYrEo6f6PmcEA+1FkxMaPiOTKeJYN8JP3nIRHb1nnZ6ZEHj9ly1Pc7SRHt
4rBoFq/86SV14YVfUSaPW771yO+KHvneXzm3NhxxQLfnVCi/+c1voziS8sc/
vhD3dyn7NtflgO93YDnm+5198XPynr1HNPO/rx74+R80R67TbPm2zC+jwx7L
sISco0lKLO8GlgP27/LEqadyQRM6qjnyqWefPA3tWs88PTK2dMmIJ58/xfTJ
aD1yz76tEv87u7XBlLz8FDiyUGI48ugtPdSDX2hQV1zZ1+cfGYnVmhFHxvlG
Zrj/Ds2QudqLp457mYwj4/bhCWJe5kzPCWEXmDQHX4BdoMudEBSz1Z//w/lI
VqbiyLhYO9lxJPnB7r33x2rfvn0eR2LTOn78eM2RlcLCKTky41jDmTJk9nM4
O109+5yoiTkyOJdkMo6MjRl1KnFkhHOO+X77S+w1oykR3wNfwP/zDzcrY9d6
ty335LjcrTmS/eJdmiPXaY7Ez+xoTvYcmZQDvt+uoD/GciRl0+btAf3ZieWA
f0xzU/YnYGR0rXfRI39u9Eji7Ai/oSNmzMG55959qf7uYG7qyrgc9P0+CQX7
1qPH31dPP/s79S//fLrpkWc+R54ZPOk40uqR+7ZojnwnvbXBV/zrUV5+ChxZ
KDEcuefz3dWP1lWqAYNKZL8WsQl0eSNjODLJHrwtVotMuf/O1A4wxD48o714
Fppk6H14ao5MHfPSn0cytX9Zwhx8oTgy2kcyNveHi7dzsjhy8pQ6dfMXv6S2
bt3qceSGDRvURz7yEckJ3tC0KDpOVAxHpm2XvSDJHM6Zlp7LM5Esctkk0dWT
xoxKdhYSGzMqCUcyhxsTzuH4WDv+2MM50yMPHQtZjnpl74HDEt9xw4vMQ+Ik
ngw9UnNkxTr17vtvy16XnBcHdFtOdtnv++1KEEN69q37D0X9beeVY77f6ZcD
tgRd9/9/Vxij995/X3PkH4QjDxwxsVRl3xfw94Gls7n7VCsH8l/27Tuijh17
Xz3zjObIf7nR7vl/pHJ/PpSrQttgki/q8i1dfm7/+/6/iQJP/lfRNvV+aJ48
Kjz5QctznVPIN8x3xi+EI/f+/+y9CZQdV3Xv3SKBQCAhfGQ93pcElKy8gA0r
CSTMAeOQlfC+vJcQY1uDNc/dLam71VK3ZmuePM/GEzbYgAcmBwOWJxkwtrAs
y9ZkbBljW9jGRtiaeh7OV7uGe09VnbHqnKo63fuu9V/39lX3vdW3Tpf27/z3
8PqvydHjfVrXBt51ysoNORKV4MgX1o4lNyz+d/L//Z9xfuyWnPmRnyNz9LTM
HIOLc13F8bi876XaPD5Dfg53doLYz4nPclfwc3gcKenZWu/bGu/ZmubImUY4
ElixsbGJPP3007WZH48//ri3pt/svzZwtQ5Hqvnpa5V9yPz7IGosKVy/OWfZ
8HpG6XBknCUFfVsTnroSR85Oc+Q0436kTPV4FvzIE10D5BdPHyAf+MBVpNi8
Vuh16h3PG8ExHS1Q0e9PP4Y8QB5HBvmte8vnD1+055zNd9ThVuiD1D80SH4Y
1ke+frzbf/53Hv+Xz9QOKU9ecwYFs00Gyc93uVgfOXr8yKQ+2PBjLZ480HCC
jGt43OPJMvzJ/H4k7zpl5YYciUpw5IGOd5MLZn7Kj/fp2ZH1+DvRo4SOvyPx
OFIj/jYfg2eNxXP4Obw4XMSRGXte6uQFKnHkzDhHSmd/hDWS9X47LI7k9NrJ
wZH/8cVzyKc+9U/kscceq838gMd//M53+e+VrO+Nc6Rs3ociRxa6fuX7Iel1
rDNPUrQXsobvSYpqJBfoceQcBY5k99oxz5FHj3Upqrt2D7mFMHPv8T1Pkje/
+UIScGQBea3jNpDBIZhREeTgHQ1n7xWlo6Hoxy8eflnIkSD4nqPUz5Qj+hyq
6w3qXodboYZ1YJDyI2G249EgL9UcE6vLz0V20eNU9W4NCWJ5mIf56GOPhBzp
ih85ujmS5snvNLxChhVYsjyejHNkFj+SvjbRsnJDjkQlOHLnvLeQZf/5fj8W
m530clQ4ktGbJFkbqe9D6sXgKzuXkZ9u+zg5fuU7CLmmwddvL/9/yJ0bv5DO
dU3E5Hdu+IL/vdHPwWv8dOvHycolnVyOXLG4g/xk68fIa9TPwePvrv9Xbp0k
Ly/w59v+1v/5Bzf/o1aNJOiFi9/j/+yVy85QnuUuywtU5ciJTI5M5LZa4chJ
5LOn/RvZvXtPbeYH9PX4sz9/n//+9MyP6HNTre/l52VT67jwfRB5vraII/N5
koocGbJkco6NnCNZua2dDE99iVqNpAk/8ni3orqCe4g1j57w557v3b+X/Omf
Qvx2ZxjPgb5tWN/yOBJ8h6+Ss8atJwPDvf6cAj+/1D+mcvWCAkdCfivkApd7
rNQ51BGDoVUEMycGhoY9jnycvN/jyKMnev3nA54zw/NKOkrdo6R63Ttv3d3D
ZNeunWF95F2O+JGQ14ocGekjDT+tME8mOPKNl7zrQ3+QHy+4Fh0NJfoeKzfk
SFSCI38ys4G0/dvYIIaLOLJ5WczHYfUoYXqRbawYnI69debrqTMkzYGHL/1/
Y1/vv/AUdizuaf+FH4hxJ/ws/TWLJVcs6Ujx4+FL/2fs6+XtS+Q1Zl4cfs3K
s2s/l+RIlV4lSY7k+TkpjmT4OWyOTMz+mKrJkRPMc2SkJ57c7+e0vv766+Su
u35A3n/K3/rHlewTVesVlYUjk3WRlvZBTDFllhxtkSe5QHEvRM6ROjWSnWlP
fW5xHHnUYws1dQf3YY3bya4B8syhg+SDH7zKj+cCz8IuR9J+5BtHu/R4wpL2
739KypF+fusTe4PPMPrZ40WLOocJvaG8BtQFvtbg8BC5e3voR57sCd7L4/+8
r/0GdS/VMeoelcGP/L4jfuTorI+U6SMNPyE/bHhNiSXrPLmbjCmwPvJ3b/ya
HDvRp3RtkF2rrNyQI1EJjnxo9u+RJf/+10oc2azNkesSHMmu6dLxcNoSXwMn
Rty3ZfnC2vM3rJlI+q5+i/9vdV+yLngO/g2+B743OpbNyxbWOHTfBR9IcWTE
mvBz160eX4vDly9eUuPLQxeNjcfgjDh86aJ27zXeXOPIH3sc2cTMC5Rz5FXA
kSp5gQr1Zf7sjxksjqzP/4j3bG2U9my1wZGPPrqb9PX1kRdffJFcf/1XyEc/
/lm/J1C8TxSDIwU5rTw/Pc6RKj6kbY5k522r9W5VmInKq/Vl9B4WcSSrZ1Rt
DTdLOHIenyNTnjqdmz0zH0ce82JHXb0BsabHkU8/c4CccgpwJOSd2s9rHedx
5NBwr58bedSLOY55cUPZ2n/goBJHgg4ffrn+sxk+d5f0+usn/H2v7Xc/7nPk
0RM9/vNHj57UeJ1u6r4uLdY/3l0St7sp2CPq7h0mu3bvJH/8TuizA7Nh7yDm
94dM6Q4S5NVfRNCP5OuTDT/T4snHG46R/2x4zONJ+37k66//mhw/3qd5bWDL
yg05EpXgyEfm/QFZ/sVT/fgtVVsW48hVehwZywWU8KNGHmAbxZLAjRGH0QyZ
ZEXIVU3+W5QDGzBmPA4Hloxed/PSBbU4/LpzJ9Sev+7c8ak4HFgyYkNgTBFH
PuOxZvRaaY5U83PU8wLV68t4HEnP/2BzJN2ztV4naYsj73/gx9518pjfq3Xl
qnPJ5//1P/3jt8uRZvZB6DVsTFqepMI8SRVPMtUvalVqLyQLR6b2QmQcOcsc
R4piymPUPS2oT+vqHvT9yIgjA8/CRpwY9yOHSH9QGwksdqK7dP38548qcyTk
t8Lcy+TnmUX0+VHzIYsVzGUZHB72/cj3+35kr/+8X9OksOaCx13h71vyfsGx
0cH+INgj6ukZIrtqfqRLHIl+pEyfbHiI7Gg4osmTuwz7k0k/8iXvWtovvTao
yMoNORKV4MjH5r+DrBv3DzWOnEvXlqU4Uj63nVkbaYAj2xi6Z8vnal4k7+ci
Trts1azac/A4eh7yYqM4nD62yHe8Z8tptTj80fP/vpa7yovDHz3v70Iv8/2M
GrPg87vl3P/rf8+Ll/xPXzyOZNVJ+nG4bl6g6gy+sGfr1Igjp3M4cgqbI+O9
duxy5E033Uyef/55smPHDjJu/ET/56eH80+zcKQoL3uhihepuQ9inicteJJt
GhzJ6rmjwZG1XjuNfI5MeeqzzXPkMfCJKB1NfA06nhDktnZ7seahZ58ip556
BQnyWu8IY7pvGdYdHkeCL3kTGXf2BjI8PODFuoEvdfx4T+n62c8eZjLjD3/4
Q+bzTzy5L/V5ZpHKeQvUzXneroD1h7z1tf2eIK/16Mm+4DiPi4/naOxxt/91
cN8V3pegZLxqwd+k9wfKVORHPlbzI13Ka73B049IwJXfRwl0esPDmjx51OPJ
Rw29P+xNQE393YEfefRlcvzkgPTaoCIrN+RIVIIjn2j7E7Jl6qflHLmQz5F0
TRm7NjK/F1mLu5ds9O43+o9/HbLeQ9s+zv25Og9+rvYc9OSJail5cTj02vFz
VC/+y1oMHr0W8CQvDof+OxFrsnqVLG0P8llBG5Y08jlS1vPS04upvNZAESND
HH7Xuk+QVy/9k9pz8PjWVacpcGR6hmSVOHLV6rV+n9Y77riD/O3ffdjPuZ01
Lzm3Ji9H6syJVF3DG8M1bIElOfs1xmaiymokhRyZ8NSbOZ56I8NTn0v32uFz
JHjq03Jy5PHj3VryY12INWt+5JUk8CNtMGSCI8etD/zIN4I6TRO+Xl6Bx6jK
kHR+q/JnfkLv/KTVk/PnswnmskBfsHu2P05O+dx6L8brDdaPd97834mjuN9b
HgcXraMVEfQ66e4jZNfjPyd/9M4tJOBI9CNHqk5veIQ80vCGMk/C9/5bw89z
vm/cj3zjjZfIiRP9wbUh53XHyg05EpXgyL2L/5RcMPv0oDbSKEfyfZxUv0kV
L3LJxpSiOkbgSF4sDhwI3/NTijV3hb5inCPjcTj4kNH3RHF4xJE/8RiTF4dH
HAli5QVG+ax3b/qM/3nWOfKjzDg8D0c+se2v/ftjV/wheeGi/+HfR//28OZT
M3NkfIZkORw5YeJkPz698cabyP94z5/7rEH3GxZxJLPXsCgvm+GpZ87Jptfw
4vqeiBmezDjLRpLfmtwLSc6xkXEk25NczvbUG9OeOu2rxzz1mq9ujiOPeZyh
K+hxA704nnn2qRpHFtGvddz46uW1iniRx5N+fivUAsn4IsO5qYKAXYH1h0jA
kYEf2RvsQUj4vwzmNS4N9j9G3VdBkLPeU/MjNxPoxTxmzO3Ezh6RCd1Ogn7R
FxLkyOz614ad5OGG1wviSYoj/2KBd6142fubGfB9/rzXHis35EhUgiMPdL6H
XNr0bwmOjM9LSHo5Uo5MzUnI19uSx5ERE92w5hxuHM7yHiMe/GnKx6zH4dev
mVh7/SgOj/JagU15cXiU18riyO+s+9daPmv0WapzZNrPSXFkKLru8rbVn4vl
td6/4e9r/7ZiwVRGz9YWao5kfPZHiiOhZ+tk3gxJuxz54Y98lFx77bU+R/7l
X70/xZHRPsi8kGOaZBwpnVljIic7vYbrTGnIn+RxpGgOiJInqcqRiRrJZM8o
miNZNZKZOLK+FwLK5UcKvCGeoMdNd88gOfTsQXLqqcCRBeW1jl/vkcmAP/sB
GO74yZ5SBf0FRRx59913C/Jb93qv0c3WCereQcG5AR4ZJkFe6ymnryPHuvqC
fFyfs/Ln9drQMeo+l47r/0z9OMr9fIDze/sI2f34z8k7fT8S6yNHk4rhyYQf
efQlcuJkP4Ea5LzXHis35EhUgiN/sezPyFUL/z3NkfPZHCmqjazFowKOzO3h
sDhy7TkpXyeKxU1y5DfWfrH23KalC1JxOMyVpGdY0j0vN3Q21fNZO5qUOTLm
5wg4cg6DIx/Y8GFmz9beq4JeQFF+a3L2R33+h5gjYfbHxBRHzi2EI0/90EfI
hRdeTL528zfIZ077Qi6OlOdlc9ZwlpxskYx4k4KZkqI6yVSOtiJHynJbY/sh
6hxJ10gWyZEnPB7SEfAT/H/f1z9E9h/Y58WaEL+BX3h7GNOZ1u0eR37bjxEh
r5V4HAlz7sDDOeHFvWXq179+RbnHDkvw88L30Dw3Zek4dV9n7C6fI++5N8hr
Pd7V67PxsRNdfH6umI7pfL8R9i+fpSOOfMzjyD92jiOhPhI50oT+o2GX32NH
hychR1abI9+3wFtzL/tzpOBvIO+1yMoNORKV4Minl/85ubrl/2bmyAVSjjTQ
l0SFIzm+zkNaHLmhdnxxjqzH4VEuLdQ/XrJyZi0Gh7mSUQ5tjSOpOPxwyIuQ
z0rH4WmOVO15ubzOkcvPiMXh0ftfufS/mLPcIccV/h28STlHxnvtJGdIsjhy
nMeQ4yxzJLDjtvMuItdc+xXyf/5zos8aZjmSPbMmk5ce5a/KONJUrquEI5me
pGimZDK3tTUrR9b3QuaJOLJRzpHJvq31Gsm8fmSvtiD/qL+fkCf37iNvfesF
JMhrDZjPnh/5FXL2+A0emwx6jBJ6OCd7S9Xhl37D9SGV8lt37PA9Te57ZDg3
Kjph6fVOUALWh9u99+zxOfLEyT7veYr/o9jPAM8fN7g3kPm1TlL3ycfK6i5d
x46fJH394EfuDP3IOy3WPpvMa438SOyzY0pjPP1Hw6N+jx1VnoTePdDDR7XP
zl+8dz554+gr3tobDHLic16LrNyQI1HWOHKtlCNNMiSXIxOxeMSR0JMnisuF
HLlYzJGXeuwYzaWMeDJ6vWjmZJIjt2/6bMCyHjMm/ZwURyr3vJRzZFvzfObs
hCRHTk/M/qjN/2By5HwmRyZnSEZzJG1x5Lv/9D1k1qxZZPHiJeS9Y/86zpHN
bI5sZnLkGoW87JwcqcKPCrmuylzZLvAkRT13BP1bkxypXCPJWcMsjpzjX4PE
HDkzyZGpXjvF+pEnQj+yp3eIPPvLqF8rcJ7tvNYb/fpI3488Hng/J7p6StWB
g08p+Y6i/FZg8djrFugZ2s35pfzI09eR4939PhsHOZzV5eJcr3WS81ioyAuk
H5fvRz6+G/JaoT7ye2F9pI1cAxO6jQT7WBeSYH4k+pGmBTM/zm7YTQ40nNDk
SZ4/iX4kyk1Z4chF9Ric1WPHNEf+9vJ3+zx075bPcb/n2Yv/KtaLBxT12Xn2
4r/kxuHxPjvxOHzlkk6fF6McVuBK+HrT0vn+3MhoZiV8LhuXNtfzWTubcnLk
Ci2O5M3gS3PkImWOTM6QrPfb4XPkWWVzpD+3huJI7bzsdTlmfGRkSEG+q5wp
1xN2zx1JnaSo544OR6ZYkseRy1M9W+kZNvUayQ5mz1YbHHnSYxc9QbzbRfoH
hj2O2k/e9S46r9VGvFnPax3v57UOkmPHAr/npBerl6mDB3+RK6810ksvveK9
Xk8g7fOhphPUfRGCPkhwuxc48p/XkxM9ff7zPv8b5uNK6ETisbJonrTnQasK
cg38+sjdjzrqRyJH2tKbGn6QiSdhZiWPI9/3vvnk2PFX/HnEJ04G/7/kkZUb
ciRKkyObwhi8KRWDr0nH4ByOzNzbUhKDP3tJxIif4H5PNBvEZ83Qp7w3nDv5
62S/VioOj8390IjDv7v+32r8CZ8L3b9VVSo1kvOscGRbmiMlMyTjHDmvwhxJ
9RvW8tNzcmRehlTIe+XyJNOT5M0B4c2UVODIMLe1WaNGch6nRpLHkbPmsnNb
0z1b8/qRvZoKeqUAR+7dB3mt55PAj7wt1O2GdZvHkRAv3kDGjV9HwI+E94cc
vLI56+eP7tKa+SHKb4XeRfrnQl0nqfsiBPM94XbvvXvIKaevJye7+4NjOFHf
j8ijE9R9JRR91vRjxb+nQPTj8hTUPhPy+OMu+pE4P7IIvcljwSkNe8ihhpPK
PPmjhtdCnozntb73fc3oR6KckW2ObGFxpGL8rRqD0zwoy329fPXs2nPwuJb7
yYnD63MnT9OKw6Maye2bP+t/Lt9d/6/ea/1PP6c1KfAiwaf0Z3Nc+Xb/a5BK
z0sWR0Z5gZk4clacI9OzP3JwZJjbWipHhnNrcudlF+1FKvqUXF9SMgdEeaYk
o0Yy7kmqcuQKZY6s5bbOU+HIRaX4kb4HdAJy34b8fq3v/5vLSdDv4vYwprPo
R44P/cjjPUb2rlU4RaSfPfywFkfK8ltteZGFepgn437kPfdQfqS/drqtMbJ1
nra43uKyu7ZFgvPTP+Bx5J5HHeRI8CN/SAJ/8r9RlvX7HhNOaXhckydf9Xjy
J96agnP2I/QjUU5JxJG12ZECjlyQqCszxZFKMxJCbV3RwuTEJGdCjmny36Kc
1MCnjB/DZatm1V53y7KFtfg7qo2En2XF4ZesnFGfqbG4g9/zkorB6bxWXT+n
zpFfisXhcY7siHHkzCRHzlblyPocyXjP1ibmDMniObKjII40tw9ilin5nmSa
I9U8yVTPHUluayy/VVYjOZ9XI1kuR3Z192rJZ6yTkPs2TH75XFQf+S0vLrDh
Rcb9yPEToD5yyM+/g+Po6u4zqpOa379jxw4tjpTp5Zd/o30+bOokdQ86QT3m
qiu4P3aC8iM9jjzZ0x+unfL5mOZkbUYe4Yr8yGDuxyYSzPSx9bdtQreSIK/+
AoJ+ZDn6/Ya7yJyGJ8kLDd2aPLnT58jjJ35DunuGjFzTyQ7v9feYgEfqhhyJ
EnFkE58jk7Vl2ThSlSHjMXiUm8ryHfdfeIr/b1ArCVwZPQ+9d6J+OHdu/N+p
n4PnotrGYG5IcAxbli+s9WSF16bj8JUdS2uvCfWQdBx+3bkTav8Guayp3EBO
z0t9jlyR4sirlTlyiTZHxmZ/THOcI1P1vfScREZedpIjDe+DFMKROT3JzBwZ
ruFk72EVjkz12hFw5AzjHKn7f3XAAn39w+TZX/6CnHIK+JHAeUXktYZ+5InQ
K1PhGkNicVZWXuSxJnApeL2m+VhJXdR9HoWvcTycCX7ffU+EHDkQMKl33spm
Yy2V4guiH5ndj0SOLEtvafiBNk/ueOsBcvKhI/48YpVrg+zvlZzuve6fELMs
iRyJSnHkX3gc+R/MGBxiv6ZabRnNkYk55VyOpOPv7DMSRBy5aunyWr+d6Hvo
r4EFebF3xKABh8b7rsLXKzuXpWrMvrfhC7XvAW6En3kt5M6IL3k1Zqy8wDhH
Kvo5mhwJMTgdh8c5Ml5f5s/+mKnJkanZH3WOPHv87DRHnl0NjkzNrBH0icqz
D1I6S2bxJIW5rWvYNZLJGSAxjkzshdA9o+heO02MGskERwp7ts7Km9eqG2v2
+bEm9OL4Za1f6x1erAm+wK2kzpOmdKvHkRAvXk/GTwg4EhgFetJ0wf51QUp+
DjAfIQtDJmeCsPNby+KXUBpszfu3mh953x7yAchrhfrIrr4gp9S7L0uZuLhw
mffaVQV7RAODXhj+xK6QI13zIzGvtWy9peEusrBhH3m5oUeNJ8d4V/X/GCZd
P+uTXptE1+jeu/vrr/mXnt4wAZEEORKlyZErw1q9ZE6gLkeq1pOx42+aIxct
2eQ9tynFktBrJ8pVjfxJlg/J8iVp7oTXgHkgPkNy/BzIb4U6SHr+B3z9jbVf
1O5VwudISc/L+XKO5M1OYHPkogRHpmdITuZwZHqGJMWRE3gcOd0CRy71eUTI
kaLZp0Y4Mr0PEld6/VbBkxT1b+VyJKffThaOnCvlSEbP1jnmOTKPH/nL537h
cWTgRwaxpl0/ckKY1wqzGSBu6PaOx6ZEn8PLL7+qzI1RXaRqziu8dqmcIeCq
k9S9SMdCP/Lee+t+ZD2vtQAOpnmYfk4Qn5bO7zXJ42lbivuRLua1IkdWRW9r
+EEGnhwiPY/0K12nktfrodOG4q/3YWKGJZEjUbocGcaENEcuYHEkFX9n5khh
nBzE34tCWYnFBX5Opji85uco9rxkxOHcGklZfZniLHchR87gcGRq9gePI+eU
ypG1XrdSjhTnZatwpKoPuSi1hg2v44yepCi/NbkXskDIkauFHMmeYaPGkak1
HK5jkxzZ3dOrKYhxg1gTOPKUUy4jQX5ZcX4ksEhXd0+GYxeri7rvknzvy6/8
Rug36nAjK7/1xMmTsc88EP3YsDTYWsbYIJhjAbcor7XLz2sN+Ejfm9P8mWSO
Lv0cRye76/WxunWyZtRL3ZcnqH0GP7LOkd8Jcw1M/12b0jdJ0C/6fP8agXmt
1dPbPLYPeLJXiyd7d/Yxr70s9W7vZ7+WCZZEjkRZ4MiFLI6kayNVfRyV+Lsj
VCwONxSLe8eg7eeI5oDI8gIV/BxujWQqL1BQXybgyHR9WWttjqRpjjzTY8gz
LXJkrN+wkCPDXsOmOVK6xuLr18qeiMSTZM6UVPIkM3AkZx7qPHo/RMKRsIZn
82okaxxZz82eXpofSchzv3qafOhD4Efe7sWa3wxjulsN65seR4LvcB2ZMAHm
ftjrs6Ojg0+ZmR3J0969+xKMYZkzesRKcrYsrgMegdv99z/h57V29/YHP6vE
/zmZuTvBxvRzCXVR912J50ajoEZtcAjzWlF2/MnOhoPktw19ev7kbrk/OZj0
Ik2yJHIkKitHtvA4cm2KI1M9dnLXk1Hxd4flWFziSWrF4ZxeJTp+Dr/npUZ9
WYIjufVlM9ticySTMyTp+R9xjgx67YyfFHFkICWOPHOqrzwc+T4WR86vc2S6
33B8Zo0SRwrqe7W8SM46NrYfwt0L4fnq62L7ISq5rQt0aiQL5chAufzIKNbW
0MmwhuqZZ54if/ZnMP+7GD+yyLxWVt4UracMc+Q999xLHn10l/+6kNcqPr7e
UJZ+fwZX6ep4OMvtvvuD+siu3gH/eb+uUvrzvdR9RnUzHoefW1ft80MlddLj
/0Hvb/uJJ130I4Ejf0CCvjt3oiqqdzTcRZaO2a/Ok2/yePLsgCdZ16veuwfk
r3E6ciTKLEd+2ePIOcocucYCR2aMvxM82WbCo8zi5/Di8NwcKep5qZEXOFej
vmwm3bc1PvtDxpETEhw5LsmR42b4gtxW4MgzKs+RdK/WPAy5ib8XIlzD2fdC
2Ot4Pcdb5/nq69IcyeoZJfLUGRyZ7BkV89Sb0p66jCNnGOTInp5+TfX5DDc8
TMj+/fu9a+tWEvRrLcKPhLzWYS/WDeIH/WNXV7fk33ft2pWLG++9917/NQ4d
epYcOfJ6pvNg7ffvhngtUPS4i3pORcD6cLs/zGuFfoz+63T1Kfw8i5v1ODj2
WOA/ouKCPsgD4Ec+CX7kRgKzYYNcA9N/16b0DRLMrz2PoB/piu7050e+o+Ee
cuE77yLD7xzW4snexwdi16uh0xR/fjpyJMoRjuT4OLm9SIk/mSsmz+JJMntf
GvBzhL1K9DhSqb5MypH1XjsTpzQF4nHkxGpy5ALhGs7CkQr7IKrrmLuGC+BI
3hpmcKRWbitjL4TNkZSvHvMkO4vjyN4+PUG82R3Ems8ceoq8973gR94exnOg
bxrWNzyOBN/h2lpeK+S0Qt6j9rEb1MMPP6LFjXS95G9efVXpPbqp+7T6Oc9n
VIK3erqDc+0/zqCToR/5wP1PklM9juzpHQhez2NC+c/n5+DYY0o0G6PSOnmy
N/Ajn3jMUT8SObL6CjgSallhfmTXy6+SgXOHPZ5UYMGIJ8d5PHmgn/Tdo+BF
5mVJ5EgUlyOXxjiykcWR0l6trB47Ao5UiImV42+lvFfFmFzkSWrF4Qocmavn
pVpeIHcGXyIvkMeRU2iOnCbjyHkCjpxZ67dTNEc2CzhSWt/L4Egr+yCmuVIr
v1XScycPR3I8SZanPlfIkR2x3OyZsX5RhvJaQ+9NXUGvFMhrhfmRf/VXF5OA
I4vzI0+cDPNOtY/dnKAXjogbH3jgAfLIIzuZ//bi4Zcyfe494b0VmWTS3sDX
8jnygdCP7Bvwn+8K+T9iZD4nm2PiGB/nYOPRoC7vvA0NEfKk70e6xJHgR0Kf
Hcxrrb5gJinUtP7Q58gTJ2FfbZh0v9JHBjq8xfcORSb8fe9/g/doMGRWlkSO
RCFHIkciRyJHIkcyb9peT2+Y1+r97P4DkNe6hQT1kUX4kbK8VkN+loJY3Lhn
zxPkV796gbzxxnH/e06c6GJy5L59+zO9pyzXNjg/1H1WGfh8wNeC2/01P3Iw
+B1C/o9+HyvqHR3qsfCaUL866P1xP7H3McfyWrcR9CNdUdyPPOlxZC9wZHhN
7/11PxlY7PHk2zMwoqrWIEeiqsyR2fuS5I7B88Tj3NxAeRwunZ2gE4dzZic0
2ubImXKOpOdIyjjyLBZHnpXgSA2WlHPkitpnZpUjbe6D5N0bkdT6ivoPS3Nb
E3shur12Gjl7ITKOnEXV+M5k5Gbn5cheL3bUks8Cvb5nAX12/vzPLySBL/B1
UmdJk/q6x5EQL9Y5Eji2B3q9e0wbHFcf9di+oBfJT3/6U58HDx9+yf+a973w
fUmOhOdU3qeHutdiwF4d5rPD3RFHPsDgyCQbC/lY9/cXfSaOyxY78jlyAwlm
w9rYHzKlr5OgPhv9SHcU9yO7un5D+vqGqGt6oL6X+shgyyAhb7PEkjciR6JM
cGR89l4TgyP5syPVOFKdIS3E4Ix4PBNHKsx1F85O0OLIer8d5foy1uwPxfqy
OEe2muNIypMsniNXCThSoU9UYh2re5Eb7a3fFFOa9yRbRBzJ6LUTW8c2OXIu
iyPbzfiRfX168nMTg36tv3oe5n5cRsAXCGLNgvzI7jAvsq8/PK5+6nG1tG/f
PqYnCZ+h7Gd7qXtl9SbUw3iut5/Y5m5gfbjteCDkyL7BgIl7+mKMnHzM2rdA
BcrkT2sKzluQ1+oaR4IfeZ2nu0gwB+R7qMoKZslALvIPAj+y+1XS2z9MXdPj
6n2hnwy0DNnhSRWWRI5ESTmynhOowpG6syNV+pIY9yIFUvEleXG4aK67lp+T
YXaCTp8SJY6cLePI+hxJJkdOrnMk9NqJ5kjyOPJLPI5UZEkRR85LcmQ4/9QE
R1ZmHyS1jjPkaEs8SRlHJvdC4hyZ7LWT2AtZwPbUeRzJ6tlqhSN1fZG+fn9u
AvTZgfmRp5xyKQnyy75O7HiSkR95TZ0ju8IYGnq3VMAnEumFFw4zOfKV37yq
9TrKDNenoj7q3o6gFxPcHtgBHLmO9PQPBFzc2xtjY95eRbK3U5k9laqi9H6A
eXV75w16Me91zo8EjkQ/0g3F/ciTXa951wJCXdPZ6n1+gAzO9f7jeUvBLIkc
iSqRIysZg2f1c5Q9SbW8wMx+jkJ9WZ0j5fVl9RmSrfEZkkoc2TjyOHJxvMZX
fR+kWI605Unq1EgmOdL3gHlrmK71pfZC6PVb89Qb5Rw5wxBH9vYN6Mn7/xz6
lMCs8l/96hly6qmX+PHcmDG3ePe3kDpPmtItHkdCvPjlsF/rsN9jx4+rfRbS
PP6CdfTYCSZH/uIXT0t/toe6V1Yvdc+VfQY/mfAju/sG/ef9HjeUD8lkZCUW
NqW+gt8vu3qoe1uCPkjenzZ5ch9w5HoCtc9jxtjKWTehW0hQnw3zh5Aj3VAi
r7X7VdLXP0xd08Xqv2XQvC+5AzkSVQRHrk3F4C0sL0e7t47CrD1rvqQtT9KE
n5M9L5DmSFl9mTJHUiwZzJAUceTsanFkxvreSu6D2PQk23me5Fr2XkiyTjIz
RybWcIEc2efF7VqCeBPqI73/yp9//uliOXJ84Ed2dwV5fn0eC2kffwmCHjxJ
jnzk4UekP2cn5zTaD6AeWxCwvs+Rvh+5gfT0DwVM3NsfY2QpJwt5GGVacN6G
nPUjMa/VDcXzWru7XiP93uWifk0XS3lepI7+xNMe5EhUHo4M8s5yc2To42jV
k0ln7W0OVQE/R+JJ6va8FHLkwnReYGaOFOQF+r12ZiV7ti4MZkhOz8aRZ7M4
8mwBRyqwZHkcmdeLtLR+c+yFqM1EZXBkskYymaO9MN0zSsiRzcviPaNiHKnY
s3V2OX7kkO9HFp3XGsyP7Orur/GIC9rzxJMpjty+fbv/OYp+rs+Kov0A6rEF
dSf8yN6+wYCNe+p1mZlZuQLeYBXUY+E1YS4r9GIO/EjgSFf8SMxrdUe0H9ns
Xc9fI97SU7qm999rwYuUsSRyJEqZI1fm4Mj1bI7MVRO5maGC4vDF2T1JZT8n
yZGy3NZUHC6qL+tQri9jc2RLiiMnKXNkevZHeRzJ6TfM6RNlx0+3uI5z7IUo
ceSiNEcu0OLItK+e2gtR5si6rz5jjjmO7Osf0FNfMAcQejo+/8Iz5IMfLM6P
HD8xzGvtCWNoqLkzpD7q3rSef+FFZm7rq6++pvwaJn/XWlxGPzbsTYr8yIhp
M7OygmeByqae8LwFfiTktd4e/m2b/rs2pZtJML8W8lrRj3RDCT+y5zXiXYr8
fQzZdXD47y14kTKWRI5EaXJklJuW9nJUONLkjARW/G04Hjcdh8s4Uurn6HCk
oL5MgSNn5OZIumermCPPVOFICU/KOLKRwZHzGRypVd+r6kNKvUh7azjTLBuu
Jxms46SnvlCTI/m5rdk4sraG6Z5RZfmR/f1+3xPIfQM/8m/+5mIS5JfdHOoW
w7rZ40jwHa4O++wQ0t0d+lkGfbpe6t608tRIWhHNk5Z4GrxWnyMfDDiyd2Ao
eG1GrNir8p6K5xCVT3DewI/c56QfiRzphmiOVPcjB64bssuQNEu+gRyJUuPI
8zsmke+v/4ynz5K7NgT6wYbTAm0EfY78cFOk01P6UaTNkf7Z191bVPV5qbZv
9aTwffnEOLbwd2HrdLbCz4P1WdU+R+8z/UFK4eftfe53xfTZuLzz9H1fnwm0
LtB/+/qnutZ+2tedtNZ8ytf3aJ37SfLdmD5Bvrv6E+Q7vj4eaNXHybd9fYx8
e2Wgb638aKAVoH8kd0Ra/g/k9kjLPkJui7T0w75uXfr35NbOQN/s/Du2Otja
Nv7t5M5zP0K2b/40uXjyu8h5iycE809L5UgZ520m7aHUmDIDV2aaZbNeMUeb
5kh+jaTQV2fuhahxZGovJMWRgXL5kQrxecw7gpg/ZISnnjpI/uAPtpAgr9W+
Hzkx7Nfa0x3kRPZ7x2NKwt/ZgB54YEe6RvKRR7LnpvaZ5WjTPB35kQ9w6iMz
s6+Gv4zSF/Q68Tlyv4t+5LWevu/pOyRgSVQ19R1vTX2bAPO/731NpNvjyP5+
It0bHB5r2Yuk9WGKJTkc+eY3/ww1yrTkM2mOvHPtZwm5pgGFck7fW/NPAUc2
cziyJeDIeL9hzT5RuWsiPYbspGSJK7mzbBYHYvvqvBxtCUfKPPXUPFRZjeRy
Nkeyeu1Y4Mh+7z9wHfl9dnp7/dkATz99kLzrXRC/3UoK8SP9vFYS1hX2eXFv
vzHpfg66euKJJ5g1kr3eZ6n/egP66pN/T8QS/Qq8YcyP7FN8zQw8XJyi+sLy
/UQTfiTc9vp+5Drv7+42L+a38XdtSl/zj7GhAfaz0I90Q3E/sqfnVTIwAHua
fdxr3uD1FusieYpYEjkShRyJGoEyy5Hx+l612kh5TnZ7kiOT0uZKvidpdA6I
hCOFua0pjgxYsknKkRFLdsbys0UcGakIP5IW5LUCRz7/PMz9gLzWr3txwdfC
mO5mw/qax5HgO1zlceTagCMt5LXa1vPPs2skX3vtSA4/UkP98u/pD0U/ziro
6Qu3Bx98wufI/v7B4LV7w1ixzzyrm9xX0FPEu4nn6c9eV3l+NodgjwhubvqR
yJFuiOLI9zYr+ZGFepG0Phwq+Txy5KhUjCNbkSNRbivGkfNNcaR6jx1tL1JF
Skwp8iUN9R9O9h1O9h7W4ciFChzZnKzzTfQeTnDkTIMc6cf3GvI9Je//e7j9
4umD5O1vBx+gmPrIiaEf2dMTxBa6x16mjh9n10g+++wvFT7z6PEAde+QH3n6
BtJH+5F92TxGmUzmOesp4mf1zzrzubP8u0Q56/v373LQj8S8VjdE57WCH/nb
0I9kX9MHry+oLpKnP0KORHE4sgk5EuWu7HNkdi+yXcWLzM2UGj13uLmtir12
kvNQZRzJqJHMx5EdFEfGe7bm9iO9/8D1NEh6+gI/Ejjyj/4o4kj7fmTEkd1Q
Ywf+ifaxl6sHdqRrJHc99hjze/up+7oGqXuJojhsQMyottTTE+w1PPjg3sCP
9DjSZ+JkrNgXysB79hWqAeqekg1G7k88tiioj4Tbvv27Q468Ncw1MP13bUpf
JUFe/WaCfqQrSua1vhZyJDtnf2CXx5LfGiRDq4fI0MIhMnzaMBn+u5L8yUjI
kaNSyJGokSTTHKlTGynrM5yLHxk8qexLGsttTc//YPfaoeehanJk2GtnniJH
gic5i5PbWqQf2R/6kcCRL7xwiJx66kUEfIExY74axnRfM6yvehwJvsOVTvuR
oN27H09x5H333cdlojgbaTJBxKT04wLV3Uv5kZ/3OHJwOGBjyEEdCGPEiI/7
k7xcLaV5XsD0yXOZlZHpn0vuC1gU+MVw27//cY8j1xL0I1E2/cj3jm32rhW/
9a4PJOiP5a1BXQ3cN+RrcLX3n9Iab/F+LtQ7kSNRyJEoFE9KHNnK4Eh6bmR7
lh47Cl6kSY7ksqTZOTZaHNnG4khxz9Z6vx09jqRrJG1w5AD8P6ypvjDWfPHF
Z8gpYX1kkX4kzDr096kzHHuZ+uUvf8nMbX3jjaOx74ti+uhxXxYmYDFIgWL5
kcDDfj/Y/jAGjBh5QMX/K1Y0y/P2U+r3lGywbJK5Laq3N8prddGPvMbTf3v6
NglYElVNfdtbU98iwPyBH3lEmNeqI+YN5kHu8HQxCThzWsiZY5EjUciRqNEr
ZY4UzPzIwpGFepGcnjzt1nNb5Rzp87mQI1dzODI++6NsjszqWcBsgBde8Djy
lMCPDOI5237kWv+Ye3oDn822N2Nar3u8yKyR9PiS/j6aJ8tm36yKamh/DBxZ
8yMH6+etRMZVUdoPHh3q6U36kS5xJPqRbqjuR44d2+xdK35LBgeJkb3BTLdf
kYAzv0sCzmwldU8z+f9qJOTIUSnkSNRIEosjI15Jc+Radk4rgyOjmYssH1Kp
R6stjkzIRm5rjCeTHLkoB0eGYs3+4HEkq2erFT/Six21BCzQG/mRkNd6oR/P
jRlzk3d/E6nzpCnd5HEkxIv1vNbenqAniPaxV0CQx5rkyMcee0zoRzqhiMHC
ryMeeZDiSP/3ccRHdu7zN6R4XqtrfiRypBtK9NnpPUK8pWdkb9DKjTX347+Q
I0ejkCNRI0lmOHI91WNHzJHRbA19L3ILpYpy5GIGR8Z67awjrJ6tQo5M5rbS
syRTHJmY/dFUIEfqxtj9VF5rrT4y4kjTDBlxJPiRV5AJE9b67+tqXivosV2P
MWsky+bbXGL8njE/8p8ZfqQNJVg2j2iWHE3qS9VHfjOsfTadZ2BKN5Ggz9cm
ghzpihJ+ZM8RMjhAjOwNWrnh/EgUciRqBMo8R24QcKTch1TjSHM8aaNva5Ij
U/M/Er12FiRqJM1yZHr2xyzO7I9cHDk4qCefBYJY8wWojzzlwjCeuzGM6Uzr
xtCPvIJMnLjef1+osYNaMe1jt6qBUOLvU62RdEphDBdxHDzuDesjf7wj9CMH
hoPvsekjG/p9kiw5mhT3I9d4f3ffsLhHZEI3+sfY0LCRYH2kK6rXR459XxPp
7T1Sbl6r7IYciRJw5Pkdk8j313+G3LX+s+SuDaDTyA8ibfwc+SFo0+kp/Qi0
Oal/JneDtiT1eaG2R9qa1L9IxPoZdYmPi/V7BL/fj5hifB6Mzy3Q5wKFn+8P
YjqtLu8c3FXTZ2P6/vrP+uctpnWfIf+97p/iWgv6NLkzqTWf8jgs1LmfrOm7
vj5Bvrv6E+Q7NX2cfGfVx8m3fX0s0MqPkW+t/GigFR8ld6z4x7qW/wO5HbTs
IzXdBlr6YXIrqPPva/pm59+J1VHXtvFvJ3ee+xGyffOnycWT30XOWzIh5Mjl
PpMY48gMNZHifFYWR5pkSVt9WyUcGeu3U/ckY76kDkfSua1MjqTmf0SzP8qo
jxysx5ovHj5EPvQh8CO/Vkhe6+TJW/z3hZzJWt/P0hR9Jnr+2utH2TWSv3r+
ef+zLU4DoTL+fIK1kvEcy4/0v9emj8xgy35bzDpCFeWs79+HfiSqAD8S8lr7
jpCBoWAGVd7rmpUbciRKwJEQt0EcF/UoieLv+MwEOv5WyAlM+jiZ+5Lw4m9D
sbhRP2dDulfJopx5gbE+JYFU+5TMruUEyvMCp89aVNO0mW1k6sxWMnVGC5ky
PdJCMnnaAjJpKmi+r3OmNJOJU5rIxMlNZMKkRk/zfI0/Zy4ZN3EOOXvCbHLW
+Fk1nTluJvnS2TPIGWdNJ/915rRAX5pKvvilKWKdUde7//Q9ZNasWWTx4iXk
fWP/2v+dTHFkq5AjTXuR5taw8dzWWM8dNY5MruE4R64WcySs4fl6HBlfw+2+
8uW1DuhpEGZuwPzIYXLo2afIu98NdUnAeTcSO54k+JEQL15BJk3a5B9zNfJa
o8+EfiwXfHYsjnzyySf1z4W2Bqn7nAr91X7qnlZPuNfw4x97HHn6BtI3NOw/
rxcrKnwvg9V5bFsd0eejWoryWvehH4kqwo8ci34kyh3Z5cgNTI6UMmSu+Lti
cbhwlrtCXqBCfZl6n5JO5fqy6bMXBYpxZGuaI6fFOdJnSSFHzi6WIxcocCS9
httVODLPPoj9dZwtt5XHkYx1XBBHptawMkcGysORg95/4DryY/T+fp8jn376
KfKWt6wngS/wlVA3GtZXQo68nJxzzgb/mPv6guMYHBwqUdFnQj9WE/TVSXLk
jh07tF9HXwPUfU4NBOIxazQ/Iu5HDvhrxyjrDqbFY9tqaoC6L1+9/eHcjwPA
kecSmOkzZoytnHUT+goJ5g5t8PRlT3d6+hYJWBJVTX3LW1N3EGD+se9r9K7n
vyVDQ7Cn2Z/7umTlhhyJEnFks4AjW+Uc2cqNwTcV4EXmj8VN+zn82Qlq9WXC
GXw69WWjhiOXKXHkwoQXqcqR+fJZs6zj4vZClPZDZJ56Vo5coMeRtTU8zzxH
DngcpCXKs3j22YPkAx/YRoK81oghbdVHXkYmTFjjv2816iOjz4R+rKZf/vI5
pid54sRJ/fOhpUHq3ozYnFpfIz/+8ZM+Rw4MDYf7EAPEKOsOpDUgYdxqSZOb
C/Ijg/mR6EeiCvAj+44Q77Jk5Jpu5YYciZJx5HwBR7ZxOLJdkSON15SZjcWN
+znt+nmBYo6U+DlcjlTvU5LkyGkRR0Ju64yIIxfyOXIyiyPnVJojW5IcycnL
LsZPN7GGLXGkzFNvS3vqwr0QVm52yRyp62lB7hF4cD09veTqq68g7e1rvXgz
YkibfuRltfmRrvuRRzk1ki+++KL2a+lpiLo3Ix6zAuvDzc9rBT/S40h43s83
VWbdbHHlIJNxqyQWS5e5luuCv2+4HTgQ5bW65EciR7ohmiObvev570I/Mv/f
gZUbciTKBEdSPo4KRyrNSFCMwRcv9eRKHM6dwaeeF5iZIwWz3NN9SmiODCXh
yMnKHDnXEY6U1/ea2geBNWyLJekaTfZeCGMdizhycdpTb1HlSNY6luVmh+u4
vheyNJafHfPUrXCkJjeE/9dD3uL111/jrclzydvfHjHkDaSe32pKN3gcCb7D
pRXjyHzavn07s0bS7vtm4159TqX9yH2afiR9nNk0QN27ozK99bqiXsz7D+wJ
81pvoXINqqgb/GNsaID8esxrdUNUXuvYJu9acSTkSNm1QS4rNy5HPowaZcrK
kcl8QCWOzNyXhMORS+3F4sVxpFpeoBZH8vqUCDhyVqLfZZoj2+QcObXOkRM5
HHl24Ry5MgdHcup7DXAkvX5hP8T4noiAI6P9nOy1vgocmfTUUxwpW8NJjoz7
6kVwZBR3qypihKefPkje9rZ1JKiPjBhy5PmRup+Pih55ZCenRrJcvq1pIB+b
9tF9dlgcOVC2J4hiqT/kSPQjUehHhjfkSJRhjqRzAms9HhMxuAmOjMXfS/Py
JD8ml+e2svwcTu9W5Vnu/LxAYa8d1T4lMo6cy+HIWaocOZ/DkfMqwZHNWTky
Oe/DlJ9e1hrOzZHrlThygXWO7LTHkQNDmhr0ZwD6fXZ+8VTIkeAX3kAK8yN7
B/0ZBfrHXh098/Qz3BrJMo5nIOJGZX4Uq6+W17rP79cacORQ2BvHzHuUy88j
5H0Tque1oh+JKtqPZHCk5t+FlRtyJMoKR67PxZEqMbiII7PlunLicAFH6sfh
6/PnBYpm8Kn2KWlUrC8TcCTM/pgaceR0GUcGqhZHnut/rrX6XpojpfW9onkf
2f10cywZX8ei3FZxrS9njg2XIxU89TwcGa7h1AybGEd2lNtnx899A44k5BdP
HyR/+La1JPAFIJ67nhTBkb19gwp1dtXWa789wqmRPFzK8QSMF349kF8wmwVu
Dz64r14fOTDkz3OscWsVNTjK3jeh/pD/D+x3jSNhPws50g1FHPk9jyMbSV/v
78jQIGHvDSb+LmTXDSs35EiUIkc2ZeLIeuzpe3RCjtTLaZVypMFcV3McaSAv
UMiRin1KVDlyTnttljufI1tSHDkpxpFNbI6c4DZH8ut7Ndaw4n5Itj2R+F5I
pnmovDWc7DvczvPU13L3QpKeerOII+frcSSdmz0zrx855P3f7GlQQ9BXD25P
P/MUedtbI468PtQNhnW9x5Hw+pd4HLnGf9++/rCPiuZxZ5Xu56P6GbJqJPft
21fY75X6HQfDrw34WjE/8vMMP3KgfJZnqqzjqsjn0Rf6kUF95GoCs2HHjLGR
Z2BK15Ngfi1w5NU+mzQ03EEClkRVU3d4a+p2Aswf79fK2BsMWTLa60I/EjWS
OLI1yZGKPo5pjszu65Th5+SfwafUp6RRo0/JiOPIVf5nNp/myEWJNZyTI/Pm
tJpZx+ZqfaW9dtp5a5jDkYxeOzKOnKfLkXPNcOSQ93+vrgbCWPOZp58ib635
kdeROkua1HUeR0K8eHHNj+zvC+rrshx7lbSTUSP50E8fKuz9B6n7GEMa4NKI
R378k3qfnSHgVaiRtMTmmUX/7lWQwfOQZX8DbgcOAkeuIsFMHxv7Q6Z0HQnq
s9GPdEeRH3lnUB/Zf4R4l4f63mDi73GAupfJyg05EmWaI9uzc2S7qZxWI7mu
ir1K8vo5unmB2rPcWfVlydkJpjgyUsiRU6rGkaukHKlS38v21PP1iCqCJcVr
mLd+ZXshChwp7bXD4MgFehwJa3g2Yw2b8COzxpq+H/k26MUB+WXXhzGdDT8S
OLI8P9KWnnmGXSPZ09tbyPsPUfe+Bqn7nIryI38S9msdDP3IiP8HDbyHMdG/
exVk8DzoKtojOoh+JMq6Hxnktfb3/Y4MD5H63mDi7zF53RLtQVm5IUeiKsGR
ejPbM3OkViyuHoNr+zmZ8gLNcCRvBp8KR0Y9W6fOjHPkFEc5cgGXI8X1vWVy
pN5+iHqtb77c1vVSjpTVSNLrmPbUG1U4stEeR2aJcwdCjnzG50jwI4EjryN2
PEnaj1zjv69fY+dxZOnxfk4dOcKukXzllVcKeX+aJU0r5kd+Pu5H2nzfTEr4
H6WLPqaChX4kqlg/sknqR+rsg1i5IUeihBwZxuAijhTN/GBwJDsfsFiOVK89
s5Xbmj8vUKu+jDVDUrVPiQ5HRqrNkNTnyDM8hjyjxpESltTlyPAzUudIur5X
jSOt+unaXGkxt5XLkfU1vNAYR3L2QhK52dXlSOC8a0NdZ1jXehwJnHoRmTBh
tf++I4UjBzg1kgcOHDDw+oOhyvndor6fPwk5cjDkyMER4COPZMU5ciUJONJW
zroJwTUH+nDBdQj9SDdE+5HAkb+Lc2QOWbkhR6IMcWQLMycwHYPzODJ7TdlW
ozF5Mb1KNDkyS16goE9JJo6cneTIQGKObC6VI+F3nSfhyIXKHCma+ZG3ttfg
Gk7tjVjKbU1yJMNTX8jz1CUc2aTEkekZknY4clBbAwPBjLlnanmttjky8CMn
Tdrovy8wyuDgQKZjr5oefvhn6RrJh36a8fWGqHuT0n9NEUeWze8ovqI9ooM1
P/KrjnAkXIeu8vRdT7eTgCVR1dTt3pq6zT9XwJH9HkdC/28T1wYrN+RIlApH
LtDhSLGXY35OwlajcXjxfo4aR4rjcL0+JTKOjPpd2uLIcRMVOPLMiCMFLJmV
I1sEHCnNy7bFkbb2Q8zltrZx90LWM9dwmiPj+yHJWag6HMmukeysoB9ZBEdC
/hrNkSPDjwSB98jKbe3t7c3wejRLmlK236vOkXuRI43J/mcX50jwI290iCPR
j3RDcT8SORLlilQ4srnSHLnVTDyey8/h57amWFJUX7YoR32ZQp8SJY6kZkgm
OXIazZHRDMlpC0c1R/J7RBW8fmUcmWMvJBdHtqU5kjX/Q8qRsIabi+TIYW3B
7Aa4Fc2Rkydv8t+3vz+sm8lw7FUT1ELyayR1X2+IujfFHdn4s78/8KzRj7Qh
G/sF8VyDuh95kyMcGeW1oh9ZfdF+ZCNyJMoZ6XFk1OsSORI5EjkSOXIkc6T+
/9VxPxJmlQPnXRPqWsO6JuTIi8ikSRv89x1JfiT4jiyOzFYjSbNkHvG4RV1p
PzJ4nZGSj1yusp0Tnb/tuB9pY3/IlOCaA3OHMK/VHSFHotxUmiOXcTjy3PgM
dwZHpmJwCUcq10Z2yuJvc7F4lrxArdxW5foy8/0uWRzJqy+rc2S7lCMht3Vy
iRw5U4cjW01xpI19EDP7Ieb3QjYK1rCcI/2+Rlk5cr4OR3ZUiCNhNgD4Al8O
dY1hfdnjSHj9C8nkySMvrxX00EMPpTjy4YcfLvGYQp4cHI4/HlTnUDhHcMuX
1+rKOS76OE3tF/BzDQKOXEEg12DMGBv7Q6YE1xzowwX7WZjX6oYwrxXlpuIc
+Z/MGe61uXssjmwXxOBcjswTg8s4Ml8cbr9GMmt9Wf5+lymOFPQpYXNkm5wj
p7I5cvw5FeLI2tyadenZkYK5NfHZNTY50tIazroXklzHEk+97qub4ch5pXBk
9ljT58i3FsWRF1D9WkdOXivowIGDKY6EPq7wOed97cFQ+fxIfc5J99kJ1lrq
vCmzKSp+fkycp7TifqSLHIl+ZPWFfiTKTdnlSHF/EnscmSMWN+3nLEn2vMzJ
kYw4XLVPyZxYv0tNjpylypHzK8ORjVocSc+OVOPIbH66/TVsfC9ExpFJT31R
2lMXc2SUm72qlptdz8/W48ioVxQoD0cODg5rK/KagCPf+jaooboujOGuJnWe
NKWrPY6E17+gNj+yrw/i3aFMx15Fvfwyu0byt789kvu1hwpS/L2GSH9fwo8M
n6/NGh/UjxEHi/D6MhxX8e9Ls6S6VPYT4n7kcuIWR0Je63c83UYClkRVU7d5
a+pW/1yNHTvP+//kCJ8jU38XYta0ckOORClz5KoYR9Zn762Tc6Ssrkylx6VW
TquZWNy0nyOenaBaX5afI9n9LrNx5NSII6ePDo7059YsKcqLzLmGM85DjVhZ
7qtL9kIWpfdCYvshPI6kPfVa72E1jkyt4bn5ODKLHxLzI/+wKI483+PIc/33
HWl+ZG9vH5Mjn3nmUO7XHjSpQf6/Jd+rL9xr+PFP9pFTQj8Snh/wZ4xTr6fA
wUXysP+5Ffl+Jbwv/bny9ojQj0QV5kf2/Y4Mw/VhYMC7LsA+k0ptMFtWbsiR
KAMc2WKFI015kdnjcdN+jvosd359mYgjlfuUaMxNmDGnPZCQI1vUOHKSmCO/
lOBI6QxJExy5SM6RqfmnpXKkHk+K5qFyffUlqus4J0cy8rP5HEmv4eXp9Uv5
6iY5cnh4WFuwbww34Mg/rPmRV5E6S5rUVR5HQrx4Xo0jwYuEeCLLsVdVrBrJ
nTt3ZnqtoRI0mPi6fyDyI8O81mESfF/SRxsclnKwcR7OyMoj5X1F3mTaj7zB
i/lt5KubElwjoF/0aoJ+pCui/chG0kfntQ5SPiRTg4J/Qz8SVSxHzk1y5EKT
HKk3b88ORyrE5Uq5rRp+TrLnJZcj+XmBmTky0WtHtb5sRiRNjpzE4MgJKhx5
1jRf5XOkWn2vnR5R5tawaB5qfo4M1nCrKkeyfHWZpy7kyGX++p1jkSNz+5Fv
g56O14YxnA2WTHPkSPMjQfv27TdWIzlcgpLvOxD6Wj/1OPKDoR/pf9+gHv8n
WTXJq8Y1ZPn1S3pf1mcn2iMKOHIZgdrnMWNs5BmYElxzoJ8zcOSVBP1IF5Tw
IwdeJ0CAA0NDCvsrjO+hZOWGHInS4ciWOEcujHFknYdEPUpiPo4CRy4uLAZn
x+Ly3FaNOFzGkdz6srVuc+TkxkC2OXJmnSNnF8WRldkHYa/j5HGo7oWIe7fy
OJLRa4fBkaIaSW2OZPSLqpQf6ee1XhPGcFeSOk+a0pUeR8Lrb/M4MuizMxL9
yMOHDzNzW48cOVJZP3J4mM8j0V5DjSOHg7Xmn7ecjGpcw9R9FUQfUwHMT2tw
wFWOXEXQj3RFcT9yYOB3BAjQz2kdDv3IYVrD1L1YVm7IkSgbHCmqLVPiSPVc
wCXLSuLILH5OanaCfl5gcgZfpj4lChw5i8ORUc/WqTD7Y2adI6fEOHKBmxzZ
XhJHGl/DWzlrOJ3bmqnWV8SRsb2QdWlPXcKRqb0QHkeyaiQryZHgRxbFkSM3
r7Wrq4vJkYcOHSr92HiiWTIpYV6rQjxYiheo4PUWIvqYCtaAs35kxJHf9nQr
CVgSVU3d6q2pb/rnKujX+joBkPRzFZj7G0PUvVhWbsiRKF2ODOM/Ixyp0l9H
gSPNs6RdPydPXqBwlrtqn5KCOXKix5ATJRx5JnDk2dXgSNW5NUr7ILI+rcts
rWG13NZMtb6JXjvx/ZB16fxsUZ2vDkeGazg1CzXGkZ0V48gVYTx3RagrDesK
jyPh9beOaI4E7dixI8WRu3btKv24skjoR1bg+FBspfNar/Niflu1zyYE1wiY
C7QyfIx+ZPWV9CNfD/3I/HtMVm7IkaisHNkm58g2bgyuxpHp+JvPkX4cHqni
fg6fIxXyAkWzE1T7lAg4MubnJDlyNosjW9McOY3iyCkjmCMN7oMsscKT8r0Q
oa/O2wtJeOrZOJLnqZviyI4KcOTB0I+MONI0Q44ujty7d2+KI++7777SjyuL
kCPdVJwjlxJ3OHJV+Bj9yOqL9iPn+RwJNxPXBis35EiUFY7cIOTIdm5Oq3p/
S1b8bTYWN+DndOSpL6vH4Tqz3JXqy1gcycoLnLNkxHBkUx6O5PQbtsWRS4zt
h+jW+mbcC4nV+ipwJKPXTm0dp3KzV6Zys93hyKcSHIl+ZB7xaiSPHTtW+rHp
CjnSTaU58lov5reRr25KcM2BftHoR7qjtB8JN+RIVNWViyPbNTnSwJwEGUea
ZEnzfk6O+jKjHBnF4YJ+lx5DzmRw5DSPIadFHDkjH0eeBRw5rjyObIn1HM7L
kbwerXocaWYN25tjI5xho8CRyTWc4kiBp+4OR/4izGsFX+DyUFcY1uUeR8Lr
bxnRfXZAvBrJ5557rvRj0xVypJuqc+TjHkd2Eqh9HjPGVq6BCcE1B/o5rwiv
F+hHVl/oR6LclCmObDXEkbIYXIUjY7mumWJyRU9S18/JkxconeWu0qeEM8td
ypHtEo4MRHPkOT5HNlEcOc/jyLkeR87xGHJ2oRzZ7M+uycORKj128nuRZv3J
nDNAVPZChBzJ8NQtc+RsqsZ3Vul+JMyYK4ojR7YfCWLVSO7evbv049IVcqSb
ivuRwJGu+ZHf8vRNErAkqpr6premvuGfq7Fj5yJHopwRiyPnFcqRZr1IMzG5
vdzWzHmBjFnuOvVlco7sVOTI+vwPMUdGvXaCOZJpjgTNrPVsPcPv2Tq9xpH/
hRwp3h8pK7dVxJEZerbS+yG0p97E5cjlYo6cVwWOPBhyJMRzl4W63LAu8zgS
Xn/ziPcjQXv27BkRNZLIkW4qzZEu+ZFYH+mG0I9EuSkeRzbm4shw1oVVjtxm
hiu5Mbmd3FZ79WXyPiW5OXKWmCMna3PkrIpwpHj+6SINjtTLaTW0hm3ltrL2
QhYn13DaU29hruHkDJu8HLnMX7+Qmz2H4amX70dCT8ciOHKTx5Gr/PcdyRwJ
OawjoUYSOdJNpfNav+zF/DbyDEwJrjkwF2h5+DX6kdUX7UciR6LcUVaObBFx
ZCL2NFVXlubIbUZicXY9Wgl+jon6MkGfEjWO7LDOkWd7DHk2lyOnURzJYUkj
HLkuzZHSuTUsjlTfB4n2LWysX/Y6NpXbuklrL0SZI5O+ui5Hhmu43nu4ahwJ
PsCloS4zrEs9joTX3zQq/EjgxZFQI4kc6abSfqRLHIl+pBtCPxLlpuxzpMjH
kcXgW2IxOJ8j88fjxfk5lvICVWdI6nLknPbaDMkkR07NypETZtf67ZjnyE7/
d4Tfuc6Rwefjf15ZOLLDDEfaXL8yjsyzF5LcD8nFkUlPPQtHJtZw9TgS8lqX
hvHcJaTOkiZ1iceR8PobRwVHgiCP1fUaSeRIN1XnyCc8juwgUPs8ZoyNPANT
gmsE9HNeRtCPdEXoR6LcVCaOXFQER4pyAUWqop8j4EjlvMD8fUqyceRiOUdG
ijhyak6OlPXaUeVIn0dWJThyjZQj+fNPNzHm1pjw023th5jZC0nth0g8dRlH
LkhwJCs3O8WRsBcyn91rh56FWg2OTPqRwJK2/MgNoyKvFQTMmOTI+++/v/Tj
0hFypJuK+5HIkSjkSORIlApHNkk5cr2UIxcpcORiZgyelSPzxeNF5Lbm58hs
9WVzFfuU6HFkC4Mj53M5clylOVLcJyqdm63hp2txpMk1rFbrW98LUdgPkXjq
cV89WMPJGTZsjqznZtfzs13lSNqPtOFJjj4/klcjCXNByj42VSFHuqm4H7mE
QO3zmDE28tVNCa450M8ZrkPAlXd4+gYJWBJVTX3DW1Nf988VciTKJRnjyMW6
HKkef2fnSP2YvIjc1mx5gZxeO62GODI5+4PBkXTP1qkzM3LkRHWO5PbaSXDk
Jz7xL+Rf/uWMBEdSfnqKI+k+UbY4UtSjtcg1rOira3GkZC+kPb2Gk72HhRyZ
9NW1OTJQuXmtnWH8djGps6RJXexxJLz+6PEjeTWShw8fLv3YVIUc6abc48hL
SdDnK9rPQj+y+kI/EuWmrHOkQl1ZMQypHperxeDqfo5urx0ZRybjcNX6srnM
PiXsfpd5OHJSwRzZ0PDn3lr+m1wcqTK3RsSR6n666XVsiCMl+dniGsksHLlG
kyMT+dmV5sjIj4w40gZLRhy53uPIlf77jnSOBLFqJPfu3Vv6cakKOdJNxTly
MYGc9TFjbNU+m8lXCPLq0Y90R+hHotyUaY5s43Akr65Mf06CLel6kupxeHaO
VJjlnoUjFfqUpDhydlkcychvrQRHavRptcqR7HVsJ7dV0VOXcSRjfk3KU6dn
2Ghw5OzKcCT4keALXBTqYsO6yONIeP11o8aPBLFqJHfs2FH6cakKOdJNpf1I
VzgSrkPoR7oh9CNRbsocR24Qc2TpOa1lcmT++jIRR6r2KZFzJDVDck4gFY6E
XjtTFDhy/DmucCRr/unmhKduo0eUfY6UrWFRjnZyL6SNu4bXSzmStxeixpHL
HeBI6MVRBEeOLj/y2WefdbpGEjnSTaU58gov5reVs24mXyHgR7gOoR/phtCP
RLmp6nFkmTG4Qhwu8HN8z5XFktLZCfK8QOEMvlSfEoojEzMkVfuUzIwk5MhW
BkcuMMORZ5bIkZx+wyyOtNcjaqRwZLiGk766zFNX4shltfWbys2eVwWOBF/g
wlAXGdaFHkfC648uP/LIkSNO10giR7qpdF6rSxwJ+023e/o6CVgSVU193VtT
t/jnCjkS5ZIyc2T7KOVIQ3G4bl6gHkdy+l3m4sj2fBw5aSRxZBX9dPU1LMpt
lfvqihyZ9NSTvropjoQ13MTIzS6dI5eE8dwFoS40rAs8joTXXzOq/Ej4jLdv
3+5sjSRypJuKc2Q7AY9vzBgbeQbm8hUCH3IJQT/SFUV+JHDkXORIlDPKy5Gt
rNoyLkfqzUmoYgxeCY7k1ZfJ+l0a5MhpPI6cxubICRk5ktlvp0COXKTNkYl1
U/j6VVvDmfoPC2fYpDmyhcmRyb2QNezcbBlH0mt41HPkCv99RwNHgnbu3Ols
jSRypJtylyPRj3RHkR8Jea2NyJEoZ2SeIzcyODLDvL1ldAzOiMOXlxiHdybz
W9XmSeapLxPOcuf0KUn1u1TmyI5RwpF680+T67g6PaIK4kjZDBsjHLlazJHz
ZRzZWQGOhLkfi8N47vxQFxjW+R5HwuufO6r8SNChQ4eYua09PT2lH5tMyJFu
Ks6Riwiw2ZgxNvLVzeW9B/yIfqQ7wvpIlJuScWSzLkdycgJ1e1zK+lt2LLfJ
knbi8Fx5gZJZ7kp9ShQ4craMI2e1BYo4coYCR05W58gzuBw5VYMjl8c5Mvxs
gFUW8DhSYW5NiiPz+ukFrGFh36i8eyF5OLJNhSOTudl1X73aHAl+ZHsYz51H
6ixpUud5HAmvP/o4klcj+corr5R+bDIhR7qpNEde6sX8NvIMzOUrBPXZsJ+F
fqQbousjMa8V5Y70OZLOCczOkbIYXIUjayxpPB43xZHpfjv0LPf4PHdJXqBk
lrtSfVmNIzn9Lhs5HDmnvTZDss6RbQyOXDhiOTLqoWSMI5cXs4bV+w+r7oUI
ZtiIPHXWLNRWah0r5GY3OsuRNlgy4sjVoy6vlVcjefDgwdKPTSbkSDcV58g2
4hZHwv1tnm4hAUuiqqlbvDV1s3+uxo6dgxyJckY2OXKRDY5cHo/BO3jxeO6Y
PCdLyjhSt76MO8t9TQ6OpONwEUcuVubIyQyOnJiVI1PzP8xwJHyO2vNPE32i
ZDmtqvsg9tawKY6Mr+O25BpW9tQZM2xYHCnIzXaLIxeF8dy2UOcZ1jaPI+H1
V3kcudx/39HCkSBWjeRDDz1U+nHJhBzppuIc2UoCjrSRr24u7z2oz24nAUei
H1l9oR+JclPV4Eieh5OOwXnxt/mY3FZua8a8QO4sd40+JTRHNov7XRrhyClN
gRQ48kseQ34pM0f+hQGO1Os3bMpPL2IN589t3czfC1H21JO1vgmOVMjNboz1
2kGOrHPk6PIjQbwayb6+vtKPTSTkSDeV5siLHeJIzGt1Q18P/UjkSJRbYnLk
/OV+TZKYI9fLOZLOCRTmA2bhyPO0mJIZkwvjcju5rZnzApU5UtCnJMGRwjjc
Y8hZChw51QpHSnrtuM6RJtdwYZ5kXk/dNEcu565f2AuZXTpHtoXx3NZQ2wxr
q8eR8PorRyVHvvbaa07WSCJHuqk0R17kxfy2ap/N5L0Hfb6CWk7Ma3VBt4R+
5G3IkSinlJsjFyvWlpngyOVJjkxKLybvkMbjOeNwJkdq5AUqzHIX1pel+l0u
V88LzMuRU5t9ljynMI58f2aOVJ9bo7aG1bxIM+tXXF9pgSMVPPVWVY5MzLCh
c7OblTkyVGM8N7t8jmwN47ktobYa1haPI+H1V4zKvFbwHVkcWfUaSeRIN8Xm
SBt5BubyFYL6bNjPAl/yVk83k4AlUdXUzSFH3oociXJKehyZ7lGixJHCGFx9
3h4//s4fkxfVqyR7fRl7lruYI5P9LvNz5HSPIaenODLQ5Ok0R84PObJZypFn
0hx5VhU50kZOa/HrONNM1I70fojMU28V7YUIOJLOzdbmyERu9ujiyNHnR4Kg
HtK1GknkSDcV58gWAjnr7nAk+pFuiO6zgxyJckcmOVLm5URzF7POSdCLv/Vi
crt+jr1Z7jr9LrNx5JIERy6qzZFU58hghuT4c+Z5HDnXY8g5FeZIUb/hnBy5
PJnTam79WuNIxjrOzpHr0p56Ho4M1/DcSnJkSxjPbQ61xbA2exwJr798VPqR
IPAeXauRRI50U3GOXEggZ33MGBv56uby3oP67KAnEPqRLujmkCPRj0S5pfwc
uUE5JzDvvL38HCmPy9U9SSoO7xT7Obq9dth5gYocKeh3OU+nTwmLI2cnOHKm
QY48e7qvFEdSPJmbI1sVOFLYJ4rFkTw/Pb2O42vNzhpm52ib5kixp57sFyXs
2drG3gup7YewOHK+KxwJ8dymUJsNa5PHkfD6yzyOXOa/72jjSKiFZHEk1E6W
fWw8IUe6qThHLiDucCRchyCvFf3I6gvrI1Fuis2RYQy+YBXFkWtycqScIdXm
7ZnkyHQ8nokjJXmBhXCkQp+STBw5NxtHTpJy5JwRyZFqPVptreHzMnuS7aK9
kKSvLunZGvfVgzWc7BmVrPPlc2Q9NzuWny3kyECjhyNHpx/Jq5GEXq5lHxtP
yJFuKu1Hnu/F/Dby1c3lvQd9vsCPxPpIN4R+JMpNpTiyOcmREIOfixyJHIkc
iRyJHKkQawYcuTCM5zaG2mRYGz2OhNdfOmr9SBCrRhJmS5Z9XDwhR7qptB95
nhfz28hXN5f3HtRnw34W9G39pqevkYAlUdXU17w19TX/XCFHolxSjCPb2Bw5
n8ORrUocKaorKzOnlcORyjWS6nmB6VnuWerLGBxZqy87V6nf5Txmn5IERzam
OXKmNY6cTc4qmiO9zws+x2j+qZAjO0YPR6qtYbUaX6McSedm03W+lefIBWE8
tyHURsPa4HEkvH6nx5FL/fcdjRzJqpHcvn27fy7KPjaWkCPdlLscCftZwJHo
R1ZftB85BzkS5YzscOQmRo+SEcCRgn47hXGkoE9JNo5Mz03Q48jWGkdOqXHk
Aj2OHMfiyGmV4ch2Lkdm8dPd5Mikry701GO9hzNwZMJXd5Mj54ex3PpQGwxr
vceR8Podo9qP5NVIHjlypPRjYwk50k3FORL+trd5Mb+NfHVzee9Bny/gSMxr
dUOY14pyU0KOXKjJkXQ+oJQjq5TTaiAOF+QFpjnSbJ+Ser/LHByZ6FMya26g
OEe2W+DIaIZkiRypPLdGzJHl7oNQ69darx3LHNnK5simFEeucIAjm8NYbl2o
9Ya1zuNIeP0lo5oje3p6nKqRRI50U3GOhL/trV7Mv5GYz1c3l/ce1GeDd4p5
rW6IzmtFPxLljnQ4MqotM82RZuftVc/P0eJIRl4gmyPXMjhSPDchxZGCfpcq
HDmNx5HT1Djy7PH1nq3IkeWvYZ0aSaGnnpyFao0jlyNHjnKOBO3YscOZGknk
SDeV9iNd4kiYI/kNT18lAUuiqqmvemvqq/65Gjt2NnIkyhmpcuQCiiNbZBwZ
6yvjIEca9nOSHJmlvkyPI9lzE2ocKc0LLIMjZzjBkdX30/PthYjmoZrhSJ6n
nubI1F6IkCOp3OxKcGQTCfJP14ZaZ1hrPY6EWHHxqK6PBO3du9eZGknkSDeV
9iO3eDE//H1vrKjg2KAPFzAv+pFuCP1IlJuyzZHtTI7kxd8VicFFHJmlRrIj
f32ZiCNV+11a40jotTMjA0dOqBZHyuafijiyOvsgRXFkwlcXcaT/WavlZufi
yKZ6jS+ofI4E33BNqLWGtcbjSIgV2z2O7PTfFxhlNPLI4cOHnamRRI50U3GO
hL/tzV7MD3/fGyoqODbotwPMi36kG6L9SORIlDuyzpGyfEAlL9KROLwzWSdZ
AY5caIgj5yQ4clZbUCOZ4siFUo4c5zHkOAFHnlE4R6rNrXEjp1VhL8QAR0a5
6+zZHxvSnnpyhk1tDa9le+qqHAlruJmxhkvnyMYwljuX1FnSpM71OBJef9Go
9yO7urqYHPnss8+WfmxJIUe6qTRHbvJifhv56qYExwb9doAj0Y90Q+hHotxU
Rx6OXJyfI6uV01qkn6OXF5ifI4MYXLXfpd+zdR7NkaEnaYIjJ87xlebIGR5H
Tqc4cppFjlyvyJGbGRxZ5ZxWtTWcXseq+dkcjkzthYx2jpwXxnKrScCSprXa
40h4/bZR70eCWDWSu3fvLv24kkKOdFNxjoQ9oo1ezG8jX91c3ntQJwnMi36k
GxoZfuRb3vIwapQJOPJAARzpRm1kcX5OLo5Mzv5QnZtQ40h5v8s8HDnZEY5s
TXjq4KmJ5tYwOXKZ2FMvx0/Px5HcNZzw1JPrWOipZ+LI1XyOpPdCKsuREMut
JnZYEjmSFqtG8r777iv9uJJCjnRTdY7c43HkXOIWR17o6euebiIBS6KqqZu8
NXWTf66QI1EuyRRHtilxpMjHScTgyyVezooSOTJVJ8mLwfl+jm59mXD2h2q/
ywwcOcs0R55TYY6U9BtmcWSufRDba9g0R3ba40jmXkiqxpfOz646R0KsCfmn
q0KtNqxVHkdCrNjqcWSH/74DAwOjlkd4NZLHjh0r/dhoIUe6qbgfCXtEG7yY
30bds7n66aDfDninyJFuCDkS5aakHNki4sgNihyZtaZMEoOvsBmL54jDTXCk
0uyPvBzJn5ugw5FTPYacqsiR45Ej2WvY+Dqu78WY5UhBna9wL2R9do5c6CJH
ziGBb7gy1CrDWulxJMSKLehHDvNrJJ977rnSj40WcqSbinMk7BGt92J+W7XP
Zuqng347wLyY1+qGknmtv/PXHHIkquqyy5HJ2khzHNmZjMGNx+Lm/Zxc9WXM
GXyacxOEHBmfm5CNI1vI5OkCjpxUBY5MzD9lcSRnbo0WR8r8dN4aNsyS7HWs
WyO5xTBHrqNys3U5cmW6xreSHFmkH4kcCbr//vsrXyOJHOmm4hwJe0SucCRc
h9CPdEPoR6LclDJHhrziezleHJjq1UrVlhXDkef7cbi9WFyc21pEfZmcI9P1
Zbk4skmdI6db5shUz9aSOLJdwJGyeTWyvOxoDdvbD8nOkbz87DRHquZmJ331
YA0vFHEkq8Y31WsHORI5MhAwY9VrJJEj3VSdI58MOXKdF/Pb6qFlpn466NsK
16ELPN3i6UYSsCSqmrrRW1M3+ucq4Mg3/DWHHImqupQ4sjXBke0MjqRzAhU4
UsSQ9fhbxpHnW+RJBY7UrZHM06dEkSOF/S5ZHMmKw1McuYTBkcEMyakz1Tly
gipHsmZ/aHJkoymO7MzGkR2yNbwiuYZtMKV9jlSf/ZGcYcPhSEFudhNyJEGO
5AtyWKteI4kc6abifuRsAjWIY8bY+Ls2d30I+u0A86If6YZoP3I2+pEoZ+Qc
R67gxeA2YnEbua18jpT1bDXKkfMzcuTsRYF0OXJy8RzZVAmO5O2D8NawyT2R
bZz9EEscKczNtsWRdV8dOXJ0cyTwYtVrJJEj3VTcj5zl/22PGWOj7tlc/XTQ
bweYF/1IN4R+JMpNGedITm2ZDkeq9Cbhc6TJWNxyjaRBjhT3u2RzpMjPiXHk
3BHKkYsTPYd15tYsy8uRovVrnidF65g7x4ZVI5nZU5dwpEKNr5wjlyFHjnIe
gTzWJEfu2bOn9OOKhBzppuIciX4kqgg/EjkS5YZscmS7BY6M4mt5HG4iFjff
8zJ7fdm6VH2Z/tyEFcr9LpMcOTMTRwYsOXFKk8eSxXHkPC5HruFypNrcGpYX
aSIvW76O83nsGTmS60ma5ki1Gl8ljmyqEkcW0691wgTkyEisGskdO3aUflyR
kCPdlNsciX6kG6L9yFnIkShnZJUjO9kcmWdWgl78rRCLC2NyBY5UqpHMyJHJ
nq1ZOXJhnCNV+l3qcWQg4MgpNY5cMAI4Mrl+DXGk8j6Iwp6I6jo2ypFiT72N
y5Hp2R8sjoQ1XFvHqhzZHO8VNackjoR74Mh3vGMuedOb1nhaFWq1Ya3y1vxa
776VTJq01H/f0Tw/MhKvRhLmgpR9bME5Qo50UW5z5Pmebvb0FRKwJKqa+oq3
pr7inyvkSJRLKpcjRTG4aY6UxOKyGrNccTifI7Vmf6jUl5mam+Ax5GyfIzsS
HBlKhSPBk5xaZY5kza0R5WWrreFsPXYM8aRoP6RqHBkqM0fOj3Pk3JI5EjgO
bk8/fdBbk1BDBT7kslDLDQteE+LF+eSLX2zx37e/f7DGsqNVvBrJw4cPl35s
wRpBjnRRbnMk+pFuiPYjMa8V5Y4yc+RidY7M5uWYjr/F4sfhZjky1+wPXY7M
MzdBkSOnSTkSPMkMHHmWDke+V4Ejz5VwpMrcGh2O5O9NqOdlZ1jHFnJbk+tY
5qkLOTI5+2MR21Ovc+RqIUfCuZ6X4shA5fmRT5NPfrKRfOpTi737dktaRD79
6SXkYx9rJFu3Xu2/L+a1Btq+fXuKI/fu3Vv6cUXnCG7IkW7JbY5EP9INoR+J
clNpjkzP3otzJJ0TuKEWN5riSFmPndI40pSfk2f2R85+l4Vy5LSSOLIxI0cq
9Rtm9djJwpF21nBZHJmc/RGf/2GKI+N1vlXkSPj/HgS+5OBgl/cq3aF6LKnb
e99u/3ij9y473q6Cdu7cWdkaSeRINxVx5IEDT5A//mPX+rUiR7qhiCO/hhyJ
ckp2OHKzlV6tNn2cWr5gFo5U7nmpNvtDv76M3+9SzpGcuQlZOHIGjyObRxRH
5snLts6RFmoktTgytR8imf2hypFJX72CHBkXKUyDg/U4A3lkmBw6dKiyNZLI
kW4qyjUAP/Jd75pD3vSmdeT3fg/qlM+tqODY1nuCfl/n+WzS0HBDyJKoauoG
jyPhHN3seF7rI6hRpo7PtGTkyA0MjtxkmSPtxd82/Rz7fUrU5iYY58hZbUGN
JIcjoWfrpBpHNnkc2Vh9jhTOrcnJkUozayxyZEZPPbWGJZ56ylcP53TyOJKV
m+0iR0aeYJkqO96ugo4cOVLZGknkSDcV1T7v2/e4x49TSOD3dXpaWlF1hsc4
nQQciX5k9TVS/MjyuQblGkduZNSWsTlS1qfVbo+d8vwcOUdq1JctovICNecm
yDlyWZoj51EcOafdZ8kZUo5cmJMjp1eCI9Nza+QcmX/2qSt7IQVxZIuII1dU
iiNR1RB4R6wayf3795d+bMiRbiryI1955dfkC1+YTz7xiQ7yyU8u8e+rqcXk
U59aTv72b4F5t4UceUMFWAkl50j0I1FuSY8j0zE4HTsussmRBcTftvycXByp
UV8m63epxJHR/L15geIcudgAR84TcuSXDHNkc7SGvc9jQckcqTf7tFocyc5t
3czlyOReSCvPU2dxZMJXpzmSNfsDORKVFKtG8qGHHir9uJAj3VTk94dXB0/g
Tw5WWP3+ce7bt4e86U1QH/lVgnmtVVeU14p+JMotVYkjy+qxE1dGjhTE4TKO
NFVfxubI1WocScXhJjhyspAj5xbKkdHnAZyyUIcjU3Nr8nJkEeu3yBpJwxzZ
locjlyNHomri1Uj29fWVelzIkW4LztPg4HDl1dcHvZsJeeyxJ8jv/R7ktcJc
ietDlkRVU9d7HAnn6KseR85EjkQ5I1c4sggfx5afk+TIVH1ZEX1KWBzJmb+X
5MhZihw51RGOhM+vtT1R46vNkdXMyzbrqfNn2KQ5Ml3ny+XImKe+LpGbnebI
ZuRIlKZ4NZKvvPJKqceFHOmmyq571lV//4B/3Lt3ox/pjtCPRLkpoxzZYZMj
i4nBbfg5urM/WPVl+TmSniEpnptQBkee6THkmSOZIwvcB8mzF5Jex2ocmdoL
Scz+iO+HiDiS0S8KORKlKV6N5MGDB0s9LuRIVBGK1tnjj6Mf6Y7Qj0S5qXI4
Mh1/V8XLMevn1Gd/LNbsU8LvtZO932VjypPk9bssgiPnjjiOrEZedkU4comY
I2P9oli52a2MGl8ljlyGHIny9fDDD1euRhI5ElWEkCNdVMSRNyJHopySExxZ
cAyetUYyTxyuzpEKfUo4/S5Nc2Q0QzLOkS1k8vQcHHn2yOTIIvOypXshBjjS
70Ekml+T9NQ9ZedIxhxUFkc2I0ei6gLvsWo1ksiRqCIU58htJOgHel3Ikqhq
6jqPI68LOXIGciTKGalz5FpljoxiTFWO7JDNbi+cI4v3c2T1ZSY40p+DoTh/
L82RS/gcObM1kDZHzvE58ixrHLnKZ5BqcGTB61e2F5Jax9T65XjrqTrfTj2O
ZM/+WMfOzVblSFjD89M1viDkyNEtqIWsWo0kciSqCKEf6aIiP/Im9CNRTskF
jizayynCz8nFke0SjuT1u0xxJH9uQooj5yY4crZhjhw3w1c5HMny1OscGe9b
Wu0eO6p7Iex1zFvDyVrfzYl1rOCpJ9dxZo5cla7xnc9Yw8iRo17gO7I4sswa
SeRIVBFKcyT6kdUX7UciR6LcUR6ObONxJBVnmuHIEmLwPH6OQgyu26eEP0Ny
nfrcBB2OhNzWxiI4crbHkbMqwpGsvOzNtfUbqeo9dlzkSOZeCIsjFyJHotQF
9ZBJjoS6ybKOBzkSVYTSea3QD/TakCVR1dS1Hkde658rzGtFuSQ1jlxjjyOX
V5MjpTWSWnF4/j4l/NkfGv0uhRy5XMqRMy1w5NnjqRrJsjhyiYgjt8Q40oUe
O7G9EOY6tsWRAk89D0e2sDiSys1GjkRxxKuRhH6uZRwPciSqCKEf6aKwPhLl
porlSJGPo+nlrLzAIT+HMUdSt09JbAZfVTmytUIcuTLOkWGvqDI4soy8bCWO
FHjqKnshSY5Me+oCjmxHjkTZF69GEuZLlnE8yJGoIoR+pIui/UjMa0W5oyRH
0r0ui+BIoY8j40jLLCnKbc3CkcnZH1p9SkQcqTo3QYkjl8U4crbPkR0Mjmw3
w5F0z1ZPVjiyleJI77OCzy+YRRHnyEXWOJKzxgpYw7L9EFGtL7/XjiJHpnrt
aHIkKzeb2WtnBXIkiilejeShQ4dKOR7kSFQRQo50UZjXinJTVedIrpcTxeC0
iuZI5Z6XnNkJOvVlMY7k9ykRzk2wxJHTPIacRnHkFEWOHGebI6n6XmscmWf2
aQFr2DZH6s3+SOdmtyzSrPFFjkRpilUjuXPnzlKOBTkSVYTiHLmVBP1ArwlZ
ElVNXeNx5DX+uRo7djpyJMoZIUciR45IjlyAHIkcyfh/Djly1Gn//v0pjty+
fXspNZLIkagihH6ki0I/EuWmRBxZry0rkyM1YnDjsbiYI9XjcFWOFM/+yD03
QcaRzQVz5MRRwJE6+yAl7Idk40hzMyRbuDW+a1I1vs3IkagMOnz4cGVqJJEj
UUUI/UgXRfuRyJEod6TCkQu4HLlRypG1GJxVVybxcUQcudSLt5cWEIsLazed
40hq/p5ojnupHDnDKY6U9RoWcaR0DRtax9IZNsosaXL2hw2OXI4ciUqpq6ur
MjWSyJGoIhTnyC3IkU4IORLlpsxxZD0GZ3Eksz+JxMdhxuBhfL2UIWE8HovN
aSnE4Mb9HNV+l/HZH9p9SrLO3xNx5Jx2XzWOnKXPkePPmeurXI7ckObIjnI4
Unv9ptZxUbmt5mdItnBzs9ekekUhR6KyaseOHZWokaxz5F7ywX9ejxyJsqK0
HwlzJb4csiSqmvqyx5Ff9s8VciTKJeXiyCUyjkzOjtTIac3AkZlicYnvI+VI
Qd/WxYw4PHu/yxwcyZyboMGR89IcOSPGkYEqw5Hzq8ORMj/d6BoWrePCODLh
qxvjyHh+NnIkSkd79+6tRI1kFN//hPIjIU5EjkSZFOa1uij0I1FuSpUjgVMW
FsiRQX8dfY7M7u3wayRldZI6cXiqvkyrT8kGTp8SvbkJKvP36hzZmeDIUDyO
nCHhyEkjiCNls08zcqSNdZx5LyTDDMlFqhwJa7idnZu9IBdHBkKOREWqSo0k
xPdwD37khz6/ngwMBc8jR6JMKp3Xin5k9YV+JMpN8TlylRZHLjLOkfnibx0V
6udY6VOSZ/6eGkfOMsSREzQ48oySOBLYvj0vR/L8dE5Oq7E1bKFGMlnrq8eR
kp6tpjmyGTkSlVZVaiT7+wf89bVjxz7yv07bHOa1DpXSOxY1chXnyM0k6Ad6
dciSqGrqao8jr/bPFc79QLkkXY5sMcWRln2cQuPwKtSXGZ6bYIYjF8Q5cnIO
jjwTOHJqpTgyU162JY6srWMLNZIyjkx66sl1rMqRC5U5MpmbvSLWKwo5EsXS
/fffn+LIXbt2FXoMg4NBTHjwV13kkjt+4z/GvFaUaaEf6aJoPxI5EuWOsnBk
q22OLCP+tujnFMeR4n6XxXLkQkMcWc9vNc2RbYnZNbK5NcnZNZXkSAueOpsj
4+tYnSMTnroqRyb2Q1gcSa/huciRqIR2796d4sj77ruv8OOAuLC2zkKGHBoq
//NBjRwhR7oozGtFuamyONJUj8vi/BxeDK7jSVrsU2KEI6k+JR6PzTHJkVOa
PJYcPRwp8gWtrl+jeyFsjmTV+S4S1PnKOJKVm03nZ/M5MljDjciRKAU999xz
zNzWY8eOFXYMUUwI9+BN1vkR/UiUOWFeq4ui81qnIUeinJExjuwYIRxpwc/R
7dmq3KdEc26CHkcGinPkkgwcuSAjR07PwZEr7HNkxrxs2xwp2gsRcaR0DS/L
zpHR58zutbMeORJViIAXWRwJfFnUMUTeI53Lin4kyrTiHLmJBP1ArwpZElVN
XeVx5FX+uUKORLmkKnJkWfG3LT8nF0dq1JeVwZHTExw5lcWRU0cZRwr2Qcr1
1E3ktqpy5CZNjozX+NJ1viyObEKORGUQ5LEmORLyXcs+LhTKpNCPdFHYZwfl
pkrhyIr12LHHkdsEHEnF4Yb6lMj6XebmyLkJjpy9KPAkpRwJua1ucuTizpAh
Q08ur5/uqqdeHEfS/aLWpDiymcuRK5AjUVKxaiQfeuih0o8LhTIp9CNdFPqR
KDdlmiPb83JkiTmtcj8nW40kf/aH2T4lVjiyMc6RUCM5U5UjoWfrtIgjm3Nz
5H8Z4Uiq37AKR8bW7wjgSNleSGody3rtsDkyOfsjPv8DORJVjiCH9e677yY7
d+4kzz77bKG1kShUUYpz5EYS9HG5MmRJVDV1pceRV/rnCv1IlEsqjiOrXxtp
y8/hz/4w06dEdW5CnSNXpTkyNjchL0e2cDiySYkjvxRx5Fl6HDlWmyNDxjHM
kZ1OcqS8TlLEkSlPfYloFiqHIxexOTLWs1XKkcuRI1Fc9ff3+yr7OFAom0I/
0kXRfiRyJModsTlypZQj23gcyaktGzEcmdvPydanxApHcufvZeTImRRHTudx
ZKNVjpyTmSNZedkcjqxwXrbcUxfvhehzpFputpAjWZ46ciQKhUJlEvqRLgr9
SJSb0ubIdrscWYkYPCNH8uPw/PVl3J6tsn6XVAzeRPXaEc3f8+e4Uxw52+fI
jswcOSnFkfOqwZExzlGp71XgSN4+yIri1q/SGmau422CWt+0p57sGaXOkck1
zOZI5gxJ5EgUCoUSKs6RG0jQx+WKkCVR1dQVHkde4Z8rrI9EuaRMHLl4ZHOk
2M/JkheoX1+mz5HrpHMT0hzJ7neJHCnmyKr76dY4cpmMIwWeenIdZ+bI1ciR
KBQKJRD6kS4K/UiUm7LJkbV5CZSPU/UeO0pxeAEcmexTwu/Zqj43QZUj5ypz
ZPuI4chFo4gjg/pN8X6IOLfVHkcuRI5EoVCoXEI/0kWhH4lyU0yOXGCWI+Px
d/VjcPN+jogj887+UO93SXOkrN+lCY6c7DHkZC5HzhuRHCnqsVP4GhbUSObr
GaXKkYI639wcuSq9fucjR6JQKFScI9eToI/L5SFLoqqpyz2OvNw/V2PHTkWO
RDkjLkcuRI7U50heHK7AkZlnf8j7XdK1ZapzE7JzZOso58hq5GXX1rBsHYt6
RinUSCp76kKOZNT4yjiSqvGt1/lSnnozciQKhRqdQj/SRSX9yNf9c4gciaq6
hBzZwuJIqtelYY7U83IuDOWCn5PmSN28wNI5cl6BHHl2CRzZYYAjuT12eBxp
ef3m4EhefnY+jlSdISngyJYkRwZCjkShUKhA6Ee6KNqPxLxWlDuScmQrxZGL
WBy5idGjZAsjBlfhSN0YPKniPEmpn6Mw+0Orvsz/zPX6lKTmJihxZJAX6M/+
aIo4sjPNkXPSHDmN4sgpShw511GONOWnF7B+hWtYt0ZSMgc1z+wPxRpfHkem
anyRI1Eo1ChVmiOhj8tlIUuiqqnLPI68zD9XQV7rUf8cIkeiqi4ljmxjcOQS
gxy5QuTlqMbgOiqAI4VxeIb6sgwcmZ4hiRxZHY7Ms37NreO8HLlYIzebNfuj
lcmR9XUs4sgm5EgUCoVKCf1IF4V+JMpNVZ4jefHxKhNxuDgml3Fkdj+nLI5U
73fJ4shZMY4Mc1uBI2e1BbLAkWecGah8jqTn1hjKyza+hvXXsd5eiOrsj83Z
OXJRkiPXaHDkCuRIFAo16hXnyHUE/UgXhH4kyk3l5Ui/P4kyR/J9HHWOvLAe
g68yGYtzvBxjNZI568uSHLmYzZHC+rIMHDlnRHHkWilHtufiSM287FXFrGM7
NZLZODK5F5KFI1OeOnIkCoVC1YQc6aKQI1FuqgocGc2zy8yReSSJw832vBRz
ZKq+LNmnhFtfVhWObAs4coYOR84ZGRyZpceOlTWsvx9i3lPfzPbURRyZ8tTj
HDnf7/mFHIlCoVAyxTlyLXKkE6I5cgpyJMoZVYMj+TEut67MVAyeisXL4EhT
fUp0OJI9NyHNkUsL4MjZChw5rRiO7DTMkaK8bBvKUiOp3C8quYa3FsiR8Tpf
5EgUCoViK+1HwlyJS0OWRFVTl3oceal/rtCPRLkkZY5cxOHIGPdk4EiBj8Pk
yDBeXlYRjtSrkVSZ/aHep0R7bsJCxfl7leHI6Roc+QHjHBmt38XLKI7Unfkh
4Ejja3gVew3nrpFcnp0jZbM/6vshbI5ckIkjAyFHolCo0ai0Hwl9XC4JWRJV
TV3iceQl/rlCPxLlkorhyGw+DjMGpzgyKat+zgoTPS9VZ3/kqC9jcaTC3ATk
SPn8U9HsyCw9dqys4Uw9o8R7IR1KHFn31NtFHLlEzpHRrFo+R65GjkShUCiO
4hy5hqAf6YIiPxI5EuWW3OLIerzMisHzyKqfU2SfEkPz92Ic2UhzZCBbHHmm
sxypXxtpeg0vE6zfPDWSWhzJ8NWFPVtrvjpyJAqFQplQ2o9Ejqy+knmtOPcD
5YbK5kiRjzMSOJKf22q4T4nh+XvIkYocKZx9yudIGwxZW8eGayRlHJnqF9Wp
MfuDzs/W5shVaY6cjxyJQqFGt9J+JOa1Vl9RXuvl6EeinJIeR6ZjcJoj2zNx
ZIXib0t+Tp4+Jen6smLm73E5MhTNkdM9hpxOceTUDBx51rhZniKO9FQqR7Lr
e7U4kpeXTdVG2uNIm3shW4m077CEI9tscGSyVxRyJAqFGqVK+5HQD/TikCVR
1dTFHkfCObrMi2Umox+JckZ2OXJrnSNZ+YAV8nFy+zmFceRGNkdK+l3qzt+b
0xRKiSMDWeFI6Nl6FnKkbY4U10ieJ+i1k58jWZ66kCOZudnIkSgUCgVK+5HI
kdVXxJGXY14ryikZ5chYPmAiBtfhyBLib5t+jhpHcvqUSGZ/yPpdzk/2bM3I
kbMTHDkz4sjZ+Tny7BI4si3GkWr9hlkcyZ19ysvLtlgbqbQXkslTT65jXY5M
5Gdn4chEfrasxnceciQKhRqlQo50UTRHYl4ryh0VxZHM/iSjgiPPk3Lk4sx9
SuxxJPRsnZviyA7kyLz9dQrjyIxrWGk/ROypJzkymjGrz5HxGl/kSBQKhZIL
OdJF0RyJea0od1QmR5qalVBUDJ7Vz0lxZM68QFm/S978vUI4cmbEkS0eQy6U
cuS4iCPHz/J15jhbHLnGPEdmyMsuLje7whyZXMNSjkz3i6JrfJsYaxg5EoVC
jVbFOfJcEvQDvShkSVQ1dZHHkXCOLkU/EuWUyuVIzRi8AI6U5gVmiMPFs9xN
9SmRz02oc6RsboJJjlwo5siJHkdOKJcjF5nmSIGfXu29kPMEdZKasz8SudnJ
dczkSHoNLxJzZDNyJAqFQjEV58jVJOgHemHIkqhq6kKPI+EcXYIciXJKyJHI
kaVx5DnIkciRyJEoFAplUsiRLormyMnIkShnZJ4jt6hxZAV7tdrKC8zPkYLZ
H9TcBHMcudwwRy6oc+RkjyMnzQtUAkdC7mTrCOdIpb0Q0TqW5merzpBU5EhG
jS9yJAqFQmUTcqSLQo5EuanKcWSJPXZscaR4lrs5jpTN30tzpGCOe8SRTTKO
bFfnyCkaHHm2SY5ck5MjtzE5Mkt9b7EcyV7HUo7keJKpGt9l6mvYFEfWZ0gi
R6JQKBRLyJEuiubISciRKGeEHFlEXqCII9X6lKjP39PgSNH8PdMcOXW+x5HN
PkdO8BhyApcjZxbPkR1ZOVI/L9tpjlxeX7+RsnJkmwZHLkCORKFQKGXFOXIV
CfqBXhCyJKqausDjSDhHF6MfiXJK+ThyEzMGZ3Nk9Xu1puNwHkdGUs0LNMyR
yv0uORypMsc9xZGdZNY8VY5sdYAjN+bjyArnZdvnyG0ZOZI/+0OfI1cjR6JQ
KBRDcY5cSYJ+oOeHLImqps73OBLO0UXIkSinVB5HVrPHjoonqR+Hq3Ikv09J
Zo5sY9SWSebvGefIaXWOnFgiRy6kOXKJJY6sgJ8u40i5r86rkSyWI1N7IciR
KBQKJVXaj0SOrL5ojsS8VpQ7SnHkfB5HrjPHkUa8nIsU5DBHdprgyLWFc+Q0
hzmyPcWRW+scGfZKMsuRBaxhka+u3WuHx5EKnnrSV5f1ikKORKFQqExCP9JF
jQyO/IM/eAQ1ypSHIxeZ5kjjMXj2uNwsR+bvd2mLI1lxuDJHzpFw5PSFviKO
PKdAjmzKwpGCuTVJjjSTl511Daut46Uq61hrDZvkyI1MjmzR5ki6XxRyJAqF
QiFHuiiaI89BjkQ5I/scaWZegtkYXB6Xy3rtyPrtmO53KZwhmeRITr9LmiNl
fUpojpxDceQsjyFn1Tgy9CS1OLKpMI5sNsiRkadsNi/b9Bq+KL2GS+TI1AzJ
JfyerZk5Muar12t8QciR5ejBBx8kP/rRj8hLL73E/Z7XXnuN7Nq1i9x///3+
94Lg8Z49e0hPT0+m933++efJU089Vfrvj0KVrThHriBBP9DzQpZEVVPneRwJ
5+hC9CNRTqkMjizfy1Hzd0Q5gfV+O+p5gXn6lChxpGRugnWOnFVdjlxgkiML
y8t2kSOpdZzkSNHsj9ReyDoxR7awOHIlcmTJ2rdvX40LeRx56NCh2vfcc889
5KGHHvJFPwecqfO+wJ/ws/D+ZX8GKFTZinPkchL0A90WsiSqmtrmcSScowuQ
I1FOKRdHdmTlyCp6Ofq9SnTj8HwcKepTojh/r0V9bkKcI5dqcGQbkyMnVYUj
vc8IPi8rHFmqn67PkVl67Yg4cnGSIzstcGSrmCMbkSNLE3BjxII8jjx69Gjt
34H96H8DHzLyMsGb1HnviEORI1Eo9CPdFO1HYl4ryh25wJHFxN+cONwgR+bp
d+kcR85wlSNF80/d4kgVX123146QIxn9okQzJJU5sg05suoCBqRzVHkcGfmG
wH281wE/Er4HfEvV90eORKHqQj/SRdF+JHIkyh2Z4sio1+Viqs8l3esyir+Z
MXgYz6rF4CORI9VmSPL7XSrOcdfhyOZlvkxw5OQSOdL/nQ1zZDXzslV8dQOe
emL9svdC1DgS1nCblCPXKnFkE3JkqaLzSmUcCZwo4r0sTIgciULVhRzpomiO
nIgciXJGxjgylhO4lSR7XRrnyNWUSuJI/bxAkxzJ6lOiw5HiuQl2ObJRgSNn
GODI1ZY4knPOdTlyta11bJEjY2t4m12OTHnqa5AjK6gonxVyUuFrWX2kTDpM
mMyljRT5nfS/y94vebzRz4FHCj2Boq8feeQR/7mImeE+6hsUealwD19DHi/r
PeF5YOpknyHRz6BQqopz5DIS9APdGrIkqpra6nEknKPz0Y9EOaUiOLIjE0de
yInBGRzJkskYXJQXqNVrJ0efkiRHMvtdSua45+HIxiRHLpFy5BSPIacUypH/
i8mRC1IcuSEDR1qo75Wt4czr2AxHsvsO5+XITWKObFfnyGbkyNJF57NGvXHy
cCRdP6mS1wrvCRwY8RscC3wd1V6a4Mjo3+EeWDli1IgjgSuj92f1DEpyIXxN
86aJPkMoFK04Ry4lQf3dlpAlUdXUFo8j4Rydp+RHDoWiH/Nk5YYcicrIka05
OFI7/s7DkZljcpsz+Oz1u1Sa4z4qOHKphCPXczhSff6pVm0ks1erBkeaWsNW
PPXkLNQcHJnKzeZz5HwpRwZCjrSvyKejvcM8HAlMFrGUzs/xPEwTHEkzMiia
S/L/t3cmvZJb1x03DHvtb9ANeBUg23yALLIwnJVtqS150Nhq9Ty3LL1+3Wqp
B1kKZCnZZRM7CWwDdhAEQbyzVzKCQNAAyI68i7XQxl64e2H1qyJZjyFZJOvw
ziN5WfU/wB+Xr0ZW8bLe+fGcew7N4a35kvYrqVmx4+v6OxJ9Z+zttM5Q/T1M
fWyh+QrxyDlqGI/MKo6sCbCoOFLHib1WZCSKYuBIyIMjL0o58rW0OdLYP4/X
O8G+TokdRyr77wk5kvRxF3Lki2KOPDFDjrzEcuSaa8bnyEhz+AY/f8PX2vHj
SHaNrxtH3gRHJqC6XyPNZ+3kypGUy+rXtnluKI6k1/dpHqvIZ/uo3d+aeR9W
DMje//HvftfHSOnt3fvVn5F9Ts2rXYzS2HecQFPPPUgtxCPnKCYemT0oa5Bc
FavysGJBveq45WozEkUxcCRkxZG3wJGB8gI5jvRYXxaEI0V93B058inCkU+A
IyXrez1ikd4c6XgtZM+dI7mY+lW+F6oJR3bHEByZhmhdVTYH04Ujf9cyF2VB
G67p2KxmO3o75cjBdXqyPYhHtrfVY78/H/1G6LfVt/drMQX3DxiW3N7FXGv+
rlny4OGBoZ+Yjth4h1SHZJxIh8z2LojnyLqOy72WJaE0da/iyPoYvd5wZJbf
b+ORRTV3V1oV9FxDPBLaJY5UxHFGjeU4cqRtXuCmTol/vUvr/nvndX3cHTny
+KW16pjkJBx5JCJHGvatSYojeZYcnyPNcrPpPLbnyBvgyInUsZCoFo6MI2Vr
ed4lNWxYDqTP67UiY6s+Hskwn5Dl6Gsc6uOR3e2yeOQHH34ovJ9jWMHtdA3m
R229nqljjcHikez3HVuS/ZDNu21WNuDIF8CRs9CQI5fZg7JGwLyoGLHa0Kt6
XPPYdiSKYuBIyIEjz4/JkfuKWGSll26slUReoKrWzp6MI/3rXcbo485y5AnC
kccZjnzGiyNPBubIv7DmyK52URyOlMXTNxwZZQ5HqLXDxtVVHNn0/bHIzdZx
5Dlw5ORi/XCazyryYTn+IjG+FfH76zhcx6N9XR1B3IuLfx0ecjEuWTzyUxHL
Mdfsu+fWj61rWqxan6x7Xn1745sx+uijj9bvWY2i++l7D3y89r7/Jp+dqs6D
lb2nlQrP5wu0IqNWXayk3z4k41BFCH6SxETZebcLyjPKkdfK9fq7uy1LQmnq
bsWR9TH6fuXLPFZmy/tlnZJa5EWT26pXsT7XmnGoKCblyP+BdkzjcKRbHEfI
kTeGPrhIyeUFjlnvMkQfdyVHrqXkyGd2jyPN87J5jhxjDvvE1Nm4upIjB/OY
zuF74MjEZBqnOWS2aW1RE3X1TalP//DhpqZMnR8rWivIckavFRlbvdNxZMN0
h3KWE1yz7/bj008rdisOm9tqv6zn4ep2kd9GOVJ0f/28nmH72w8HevjZQfnJ
7z+p/P0P+/3odP/+A+7xfjLxReViYxxaReRZoQ5FWrNrIeHX0MyaijJw5AzF
cGRWceRhxZFFznGhXuTcXY0dj5yea6C5ceQ9gQ8+LUd6+eXRe/BFqncZso/7
zDnypIgjL86LI23n8OAxgWvt6DiSvRbix5HrOXzemiP3d5IjTVlQ5ANTttOt
haN/1z01ul4VItEapvXfXd5nF3P67GDIkH/44x/XPv/qUMocgzhXsRr6SZV+
/U7Hkb8Z8NqQ5VqeWpFxxcRP23gkfzvvq3/Uro9s3lNw/yCvtb+djdsVg7+7
Ojs9n5rG/jSvSz+XrTpWt34u+33HkHY/Vv2+B43rCpk1HS3zvPkd23BkXcfl
TsuSUJq6U3FkfYxeq3yZb1Yc+aDlSNG5bPobUIAjoQQ5smaXO5E58s3gHGns
o0fvwRep3qVRH3dDjjwzLUd+IwhH7us5ksbT2znc5GV2x6Odv1dfSoMjjedx
4Jg6x5GamPokHHluOzjSNi5CWdJ2HVnPkobq4oFsXijljILwV5+b2cX4Wh+c
MmSzHrBoGUcQr+tUtBJxIM1NXbPXkNd4TtyIciZ7v+p5tQbxSMH9Q45c33b/
/v2+3+XDh5+VoljCr3/9Dnld2ziEJDYh5MpIInGQ6O+tiZ8O47CBuNWIX6fV
MB55FRw5C1GOpPFI//MnioEjIW+OvBuEI6U1dmbEkXa1dgLWu7Tu4z7kSFUf
9xOnW0XlyOfT4UhF/9MBR+4x87hlMPM6UWNxZMhrIWxc3ZcjJet8OY58Rc2R
qlpRiXKkKFeU5UKhJEy4IqN1Tt7h0PcUxZwoH3Iq1ozY+fNd3HDAX70fv/a/
uxheU+f1D38kvnkXL3PjiG6d5QcffMA8pii7Po41vz58+LC/r96/Lva33t9P
B88b3s7z2ZAj+fvr5204csN03f7UPEn3p1a9RrT/fmrGDsJblCWn1IrZ9uRH
o88agVs1/JqCsmUXj/yw5ci6jsvtliWhNHW74sj6GN0LFI/cKIqBIyEpR+4J
ObLz7WitSz1Hvj4bjvTOC1TV2nHiSIN6l1fWMu+/58iRp3Qc2QocaV0nars4
kl3nG4kjlWt843Gkcw4p4TVZrii9XSiTWKGM90T81+X5kfVsojVwKzJy6riP
yV0crCtckcdVotymk0087uOPPybrMd9peXLtf33yye/7+9a9Gd/pY6L1WD92
E3fc8EeMeGQtmrva8WStji/9c1opT6WkgtmOyaoB36doNTmHmyvLsuZ3bBOP
vAeOTF6UIx8DR0KzkZojbzb8EY8jJWsjk+ZIhzWS0h6SIetdmnOkvv/elnHk
RT+OvBaaI2PPX8kc9qu1E44juR6SJhzJ1IvS1hz25EhlvZkuH3Q15EMhGx6K
ObHbLihnSvJIhYxYDP8exvIO1fEKej95XkGfr4hN0rVnq+KQ81mG/FX0MRwa
nzPnSHNfqebBjs/qkTJFvS+0NmzNbPXr1/HAjgfHyGvtVOe3vvvuuwN2rPe5
3kfZ+81XUzBtihw9nrKMxiOvtBz5asuSUJp6teLI+hjdRTwSmpVcOfJSCI6U
1dhR5APG8r9jxnOsOFLqh/tx5NkgHPnCzDnyFQ1HqvvWzIEjvWLqxvN4bI7k
6w7H5khlvRnCkqJY5aCHgYQPN5zYxgYP+boeUr9AWkuziwmuSjUDkvu7nFPu
fvJeUp+czSEMkcto+tjd5gQoJaU0F9f7wnPkXXBk8gJHQvOUL0c29UlCc6Rs
TdmWcqTZ+jL/Pu48R8r6Jig4so5JPm/KkecNOPIEz5HH0uXIF4w4UhFPT4Ij
xfM4PEducrMvB+PIl7W1omLFI3sOXJF6M8J1hOq6j6sVE/vrY4S8ClmtD6GY
15SuIaM+p8hHMeFDUQ6h6/tBEBRSQ4683HLkKy1LQmnqlYoj62N0p/Jljllx
pK7mcBQDR0IWHHmu48jLE3NkZP/bhyNVeYEcRzrVKfHv4z4WRz7ZcOQFC458
bkYc6bm+d1SO5OfxJBwpyM825shLao6sY+qnBXP4pC9HMmxWtNsyPuzuWz+e
rBeU8OGGE9vHa5mPkdHjXRlR9lzde4ERTf26sTT19wBNow1HftBy5B1wZPLq
OPJ2E49cVhxZ/Wso84ojfc/zKAaOhHw5kllXxvVMmClHxsgLbGqUeNe7lPSQ
jMKRe+Yc+Rw4cvc40j43W82RfG72Zh5Pw5EFyRUt2lxRYWxQwIoFjQUaxQS7
MXRNj5XiNhu/dDo+pH7S1EwmjTEXzHYC9TqH+c6MVmScuVZkhDYaxiMvleu8
yVstS0Jp6lbFkbcapjx65FiZLR+UhxUCFnnhdp4TRTFwJBSDI79nx5EqHzxt
jrTzw805UrW+zJQj5f33QnLksz1HrmOST8+aI3V9ayRzWLG+d3KOvGHPkTZx
dW7+aq6FsPNYt8ZXx5F0je8Y8cjNdsH7rRwrFsw2YcQgXGcq3euOy4chucGI
7abgupWZXxdDuepzr0b8Dkz2d8Vsx5gHO6xly5Hv9xxZx7teblkSSlMvVxz5
csOUR48+Wi4rjqwOZZlXHGlznuQCRTFwJBSTI18kPdxnzZGq3FabeM4bAepd
SnpIBuNIpo97xZDPE458zpQjn02II/u+NeNzpGx97xhrfI3msC6uruPIl15n
8rO3jSMpI5quF3StLbNyeE54BgzunzO8EIpPjFhO8NlYXyuKD1/wry/y62JK
eSwiSPSe2vlWMNsx5sEOq+8f+X7NkRfBkbMQ4cgjx8pF9qAsDssyK4r1uV20
ysm2QIhHQilxZNd7z5Yju9oxg957bH2SneLIEPUu9Ryp6783DUee3z2OVMzf
ZOawQ80oGlOPw5G3tRx5djSODBUznGbdYFAuEsjFnzeKqzkwi8k+52SMqpx/
rynikrL9ii1ZXDR0PDLIdYAJjs1YWrYc+X7DkRfKdd7kzZYloTR1s+LImw1T
1hy5XN5v45F5WdfaqfNbTZS3ordFMXAk5MSRvA/uzJFWsZx5cKR5XqB9vcug
HGnSx53jyO9F5sjj4Mhoc1iQ2+rJkevvxIcj1Wt8zTmSXA+JEY8UcuG4TOjC
htpYUMFsy6TZl27bxK/PmW2hQvBPzmxXKvrR3B8LJZFfF+t9pvh8on3IdSrI
qFRYvh9INQ9nrkWb1/reB4hHzkc0r7XiyMWD6je44sisaH6/fK4rRDFwJDQr
jhTlA74lkYvfzT9Pu0bSNy9QV6fkBTYmeXcglz7u43HkRXCkEUeGmr8/4J4f
gyPZ3GwxR27mcSiOPJcUR9oxn1dskPEFbPP+tDG/Qv7euWQf2JiXNP4l8OML
wgeFTDkZXVUw2wMN9x3yl9P3mZNRqQi8W8jmxvZoucya3zHEI+ckTTxS+bum
VhQDR0K2HHlZx5GvCTmy88FFfff8arXKONLEN9c/xowjLeM5HvUu/TjylgVH
Xh9y5GlwJD1uvnnZeo60YUv5Y1+ksuRI05i6D0dq1/i28zgVjnThwBUZXdeB
0bVkrrl9XLyi8/1XK3msRsKCORPXs4vxbdiAxgkHoowRQjn7etP7+DsrJx84
AvsaM+x8tVy0ea3v1Rx5vo133WhZEkpTNyqOvNEwZROP7Dkyq+Zr7qUoBo6E
NBzZ17rcCo6099Wj5AUqONKs94dkfZkxR6r7uNtz5NV0OfLcNnGk2zyWcaRx
D5sgHElYckYcyfqeLgxYkLGRBfdxMUNJDGijgozDvEGpT099e9M4DuffF/3+
6H14+twQ3JEP/s7JKFfObEOxVZDRTOLjOx7DBnzfiTSMR4Ij56ENRx45+mi5
WP6p+u0vyyynv1luimLgSGh0jjTpHWlTYyeGDx4mL1AWz/Gpd+nMkZfMOfKU
jiNPunLkOUOOPB6RI2+BI6VrfSfgyGuaNb5OHLkfLh4pYEJOtvFAk5ifigmJ
xLE+Mf8Jn1OQkfCgeXzPkgkJw222p1DBbEdQiNxcQ7mtORxfer5nWZ89Vqmz
b1paLpfN7xjyWuckktd69FjFkfeHHEnPccvfiSgGjoTAkeBIcCQ4EhwpNCcu
FOaHSvjMNlfNKNZn8jjVc/XxmHzwd05G0zgTG3PyUMJr3Fg2ygKwmOg1pv6c
Nt/HnI/n3IR45Bw1jEcK10cy55Tpb0wUA0dCCo48NQJHuvjgs+dIj3qXVhwp
qXcp4khR34QpOfKRuXCkVZ0oEUfGnb88R6pqD7vlZg/zs3mOFK+RtOXIVybh
SP5/8Yrz39nrwxutyOgi+houylupH1cMHk+ft1FBRrUK+X3F5nXoa1qrixfl
fPyIVdZqknhW3r53PUZSTsbB92Pw3Ywl52PAHusJZD7v5fN9Si0XbTyyWR95
ro137bcsCaWp/Yoj9xumPHL0EZLXmg3PC+b8N/m9iGLgSMiGIy/tHkfyLOm/
vsyMI8V1SniOFPnh5hx5xoojXxRz5IlwHPloxZCPbi1H2tQbDnwtxJEjTWLq
HEdq+qAqe0iaciSpF9VfCyFx9VjrI/1jfT7xwXTkEwMbMHgIJZrDKb++EFkp
fyczO56+c31qIR45R7HrI9V5rTaKYuBIKAhH3gNHWsVzUuJIeR/3OBx5tuLI
M9vPkZPPXwFHSnJbtRwpuhbCcqR0DofmSL7ucEyO5HtGuvaNDNtv0ruXCJOb
K+01IqjtY15PR7SeMoJivS40jbbleMac84ZaLtt6reDIGYnNa33Q5rW6XIsc
KoqBI6EpOdIhJ3Ac/1vFkaHzAv04Ul3vUtLH/YIoL9CPI59hOPIpB448VnPk
Y5Qjn2k48uuTc+Trs+ZI4x42zjH1RDny7F4jv3gke41/JbitYkQybrQio1l/
x57PVu37NFxXcMrJKFVBRoOYizQmRHJfferA9DnAIeJticWthEI8Msz3N8V3
6KE+T7xwP19Cablo45HvfVh+HnmtM9Emr/XokUcQj4Rmo6Q4UuaDj8qRbwn8
7xh5gZZ1Sq7Z9E3w48iTDEeeIBx5vGLI4zKOPG7Jkd+uOPJbFUc+3nLkY3Pn
yBTi6S4caX4thOVI+Rw24UgSV1dx5CWWI1+OzpF970ZNXFHYs6OgtxXMY3hG
VDIgwwVG+XYKX3bg76pYJKd1Yw36SkpuK2R9Irle87rH+Em/D9DufJeFZDvc
99KfE7nB+RNBi0E88mwb77resiSUpq5XHHm9YcqjdTxy8aD6P1SWeVZ4n3dR
DBwJmXBk64NPzpGj+d+BOVKZF+jJkZI6JSKOPBeFI69JOPKSmiO/W3Hkd042
qjnymyxHtj0kx+TIyw4cmW5etooj/WPq5hzJx9StOZK7FqLnyH4OV/Kr12q2
DomynTa20nPZkM8GMcl8NcyNk/iqovo8/f30dWR5d6r7Bv61JOZRkNHn++GU
B49vZUWYeqm7rO36/ro6PmFfl10DnMr6SMQj5yJSZ+fIcH2k729YFANHQgKO
/EdwJOeHh+7lHrveJe3jbsaR4j7uwTnyyYojn6g58jQ4ctL87NC1dtw5so6p
93H1K+waXzuO5K6FeHKkupfHkAEHLEjjEEIV/cjGCJV8ZpDLtn6dXB5ntNDQ
ZxH43A45Vpnw9pyMYcTWNIVGqBU7hrIYr0vnoJvE83paLRZz58ipY4PTxiOP
1Hmti4oji8NymWXe52wUA0dCo3Ek33eP58g3LXzwCD73TV+OtIjnRKp3KeJI
rv+eDUeeeanRiZolfTnyKTFHPgaODDuHbzrOYV1MnZnHUTiSqxU1LUdyXGcq
GQdyGvY6j9FvYaCcjNYq5Pdl5sqFtxdkNJX68Xkrug2FU0bG6WQ7Z3SvYzeX
9fN6Wh0ctH0/3p9734/98vOff7X6DHd2QLfLL3yh/qx3yy9/+fGKI/9U1giY
LXPvczaKgSMhJUfuR+VIof9ty5E3BbL1uaXPjdeDL1a9S6M+7uBIZe+aKyqO
3FvLv05UoDmsfX7AWjveHDnMz1Zz5G1jjuzncBSONO/VRvvNCfsdaphPyX4s
s/nGkyL6xrlA4f1se0Y0fmzObG+LArLjpMyZyzgwDeXM9pRaEI6cdzyy3n6+
0pM7pKfKL33pr8uDgzYeucyczz9wJASOtORIlU9u81jih4fuwRer3qVRH3cf
jjzlwJFPizny8YohH5+cI+/yHEkY0okjbWORJnP4psUc9uJIxbUQJUdqcrNZ
jmRys+k8NuVIbg7H4EiLtUjs2ihh/qeLpuaPZEVzEtPMK9x1xT8mfrmo2y6a
1zrPeGS9VrDe5wvlxYu3y5/85KflP/3wX8of/ehfyx/98/z0Q5vHVp/x5z//
t00+a+Y/16MYOBKaJUda+tQusuRI2zWSYetdWvZx13LkfjiOfKblyKeHHPkt
a45cq+HIb5hy5HU/jmxzjJPhSI/5G6TWjg1HDvKzXyu5elGOHFnP4XMjcqRN
bUR2jaS0l5xtnT3D3mCqviT+dW9Y5co1lUa1IHIyOjDIZo1eEU80BjZXJbD/
ZsfTxTcOwJG+13kS1mI5d4683uSzfu5zz5S/+MWvgiPQHGzzW+d/HkYxcCSU
IEeK+n1Ie36MxJHhe/CFrHdpyZGtTPq4yzlyrbqHJM+Rlw058lTSHEnn79W+
TlSnuXDkW0E4UhRX1+VmX9VypLhelK5W1JgcGaQXAMd4uVPtRTvG81hD6ZlP
y9a5Mc2xZXNg1SrGUccaY71frM8w9T5Yyj4P1iMXNVSueII6WND1kXPs+1HX
nHmlGo+XP/3pfzS/K3/+82flw4cH5cHBYie0+b3D+kgobY3KkS1Xifxv3gf/
gcAHT5kjXddIRuybwPVxn5Yjv23LkY/G48hLwTnSssZOrPkrmcM+dYc5jtTk
ZofkyPPGHHkjcDyy8FIfm+viJoV7Tcks1/BZJtl2YL68z6OyX5PltDasiyu2
vpIdOzBxw2x4DR7xyMiva8V7ZqIsqZaJb0398OGcm3r94hjrIw8PDxuO/OIX
L1QseavSjUo3Z6Ib1X7frsYT5c9+9l/NZ1lUbByi5kyY6xexlJORyuI1BOd+
FANHQlE58vVhTuBWcWToWjsjcOQlF45ca3YceSoWR6ri6elzpPm1EP081uVm
gyOJ2Fy6THBbonLLN3R7n43ycpkqP+26In2v9HiHmXf55OfO1Dpo10e+++57
1f/HZyu9UOlKpaszUb2vL1V6vPzxj/+9+SwHi0WzZjDW70+37f37k5LaczaK
gSMhcGSjvVYx8wL9OZKwpLT/nkkf944j5X3cY3Hkd5LnSPP+p6lx5B47j2fO
kfUcviCIqY/JkW65rEUzdv5J09Mx0vqnwVrEvBAzKye9f039KStfxYMxxPtI
RwslEAvaeuVkDCxt7J1TQcZC8vfuqa6zs1odlr/97f+WX/3qmfLrX79Zfu1r
e5X2E9f1dtwrH3nk5fIrXzlZ/vKXv2o+SxOPzMLnALNzb6vUnrNRDBwJ6Tjy
PMuRr3IceTkIR75px5Ey/nPwuTn/W5cX6Fprx6aHpDNHmvTfs+fI5wlHPsdw
5LMdRz53uRE40q5OlOsc1s5jo5j6DwTz1zSubsqR4jk8B470Y7x8sw4xsM/D
5aDmJJeVy4USKydjcLZwUNbmHnr1g4DGE82dCyzzvFYT5WTcPdXneL02e+5W
57R2ee+xclrTyWsNIME5G8XAkdCYHLkXjyO1TKh5rClH+sRzfDhSnNvq2sdd
z5GnInDkd4UceWrrONK2TlToOcxz5HAeh+NIdUzdlSMvBuHI/SAc6cd43f/v
DWPpOM6E64x6MVK2bPwKxfqaah+XrhxGfRZPv2fZ7l89ipUp7mO0NHwcZK8R
vtuMjGplBo8pSunc33b152ne5LgeLPJWWeJacrfR/hexROfe1mmJeCS0PRyp
iuOE5EgfTcKRLw19cHFeoHiNJB/PcePIYb1LGUd+T8KRayXDkWcNOPJaYI50
yMuONn85lrTohWoYVw/LkXxutpIjTdb4+sYj87BrcExySeMrb98v799XGGdK
QjkZNcrs4rGQp+h3PrnoXIHE13wSmDO+8w2yEz1PM3AklDBHEra54sGRIi6T
xnKS4Ei7eA7HkU71Lk05UtXHfciR8r4Jbhz5NMORT1QM+UQgjvyaF0feGnDk
xR3lSKN1vqqaUYYxdTlHvsbnZltz5K0ZcGRuxI10jMNxueDvfLM9tX8okFks
Cto24bhDqWgb52IUA0dCoTmy6+EehCMVOYGjcqTKB7fgyCB1SsJxpL7/HsOR
p+058slEOfLClnOk3RwehyOba0xcTHLz/YtqRV0QzGE6j2NzZNT4meCacRzf
pZBsd2JyA5fT+GuivEZod7WtvjyUpth5t42KYuBIKBZHvkg4ctB7z9T/3tQm
EfrgY3CkJCbpmhc4HUcO+7ibc+T1HeHIe6TmsCtHvimpsaPgyIjz1/taSCiO
ZOYwO4/FHLnJzd7kZ8s4UlMrKuF4pFBZK6/3lcQ5Z6JlztTcn3qNGRRepsce
giaS9TzMyJioohg4EorEkVeFHGkTx0mXI13jOSxHuq0vc+PI86E5sq61c1LD
kc+acuRJcOQoHGlWa6efxyYcuffG4HrIMDf7de5aCM+R93iOvJoOR9bXprU1
bQYq+nFp7FOT5ynWtrhcX29GbV0Ui/o1EcRe/1fGA5b2Wjg8Z9cU6zvKyOgS
G4KgscT+blprScZIoueUi6IYOBJKgiPVvRJENXZi+t9iP3xXOPIGOFLIkW/M
kyMlMckXqSx72HAx9T3ZHLbkSEGtqKk5Uh9vzLl4YpZ3ccDc/jq4Jl4T7to4
ZV47LvWTvr5miPdZktFKy+n92Wgy+GzhjjN/HGz4Mcz7m9RyhSCxQp4HIffH
Z7+iGDgSGoEj2VjO9nFkqLzAsBzJ1ykJwZEvgiMVHGlcJ2pijuTzs1W1h6fi
SHo9xJwjTweNRw75a/0/nPIXw2LedWuGvm/vMyTAN93+uMenMiNl7bgwfHxQ
ZRO85xZ+tu7YZcw4jXzmLBT6/IbcxJ5LLr+PUQwcCQXjyNcEPvicOPLtVgHz
AmXxnGj1Ls36uMfhyKsKjrywoxypyMuOMo/f5uaxOUdK4uoajlyveTbhSPE6
31AcWc/hfh6T3OxTAers0DWGcdZu5WQkUnHpMuY19GniOF28rGPmxcTcDLmr
O3bSOSmZvxA0uRKem/Sccvl9jGLgSGhWHBnS/35bohHyAj3qXfI9+Oz7uI/L
kRe9OPIbc+HIfUlOa3SOVM/j+BzJzuNxOfJsbI5k/ocLfeIR/Ab6/o2ixicz
9f2h4xUZM7bX2ieJR0JBZHzsBMc+vHzmLIR4ZJpCPBJKTUKOPDceR+rzAWUc
yfOfvc9tz5FeeYEe9S7VHGnWf8+MI/cT4sin0+NIQZ0od44MPYdVHCm4FuIZ
Ux+HI18dcOS5iThyjOvMRlJwpFscLzPnSNm+BPJH65ovi8XUPjHkewxFY6NU
j2306zMz1tTHZmwlOEfpueRaFyuKgSOhFDhSEYs058jQihjP8ah3yXPkPXeO
vKjnyJPVPDhJOPKEjCNP+HLk8xNw5J1AHPmmHUfeHGMOM9dCbio40vNaiBtH
GuZm03pRCXCkiCXp7a5+mjGnLol070l9YytZxnA8/O9Fx6yCa+0m19sXzOOh
cAodKxG/Znvsp+Ykr/NlBxTlO8/IOLE853uo+KLpeed6jkYxcCQEjpw0L9C2
TomKI5V93AccadHHXcORx4Ny5IkROfL2lnPk21qO5Nf6huDIN4JzJFcrSsuR
N2Ydj+TiiUtmO5pfx/p3hqL+t8F1fPa6+mIpiVtBWyFRHCWp49zNWfZcg/jf
Hfp9QcHODXp+yBTivIli4EgIHDl6XmB8jlT3TZiGIy+E4chHwJHOMUnXHjaB
OZLPbU2bI3X8uCSPGfijoSTyb9m/ubzU9hq0wbX2YRxK78/4augPkZiUNnal
2m8HLbZU9PN5fD+h45HiGHI+2ryDUhM9/rsp19ii6/kZxcCRkBdH3h3433KO
fEPBkeoaOxxHOq8XC+WD+8dzfOpdGnGkpv/ekCM1/fc6jjxTc+RLEo68NiuO
rHmEXgeRc+Trwzm858uRb+0GR0r716h6f9wT14riOJLJz04gHjngyAHrWcb1
bOIC1bZ4HWS2YcqlnGkXZOz8uSHTjXU9XsCRC3t/yoodReO2iGVJTx83dN4e
f2zHnW9QShJfQ5pcFr8/oc+PGOcdVRQDR0LgyIk50m59mZIjDfu4x+LIuofk
MzvCkb51ovgaO9PNYZe6w9z8tVjjO1eONM1PHTJlZseIY+SnaeOldn79wsp3
DKfp4ynboVGPW+I5kVPNZXxeaAxFMXAkBI4088ONODJEPCckR4r7Jnhz5Ckz
jnwqBEcei8+R9Rq9yz4c6ZCXPQlHeq+RfFN6LcQmN1vNkXeT4sjVauWlwvP5
9DUKZtv3dVdFgNcIsS+FZDR4XyieQswN6fG2PNZjKernTlC79nmlovMxsTkZ
UlEMHAklzJHqtZEx/e85cKRtvUtzjjwdgiOPX1rHJMGRE3Lk26NxpFludgSO
vBiXI2EwGAwGg0kMHAk5c+QdN44M1jtySo6MkBdoWKckFkeeqY9zdI48P0+O
7OtEzZMjxfPY5VqIiiNNr4V8X8mRfK0oFUcOa0XR6yFd75pa4EgYDAaDwSIY
OBKamiOda7WOzJGBeyeMWe9SxZGq/ns7w5Ev3Ot1RcmRfyfgyJTzslUcKbgW
oqo7fN1mDgfgyMEcZtf40nkMjoTBYDAYbBIDR0LgyPQ40rrepVkf987/rmM5
Jn3chxy5N2OOvNnEXY04sp2/W8uRkjlsFFPfH4EjhXNYx5F8/5pujW8tcCQM
BoPBYBFMxJEQBEEQtM0CR8JgMBgM5mfgSAiCIGjXBI6EwWAwGMzP/qqc/v85
BEEQBI2pvyxhMBgMBoP52N+W0/8/hyAIgqAx9TclDAaDwWAwH/tFOf3/cwiC
IAgaU/9ZwmAwGAwG87XfV/qHSi9DEARB0Bbr7yv9XwmDwWAwGAwGg8FgMBgM
BoPBYDAYDAaDwWAwGAwGg8FgMBgMBoPBYDAYDAaDwWAwGAwGg8FgMBgMBoPB
YDAYDAaDwWAwGAwGg8FgMAP7f2ziwnU=
     "], {{0, 669.}, {914., 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   AspectRatio->Full,
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{357.7096801757813, 278.3424882684286},
   ImageSizeRaw->{914., 669.},
   PlotRange->{{0, 914.}, {0, 669.}}], 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztvX2QVdWd782L0gIiamx8gRa1MY2BTkCZlhIQGYnCDBObhEmQoUcScERA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     "], {{0, 494.}, {500., 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   AspectRatio->Full,
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{291.55462646484375`, 260.13978759765627`},
   ImageSizeRaw->{500., 494.},
   PlotRange->{{0, 500.}, {0, 494.}}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{3.83224284458783*^9},
 CellLabel->
  "In[113]:=",ExpressionUUID->"48d6f201-f071-4acc-bd07-04681ea7255c"],

Cell[CellGroupData[{

Cell[TextData[{
 "HDDSvals = Recurse[\n\tLOSvals~Join~{\n\t\tkB->1.38 10^-23,\n\t\tT->295,\n\t\
\tg->9.8,\n\t\tmu0->4 N[Pi] 10^-7,\n\t\trhoeAl->2.65 10^-8,\t\t\t(* \
Resistivity of Al *)\n\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., \
GUESSTIMATE *)\n\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, \
measured *)\n\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)\n\t\t\
massSOS->0.25,\t\t\t\t(* Final design value *)\n\t\tmassM->rhomM l N[Pi] a^2,\
\n\t\tBresid->1.25,\t\t\t\t(* Residual field *)\n\t\tPi->N[Pi],\n\t\t\
rhomM->7400,\t\t\t\t(* Mass density of magnets *)\n\t\tztube->0.0155,\t\t\t\t\
(* Separation for magnet to push its own weight, measured *)\n\t\t\
zpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)\n\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate \
magnets *)\n\t\t(* preferred value of small magnet dipole moment *)\n\t\t\
mzpref->0.007945632135874319,\n\t\t(* magnet moment per unit volume for \
magnet stuff, assumed the same for big and small *)\n\t\t\
mz->mzpref/(lold*N[Pi]*aold^2),\n\t\tlold->0.003175,\t\t\t\t(* length of \
small magnets *)\n\t\taold->0.0009525,\t\t\t(* radius of small magnets *)\n\t\
\tl->0.006,\t\t\t\t(* length, ",
 StyleBox["Srinath Karat email, 2021-06-08",
  FontColor->RGBColor[1, 0, 0]],
 ", as for AODLvals *)\n\t\ta->0.002/2,\t\t\t(* radius, ",
 StyleBox["Srinath Karat email, 2021-06-08",
  FontColor->RGBColor[1, 0, 0]],
 ", as for AODLvals *)\n\t\t(* coil length *)\n\t\tcoillen->0.4*0.0254, (* ",
 StyleBox["Srinath Karat email, 2021-06-08",
  FontColor->RGBColor[1, 0, 0]],
 " *)\n\t\t(* the ends of the coil relative to the centre of the coil *)\n\t\t\
coilz1->-coillen/2,\n\t\tcoilz2->+coillen/2,\n\t\t(* the inner and outer \
radii of the coil *)\n\t\tcoilrad1->0.275*0.0254/2, (* ",
 StyleBox["Srinath Karat email, 2021-06-08",
  FontColor->RGBColor[1, 0, 0]],
 "  *)\n\t\tcoilrad2->coilrad1+coilturns*wirediam/(coillen/wirediam), (* ",
 StyleBox["Srinath Karat email, 2021-06-08",
  FontColor->RGBColor[1, 0, 0]],
 " *)\n\t\twirediam->0.0094*0.0254,  (* ",
 StyleBox["Srinath Karat email, 2021-06-08",
  FontColor->RGBColor[1, 0, 0]],
 " *)\n\t\twirearea -> wirediam^2, (* assume square packing *)\n\t\t(* the \
number of turns *)\n\t\tcoilturns->1000, (* ",
 StyleBox["Srinath Karat email, 2021-06-08",
  FontColor->RGBColor[1, 0, 0]],
 " *)\n\t\twireareaAO->6.47708\[Times]10^-8, (* for comparison: effective \
area of AOSEM wire *)\n\t\tcoilsigma -> coilturns/((coilrad2 - \
coilrad1)*(coilz2 - coilz1))\n\t}\n]"
}], "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.48069930379321*^9, 3.480699340598193*^9}, {
   3.814193152626812*^9, 3.8141931681875067`*^9}, {3.8141932051916847`*^9, 
   3.814193240900976*^9}, {3.8141933150605392`*^9, 3.814193329634098*^9}, {
   3.81419350992902*^9, 3.814193605612219*^9}, {3.8141936599727077`*^9, 
   3.814193703912157*^9}, {3.814245962285343*^9, 3.814246054493347*^9}, {
   3.814246096882122*^9, 3.81424609767097*^9}, {3.814246191198668*^9, 
   3.8142462185994873`*^9}, {3.814246258711887*^9, 3.8142463584737673`*^9}, {
   3.814246404736154*^9, 3.814246425590207*^9}, {3.8142464623580513`*^9, 
   3.814246481204917*^9}, {3.8142465287931967`*^9, 3.814246570064755*^9}, {
   3.8321602624152317`*^9, 3.8321603488047323`*^9}, {3.832160405707703*^9, 
   3.8321604349373693`*^9}, {3.8322424255474453`*^9, 3.832242430102974*^9}, {
   3.8322429408867817`*^9, 3.832242990671521*^9}, {3.8322430685096397`*^9, 
   3.8322431022063828`*^9}, 3.8322431543636513`*^9, {3.8322432599242983`*^9, 
   3.8322432721866217`*^9}, {3.832243351996809*^9, 3.832243374628625*^9}, {
   3.8322434263843937`*^9, 3.832243603478817*^9}, 3.8322436817867117`*^9},
 CellLabel->
  "In[113]:=",ExpressionUUID->"ec495fa6-01e9-4245-92ed-ccdfaff6db26"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0001394867138193868`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.011999999999999999`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.006`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.01016`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.00508`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.00508`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0034925`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.00910336`"}], ",", 
   RowBox[{"wirediam", "\[Rule]", "0.00023876`"}], ",", 
   RowBox[{"wirearea", "\[Rule]", "5.7006337599999996`*^-8"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "1000"}], ",", 
   RowBox[{"wireareaAO", "\[Rule]", "6.477080000000001`*^-8"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.7541909235018108`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.4538417843516493`*^9, 3.463844900775058*^9, 3.480692290540955*^9, 
   3.480695055734477*^9, 3.480697045556779*^9, 3.480699411967904*^9, 
   3.481566894140891*^9, 3.4819420607019053`*^9, 3.6626247130171137`*^9, 
   3.799212566602963*^9, 3.799212758204702*^9, 3.8141938505514174`*^9, 
   3.8142461557551527`*^9, 3.814246236167638*^9, 3.814246865465023*^9, 
   3.814247685526759*^9, 3.814248516564362*^9, 3.83224229400727*^9, {
   3.832242965483184*^9, 3.8322429918118677`*^9}, 3.832243570230466*^9, 
   3.832243613400269*^9, 3.8322437627858686`*^9, 3.8322462992705927`*^9, 
   3.8322466456294117`*^9, 3.832397039119849*^9, 3.8324035312953377`*^9, 
   3.83257895943302*^9, 3.889696116413104*^9, 3.8901189105657873`*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"da8ced68-99fd-48df-bb68-e3f69f3c79e0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "HDDS", "]"}], " ", ":=", " ", "HDDSvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}, {3.480699304968781*^9, 3.480699305631609*^9}, {
   3.8141937544519453`*^9, 3.81419375866918*^9}, {3.832243683522756*^9, 
   3.832243684272985*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"f6052a88-9fe1-4b8f-9f01-d87cf17b0939"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "HDDS", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.13030351516936053`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005607360550285311`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"HDDS", ",", "z"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, {3.480699306305072*^9, 
   3.480699307040391*^9}, {3.814193775850436*^9, 3.814193777343864*^9}, 
   3.814247837428177*^9, {3.832243685305995*^9, 3.8322436867404423`*^9}, {
   3.832247014337783*^9, 3.832247038773687*^9}, {3.8322474960305*^9, 
   3.8322475013168163`*^9}, 3.832247967535845*^9},
 CellLabel->
  "In[115]:=",ExpressionUUID->"8e0bb816-94ea-4e37-a97a-6ce3311929e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.13030351516936067`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005607360550437446`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.832246299318676*^9, 3.832246645680643*^9, 
  3.832247503746889*^9, 3.8323970406421547`*^9, 3.832403532381516*^9, 
  3.83257896041936*^9, 3.8896961168217297`*^9, 3.8901189109584103`*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"d2a0fba9-7fde-41c2-b892-1fe0eed62c84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "HDDS", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"HDDS", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, {3.480699307709909*^9, 
   3.4806993083441687`*^9}, {3.8141937781239767`*^9, 3.814193778723106*^9}, {
   3.832243688566028*^9, 3.832243689608747*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"d66a1f31-b8f9-45d2-9740-47f621c6c0b9"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4VO0bB3C0EGUtSxTFW4lKpZLwRVIKpbRJsrXQhpk5M0PZ1ylFyJrM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       "]]},
     Annotation[#, "Charting`Private`Tag$489390#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.13030349927278273`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699525015361*^9, 
  3.481566993083891*^9, 3.4819420608359413`*^9, 3.6626247782161903`*^9, 
  3.799212566665503*^9, 3.799212758279677*^9, 3.8141938506505527`*^9, 
  3.8142468655727882`*^9, 3.814247763779603*^9, 3.814248593768003*^9, 
  3.832242308637123*^9, 3.832246312891868*^9, 3.832246657505343*^9, 
  3.832247532113949*^9, 3.832397053457816*^9, 3.8324035440914917`*^9, 
  3.832578971532844*^9, 3.889696121551996*^9, 3.890118915614365*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"057a2134-7b48-47f6-864c-967498c6bef2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "HDDS", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "HDDS", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}, {3.4806993090802107`*^9, 
   3.480699309671587*^9}, {3.814193779450665*^9, 3.8141937800273237`*^9}, {
   3.8322436906748533`*^9, 3.832243691603806*^9}},
 CellLabel->
  "In[117]:=",ExpressionUUID->"3af80dbb-cd80-4d70-81b3-de5fc9c3cb15"],

Cell[BoxData["0.005607360550437446`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.4806995251344767`*^9, 
  3.481566993139513*^9, 3.481942060861919*^9, 3.662624778303006*^9, 
  3.799212566717863*^9, 3.799212758288528*^9, 3.814193850662404*^9, 
  3.814246865582979*^9, 3.814247763822814*^9, 3.814248593809575*^9, 
  3.8322423090602283`*^9, 3.832246313047535*^9, 3.832246657593799*^9, 
  3.83224753222582*^9, 3.8323970535423117`*^9, 3.832403544154326*^9, 
  3.832578971583494*^9, 3.8896961215798683`*^9, 3.8901189156460733`*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"4fb8cd59-ed15-4c45-b6fb-ecffbdeb24b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "HDDS", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "HDDS", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}, {3.4806993103161793`*^9, 
   3.480699311077731*^9}, {3.8141937806353197`*^9, 3.814193781189724*^9}, {
   3.832243692280777*^9, 3.832243693148573*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"18141311-8995-4ce3-9390-69e5b18bbd18"],

Cell[BoxData["0.13030351516936067`"], "Output",
 CellChangeTimes->{3.832246313059547*^9, 3.832246657611475*^9, 
  3.832247532321741*^9, 3.832397053576797*^9, 3.832403544163528*^9, 
  3.832578971596073*^9, 3.889696121589179*^9, 3.890118915652356*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"e8efdf6d-7f81-40d6-951b-8caf9f1cc42a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "HDDS", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"HDDS", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623603106723*^9, 3.662623611969966*^9}, {
   3.814193782119986*^9, 3.814193782621785*^9}, {3.8322436943064117`*^9, 
   3.832243695005291*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"65ade7c5-c901-42ae-b528-b3f35d131c4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjnswGwYAh9OIdoe1mM6jNgSdzqwdlSmxn1U9FqHaoQ9azqO6xTOtV0WS
KpEwxZ03aanUlKAhgoiI3rCW6tKNrnMeV9uN6WpFOfPo7I/ffffdfX/8LMLj
T0cRCQQCdWf/c6W62yzD+5UrgZDw2Ljf7YvJez6KlUFbFHv2kKvkbEjrooma
S1Ror2PUbqsAuinrXoVcD8wYeRFPdpeBvkB1UUfSEfTGMNzwy9tIszkb5bt4
ClKdRm2uuA6OzpHRQTGB+Lcuscox+nvUn+B3Wh49B69ROacmrAmVlAUh7a8Q
fGrc0s/7rBUKd/9p2pEwfEgT3w8NkIA3Jyt9qhsOqZHf2KB1OwYUnowYdQQq
A1x67YekGCCtajkIokAmEUlOfjKYfyVRB1+KxlutK5oj051YVJR0lFp+AzpN
NOSEbhjb8VQOuxk4cMcy/scaOUh6paVb0zG4mb5YlDbVg0irJ4LnFXFgC51/
dVlQQNdE62keNQHLytGB+sVeNBzr/9vBNBHCZq2iRz8oEXdm2zR/LxNz2Uur
/Nw+GBwelrA2mfAgF8rP71ch6dYngUm/XcHZyOEKtb8KGjoGOmbDV8HFIb0m
rgp0vUK1uikJh2wSaWrhTv9T1aYJPxmy47ZRm00qjOTbuexPScFdzmlp8o5P
vviabxSUiouL1rPB1SocoBDmR7zSsMsk9gyLpYKzO7XV0PEa3En6B/X8VHhv
TieLoZ+OSJ01xtTOH5O8iJgEIgs/r55i0sr6MDHgF8F+wYKILX6e+UaJDPnD
PrIyA+e+c4nQcFeC3vzocKqYjYtTQzRGbC/GPw9rGc/lIMTRtOv3EgU8Z1zN
l125eLUr0p8r7AHnn5IETgsXrW6CzfxGORomO5bHTa/jMnMy/IG0G3MPywk5
xdfR1VP3rFzUBU3iYLELKROU89J1oqgTTsdkbd4ZmRidm4mZzpchxDdOw2Il
E0pzSt9HnA5caE6Y2Aq/gUvvj6WX8aRI0qG4OkzcwFj0WKMxpx3fdnocjPXJ
QkNoMnuzoA0n8cFxZncW7OnvOs2LJfAZ7PzzyZFshPVlsdh992FVUW1gX5ON
jYzLS7VjrTBgnBh+acRDXn/LbL5pC1aMpVJmAQ+BqbfcNjhiSAzirLe2eNCe
VL9N0GtC9t4Fs5mkHFhRyLLisnugBLTVDv2Rg7DHRb9seDdgu5zavCeUjwvb
5p7Zr+shk99c0B/nI0S4b8qw/S58bGwlZA8BoPvOx/sqRVgrziXk9QpgLs14
YHGtDlzfo8/W7HIxtHv+ajDrDl4XU+KVt3Mxu0f0sllQi/8A9zrCzg==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$509875#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.13024859371082237`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVjnswGwYAh9OIdoe1mM6jNgSdzqwdlSmxn1U9FqHaoQ9azqO6xTOtV0WS
KpEwxZ03aanUlKAhgoiI3rCW6tKNrnMeV9uN6WpFOfPo7I/ffffdfX/8LMLj
T0cRCQQCdWf/c6W62yzD+5UrgZDw2Ljf7YvJez6KlUFbFHv2kKvkbEjrooma
S1Ror2PUbqsAuinrXoVcD8wYeRFPdpeBvkB1UUfSEfTGMNzwy9tIszkb5bt4
ClKdRm2uuA6OzpHRQTGB+Lcuscox+nvUn+B3Wh49B69ROacmrAmVlAUh7a8Q
fGrc0s/7rBUKd/9p2pEwfEgT3w8NkIA3Jyt9qhsOqZHf2KB1OwYUnowYdQQq
A1x67YekGCCtajkIokAmEUlOfjKYfyVRB1+KxlutK5oj051YVJR0lFp+AzpN
NOSEbhjb8VQOuxk4cMcy/scaOUh6paVb0zG4mb5YlDbVg0irJ4LnFXFgC51/
dVlQQNdE62keNQHLytGB+sVeNBzr/9vBNBHCZq2iRz8oEXdm2zR/LxNz2Uur
/Nw+GBwelrA2mfAgF8rP71ch6dYngUm/XcHZyOEKtb8KGjoGOmbDV8HFIb0m
rgp0vUK1uikJh2wSaWrhTv9T1aYJPxmy47ZRm00qjOTbuexPScFdzmlp8o5P
vviabxSUiouL1rPB1SocoBDmR7zSsMsk9gyLpYKzO7XV0PEa3En6B/X8VHhv
TieLoZ+OSJ01xtTOH5O8iJgEIgs/r55i0sr6MDHgF8F+wYKILX6e+UaJDPnD
PrIyA+e+c4nQcFeC3vzocKqYjYtTQzRGbC/GPw9rGc/lIMTRtOv3EgU8Z1zN
l125eLUr0p8r7AHnn5IETgsXrW6CzfxGORomO5bHTa/jMnMy/IG0G3MPywk5
xdfR1VP3rFzUBU3iYLELKROU89J1oqgTTsdkbd4ZmRidm4mZzpchxDdOw2Il
E0pzSt9HnA5caE6Y2Aq/gUvvj6WX8aRI0qG4OkzcwFj0WKMxpx3fdnocjPXJ
QkNoMnuzoA0n8cFxZncW7OnvOs2LJfAZ7PzzyZFshPVlsdh992FVUW1gX5ON
jYzLS7VjrTBgnBh+acRDXn/LbL5pC1aMpVJmAQ+BqbfcNjhiSAzirLe2eNCe
VL9N0GtC9t4Fs5mkHFhRyLLisnugBLTVDv2Rg7DHRb9seDdgu5zavCeUjwvb
5p7Zr+shk99c0B/nI0S4b8qw/S58bGwlZA8BoPvOx/sqRVgrziXk9QpgLs14
YHGtDlzfo8/W7HIxtHv+ajDrDl4XU+KVt3Mxu0f0sllQi/8A9zrCzg==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$509875#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.13024859371082237`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {46}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGI9BgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gb71C/bgCY0Qu1vtH/+e+XHS75NUHc02WcyzzW7kNkMdU+z/RuuCdVn
W1vs14Ld1WqfJ9QMtKIV6r42+0+SZawn9rZB3dlubwJ2Z4f9NrA7O6Hu7LIH
AClttbE=
   "], CompressedData["
1:eJwBgQF+/iFib1JlAgAAAC4AAAABAAAAAAAAAAAAAABtk9z6w6GDP3ixbzAl
mpM/ajjZuWRTnT++3lxGY3mjP+cuZcc+Nqg/ma3bQUnZrD/n6p7tQa2wP6Co
TnGW2LI/87zUeBPqtD9VLfZBOt22PzZIJsXXrbg/ILWoQDRYuj86bAaqMNm7
P5gIvmdRLr0/XRvOILpVvj+m480kIE6/P8Io0ndcC8A/vXOJoJRXwD++5oTq
u4vAP3yQWM4CqMA/FIr9MsaswD9RNooJkprAPwYbcesmcsA/Mf4+A4I0wD+U
6Eb7y8W/P4J+FoLG/b4/HymetLgUvj/nTJ4FCQ+9P9NniHSp8bs/BWcnBPDB
uj82DKwbWYW5P94rXkNHQbg/lrTEPsD6tj+tg/PwOLa1P3nN7D10d7Q/cz1R
V3ZBsz/w3sqgiRayPzVolOxO+LA/R0QBxanPrz9ujp2yYsutP/U4q+gy5Ks/
rkln1/EZqj9PbYGLhtmmPx6qe+cwAqQ/VJfz3K2JoT9HT7Wn
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.66262477963708*^9, 3.7992125668182993`*^9, 
  3.799212759422963*^9, 3.814193853077264*^9, 3.814246867872548*^9, 
  3.8142477659461203`*^9, 3.814248595891169*^9, 3.832242312947443*^9, 
  3.832246317177343*^9, 3.832246660802291*^9, 3.8322475461587553`*^9, 
  3.83239705733352*^9, 3.832403547367547*^9, 3.832578974749048*^9, 
  3.88969612294271*^9, 3.890118916947055*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"4d760d37-0486-4a2a-9df2-2b942f89e5d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "HDDS", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "HDDS", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "HDDS", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626236050185127`*^9, 
   3.662623609386401*^9}, 3.799212531136713*^9, {3.81419378324492*^9, 
   3.814193784414452*^9}, {3.832243695808785*^9, 3.8322436972248993`*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"530ad6cf-6e30-41cc-8cd8-d2201e3f7dd8"],

Cell[BoxData["9622.729378687809`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624779712291*^9, 3.7992125668301373`*^9, 3.799212759473455*^9, 
   3.7992244859239483`*^9, 3.814193853141307*^9, 3.814246867917796*^9, 
   3.81424776598672*^9, 3.814248595928607*^9, 3.8322423132616453`*^9, 
   3.832246317306079*^9, 3.832246660921652*^9, 3.832247555513609*^9, 
   3.832397057444703*^9, 3.832403547436111*^9, 3.832578974793457*^9, 
   3.889696122978929*^9, 3.8901189169745893`*^9},
 CellLabel->
  "Out[120]=",ExpressionUUID->"eddf33f3-89c4-441f-946e-3097ea6b9f12"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"f4e72ab5-1dac-4fdd-84a5-\
a651f9e74607"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"HDDS", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9, 3.48069931407596*^9, 
   3.814193784954692*^9, 3.832243697992732*^9},
 CellLabel->
  "In[121]:=",ExpressionUUID->"f124276a-fbb4-403a-bc9e-e87a075eb6cd"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xc8Vf//AHC7VERLyigaVkbk01AvoSWJJEkJDSrzjnOumXFRWRUKSWWT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       "]]},
     Annotation[#, "Charting`Private`Tag$510003#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.13030349415137601`, 0.1303034632157872}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699539484208*^9, 3.481567006130314*^9, 
   3.481942077639205*^9, 3.66262479351025*^9, 3.799212566887249*^9, 
   3.7992127713239603`*^9, 3.8141938712469807`*^9, 3.814246883847354*^9, 
   3.814247781671936*^9, 3.814248611221245*^9, 3.832242336465692*^9, 
   3.832246681700676*^9, 3.83224758166888*^9, 3.832397080088891*^9, 
   3.83240356747442*^9, 3.832578993995899*^9, 3.889696131179994*^9, 
   3.890118925103282*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"599baba7-67e9-4744-9990-c6d3d047715f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"HDDS", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9, 3.480699314862365*^9, 3.8141937856826353`*^9, 
   3.832243699458761*^9},
 CellLabel->
  "In[122]:=",ExpressionUUID->"b4181ed8-2fab-4bad-9ece-701e50b45b57"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13k0Fe8fB3CSVq2WIoWUslTSom/kTWQXypaQNdwQ7r0z91qydJUKRakI
RSsRXUq2TClLKRWlEqGopA2phH7P7685rzNz5jnP+Tzz+bxHyXPvNp8JIiIi
YqIiIv+/ahsNfwmX6N80YpelLjoNerO0K9JKyxv0LFoCd3zjyWPxzproqPJX
ehndop+LeBrQCDTheJV/0vtr40If4+liNTU1yL78j97WPsYinGeJ4rA+1tby
qTBM6vviwnPB0KjzJ/NyWXzrHj06TgdAWu/4crNyVTQ1qt9MpiJQJvouybRp
I6bFmXvuzEmE8/II+T19hijY1X8r428qHpTxuqMszaHm0ZZ3/HcGPJM++BzO
sIFm867oecjBQHmIcWHrdkwr/mNodOsiTJ5c2SDl5Ij91a/drwTlIvW1k7Ji
vTMe/flt/mlCAYbffuBPGnPFuHxfSoZyEWZ8mBNyssIdR5XfZs1tv47cnQpt
Mjs90VSh3CwdUIw75v53WANesN4zK2dVTwl0rx0qcsv3wQs5s/ErATehfzTt
ebWpLwxtfVuy6kpx+X2U2J3J/mja5zv7p2oZDpfkFKTeZsFKqm+FVlA5fone
SGx1DICd4flhgwMVqK3JpMokg7Dug3TVgYxKKIhRqVOEe1HjcXFa+MEqBO5M
6QgvC0bZiqtR21m3cWjgoGZ7agi8L0h7sjSq0XlZ55hkWgi6g1QDpqyqxgbX
b9/MMkIQkVbTc2F1NT7WORTezAkBvK2XvVpfDePMpSuPFYag7aNq90qDakww
rVE3bAjBRA1K7ah9NcIyx1VyR0OQ26d0ZXFkNVim3IVcr1CwBS8ep9RVIy9v
Y9X33aFouLpCZ7ShGn0SIq4BrFDUtIU88mqsxp6nhzO8QkLxvSPda8XTagQ4
n1uwLSoUSdks+7zX1QgKeCi76kwoHLKcTCy+VIN9TEnm07NQ8E0jT52YwiDi
5aOZrpvZOLO790uuKoNbsv/iM7ewQf05fi9FjcGgs6ZYhykbLZqSjWHqDFjt
Kb/crNkI6Y0LNF3BwLHbsdPdhQ3xxxtHXmky0Orvuu5NsbHhoKjOC20GH//9
tAvIYyPa/6brmi0Mlhgsa8ovYEP43dB6gjGDXbFOZl+K2LA1KQ15QvxiYsWm
oFI2dHbam7FMGdRMjVYJvsfG/pozhicsGGRJTvvN7mBjfmiXzx1bBtuXLToT
PpeDJTJ0cLQrA0GXSeVVaQ5qLbcOr3ZjUHImpL1tPgfmjNuNbmKp2fcVdBU4
CJ2j/dbAnaz3e8+FUXUOBK2y3cOeDJwelBVEbuHgPSf0so4fA7dAeyaKx0H7
bw0zzVAGScuiugrDORjuLhmtJ77ddWVC5z4O8l0/f3JnM1BwGDXSj+PgzN+g
kCQOg0698w0iKRyw+p3WdVIMvGb/eBZzlYPg8YYTbuEM/IoTevZ3cNDHzHte
u59BjFy98Z8uDmYubE2zFTBIjxG7EtTDwajZV24bcaN1GGtHPwerxww4/XEM
Vvf7fls5Qt6Xs/2wWDyDkSWGf15JcxF+8+/iSQkMJBP2OVvLcpF6/rV7LLHG
YFnFPXkuRq2P3Rwjdrujua9QmYu8l9m5PxIZ3HVdJBa3moudz7YWPj7K4MjJ
PxKaVlxUph/Vdz3O4MLY2qCLNlxo7Bn+94D4tndwk5wdF0oLa1q1TzD4rvUh
WXwnF5eWlTyZmcrArqlFps2PCznuhE/XTzKQn1KkeEDARW3sQEVjGoNr/N1r
31SQ53F8jf1Zsn71jGCZai7UR1jF54hfiN+4anOXi9lDJazPxP+SxZTv13PR
o3U/at85BjZ55+Zce87FpshOozPZDH68fv016hvZnwHPsPA8g0lKsWrlA1zY
3RzS+0os56u6e+gnFyquUaEaFxhsHqTb/Ua5GBv9EHOJOGW6dKPtVAoH9qgY
Jl9ksFbXOldZmcILtxgng8sMTGOH37uqUIjyv/OKTexSn6l4WpVCntet4xeJ
BXb9pyQ0KcyR+3V90hUGzwMOHfipS6FpXtfpauI+oebdVfoUJt6b2fWZePx3
65i/IQWXNEvPebkMVOJUuB1mFDzsVGYHEFOZNV51DhSujR2Xk8hjcPgd66yo
MwWJg8kaWsRZqnPbdFwpNFd8pR2J6264byvyopC/Y1HFWeL5j8f004IpzH13
dkjlKqm/1MWIZjaFsZbNzcbE+s6Wt2bQFFJ1hZ99iP1601fFRlKQtFn2IJu4
bFx70Z7DFE7JvtCbnc/g5o/vaX2JFN4b60/XIBa+z5VmJVPgMVu/GRPnP1gw
w/80hZeiaeN84tyqlviPZyhMW/FTNYX4UlHiRL+zFKbsWR+YS3zu5L+/uy9R
KC/O1XlOnHnoFt2bS2FV6WjtJ+L0iJBBnwIKs6op1hjxCc93fd4lFJQyFo8o
FTBIts/Y/b6UgqcI1atFnGRq3+1VQcH44JrPm4njV9a98rxLwadPU8+dOE4p
2r77Pqlnf0pCIHGs1H9PPRooGLmdH+QTR00esOxqpLAphs2OI44Yyat3f0LB
8qqUxDFi/hcvo85mCuJbTlelEVOd8syuVgrrHsyKzyFmNz/XefuaQkJDwp48
4uDapFK3DgpLexT9rhMHlpms6eiiMP60PbKUmJUvUujaQyHb6Xl+JbHv2TK1
9o8U2HayPxli75TQSy79FCxKKhzuEXvEqS9+842CY9jjp7XEbrz3mTsHKQxV
eO2uJ3bekynbNkzqm50o1UDs6OaQ6jxC4ZCf25v/37eznTXn9RiFZbs+VtUR
2xjVJ+wQpVHzcVPZfWIr7ZgprybSGAsPeXyX2Fxto8BpCo38nNSx28QmCwf/
tU6n4TRSaVxObDQ7P9xxFo1fa0ZyS4gNxHx+vZhLw1zKfdk1Yr3hhWwHGRpR
bNHqS8Q6n158fS5LI3jTj+As4g1vjrLsF9JoDdm8KZV4XZNpb4sijZ/KU5Yc
Ida6K+ppt4TG7TD7pdHEq26UtzcvoyF7fZMBh1jjCnvHdnUa56RbaF9ilaQe
m21aNCQn71hnQawck9X4dB2NlBNBlTrEihxHU9v/aCy/EeWmTizn3AAbfRqi
6b2Dk4nnWcVWNBnScPD0+jBEzpuUvo62tQmNF+nqw53EM1UKVm7dSiMy7KvP
TeLpsrvzHtnSqPOcU3eWeIqEgoqVPY33m54YxhNPGDi20NKFxhv54GMOxD+r
OBLmLBoDw/G8j+T76lVVWVUWSGMop23LQ+KXqa22y0NohE3K1y4grgzceGoS
j8b5ndKHgogFC0UW18TRGDbc2NNLvm/q0HUjrUM0ytTzXt4l9vvp6ZudQON6
woYfmcSWj+7nRx2n4R0/IcWWWCryiLZuNo1Ss4QT10h/mfRJ1/nqBRpqDprF
+4l/232NkLtCIzvk9C9H4jcatnd/X6MhLjl1YIz0q/NvZKxuVNIwGasoBLGW
bo7nypc0krfreKRfIvP9yva4zDZSb/flvR7EMlLiVyTe0qD916QsJx757Pul
r4esf3F0VzHpr3fOrOBdHqTBO/W05TbpvzZ/byUqzuJBbvEu7YIc0p99WUVH
5/Lw0rhugy/x2uYFzePSPGw0eeKpSDz/6r757fI8PNG8o3mM9P9OZ6PzaWo8
bLu1pdSHzIe95U235hrzkGXVuv9jJunX4l9uGJvxoEynVaYTm9pMKw6z5OH9
ZFMdS+LFvUYF3dt4yJx8fFpBBpk/c8qzhbt4iOHJDvqcIefZ/8LhbXweak16
xkpOk/Mwn++Sks9DfW5xYn0Kg7+eJ3fUFvIgT5XleRF/LCh2GBHycKrFcPZ4
Mplvhl9tPMt48HXGDU1iaq/XFq1aHgJk3P0TybztqLVa+ewtD0vLqcQlZD5f
4y4WmSvJx0z1ft8HZP4LAm03HZHhI11zt6kRsbNPdNhEOT6OOh20qyL5Qdy+
Y2hYkQ+9Dp3v+bFkv2vTP7Wt5GNy25sNsdEMpg3Oab5ozseS6fVq4hEMdgeL
Xvovlo/wWU84gSTP6PppvhPG8WE7GjnlUQiDue67FDUO8fHfjU8P1YmrrKvS
Fx3jY/dCQXfvXnKeVvGPimXxcUGQuG17INnfl++8R2V8NOsedREn+WnRnk4L
jx98HD+UN7fJhcE3g3Cvs0N8TBqytlAiZubLhLf/4uNykfez0J2kv9Va5O0Y
54P3xaFR0pnkDaXSKdumh0GQfTvUypGB+svE+5uXhsHWq+vCWZL/NmzRwZId
YTBJEo1kSL7crnBS6wMThmcRzdp/SV6dv1f1h9S9MMz/JWanQtxxu7Jwc10Y
/vklP7Ih+Zbl9k4j61EYXupbvTq/nMyDTM1l9q/D0MT767B5KYOiBQ8X1AyG
4UggNdVjEQOJ+SLiZ1XCkdLyVF9lNoPa2axWh4RwlG783lT4juR33dxoGf8I
NISbqryyrkazSuc9Ce1I9A6ZdYoX30agReyM7TL7cEBx63vD4So0rpT/0dS7
D+PKy80t1lfB37olZX1xFL6beD8wDayE/PPwDMo0GtseXo5af7ACvR5TN30p
jIb3h3tX/S+Xo+FI49vpijEY4VQ/PlBQBouWLA+FpBicSY8vQ/EtrBrt13w8
FIMnHh9OR5L/JY07wROWesfib9PJGdF1N3HEJ1hpXmMs1pd/Lhp4dQOHlkcp
jK/ej+dSf8TfDpbgXHyNQuK5/eD1Mqtqx4shW78/sHSyABpaxx57KhTjsfcT
KcFUAeI05FwOLyiGQHRhpc10AeZt0/QQzivG9403p/XNFGBg+69nYrOLUVvw
8bK8jAD/rM555IsUI/S4VXfMEgEe1HXqSXUL0eg2z9HSQABNN8M6/YtCxP71
Gp9vKEC7YXAFnS2E9umiiz1GApL7D64szBQi56nZ0D5TAY7Y/5eicFIIvlFE
8nVrAS4kznKYdFAIFbWuhzJuAqhJ9Yx+9hPiTe0K9rtdAkh6ZP9W8xEi2StM
rshDAOM3SRTLQ4jRDEl/Mx8BuPYtf/p2CNE8y3hSRIAABkIvpQFzIeLzUwpM
gwQoYi9Yu85ECD2zt3bSwQKk/056wDMUIi+Wd/4aW0DymP9+UV0h3BXum4dz
BfDs+XHZeIMQ0pVzBkxoAXJ3aVknrBXigZNbmhRfgLff5cOfaQoR/TNPvytM
gMUxneqyK4T4Hzva2Iw=
       "]]},
     Annotation[#, "Charting`Private`Tag$535739#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.13030351165367896`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699548181242*^9, 3.481567013982223*^9, 
  3.4819420873711357`*^9, 3.662624801931018*^9, 3.799212566920704*^9, 
  3.79921277848875*^9, 3.814193882907139*^9, 3.814246893343824*^9, 
  3.8142477919849243`*^9, 3.8142486206872263`*^9, 3.83224235068464*^9, 
  3.832246694636119*^9, 3.832247597788625*^9, 3.832397093452835*^9, 
  3.832403580741884*^9, 3.8325790055723753`*^9, 3.88969613617089*^9, 
  3.890118929990213*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"a7346cfe-f9d3-49bb-8c7b-46ffa1d996a2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for bigmagnetvals5 (5x10 magnet, 400 turn coil)\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.79921627913453*^9, 
   3.7992162941664057`*^9}},ExpressionUUID->"2813d2a2-de64-4046-a4e2-\
dd4ff7805916"],

Cell[CellGroupData[{

Cell["\<\
bigmagnetvals5 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.005,\t\t\t\t(* length of half-big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of half-big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.16*0.0254,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254,
\t\tcoilrad2->0.55*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"377650f6-9d15-4e9d-b438-1fb4d43219f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0029059732045705585`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.012999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.004064`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.002032`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.002032`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.008889999999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01397`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.9375038750077497`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.463844933665338*^9, 3.47966690722052*^9, 
  3.4802449126813803`*^9, 3.4806923165771303`*^9, 3.481941607857794*^9, 
  3.481942088088718*^9, 3.662624802714809*^9, 3.799212566985938*^9, 
  3.7992127791094713`*^9, 3.814193883816553*^9, 3.8142486215970173`*^9, 
  3.83224669588691*^9, 3.8324035808229523`*^9, 3.8325790056180773`*^9, 
  3.889696136198326*^9, 3.890118930019207*^9},
 CellLabel->
  "Out[123]=",ExpressionUUID->"5d8fcf77-ebec-4fc8-996c-25d23facc312"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BM5", "]"}], " ", ":=", " ", "bigmagnetvals5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9},
 CellLabel->
  "In[124]:=",ExpressionUUID->"d7341d39-4812-48b4-ab2d-5d6ef0b56354"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.6371543615438662`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0050900302724624065`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"BM5", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, 3.6626239941508102`*^9, 
   3.832402656425057*^9, 3.832402752159972*^9, 3.832402872652149*^9, 
   3.832403066591175*^9, 3.832403169608673*^9},
 CellLabel->
  "In[125]:=",ExpressionUUID->"e34482ee-c873-4a58-8d7e-00471656aa43"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.6371543615427959`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.00509002348796162`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662625110723606*^9, 3.799212567040732*^9, 
  3.799212779146633*^9, 3.814193883848756*^9, 3.814248865280354*^9, 
  3.832246695941255*^9, 3.8324035832500963`*^9, 3.8325790074801817`*^9, 
  3.8896961370024757`*^9, 3.890118930784669*^9},
 CellLabel->
  "Out[125]=",ExpressionUUID->"94f1bace-a028-4192-8c44-104bed563498"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3ANo5KZFZUVDX1pkKyXSsMsWREZTXvcc+xN4qLQoK3SllQq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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.6371543536135365}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BM5", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, 3.662623996847999*^9},
 CellLabel->
  "In[126]:=",ExpressionUUID->"94469ae9-0aa1-4d7b-bde4-deec403b3e7a"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk0Vd0bB3AVUglJhmgwlJReKmSIryRlLJkihEYyXfcc80zSNYQGmlWa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       "]]},
     Annotation[#, "Charting`Private`Tag$553183#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.6371543536135363}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6626251467152987`*^9, 3.7992125670504713`*^9, 
  3.7992127791877413`*^9, 3.8141938838815813`*^9, 3.81424889461502*^9, 
  3.832246732781925*^9, 3.832403622107024*^9, 3.832579037178129*^9, 
  3.889696149575406*^9, 3.890118943095183*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"5fa0fec5-f2cf-45b2-aa0a-25d87312eed4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BM5", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BM5", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"cc740a61-a5f2-4a3e-95e3-83f535b4fb22"],

Cell[BoxData["0.00509002348796162`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.4819416080006037`*^9, 3.4819420881974697`*^9, 3.662625146797575*^9, 
  3.799212567102704*^9, 3.799212779197138*^9, 3.8141938838948603`*^9, 
  3.8142488946583967`*^9, 3.832246732854556*^9, 3.832403622375496*^9, 
  3.8325790372313337`*^9, 3.88969614960369*^9, 3.890118943110691*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"d192db3c-cb25-4946-af10-a670eddf760d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BM5", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BM5", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"9a31230c-7433-4b9d-99bf-6abf92d55d95"],

Cell[BoxData["0.6371543615427959`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.481941608053739*^9, 3.4819420882381277`*^9, 3.662625146876009*^9, 
  3.799212567112886*^9, 3.7992127792319937`*^9, 3.8141938839204893`*^9, 
  3.81424889469569*^9, 3.832246732873622*^9, 3.832403622386537*^9, 
  3.832579037243458*^9, 3.889696149610354*^9, 3.890118943114032*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"8bdcdb74-65a1-490f-a122-261697faad7b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM5", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623628457925*^9, 3.662623630065835*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"ed33ce46-c711-4ecf-9625-01290b2a55e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVj3k0GwYAh7MINVVVjc61uluqHl0qVqI/j6JzFHVsbWkzR7UokQq6OZI0
rmDTlkxVO6ZT66oec4xnbNSR0kdSYqRp5NibY1qdvHV9D2/2x/e+f75/Puu4
9NOJRAKBQNvmf2vqeizzTr7yIhCmtKPFl4/Lfgjq04w4IYmjq7ja/AAdjUlE
7b9paP/8Xk5d5c8wzH4XUMn2A91pisKxH0TwCs1TlBAM/Zz24zZjo7jm8Fli
yOtwRAp3CSN7n8HNIyEpOjUKHU5dj94rE6HpREm37dEz2Nn0ImNHxDRqqSt3
A5djoHnZwwhblqDPN0we6EqH+fs/6cwdmUPRYpdAbBiH9ZzCWh+OFMN9/imp
ong8dHShh7BlGCb9o0cpTQQpMTb2UIgcVp+0ic5dTILOxLKsoHQBr/uqOwW2
l1HuZsQ6EqCAqXPRrxSdFOyOuFDWvKEAaY9AsClPhUHdjVauQIkEu8nSudtp
GKCsWjUYqmBopicuozHQutPAgp6vQvOx31YpFhkIJW0YU6dUSPt0y6LCgAlj
U9eB5L1qkF3G23I3mBATRQ5T3mqw7h2OYs1fheFqlkB1Rg0tfbK+5XgmdJKd
haXxagTvqRSJfmRhkPJqX0Tsdj91Z8OsJAsNbed4BwLVmKhw9jTOzgZXoEfU
dVBDpowoMYnOwSUWt2FlQwVzKmFpIuAahsKG/H2GVPDwpbV+4PYF1s5P56nY
Kuxd1OelGH0JoQn9PN1TBbOy+FQGMReaihiTmUUlpMOn4vOVuTDYtytcd/s/
r1c4YNOfh8Ga/m+ivJUIbnnqkvMoH3fkxUQ7uQISd/pjCb8Ajs7Scl+OAv4L
XlbrXmzo9eYcHDNRoGCtmlHwmA3hUi1COxfQLOtcl1hw0DjAI/FPL2BRWEMo
ruLg4n73SfIzObSJI1WeJC72w8v8CVGOj491tZ/M48LbvSer/uBLxISkaVlr
uPjX9r4HPVyG2BaGdDPuOjIfJr9b5b8AS5/qRZFex9lp7c2FTimSu/0OXAni
QUO097vyZh6h+NCH2cPD4A2zm2zKPIJGuv+cdC0ELzsdo5fmYHe7jvxRfSGa
HhyXaLX+DnLKifG/TIpgXq9/6rulWWhMOzqYXxdBWY2n5MOzaCOn2W9uFuEu
e9iCWiBBocGK5QKrGKmujkzLsRlQI9sbRv8oRv5NVhTDegZbNbSWHRdKcKv6
UEpWxjS6er9aMZKU4PsIa1qm8DmCHJzabPxK8aSRo15zfY63VXxC2S+lGFHU
llMqxWCHHJ1968zH2cD7zIwtEd5UUdP7v+XD7pbY0yVdhP8Aw6G9Qg==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$574851#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.6371506623502803}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVj3k0GwYAh7MINVVVjc61uluqHl0qVqI/j6JzFHVsbWkzR7UokQq6OZI0
rmDTlkxVO6ZT66oec4xnbNSR0kdSYqRp5NibY1qdvHV9D2/2x/e+f75/Puu4
9NOJRAKBQNvmf2vqeizzTr7yIhCmtKPFl4/Lfgjq04w4IYmjq7ja/AAdjUlE
7b9paP/8Xk5d5c8wzH4XUMn2A91pisKxH0TwCs1TlBAM/Zz24zZjo7jm8Fli
yOtwRAp3CSN7n8HNIyEpOjUKHU5dj94rE6HpREm37dEz2Nn0ImNHxDRqqSt3
A5djoHnZwwhblqDPN0we6EqH+fs/6cwdmUPRYpdAbBiH9ZzCWh+OFMN9/imp
ong8dHShh7BlGCb9o0cpTQQpMTb2UIgcVp+0ic5dTILOxLKsoHQBr/uqOwW2
l1HuZsQ6EqCAqXPRrxSdFOyOuFDWvKEAaY9AsClPhUHdjVauQIkEu8nSudtp
GKCsWjUYqmBopicuozHQutPAgp6vQvOx31YpFhkIJW0YU6dUSPt0y6LCgAlj
U9eB5L1qkF3G23I3mBATRQ5T3mqw7h2OYs1fheFqlkB1Rg0tfbK+5XgmdJKd
haXxagTvqRSJfmRhkPJqX0Tsdj91Z8OsJAsNbed4BwLVmKhw9jTOzgZXoEfU
dVBDpowoMYnOwSUWt2FlQwVzKmFpIuAahsKG/H2GVPDwpbV+4PYF1s5P56nY
Kuxd1OelGH0JoQn9PN1TBbOy+FQGMReaihiTmUUlpMOn4vOVuTDYtytcd/s/
r1c4YNOfh8Ga/m+ivJUIbnnqkvMoH3fkxUQ7uQISd/pjCb8Ajs7Scl+OAv4L
XlbrXmzo9eYcHDNRoGCtmlHwmA3hUi1COxfQLOtcl1hw0DjAI/FPL2BRWEMo
ruLg4n73SfIzObSJI1WeJC72w8v8CVGOj491tZ/M48LbvSer/uBLxISkaVlr
uPjX9r4HPVyG2BaGdDPuOjIfJr9b5b8AS5/qRZFex9lp7c2FTimSu/0OXAni
QUO097vyZh6h+NCH2cPD4A2zm2zKPIJGuv+cdC0ELzsdo5fmYHe7jvxRfSGa
HhyXaLX+DnLKifG/TIpgXq9/6rulWWhMOzqYXxdBWY2n5MOzaCOn2W9uFuEu
e9iCWiBBocGK5QKrGKmujkzLsRlQI9sbRv8oRv5NVhTDegZbNbSWHRdKcKv6
UEpWxjS6er9aMZKU4PsIa1qm8DmCHJzabPxK8aSRo15zfY63VXxC2S+lGFHU
llMqxWCHHJ1968zH2cD7zIwtEd5UUdP7v+XD7pbY0yVdhP8Aw6G9Qg==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$574851#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.6371506623502803}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {55}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGJzBgRQqzDwv7Lf0B5CO9pbbjlRtm++l73zpSldm/n9
oeKB9trtYjfPfQ+2N5j2J+mkfpi96dJHbw6nR0DVR9nbHV7HsPN6DFRfvP2S
Aluu64sToPoT7VfUK0+5eDsJak6y/bo+TrkzwqlQ89LsN819v/yYdzrU3Az7
HWuuGh5szoSanwU1Pwdqfj7U/AKo+YVQ84ug5hdDzS+Fml8GNb8can4F1PxK
qPlV9rvBoBpqT439gVMLXbd9rrV3AttXbw/SdUO0AWpvg33ql21AExqh9jfa
P/+98uMl3yaoO5rsM5nnml3IbIa6p9n+DdeE6rOtLfZrwe5qtc8TagZa0Qp1
X5v9J8ky1hN726DubLc3Abuzw34b2J2dUHd22QMAgjfY7w==
   "], CompressedData["
1:eJwByQE2/iFib1JlAgAAADcAAAABAAAAAAAAAAAAAAAQrfhPuzauPy6vD5ts
Dr4/eX9DU+hYxj+UXn/A6OzJP8gm5/ADcM0/NwiCFgxw0D+B43KCjx3SP4Bz
9uaXv9M/dbo/6UBV1T8m/+0jt93WPzsAr+44WNg/R7QaDRfE2T+MecIztSDb
P6eQI2aKbdw/3jOcNCGq3T97TxXUF9beP9AOBhcg8d8/e3Cton994D9RDozo
xvngP9VKQHdbbeE/rua9CjzY4T8oeZriB5TiP/SKpbzJLeM/bU5TxZmm4z9a
kID5+P/jPycz2oG+O+Q/uVcPZwRc5D+BageyE2PkPwbrubJRU+Q/aedz6i0v
5D+rjaT7EvnjP3CM/3FZs+M/BpLm/z1g4z/BfeaZ2gHjPzq6KisgmuI/jtKR
c9Uq4j9/vehilbXhP/X3XbfPO+E/4J6/ksq+4D8yo/mppD/gP3tWNOCvft8/
JkJ4/3h93j+IhOBwF33dP1qpwjfGftw/FffdgI6D2z+lfs4aTYzaP11K64C3
mdk/NsoqpmCs2D/Ny4IpvcTXP4WzWU0n49Y/+qH5ZuIH1j9ehLrB+GTUP44W
KaS/3NI/9KFuMi9v0T+t4OQR
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662625159674733*^9, 3.799212567205351*^9, 
  3.799212790103311*^9, 3.814193895171023*^9, 3.814248905320035*^9, 
  3.8322467468693953`*^9, 3.832403633573143*^9, 3.832579048077145*^9, 
  3.889696154233584*^9, 3.890118947605482*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"0903474e-429b-4c47-87df-50fb621adf3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BM5", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM5", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623631777481*^9, 
   3.66262363489753*^9}, 3.799212531138236*^9},
 CellLabel->
  "In[130]:=",ExpressionUUID->"f6234f0a-64d6-4d54-b176-b040b7db139d"],

Cell[BoxData["38794.56848394872`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662625159753221*^9, 3.799212567216333*^9, 3.79921279016667*^9, 
   3.814193895206292*^9, 3.8142489053622847`*^9, 3.8322467469824963`*^9, 
   3.832403633634568*^9, 3.8325790481195107`*^9, 3.889696154256545*^9, 
   3.8901189476363773`*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"d937230f-068e-443f-b421-13d89b82bb84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BM5", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.4794964690726423`*^9, 
   3.4794964944567127`*^9}, {3.479496975356181*^9, 3.479496976183571*^9}, {
   3.47949787094656*^9, 3.479497874578391*^9}, {3.4794981429899273`*^9, 
   3.479498147044504*^9}, {3.479498193967552*^9, 3.479498236581649*^9}, {
   3.479662116006764*^9, 3.479662117075882*^9}, {3.479666955542605*^9, 
   3.479666963425733*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"837fae9f-d025-4dd0-a738-adfe2d58ee62"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk0Vd0bB3AVUglJhmgwlJReKmSIryRlLJkihEYyXfcc80zSNYQGmlWa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       "]]},
     Annotation[#, "Charting`Private`Tag$553183#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.6371543536135363}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.478973514856566*^9, 
   3.479486967021886*^9, {3.479496470359309*^9, 3.479496495124946*^9}, 
   3.479496976846184*^9, 3.479497079117694*^9, 3.479497903680291*^9, 
   3.4794981476612797`*^9, 3.4794982377851954`*^9, 3.479663512480014*^9, 
   3.479664582004204*^9, 3.4796657495921383`*^9, 3.479665823576626*^9, 
   3.47966696773402*^9, 3.479667628752988*^9, 3.480245019281752*^9, 
   3.48069231710384*^9, 3.481941608391829*^9, 3.4819420887496758`*^9, 
   3.6626251598288507`*^9, 3.799212567265808*^9, 3.7992127901811323`*^9, 
   3.814193895212741*^9, 3.814248905396585*^9, 3.832246747071702*^9, 
   3.83240363365028*^9, 3.832579048153647*^9, 3.889696154262864*^9, 
   3.890118947641317*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"218b0327-2526-4a8f-ae10-6beeb5dcedad"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (10x10 magnet)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 
   3.4788951754720497`*^9}},ExpressionUUID->"50028e12-664d-4797-b26a-\
9e356f598b23"],

Cell["\<\
bigmagnetvalsSA = bosemvals10 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1)),
\t\tcoilturnarea -> 1/coilsigma
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.8141939008883657`*^9, 
  3.81419390454418*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"f15ccc8c-1273-46df-894d-99940b8f8b0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BO10", "]"}], " ", ":=", " ", "bosemvals10"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9},
 CellLabel->
  "In[133]:=",ExpressionUUID->"65d4aeeb-a263-4296-9eb2-cfe938d46820"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.694858202857608`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0071958504693359565`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"BO10", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.007"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, 
   3.66262400355859*^9, 3.832402659621607*^9, 3.83240287572834*^9, {
   3.832402927977186*^9, 3.832402929488484*^9}, {3.832403440396062*^9, 
   3.832403459167037*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"9e29d255-97ef-4440-b21e-f182851efff1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.6948582028560362`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007195845077775158`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.66262557733585*^9, 3.799212567306459*^9, 
  3.79921279023442*^9, 3.814193895260132*^9, 3.814249136481043*^9, 
  3.8322467471373653`*^9, 3.832403636021921*^9, 3.832579050395756*^9, 
  3.889696155214696*^9, 3.89011894857943*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"fbfe4546-fcdb-4c73-bba6-4f8df494e5cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3BDRQiRWWiiwU9Cg8I31VUpogFxyVhRpCScc/Y5h5BOEyVT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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 1.6948581299755139`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, 3.662624006302704*^9},
 CellLabel->
  "In[135]:=",ExpressionUUID->"86da488b-07c5-42ac-abad-116c78ad154d"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nlYTesXB/AGlHST0hxFlKFbbjKk4StD3CiFBvxKKkPRQKoz7XNOoxyh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       "]]},
     Annotation[#, "Charting`Private`Tag$576449#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 1.6948581299755128`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662625615035322*^9, 3.79921256735336*^9, 
  3.799212790273066*^9, 3.814193895266679*^9, 3.814249167700857*^9, 
  3.8322467872289543`*^9, 3.832403674014387*^9, 3.832579081160286*^9, 
  3.8896961684675293`*^9, 3.890118961561225*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"4b13d64b-3932-4bfb-93ea-3bb3b7014b07"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9},
 CellLabel->
  "In[136]:=",ExpressionUUID->"7fb93265-7e27-4cad-8673-f16f2172d585"],

Cell[BoxData["0.007195845077775158`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.479486914888383*^9, 
  3.479659289850292*^9, 3.4796634565750093`*^9, 3.479665742764594*^9, 
  3.479665816570661*^9, 3.480243747684814*^9, 3.480692317253339*^9, 
  3.481566060871256*^9, 3.481941615983523*^9, 3.4819420888840933`*^9, 
  3.6626256151021233`*^9, 3.7992125673632507`*^9, 3.799212790282357*^9, 
  3.814193895300891*^9, 3.814249167747781*^9, 3.832246787300735*^9, 
  3.832403674082446*^9, 3.832579081202701*^9, 3.889696168503677*^9, 
  3.890118961582526*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"9319a46a-f4b8-475c-a060-7efbef969672"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9},
 CellLabel->
  "In[137]:=",ExpressionUUID->"4f528aab-fdf6-421c-af92-23b463b6b6bd"],

Cell[BoxData["1.6948582028560362`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.479486914934926*^9, 
  3.479659289887826*^9, 3.479663456628942*^9, 3.479665742793458*^9, 
  3.4796658166882772`*^9, 3.480243747711088*^9, 3.480692317295466*^9, 
  3.481566060924111*^9, 3.481941616034875*^9, 3.481942088922996*^9, 
  3.6626256151756268`*^9, 3.799212567408977*^9, 3.799212790316127*^9, 
  3.814193895308795*^9, 3.814249167754497*^9, 3.8322467873223553`*^9, 
  3.832403674100341*^9, 3.832579081211204*^9, 3.889696168507361*^9, 
  3.890118961586832*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"d17fb2be-4b33-46ea-907d-a4c13db9eac8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO10", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623646129085*^9, 3.662623647656955*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"3b437d79-499c-427c-93bd-703723471f2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AAOCro4J3Pt2pS7z0
xis/qg0Qjc6NtT+0o2cCBfI8P/+JjRp2bMY/EHf5R5CART/Yc5vXap3QP0zr
PDvRZEw/Na8lxyvd1T95KFhlTe9RP8zlGwigfNs/NTpkZ1ZsVT9vc8GIdFPg
P6ZEiLcjNFk/NDeInUYS4z+aNuudSupcP+0jWLRZtOU/vENQ30owYD8TPyC0
IRnoP4botpbSEGI/wq5+zl2e6j/FvEZrbNFjP/NLCpAe5ew/xQT2CjOJZT+K
UOEusAzvPyBJsdFbZmc/faZOK9yl8D/vvJW1liNpPxhZuBySpvE/GS2GwDMG
az/pQDkTpq/yPwQRlpb932w/pPxYcwam8z9kJM+J2ZluP7S4qBYIf/Q/EBoK
0os8cD/2HhXxHFz1P6g5we0zHHE/FAV0WMcc9j9uV/4cjQ5yP0BAfXti3vY/
FC/LsXz8cj+tz2Ut8Yz3P3WeLFV12nM/pfaReM8h+D8DDBQMH8t0Pz6f44jp
s/g/TBGQ0dGrdT93YmQs8y35P3XQm/waiHY/ryc5tSmY+T/MjS07FXd3Pxfe
vzJ0/Pk/3eJTiBhWeD/fW9KiKkz6Pxs2AOnMR3k/ZhsO6aOT+j86QzyvFzV6
P1eCYVT7yvo/E+gMhGsSez+FZYDTpPH6PxqLY2xwAnw/JKGYS8wN+z/bxU5j
fuJ8P/IFpDCGG/s/fbrJvyK+fT+/brAmmh37P0ytyi94rH4/lA2LZZkT+z/W
N2Cu1op/P3ENZJhA//o/RuA9IPM9gD8yc+3Pxt36P3/wlXB/roA/gZjHyF+0
+j+o3bXz1hyBPxZUkXLVgvo/6MmYAIeUgT+lEcguxEP6PwUCxpQ7BII/1S9B
O8UA+j84ObaySH2CP2YTGAIJsPk/XE1uAyH0gj9bgEhmS1n5P12tcNv9YoM/
X2EQBl4C+T91DDY9M9uDPxnqB1pCnvg/ardFJm1LhD/gPnjb9jv4P08/HUJy
uYQ/hGvxfqfX9z9LxrfnzzCFP1M2JywJZ/c/JJmcFDKghT/elPQo9fr2PxRr
RMvsGIY/nuiUeCeD9j/0GbS0co+GP+K+MB5rC/Y/sRRuJf39hj9e5a7vUpr1
P4UO6x/gdYc/RWjNFJce9T82VLKhx+WHPw28uxR8qvQ//pg8rQdfiD/mGdNb
biz0P7a6jusS1og/GqxHAsuw8z9LKCuxIkWJP1b8Y+jaPfM/95SKAIu9iT+B
B49P/MHyP4BNNNf3LYo/zjHlJ0NP8j/xlDZvvp+KP3EtSARM3PE/de3JBA==

                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$596934#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.6947270880981902`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AAOCro4J3Pt2pS7z0
xis/qg0Qjc6NtT+0o2cCBfI8P/+JjRp2bMY/EHf5R5CART/Yc5vXap3QP0zr
PDvRZEw/Na8lxyvd1T95KFhlTe9RP8zlGwigfNs/NTpkZ1ZsVT9vc8GIdFPg
P6ZEiLcjNFk/NDeInUYS4z+aNuudSupcP+0jWLRZtOU/vENQ30owYD8TPyC0
IRnoP4botpbSEGI/wq5+zl2e6j/FvEZrbNFjP/NLCpAe5ew/xQT2CjOJZT+K
UOEusAzvPyBJsdFbZmc/faZOK9yl8D/vvJW1liNpPxhZuBySpvE/GS2GwDMG
az/pQDkTpq/yPwQRlpb932w/pPxYcwam8z9kJM+J2ZluP7S4qBYIf/Q/EBoK
0os8cD/2HhXxHFz1P6g5we0zHHE/FAV0WMcc9j9uV/4cjQ5yP0BAfXti3vY/
FC/LsXz8cj+tz2Ut8Yz3P3WeLFV12nM/pfaReM8h+D8DDBQMH8t0Pz6f44jp
s/g/TBGQ0dGrdT93YmQs8y35P3XQm/waiHY/ryc5tSmY+T/MjS07FXd3Pxfe
vzJ0/Pk/3eJTiBhWeD/fW9KiKkz6Pxs2AOnMR3k/ZhsO6aOT+j86QzyvFzV6
P1eCYVT7yvo/E+gMhGsSez+FZYDTpPH6PxqLY2xwAnw/JKGYS8wN+z/bxU5j
fuJ8P/IFpDCGG/s/fbrJvyK+fT+/brAmmh37P0ytyi94rH4/lA2LZZkT+z/W
N2Cu1op/P3ENZJhA//o/RuA9IPM9gD8yc+3Pxt36P3/wlXB/roA/gZjHyF+0
+j+o3bXz1hyBPxZUkXLVgvo/6MmYAIeUgT+lEcguxEP6PwUCxpQ7BII/1S9B
O8UA+j84ObaySH2CP2YTGAIJsPk/XE1uAyH0gj9bgEhmS1n5P12tcNv9YoM/
X2EQBl4C+T91DDY9M9uDPxnqB1pCnvg/ardFJm1LhD/gPnjb9jv4P08/HUJy
uYQ/hGvxfqfX9z9LxrfnzzCFP1M2JywJZ/c/JJmcFDKghT/elPQo9fr2PxRr
RMvsGIY/nuiUeCeD9j/0GbS0co+GP+K+MB5rC/Y/sRRuJf39hj9e5a7vUpr1
P4UO6x/gdYc/RWjNFJce9T82VLKhx+WHPw28uxR8qvQ//pg8rQdfiD/mGdNb
biz0P7a6jusS1og/GqxHAsuw8z9LKCuxIkWJP1b8Y+jaPfM/95SKAIu9iT+B
B49P/MHyP4BNNNf3LYo/zjHlJ0NP8j/xlDZvvp+KP3EtSARM3PE/de3JBA==

                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$596934#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.6947270880981902`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {46}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGI9BgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gaovY1Qe5ug9jbbv+GaUH22tcV+Ldj+Vvs8oWagUa1Qd7TZf5IsYz2x
tw3qnnb7YsVMr6M32+1NwO7qsP+qEdN/6GuH/Taw+zrty0HWCHZB3dllDwCe
S7Qu
   "], CompressedData["
1:eJwBgQF+/iFib1JlAgAAAC4AAAABAAAAAAAAAAAAAAA4ioxNc4m7P2Q0/HmX
eMs/Or5lU3eF1D8R1V6ZujXbP5iJJ9yb4uA/w5audDYW5D8G/89kIzLnP0eF
V+MXM+o/egcvBg8W7T/x39TDSdjvP736IaesO/E/pV+NnIx48j/4nril2KHz
P+sZapvKtvQ/a62a68C29T8kt2mAPaH2P52zt5Hkdfc/YNVJaXs0+D83xyZL
59z4P5uZCXosb/k/WK98dG3r+T/JmJ9A6lH6P28p+e//ovo/8htLKSjf+j/H
G+Cy+Ab7P9Ftg9giG/s/bASuxHIc+z+CkIj9zQv7P1fF1lgy6vo/T2EOJLO4
+j/DvEY2sir6P4S7qTCaa/k//jhFb56F+D8koFeRMAf4PzNzks68gvc/hFkZ
5WP59j8ogVIqNGz2P29lwbcn3PU/b5UqSCNK9T9w2XoH9rb0Pw278INZI/Q/
rdlrh/KP8z9YNsH1Uf3yPxD/Wh/2a/I/u8Ks/Evc8T9Ks8D/
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662625626200384*^9, 3.7992125674964523`*^9, 
  3.799212800167831*^9, 3.81419390488977*^9, 3.814249176887363*^9, 
  3.8322467991704903`*^9, 3.832403684132328*^9, 3.832579090375058*^9, 
  3.889696172439312*^9, 3.8901189653929873`*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"e037af32-21eb-4302-833e-a928f69d0292"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BO10", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO10", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626236492010603`*^9, 
   3.662623652752903*^9}, 3.799212531139517*^9},
 CellLabel->
  "In[139]:=",ExpressionUUID->"757f8d27-49aa-4b6a-bf4d-99a07057acb5"],

Cell[BoxData["61049.691287075046`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662625626266868*^9, 3.799212567508616*^9, 3.799212800221095*^9, 
   3.799224529550167*^9, 3.814193904943308*^9, 3.814249176921521*^9, 
   3.8322467992815027`*^9, 3.8324036842034073`*^9, 3.832579090413969*^9, 
   3.889696172465146*^9, 3.8901189654193497`*^9},
 CellLabel->
  "Out[139]=",ExpressionUUID->"7875f9d8-8780-4200-b8a2-9c130a68f9bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95plus", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BO10", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "BO10", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9},
 CellLabel->
  "In[140]:=",ExpressionUUID->"4d8ac11c-2d99-4a2c-9304-7c7688c4bfc1"],

Cell[BoxData["0.008975706429660208`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819416198814373`*^9, 3.481942093179961*^9, 3.6626256284126587`*^9, 
   3.7992125675779953`*^9, 3.799212802210847*^9, 3.814193906761861*^9, 
   3.8142491786437597`*^9, 3.8322467994692993`*^9, 3.832403686032386*^9, 
   3.832579092223116*^9, 3.88969617320901*^9, 3.890118966150988*^9},
 CellLabel->
  "Out[140]=",ExpressionUUID->"0e7d2ec1-6272-4e6c-aecf-90203e5f0e30"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95minus", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BO10", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "BO10", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9},
 CellLabel->
  "In[141]:=",ExpressionUUID->"bace1cb2-a4e2-4b19-8fa7-dd30a5449edf"],

Cell[BoxData["0.005594057700825485`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.481941624492373*^9, 
   3.481942097749235*^9, 3.66262563115217*^9, 3.799212567606304*^9, 
   3.799212804408636*^9, 3.814193908988564*^9, 3.814249180806416*^9, 
   3.832246799580441*^9, 3.832403688402554*^9, 3.8325790944613132`*^9, 
   3.889696174127078*^9, 3.8901189670655413`*^9},
 CellLabel->
  "Out[141]=",ExpressionUUID->"4599a4a8-3bc2-4839-a1ef-b0a582273ebd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement", "Subsubsection",
 CellChangeTimes->{{3.478970601031336*^9, 
  3.478970602486655*^9}},ExpressionUUID->"17a3342e-9e8b-4795-a16a-\
47c460a7b7cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v10", " ", "=", " ", 
  RowBox[{"Recurse", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zflange", " ", "->", " ", 
      RowBox[{"0.1", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"end", " ", "flange", " ", "thickness"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"l", " ", "->", " ", "0.010"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zplug", " ", "->", " ", "0.001"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zcoil", " ", "->", " ", 
      RowBox[{"0.315", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"coil", " ", "length"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"zc", " ", "->", " ", 
      RowBox[{
       RowBox[{"l", "/", "2"}], "+", "zplug", "+", "zflange", "+", 
       RowBox[{"zcoil", "/", "2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"newportcal", " ", "->", " ", "0.5"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "micrometer", " ", "to", " ", "stage", " ", "factor", " ", "for", " ", 
      "Newport", " ", "NVM80"}], " ", "*)"}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478364871938177*^9, 3.4783650430215597`*^9}, {
   3.478365123922604*^9, 3.478365126702361*^9}, {3.478365254617469*^9, 
   3.4783652660805397`*^9}, {3.4783655084186296`*^9, 
   3.4783655130572557`*^9}, {3.47836555422621*^9, 3.478365578866078*^9}, 
   3.478366553883871*^9, 3.4783667391579103`*^9, {3.479485983949397*^9, 
   3.4794860302373734`*^9}, {3.4794860941303663`*^9, 3.479486095079904*^9}, 
   3.4794861957899227`*^9, {3.479502242049817*^9, 3.4795022420685263`*^9}, {
   3.47965572449089*^9, 3.479655724556625*^9}, {3.479655785531518*^9, 
   3.479655785532816*^9}},
 CellLabel->
  "In[142]:=",ExpressionUUID->"bfa8b184-c367-4662-ac83-aa02c4a7b9f3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"zflange", "\[Rule]", "0.00254`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"zplug", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"zcoil", "\[Rule]", "0.008001`"}], ",", 
   RowBox[{"zc", "\[Rule]", "0.0125405`"}], ",", 
   RowBox[{"newportcal", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4794861147697887`*^9, 3.479486119482292*^9}, 
   3.479661794400094*^9, 3.4796627436715107`*^9, 3.47966574239032*^9, 
   3.4802437567011843`*^9, 3.4806923249227753`*^9, 3.4815660675895853`*^9, 
   3.4819416246164713`*^9, 3.4819420978508997`*^9, 3.662625631374776*^9, 
   3.799212567648368*^9, 3.799212804451633*^9, 3.814193909025641*^9, 
   3.814249180840733*^9, 3.83224679966721*^9, 3.832403688453783*^9, 
   3.83257909449811*^9, 3.889696174155698*^9, 3.890118967087585*^9},
 CellLabel->
  "Out[142]=",ExpressionUUID->"23920a7b-b63a-4ab1-82bd-7eed0cc044f7"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"m10", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "0", ",", " ", "0.5", ",", " ", "1", ",", " ", "1.5", ",", " ", "2", ",", 
     " ", "2.5", ",", " ", "3", ",", " ", "3.5", ",", " ", "4", ",", " ", 
     "4.5", ",", " ", "\[IndentingNewLine]", "5", ",", " ", "5.5", ",", " ", 
     "6", ",", " ", "6.5", ",", " ", "7", ",", " ", "7.5", ",", " ", "8", ",",
      " ", "8.5", ",", " ", "9", ",", " ", "9.5", ",", " ", 
     "\[IndentingNewLine]", "10", ",", " ", "10.5", ",", " ", "11", ",", " ", 
     "11.5", ",", " ", "12", ",", " ", "12.5", ",", " ", "13", ",", " ", 
     "13.5", ",", " ", "14", ",", " ", "14.5", ",", " ", 
     "\[IndentingNewLine]", "15", ",", " ", "15.5", ",", " ", "16", ",", " ", 
     "16.5", ",", " ", "17", ",", " ", "17.5", ",", " ", "18", ",", " ", 
     "18.5", ",", " ", "19", ",", " ", "19.5", ",", " ", 
     "\[IndentingNewLine]", "20", ",", " ", "20.5", ",", " ", "21", ",", " ", 
     "21.5", ",", " ", "22", ",", " ", "22.5", ",", " ", "21.10", ",", " ", 
     "21.03"}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478359123403325*^9, 3.478359312201968*^9}, {
   3.478359382197403*^9, 3.478359482378661*^9}, 3.4783602880061617`*^9},
 CellLabel->
  "In[143]:=",ExpressionUUID->"385289ce-be9a-46d2-8000-5cd05c46f4d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f10", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "21.6", ",", " ", "24", ",", " ", "26.4", ",", " ", "28.6", ",", " ", 
     "30.7", ",", " ", "32.7", ",", " ", "34.7", ",", " ", "36.4", ",", " ", 
     "38.3", ",", " ", "39.7", ",", " ", "\[IndentingNewLine]", "41", ",", 
     " ", "42.6", ",", " ", "43.8", ",", " ", "44.8", ",", " ", "45.7", ",", 
     " ", "46.4", ",", " ", "47", ",", " ", "47.6", ",", " ", "48", ",", " ", 
     "48.2", ",", "\[IndentingNewLine]", "48.4", ",", " ", "48.8", ",", " ", 
     "48.7", ",", " ", "48.6", ",", " ", "48.3", ",", " ", "48.0", ",", " ", 
     "47.4", ",", " ", "47.1", ",", " ", "46.2", ",", " ", "45.6", ",", 
     "\[IndentingNewLine]", "44.8", ",", " ", "44.0", ",", " ", "43.4", ",", 
     " ", "42.5", ",", " ", "41.6", ",", " ", "40.6", ",", " ", "39.6", ",", 
     " ", "38.7", ",", " ", "37.8", ",", " ", "36.7", ",", 
     "\[IndentingNewLine]", "35.8", ",", " ", "34.9", ",", " ", "34", ",", 
     " ", "33.1", ",", " ", "32.1", ",", " ", "31.3", ",", " ", "33.3", ",", 
     " ", "33.4"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478358656639378*^9, 3.478358736957609*^9}, {
   3.478358785279069*^9, 3.478358785557148*^9}, {3.47835979499054*^9, 
   3.478360057375266*^9}, {3.478360132331086*^9, 3.478360132808681*^9}, {
   3.478360292284709*^9, 3.478360320802071*^9}, 3.478360369604032*^9},
 CellLabel->
  "In[144]:=",ExpressionUUID->"85cc34c7-864e-4269-8e0f-16cbc322e570"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c10", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m10", "-", 
         RowBox[{"m10", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.",
     "v10"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47837088802363*^9, 3.478370914162881*^9}, {
  3.478961618977281*^9, 3.478961625407113*^9}, {3.479486145012785*^9, 
  3.479486146227991*^9}},
 CellLabel->
  "In[145]:=",ExpressionUUID->"137e75f8-6f4d-40fa-ad7e-bad45f9f505f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m10b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "25.", ",", " ", "24.5", ",", " ", "24.", ",", " ", "23.5", ",", " ", 
     "23.", ",", " ", "22.5", ",", " ", "22.", ",", " ", "21.5", ",", " ", 
     "21.", ",", " ", "20.5", ",", " ", "\[IndentingNewLine]", "20.", ",", 
     " ", "19.5", ",", " ", "19.", ",", " ", "18.5", ",", " ", "18.", ",", 
     " ", "17.5", ",", " ", "17.", ",", " ", "16.5", ",", " ", "16.", ",", 
     " ", "15.5", ",", " ", "\[IndentingNewLine]", "15.", ",", " ", "14.5", 
     ",", " ", "14.", ",", " ", "13.5", ",", " ", "13.", ",", " ", "12.5", 
     ",", " ", "12.", ",", " ", "11.5", ",", " ", "11.", ",", " ", "10.5", 
     ",", " ", "\[IndentingNewLine]", "10.", ",", " ", "9.5", ",", " ", "9.", 
     ",", " ", "8.5", ",", " ", "8.", ",", " ", "7.5", ",", " ", "7.", ",", 
     " ", "6.5", ",", " ", "6.", ",", " ", "5.5", ",", " ", 
     "\[IndentingNewLine]", "5.", ",", " ", "4.5", ",", " ", "4.", ",", " ", 
     "3.5", ",", " ", "3.", ",", " ", "2.5", ",", " ", "2.", ",", " ", "1.5", 
     ",", " ", "1.", ",", " ", "0.5", ",", " ", "\[IndentingNewLine]", "0.", 
     ",", " ", 
     RowBox[{"-", "0.42"}]}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.480242266026979*^9, 3.4802422811926517`*^9}, {
  3.480242551485073*^9, 3.480242638696825*^9}, {3.480243603406623*^9, 
  3.480243604629949*^9}},
 CellLabel->
  "In[146]:=",ExpressionUUID->"08ac2375-fbe3-484d-8d93-994ce7d26d31"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f10b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "33", ",", " ", "33.9", ",", " ", "34.8", ",", " ", "35.6", ",", " ", 
     "36.4", ",", " ", "37.3", ",", " ", "38.5", ",", " ", "39.3", ",", " ", 
     "40.2", ",", " ", "40.9", ",", "\[IndentingNewLine]", "41.7", ",", " ", 
     "42.6", ",", " ", "43.3", ",", " ", "43.9", ",", " ", "44.5", ",", " ", 
     "45.2", ",", " ", "45.5", ",", " ", "46", ",", " ", "46.3", ",", " ", 
     "46.6", ",", "\[IndentingNewLine]", "46.7", ",", " ", "46.7", ",", " ", 
     "46.7", ",", " ", "46.7", ",", " ", "46.4", ",", " ", "45.9", ",", " ", 
     "45.4", ",", " ", "44.7", ",", " ", "44.1", ",", " ", "43.1", ",", 
     "\[IndentingNewLine]", "42.1", ",", " ", "41.0", ",", " ", "39.7", ",", 
     " ", "38.4", ",", " ", "37.0", ",", " ", "35.3", ",", " ", "33.5", ",", 
     " ", "31.6", ",", " ", "29.7", ",", " ", "27.6", ",", 
     "\[IndentingNewLine]", "25.6", ",", " ", "23.3", ",", " ", "21", ",", 
     " ", "18.5", ",", " ", "16.1", ",", " ", "13.5", ",", " ", "10.9", ",", 
     " ", "8.35", ",", " ", "5.70", ",", " ", "2.97", ",", 
     "\[IndentingNewLine]", "0.376", ",", " ", "1.90"}], " ", 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.480242672165991*^9, 3.480242777357607*^9}, {
  3.4802428393374243`*^9, 3.480242994903599*^9}, {3.4802430986494913`*^9, 
  3.4802431295923853`*^9}, {3.480243226913352*^9, 3.480243571963694*^9}},
 CellLabel->
  "In[147]:=",ExpressionUUID->"fb52f218-0295-4138-aee9-078f0f6dbdfd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c10b", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m10b", "-", 
         RowBox[{"m10b", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v10"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47837088802363*^9, 3.478370914162881*^9}, {
   3.478961618977281*^9, 3.478961625407113*^9}, {3.479486145012785*^9, 
   3.479486146227991*^9}, {3.480243648203948*^9, 3.4802436546744833`*^9}, 
   3.4802439178688*^9},
 CellLabel->
  "In[148]:=",ExpressionUUID->"89f9ff9b-b7d8-44c6-a739-d7366d4e4c08"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1000", "*", "c10b"}], ",", "f10b"}], "}"}], "]"}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.478358869240918*^9, 3.478358894149914*^9}, {
   3.478358970183876*^9, 3.4783590158067007`*^9}, {3.47836015386373*^9, 
   3.478360163119385*^9}, {3.478366673756214*^9, 3.478366679969379*^9}, {
   3.478367462673428*^9, 3.4783674799853067`*^9}, {3.478368631699589*^9, 
   3.478368685400792*^9}, {3.4783687314761667`*^9, 3.478368733441554*^9}, {
   3.4783687696995564`*^9, 3.478368770875265*^9}, {3.478370370616754*^9, 
   3.478370372904202*^9}, {3.478370502073501*^9, 3.478370514529298*^9}, 
   3.478370885346918*^9, {3.478370917867898*^9, 3.4783709191468763`*^9}, {
   3.478961631541224*^9, 3.4789616328231297`*^9}, {3.480243885079197*^9, 
   3.480243886827784*^9}},
 CellLabel->
  "In[149]:=",ExpressionUUID->"d71f22e6-3597-4777-981b-faefce5cd1af"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdk8srRHEUx28S0jR5XMN4zmDGTFIyJEm/M2bmzgIppJSVoryysLHS/AFk
ozTKziOSBbFSRKywGBaGhWQhK6Yh5BHzO9+fhVO326fP+Z1zOvd37X1jHf1J
mqbV/j6J9/X75NCu7iYtESEiybMu8iQiDtZdNCDDC19BpyeJ8NKV9BWc72mG
d3L+Mlh3cn3ywTvgwbqD5sO/YfXDl3O9cbBezj6qfBn3bw3Al6EeeLYU8ytf
iv4GvJ3rhcG6nf2+8jZmLQhv4/rOIO3Evy4m3CXor7iY6/UEaVty0R+zL/zH
Bf84H/tT562Y3wDnMW8ZyM/FecUWnsek8nOYpwLwOrzibHxvPzgL+/XhfCbm
UZyB/GYauv9YjXWYsW8vDUo2YX9Eo5LTsV9BI5LTMH8TOAW+kYYlJ4MbwEnY
bz36afgedXR+9tp5t/QpeJ4aupL8Jvj+VFNU8jN7rZIuJT8Jvq8O2lh4XDlu
eRA8j43WJd/CW6ir8aZ9ei4iDl9cvTMHqRSSF3xRrMUibX0Zl8JI7jZXbR7t
8f/wLX4AeiSFBA==
     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.16950000000000126`, 12.5405}, {0., 46.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.478358895979022*^9, 3.478358972250873*^9, {3.478359003617921*^9, 
   3.478359016368936*^9}, {3.47836013995588*^9, 3.478360163674849*^9}, 
   3.478360374248694*^9, 3.478366680674487*^9, 3.478367480647264*^9, {
   3.478368632443274*^9, 3.478368686420216*^9}, 3.478368734382247*^9, 
   3.478368772182708*^9, 3.47837037368084*^9, {3.478370502759603*^9, 
   3.478370515076358*^9}, 3.478370922682131*^9, 3.478894392703998*^9, 
   3.4789609320542917`*^9, 3.478961633495669*^9, 3.479485745361719*^9, {
   3.479486132534732*^9, 3.4794861523034983`*^9}, 3.479661794640168*^9, 
   3.479662743820785*^9, 3.479665742592085*^9, 3.480243756892487*^9, 
   3.4802438881018877`*^9, 3.480243922252112*^9, 3.480692325124424*^9, 
   3.481566067790287*^9, 3.481941625063833*^9, 3.481942098115423*^9, 
   3.662625631567731*^9, 3.799212567775642*^9, 3.799212804559462*^9, 
   3.8141939091332827`*^9, 3.814249180936748*^9, 3.832246799864171*^9, 
   3.832403688584175*^9, 3.832579094605176*^9, 3.8896961742127132`*^9, 
   3.890118967140286*^9},
 CellLabel->
  "Out[149]=",ExpressionUUID->"4b91e163-7c3e-4b74-868b-4def991c71fe"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"quadsect", "[", "BO10", "]"}], " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c10b", ",", "f10b"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", 
       RowBox[{"-", "15"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, {
   3.479496268693829*^9, 3.4794962786689043`*^9}, {3.479496348223323*^9, 
   3.4794963960461197`*^9}, {3.479498099636911*^9, 3.479498116836277*^9}, {
   3.479661771654023*^9, 3.4796617820129557`*^9}, {3.4802439413724613`*^9, 
   3.480243944481743*^9}, {3.480243980865246*^9, 3.4802439981026154`*^9}},
 CellLabel->
  "In[150]:=",ExpressionUUID->"0e5bf6c5-df10-4466-adb0-1a4bb5380fbc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"quadsect", "[", "BO10", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.479492922070776*^9, 3.479492925832822*^9}, {
   3.47949628323759*^9, 3.479496283675993*^9}, 3.479661799309276*^9},
 CellLabel->
  "In[151]:=",ExpressionUUID->"aab122d0-9757-415d-acd6-ff7fa2ba159a"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`], 
    AbsoluteThickness[1.6], 
    PointBox[{{0.005290499999999999, 43.1}, {0.005540499999999999, 44.1}, {
     0.0057905, 44.7}, {0.006040499999999999, 45.4}, {0.006290499999999999, 
     45.9}, {0.0065404999999999994`, 46.4}, {0.0067905, 46.7}, {0.0070405, 
     46.7}, {0.007290499999999999, 46.7}, {0.0075404999999999995`, 46.7}, {
     0.0077905, 46.6}, {0.008040499999999999, 46.3}, {0.0082905, 46.}, {
     0.0085405, 45.5}, {0.0087905, 45.2}, {0.0090405, 44.5}}]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.005212375000000233, 42.90000000000009},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.005212375000000233, 0.0090405}, {42.90000000000009, 46.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.47949292648037*^9, {3.4794929901025677`*^9, 3.479493006913755*^9}, 
   3.479493322040373*^9, {3.479493571055421*^9, 3.479493582720769*^9}, {
   3.479493654111162*^9, 3.479493680849517*^9}, 3.479494594442368*^9, 
   3.4794951275012083`*^9, 3.4794962841775846`*^9, {3.479496352894401*^9, 
   3.4794963992533207`*^9}, {3.4794981044621353`*^9, 3.47949812000502*^9}, 
   3.479661800865757*^9, 3.4796627438875427`*^9, 3.47966574265806*^9, 
   3.480243756913067*^9, 3.480243949523509*^9, {3.480243993159051*^9, 
   3.48024400283206*^9}, 3.480692325191889*^9, 3.481566067857037*^9, 
   3.481941625118208*^9, 3.481942098169249*^9, 3.662625631684383*^9, 
   3.799212567812482*^9, 3.799212804595092*^9, 3.8141939091620903`*^9, 
   3.814249180978654*^9, 3.83224679991765*^9, 3.832403688645735*^9, 
   3.832579094652985*^9, 3.889696174231102*^9, 3.890118967153517*^9},
 CellLabel->
  "Out[151]=",ExpressionUUID->"dd52cbcf-6fd0-4970-8c83-41ad1b290c4a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"BO10", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"quadsect", "[", "BO10", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "z", ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479492821084407*^9, 3.479492906857025*^9}, {
   3.479493026130746*^9, 3.479493088769916*^9}, {3.479496292861574*^9, 
   3.479496298886504*^9}, {3.4796617492454433`*^9, 3.479661752316023*^9}, 
   3.4796618065898314`*^9},
 CellLabel->
  "In[152]:=",ExpressionUUID->"f79e74b4-094f-44cd-87ce-9907a0a87f23"],

Cell[BoxData[
 RowBox[{"1.5052714250003707`", "\[VeryThinSpace]", "+", 
  RowBox[{"12320.257983193189`", " ", "z"}], "-", 
  RowBox[{"837815.1260504148`", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.479493065534417*^9, 3.479493090921401*^9}, 
   3.479493347575324*^9, 3.479493687032943*^9, 3.4794945945082073`*^9, 
   3.479495127601207*^9, 3.4794962995907373`*^9, {3.479496356170768*^9, 
   3.4794964020264187`*^9}, 3.479661807352735*^9, 3.479662743921276*^9, 
   3.479665742692679*^9, 3.480243756989594*^9, 3.480244010141424*^9, 
   3.480692325243474*^9, 3.481566067893443*^9, 3.481941625191751*^9, 
   3.4819420981852303`*^9, 3.662625631766376*^9, 3.799212567844816*^9, 
   3.799212804611115*^9, 3.8141939091797047`*^9, 3.8142491809854097`*^9, 
   3.8322467999514427`*^9, 3.8324036886926394`*^9, 3.832579094678115*^9, 
   3.889696174238761*^9, 3.890118967158544*^9},
 CellLabel->
  "Out[152]=",ExpressionUUID->"7b9e5c4e-f27e-42c6-94f9-19cb84fafd35"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"quadsect", "[", "BO10", "]"}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"BO10", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.0055", ",", "0.0093"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479493098474358*^9, 3.4794931473471107`*^9}, {
   3.4794950541082687`*^9, 3.479495059418387*^9}, 3.479495140140613*^9, {
   3.479496302750866*^9, 3.479496325477083*^9}, 3.479496410959276*^9, 
   3.4794980716129704`*^9, {3.479498110109133*^9, 3.479498134380343*^9}, {
   3.47966180953386*^9, 3.479661832340538*^9}},
 CellLabel->
  "In[153]:=",ExpressionUUID->"c769e96c-c61c-40a0-9e0c-b4f689616d07"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{0.005290499999999999, 43.1}, {0.005540499999999999, 44.1}, {
      0.0057905, 44.7}, {0.006040499999999999, 45.4}, {0.006290499999999999, 
      45.9}, {0.0065404999999999994`, 46.4}, {0.0067905, 46.7}, {0.0070405, 
      46.7}, {0.007290499999999999, 46.7}, {0.0075404999999999995`, 46.7}, {
      0.0077905, 46.6}, {0.008040499999999999, 46.3}, {0.0082905, 46.}, {
      0.0085405, 45.5}, {0.0087905, 45.2}, {0.0090405, 
      44.5}}]}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13lcTHsUAPASLbJTMdGrVBJJ0kLpXNXMvAhtJC1KC71W9Uzb3N9Mk2gh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        "]]},
      Annotation[#, "Charting`Private`Tag$599140#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.005212375000000233, 42.90000000000009},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.479493147789712*^9, 3.479493348745586*^9, 3.479493687869093*^9, 
   3.479494594544231*^9, 3.4794950600870647`*^9, {3.479495127635968*^9, 
   3.4794951412551003`*^9}, {3.479496311016521*^9, 3.479496326374604*^9}, {
   3.479496357540121*^9, 3.479496411535761*^9}, 3.479498073597056*^9, {
   3.479498111163803*^9, 3.479498134994309*^9}, {3.4796618101860933`*^9, 
   3.479661833787763*^9}, 3.479662743973064*^9, 3.479665742731904*^9, 
   3.4802437570207*^9, 3.480244013149205*^9, 3.480692325283217*^9, 
   3.481566067931078*^9, 3.4819416252399197`*^9, 3.481942098241775*^9, 
   3.662625631852418*^9, 3.799212567910635*^9, 3.7992128046693277`*^9, 
   3.81419390922727*^9, 3.81424918103365*^9, 3.832246800055379*^9, 
   3.832403688760427*^9, 3.832579094731608*^9, 3.889696174260853*^9, 
   3.890118967181047*^9},
 CellLabel->
  "Out[153]=",ExpressionUUID->"d5c132e9-ad49-4d80-88fd-dc6e81103b91"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmaxq", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"BO10", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], ",", 
      RowBox[{"z", "^", "2"}]}], "]"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.479495438249634*^9, 3.479495505318678*^9}, 
   3.479662502748355*^9, 3.4796629041886263`*^9, 3.479664469475191*^9, {
   3.479665540402864*^9, 3.479665540432529*^9}, 3.479665679958331*^9, {
   3.480252658965609*^9, 3.4802526608978167`*^9}},
 CellLabel->
  "In[154]:=",ExpressionUUID->"becee2b2-4d84-4484-9d32-defedfca584e"],

Cell[BoxData["0.007352611334002001`"], "Output",
 CellChangeTimes->{{3.479495497456901*^9, 3.479495505729022*^9}, 
   3.479664646330089*^9, 3.479665767660248*^9, 3.4796658003302927`*^9, 
   3.479666123140691*^9, 3.480085429491647*^9, 3.480244564434903*^9, 
   3.480245921975265*^9, 3.480252685630768*^9, 3.4806923253165283`*^9, 
   3.481941625292397*^9, 3.481942098249529*^9, 3.662625631900302*^9, 
   3.799212567919506*^9, 3.799212804678075*^9, 3.814193909234909*^9, 
   3.8142491810399427`*^9, 3.832246800080142*^9, 3.832403688775755*^9, 
   3.8325790947408123`*^9, 3.889696174264653*^9, 3.890118967184883*^9},
 CellLabel->
  "Out[154]=",ExpressionUUID->"35e1181f-8255-4dd9-a221-2086716cd00e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmaxq", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"q", "[", 
   RowBox[{"BO10", ",", 
    RowBox[{"zmaxq", "[", "BO10", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4796645166114473`*^9, 3.4796645680107403`*^9}, {
   3.479664629540166*^9, 3.4796646354272118`*^9}, 3.479665680445608*^9, 
   3.479665788251362*^9, {3.480252661732663*^9, 3.480252662768613*^9}},
 CellLabel->
  "In[155]:=",ExpressionUUID->"2b309981-7b7d-440a-b82c-8c01b1981b68"],

Cell[BoxData["46.7983056675278`"], "Output",
 CellChangeTimes->{3.479664568867193*^9, 3.479664646359799*^9, 
  3.479665585669737*^9, 3.479665767693388*^9, 3.479665800365254*^9, 
  3.479666123176936*^9, 3.48008543183556*^9, 3.480244564491827*^9, 
  3.480245922030847*^9, 3.480252685747806*^9, 3.4806923253494253`*^9, 
  3.481941625327002*^9, 3.481942098307748*^9, 3.662625631954908*^9, 
  3.7992125679541473`*^9, 3.799212804710845*^9, 3.814193909257782*^9, 
  3.814249181062739*^9, 3.832246800131958*^9, 3.832403688812031*^9, 
  3.8325790947663918`*^9, 3.889696174273069*^9, 3.8901189671951447`*^9},
 CellLabel->
  "Out[155]=",ExpressionUUID->"5c16b886-75ff-4181-b868-0db0ef795689"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"delta", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"zmaxq", "[", "BO10", "]"}], " ", "-", " ", 
   RowBox[{"zmax", "[", "BO10", "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.479495523610161*^9, 3.479495542381401*^9}, 
   3.479661946209796*^9, 3.479662081271207*^9, 3.47966250284426*^9, 
   3.47966290430508*^9, 3.479664469476417*^9, {3.479665683454405*^9, 
   3.479665683520638*^9}, {3.480252663458889*^9, 3.480252664767067*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"7c49e19e-4363-4f73-8b6e-1a43e496b3ee"],

Cell[BoxData["0.00015676625622684272`"], "Output",
 CellChangeTimes->{3.4794955436804543`*^9, 3.479665380340073*^9, 
  3.479665767759824*^9, 3.479665800431348*^9, 3.4796661232447157`*^9, 
  3.4800854342417307`*^9, 3.4802445645293713`*^9, 3.480245953636918*^9, 
  3.4802526858259706`*^9, 3.480692325383745*^9, 3.4819416253693733`*^9, 
  3.481942098341453*^9, 3.662625632016404*^9, 3.7992125679638157`*^9, 
  3.799212804718833*^9, 3.8141939092640553`*^9, 3.814249181069042*^9, 
  3.832246800169578*^9, 3.832403688821488*^9, 3.832579094774971*^9, 
  3.889696174278645*^9, 3.8901189671984377`*^9},
 CellLabel->
  "Out[156]=",ExpressionUUID->"c2d8eb67-a675-40f6-b834-9110924336e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Scale factor to make measured and theoretical curves have same maximum\
\>", "Text",
 CellChangeTimes->{{3.478970887912784*^9, 
  3.478970908928837*^9}},ExpressionUUID->"33369bd6-4667-4e2d-9f02-\
e69a722930b7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"fmax", "[", "BO10", "]"}], "/", 
   RowBox[{"fmaxq", "[", "BO10", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970696648231*^9, 3.478970705072441*^9}, {
   3.478970839616865*^9, 3.478970857497159*^9}, 3.4789715324564857`*^9, {
   3.478971784562731*^9, 3.4789717872495337`*^9}, 3.478971846731222*^9, {
   3.4789723755682993`*^9, 3.478972380734989*^9}, {3.4789735142646723`*^9, 
   3.4789735163909893`*^9}, 3.479661959846012*^9, 3.479662130234865*^9, {
   3.479665563524087*^9, 3.479665591276129*^9}, {3.479665788451865*^9, 
   3.479665788518486*^9}, {3.480252675294587*^9, 3.4802526771361427`*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"c7efb6f5-403c-4fe9-808d-5c2ffef498ea"],

Cell[BoxData["0.03621623002543994`"], "Output",
 CellChangeTimes->{
  3.478971485608411*^9, 3.478971533659111*^9, 3.478971787849442*^9, {
   3.478971841091794*^9, 3.4789718473084917`*^9}, 3.478972382639682*^9, 
   3.4789745781001587`*^9, 3.478974629064003*^9, 3.4794913230668173`*^9, 
   3.4796653804411373`*^9, 3.479665592037429*^9, 3.4796657678267307`*^9, 
   3.47966580051572*^9, 3.479666123310278*^9, 3.480085442306896*^9, 
   3.480085474403487*^9, 3.480244564572826*^9, 3.480245967181128*^9, 
   3.480252685882967*^9, 3.4806923254154778`*^9, 3.481941625424059*^9, 
   3.4819420983918962`*^9, 3.662625632057599*^9, 3.79921256799863*^9, 
   3.799212804753097*^9, 3.8141939092872353`*^9, 3.8142491810939283`*^9, 
   3.832246800237187*^9, 3.8324036888592663`*^9, 3.832579094800611*^9, 
   3.889696174287732*^9, 3.8901189672100077`*^9},
 CellLabel->
  "Out[157]=",ExpressionUUID->"e2a95a20-e697-418b-a5a1-320bd7a97568"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BO10", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"c10b", ",", 
        RowBox[{
         RowBox[{"scale", "[", "BO10", "]"}], "*", "f10b"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"scale", "[", "BO10", "]"}], "*", 
      RowBox[{"q", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.0055", ",", "0.0093"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}},
 CellLabel->
  "In[158]:=",ExpressionUUID->"cf9944be-38ea-4989-849a-5e06ab1b9d29"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nlYTesXB/AGlHST0hxFlKFbbjKk4StD3CiFBvxKKkPRQKoz7XNOoxyh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        "]]},
      Annotation[#, "Charting`Private`Tag$576449#1"]& ]}, {}}, {{}, 
    {RGBColor[0, 0, 1], PointSize[0.011000000000000001`], AbsoluteThickness[
     1.6], PointBox[CompressedData["
1:eJw90H9Q0wUABfCvXBRBMBEVRsrSA6vFnSyxBEaPYc6LHVIjpEEiESxwFjR+
jbUFbDpYCKWZIEJ1NIRcgEQwlHFwihA7ugbL3RELuXH8htTYxvbd7qjuPP54
9+7z37u3LyOXm+VGEET4f/m//9wkBPfblTBSEkrZtHV8Icxx3XlFiRh/meBX
1Toi58arb7ZW4kZQd3Ic3YLl5EjatyGVqBWbNbbvLajXNd2saqqA3EgJ+MHf
Ck60V2wJrQJrf8U+FdJohbMj38BvUEC/oLj8YoIN6v2mzHepCvQd/cViuGdD
6jdv2lhXzuMAZ2EmibMBL4+2ioN+53HZ6dMd2rWBPvEu6t6vzkGWzNw1+bId
Z9ekNzy9z2ElLXdbaocde9Lno+xKOXiU2vsMfwfGJk78Nve0HJydt/YeynNA
ckyTZpDLwKROZYWPOhDaS3s0SMjw06hbpBeDhIleWd4uLUfwmN901SkSFxof
7Wggy1AXElavaSHB3M5TKYvLsP0l1htH/iAx6S4X/L1YCiWda+4lnIhYSawZ
NX+OZ4zJn9RQnLiqD+5UmaRbJruthlKjZMsp14ZtKfrPtny7rJb6mk6MGgNb
5z1LIpCfzfQdKkGgmO5jriMh5kScXu0X4foLPtyeEySmwjxlI5piHMmblz6Y
dyBq95SqqbMIbMHQ4elqB6451SNSdSFO91b1Kxx2uGYky+81F6DYPfHYwSw7
3h+O9w7/Lh87Wnay3O5sQKsOCqNcFaLrsS6Yvm0Dey4+5C5f+hRcZrkHN8YG
SdFg4b0LeSiYYqSr8qzo1exnsLxzESQa9ysqsEAkGyraID5GXI4gSpizDmY8
X9tmOQNH+6axLuEfuPw93DIXs9Fi+Vo4cPgxtOYfjwea+OgZjlgtdD2EpI1T
rf89EwHOk14B6jUwRWsTirsZT/5dgSv2y4BoTTpIXvwt3slFiJ7P0M4nnXqy
Zw5EZ/PxxGgeVrr20epbzShjL00MBCfBoLWm5sc9AGEKTQt97h0YfFtLfj46
CWJ2ZoKx8BbG+rM6GlIMIHyylzx7WGgqpp754KwOhHB6c+TZQ7h+e/XtV5V9
IGL4H41HucP37jj/w9kqDC7pl0pePzCwu7mPfaWxE/8ClaGTjQ==
      "]]}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13k81NsbB3CUNZUWS5ZiLkVSUdEP9QgRIcS1FC26llRE9vmeYahsKZK1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        "]]},
      Annotation[#, "Charting`Private`Tag$599246#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 1.6948581299755128`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480252591260969*^9, 3.480252685939891*^9, 3.480692325467414*^9, 
   3.481941625474936*^9, 3.4819420984427*^9, 3.6626256321537743`*^9, 
   3.799212568061824*^9, 3.799212804819854*^9, 3.81419390933317*^9, 
   3.814249181157241*^9, 3.8322468155927353`*^9, 3.832403688925871*^9, 
   3.832579094857079*^9, 3.88969617431282*^9, 3.890118967237935*^9},
 CellLabel->
  "Out[158]=",ExpressionUUID->"0fed83f0-22e9-4693-97d2-1d59c9ba1999"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (5x10 magnet)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.478895153999941*^9, 
   3.478895157728011*^9}},ExpressionUUID->"3e8ab641-d0ac-4724-a259-\
68c331873309"],

Cell["\<\
bosemvals5 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.005,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.478895116514908*^9, 
  3.478895118897944*^9}, {3.478895285651181*^9, 3.478895286185315*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"fd944fd5-79d6-47c7-8f61-db697a9b9078"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BO5", "]"}], " ", ":=", " ", "bosemvals5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9, {3.478895122464415*^9, 3.478895146305952*^9}},
 CellLabel->
  "In[160]:=",ExpressionUUID->"8ab6d7d1-aec3-4982-9aeb-d4f7c5ad9135"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9628352953498257"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0061809572312008145`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"BO5", ",", "z"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, 3.662624014406456*^9, 3.8324026631840897`*^9, 
   3.832402752873056*^9, 3.8324028780597067`*^9, 3.8324029426831017`*^9, 
   3.83240317051573*^9},
 CellLabel->
  "In[161]:=",ExpressionUUID->"f55e7bfe-ea93-4c0f-8155-1bd9f471e265"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9628352953496105`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0061809543072630976`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662626007345862*^9, 3.799212568089175*^9, 
  3.799212804847822*^9, 3.8141939093572483`*^9, 3.814249467991371*^9, 
  3.832246815846258*^9, 3.832403698733307*^9, 3.8325791029035482`*^9, 
  3.889696177950967*^9, 3.890118970754711*^9},
 CellLabel->
  "Out[161]=",ExpressionUUID->"5ffc35eb-79ee-4234-a79f-753d0611d8b4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1ns4VNv/B/C+IaIkRAqhUqdUkopc3m5FJ5wUKoqiIiG3MbNnSK5pQhSi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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.9628352949866621}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO5", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.4802448296734753`*^9, 
   3.480244857272909*^9}, 3.662624016974782*^9},
 CellLabel->
  "In[162]:=",ExpressionUUID->"7e4b96fe-abcd-4197-ae39-f1075f7afa58"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk8lNsfB/BuEVESIoUsbbdUlLoUPkRSllKoVISKhBjGzDNDsqaxRBEi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       "]]},
     Annotation[#, "Charting`Private`Tag$603765#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.9628352949866623}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662626043423575*^9, 3.799212568134398*^9, 
  3.799212804883904*^9, 3.8141939093822317`*^9, 3.8142495011325827`*^9, 
  3.8322468500336514`*^9, 3.832403735004586*^9, 3.83257913446159*^9, 
  3.889696191561161*^9, 3.8901189840735273`*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"ee26ccea-0ad9-4f7b-830f-6106f390342b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BO5", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BO5", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9},
 CellLabel->
  "In[163]:=",ExpressionUUID->"126f4d47-0600-43f1-aa14-0dd4c6aaac9c"],

Cell[BoxData["0.0061809543072630976`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480692325590218*^9, 3.481941625685656*^9, 3.481942098570314*^9, 
  3.662626043505526*^9, 3.799212568143976*^9, 3.799212804892929*^9, 
  3.8141939093877068`*^9, 3.814249501299286*^9, 3.8322468500933943`*^9, 
  3.8324037350871763`*^9, 3.832579134506456*^9, 3.8896961915831337`*^9, 
  3.89011898409993*^9},
 CellLabel->
  "Out[163]=",ExpressionUUID->"bf245c1c-a53b-4ba0-837f-a42f74f4929f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BO5", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BO5", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9},
 CellLabel->
  "In[164]:=",ExpressionUUID->"4917d071-f59b-4f1e-a96c-a6c9042c6636"],

Cell[BoxData["0.9628352953496105`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.4806923256341553`*^9, 
  3.481941625797789*^9, 3.4819420986261683`*^9, 3.6626260435614357`*^9, 
  3.799212568179838*^9, 3.799212804930097*^9, 3.814193909408791*^9, 
  3.814249501338162*^9, 3.832246850114264*^9, 3.832403735104374*^9, 
  3.8325791345147*^9, 3.88969619158677*^9, 3.890118984104707*^9},
 CellLabel->
  "Out[164]=",ExpressionUUID->"816b8f23-cca0-43a0-a07a-3b8ddbc03461"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO5", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623663118393*^9, 3.662623666744122*^9}},
 CellLabel->
  "In[165]:=",ExpressionUUID->"2c444fb3-82df-43cc-9185-44884396c783"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxn04FAYAx/F7cOwxeo6d5DCE2JoROW+n3x55zclGwkNjHKY7727UHJc4
hwgdT1Z7YTQtND3eJ9HTad4eOzYqyTv3rmIzDc/aH9/n8zWLSQmKUyEQCLS3
/e/WzR4Tjq/S/e1uxJmlnJi77d+3NXQU+y0MO2pxM9p/TFAhvqZh7byUmNJ8
H6SsHZ8KrhfCqzL02P8IQZfR3EQMOt7c3RIsL47hgnVYXMDGZ/B4nTlDMZuE
oysj4SwrBB2WoRR77p+45cnvMj8eDqL96TMGpKf4hir79pQ0EucC83RVM5+j
7+Sn86fsoiH3W4jRz58HT9xZM0mKwbU7S+P5YYsQ9nkzWaJYBOvfuKr2aAlC
tb81HYrjcLBupOtL/RWY+rWJIuITsFwXYsfPWMVGX3VHjXkiTjRwfr3SsAYD
G96AgzoTkv603LYn61DTqanZm2fhSard854NMRgWE8VPa5Ph1KduxHkhAYmi
OVlKS8XnOn9NNQ9L0eQyqHAwSkOYnpVGa7kMyaH7RmUH0qGId7as8peDbDva
lrObDvExusBXLgf7u49C2M8yECQtIEexFFDVImuZjGZixlPSOzevAF2nQiS6
w8b8Q2eyH1UJ9u83din8r1DLoheWZSkxVmbjppeVhW5zK94Xt5WYWwrmHzqb
DcNH28c0hUoYUgmSMZ8LGLQx7i6aUML1JO2uvuNFeAb/XOfxWIn3xFoFTN2v
of6yJUbzFyUopbGsVJUc7FB0sq2LlJgVno7NXcpBVAQjlRGsBKd3+MHhfg7G
qq5p75CVoLeM2GY35yKpxLU6UqjAtFN063RJHv6IDaW8k6aA94K76aY7F3tT
5Mpn7yqQ97I6Na+Vi7TBxFvejXI0zXVsThtdQv0RL3VdVznEw9cJRYJLSMwx
bIh4IANRZUjgppYP3dH2pFYfGZxdOu/5cvKRZCszDxyUIjIgWdVsKx85lXWk
AhcpzrWkzu7FXMbFzYxMg24J2FpUd4fZy2hPGHnF+UCC811eR5L8C8ANr3wz
Xi9GIIw90nsKYKoqthAZi+E/1LU+YVeI0g/j3//3yjosam+S7X8oRL3sJ2I/
cR1kpueo/BAPAdq8sdyMNWwZtLenX+Wh02qionFlFW3kZMu9PR4ou8ygqOhV
FB6QmSywi4AXAxqYXAH1zL26x6tFkDqpMXQCV7B/ndaiEcXH+MHJrt8eLqOz
t1ymO82HlzbpExO3ZfhbH2077FUMN8uPHcv7l7AtKCGU3i/G8FpK9JTLErgB
x2e2bUqwaerdZDOwiFcCakr/9yVoTE5iJvgs4j9ExMV2
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$624441#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.962833270642868}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxn04FAYAx/F7cOwxeo6d5DCE2JoROW+n3x55zclGwkNjHKY7727UHJc4
hwgdT1Z7YTQtND3eJ9HTad4eOzYqyTv3rmIzDc/aH9/n8zWLSQmKUyEQCLS3
/e/WzR4Tjq/S/e1uxJmlnJi77d+3NXQU+y0MO2pxM9p/TFAhvqZh7byUmNJ8
H6SsHZ8KrhfCqzL02P8IQZfR3EQMOt7c3RIsL47hgnVYXMDGZ/B4nTlDMZuE
oysj4SwrBB2WoRR77p+45cnvMj8eDqL96TMGpKf4hir79pQ0EucC83RVM5+j
7+Sn86fsoiH3W4jRz58HT9xZM0mKwbU7S+P5YYsQ9nkzWaJYBOvfuKr2aAlC
tb81HYrjcLBupOtL/RWY+rWJIuITsFwXYsfPWMVGX3VHjXkiTjRwfr3SsAYD
G96AgzoTkv603LYn61DTqanZm2fhSard854NMRgWE8VPa5Ph1KduxHkhAYmi
OVlKS8XnOn9NNQ9L0eQyqHAwSkOYnpVGa7kMyaH7RmUH0qGId7as8peDbDva
lrObDvExusBXLgf7u49C2M8yECQtIEexFFDVImuZjGZixlPSOzevAF2nQiS6
w8b8Q2eyH1UJ9u83din8r1DLoheWZSkxVmbjppeVhW5zK94Xt5WYWwrmHzqb
DcNH28c0hUoYUgmSMZ8LGLQx7i6aUML1JO2uvuNFeAb/XOfxWIn3xFoFTN2v
of6yJUbzFyUopbGsVJUc7FB0sq2LlJgVno7NXcpBVAQjlRGsBKd3+MHhfg7G
qq5p75CVoLeM2GY35yKpxLU6UqjAtFN063RJHv6IDaW8k6aA94K76aY7F3tT
5Mpn7yqQ97I6Na+Vi7TBxFvejXI0zXVsThtdQv0RL3VdVznEw9cJRYJLSMwx
bIh4IANRZUjgppYP3dH2pFYfGZxdOu/5cvKRZCszDxyUIjIgWdVsKx85lXWk
AhcpzrWkzu7FXMbFzYxMg24J2FpUd4fZy2hPGHnF+UCC811eR5L8C8ANr3wz
Xi9GIIw90nsKYKoqthAZi+E/1LU+YVeI0g/j3//3yjosam+S7X8oRL3sJ2I/
cR1kpueo/BAPAdq8sdyMNWwZtLenX+Wh02qionFlFW3kZMu9PR4ou8ygqOhV
FB6QmSywi4AXAxqYXAH1zL26x6tFkDqpMXQCV7B/ndaiEcXH+MHJrt8eLqOz
t1ymO82HlzbpExO3ZfhbH2077FUMN8uPHcv7l7AtKCGU3i/G8FpK9JTLErgB
x2e2bUqwaerdZDOwiFcCakr/9yVoTE5iJvgs4j9ExMV2
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$624441#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.962833270642868}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {49}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGJDBgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gb71C/bgCY0Qu1vtH/+e+XHS75NUHc02WcyzzW7kNkMdU+z/RuuCdVn
W1vs14Ld1WqfJ9QMtKIV6r42+0+SZawn9rZB3dluX6yY6XX0Zru9Cdi9HfZf
NWL6D33tsN8GdnenfTnIWsEuqPu77AGyNMFI
   "], CompressedData["
1:eJwBmQFm/iFib1JlAgAAADEAAAABAAAAAAAAAAAAAADrgSH/FjqyP1kLMOS7
K8I/rxbLq9cdyz8PzRa0tPLRP51FwgZyOtY/KbUqfaNf2j+4L1IeI1zeP2J0
/dkbFeE/X07ki1Pi4j8uyxNUY5PkP1lul95EJuY/VxyrgUaZ5z/p8SNhD+vo
P056wYqiGuo/sxYOBGAn6z/JvjXtBBHsP4psrN+p1+w/t4uLQ8B77T/++2Bh
Dv7tP2hELlipX+4/oB7ym+6h7j9BswEse8buP+OycNohz+4/Cf9lSOC97j9q
HyIj05TuP1Z+wh0qVu4/9jauORwE7j8L18bL3KDtP5aupdeRLu0/eh/R30uv
7D9mHBOp/yTsPwC/456Bkes/ZryO6YL26j9Dt9L5j1XqP/S/lTEQsOk/iWmT
p0YH6T/z0YykU1zoPxi7rhI2sOc/8dXBIc4D5z8Wj2Rz31fmP5SZwf4SreU/
fvUznfoD5T+14q3jEV3kP7GqFsrBuOM/wumhKGEX4z9AVE+4N3niP1d9DPh/
3uE/25t4Y2dH4T/yysfm
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662626054357819*^9, 3.7992125682593393`*^9, 
  3.799212814352689*^9, 3.814193920153544*^9, 3.814249511183578*^9, 
  3.832246861691285*^9, 3.8324037474240637`*^9, 3.832579144277835*^9, 
  3.889696195680448*^9, 3.8901189880944853`*^9},
 CellLabel->
  "Out[165]=",ExpressionUUID->"031e278a-e25c-41c1-b8a0-d83ea4dcf1a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BO5", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO5", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623664744658*^9, 
   3.662623670310789*^9}, 3.799212531141622*^9},
 CellLabel->
  "In[166]:=",ExpressionUUID->"2a59b881-d376-43d8-b396-175d1e1c9938"],

Cell[BoxData["43704.611046694976`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626260544412813`*^9, 3.799212568271042*^9, 3.799212814410021*^9, 
   3.814193920220907*^9, 3.814249511218038*^9, 3.8322468617927933`*^9, 
   3.8324037474919987`*^9, 3.832579144313057*^9, 3.889696195698113*^9, 
   3.890118988126347*^9},
 CellLabel->
  "Out[166]=",ExpressionUUID->"36568276-99df-4e62-8ced-daa936201418"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement", "Subsubsection",
 CellChangeTimes->{{3.478970601031336*^9, 
  3.478970602486655*^9}},ExpressionUUID->"8741529c-9780-4efa-acce-\
b0a7f8555815"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v5", " ", "=", " ", 
  RowBox[{"Recurse", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zflange", " ", "->", " ", 
      RowBox[{"0.1", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"end", " ", "flange", " ", "thickness"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"l", " ", "->", " ", "0.005"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zplug", " ", "->", " ", "0.001"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zcoil", " ", "->", " ", 
      RowBox[{"0.315", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"coil", " ", "length"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"zc", " ", "->", " ", 
      RowBox[{
       RowBox[{"l", "/", "2"}], "+", "zplug", "+", "zflange", "+", 
       RowBox[{"zcoil", "/", "2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"newportcal", " ", "->", " ", "0.5"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "micrometer", " ", "to", " ", "stage", " ", "factor", " ", "for", " ", 
      "Newport", " ", "NVM80"}], " ", "*)"}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478364871938177*^9, 3.4783650430215597`*^9}, {
   3.478365123922604*^9, 3.478365126702361*^9}, {3.478365254617469*^9, 
   3.4783652660805397`*^9}, {3.4783655084186296`*^9, 
   3.4783655130572557`*^9}, {3.478365552219092*^9, 3.4783656736355543`*^9}, 
   3.47948618034295*^9, 3.479486213991674*^9, {3.479502242119833*^9, 
   3.4795022421218023`*^9}, {3.479655724672627*^9, 3.479655724740677*^9}, {
   3.4796557854574213`*^9, 3.479655785465637*^9}},
 CellLabel->
  "In[167]:=",ExpressionUUID->"40407238-0b55-4802-84a1-94f993312b98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"zflange", "\[Rule]", "0.00254`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"zplug", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"zcoil", "\[Rule]", "0.008001`"}], ",", 
   RowBox[{"zc", "\[Rule]", "0.010040499999999999`"}], ",", 
   RowBox[{"newportcal", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.478365674218483*^9, 3.4788943916835203`*^9, 
  3.478960931218412*^9, 3.478973701033331*^9, 3.479490566372048*^9, 
  3.479664646024015*^9, 3.4796657673893423`*^9, 3.480084171866323*^9, 
  3.480244564038784*^9, 3.480245921425527*^9, 3.4806923260597963`*^9, 
  3.481941626208601*^9, 3.481942099102745*^9, 3.66262605449503*^9, 
  3.799212568309299*^9, 3.799212814419347*^9, 3.8141939202278757`*^9, 
  3.8142495112261133`*^9, 3.832246861812539*^9, 3.832403747505988*^9, 
  3.8325791443441896`*^9, 3.889696195719267*^9, 3.890118988131299*^9},
 CellLabel->
  "Out[167]=",ExpressionUUID->"5a48644c-ac79-4405-9ce4-e696db5dc7f5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cal5", " ", "=", " ", "0.5"}], ";"}]], "Input",
 CellChangeTimes->{{3.4783589573423653`*^9, 3.478358966550098*^9}, 
   3.478973591713312*^9},
 CellLabel->
  "In[168]:=",ExpressionUUID->"c4821a4d-17ad-4a62-868d-79afc8bf9aef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m5", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "20.02", ",", "\[IndentingNewLine]", "20.0", ",", "\[IndentingNewLine]", 
     "19", ",", "18", ",", "17", ",", "16", ",", "15", ",", 
     "\[IndentingNewLine]", "14", ",", "13", ",", "12", ",", "11.5", ",", 
     "11", ",", "10.5", ",", "10", ",", "\[IndentingNewLine]", "9.5", ",", 
     "9.0", ",", "8.5", ",", "8", ",", "7.5"}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47835857022501*^9, 3.478358649532322*^9}, {
  3.478358853952238*^9, 3.478358855805633*^9}, {3.478370614629692*^9, 
  3.4783706455854597`*^9}, {3.478370676433776*^9, 3.478370679402834*^9}},
 CellLabel->
  "In[169]:=",ExpressionUUID->"fab4ed2e-8b7b-4354-a878-ca8d74d41502"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f5", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"21.7", ",", "  ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"was", " ", "25.7"}], " ", "-", " ", 
       RowBox[{"typo", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", "21.7", 
     ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"was", " ", "25.7"}], " ", "-", " ", 
       RowBox[{"typo", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", "23", ",",
      "\:3000", "24", ",", "\:3000", "25", ",", "\:3000", "26", ",", "\:3000",
      "26.9", ",", "\:3000", "\[IndentingNewLine]", "27.6", ",", "\:3000", 
     "28.2", ",", "\:3000", "28.7", ",", "\:3000", "28.6", ",", "\:3000", 
     "28.7", ",", "\:3000", "28.5", ",", "\:3000", "28.2", ",", "\:3000", 
     "\[IndentingNewLine]", "27.6", ",", "\:3000", "27.4", ",", "\:3000", 
     "26.5", ",", "\:3000", "25.9", ",", "\:3000", "25.4"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478358656639378*^9, 3.478358736957609*^9}, {
   3.478358785279069*^9, 3.478358785557148*^9}, {3.47836952405042*^9, 
   3.478369528607705*^9}, {3.4783705484182587`*^9, 3.478370609603867*^9}, 
   3.478370656935858*^9, {3.478370688621035*^9, 3.47837070158915*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"efcfd2d9-3339-4b5f-a21c-c05beabe29d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c5", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m5", "-", 
         RowBox[{"m5", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478370938123036*^9, 3.478370942043363*^9}, {
   3.478961639423946*^9, 3.478961643935979*^9}, 3.4789735974419727`*^9, 
   3.479490549175753*^9},
 CellLabel->
  "In[171]:=",ExpressionUUID->"9dc654f5-12e7-4376-b988-c7b6004ee35f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m5b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "25", ",", "24.5", ",", "24", ",", "23.5", ",", "23", ",", "22.5", ",", 
     "22", ",", "21.5", ",", "21", ",", "20.5", ",", "\[IndentingNewLine]", 
     "20", ",", "19.5", ",", "19", ",", "18.5", ",", "18", ",", "17.5", ",", 
     "17", ",", "16.5", ",", "16", ",", "15.5", ",", "\[IndentingNewLine]", 
     "15", ",", "14.4", ",", "14", ",", "13.5", ",", "13", ",", "12.5", ",", 
     "12", ",", "11.5", ",", "11", ",", "10.5", ",", "\[IndentingNewLine]", 
     "10", ",", "9.5", ",", "9", ",", "8.5", ",", "8", ",", "7.5", ",", "7", 
     ",", "6.5", ",", "6", ",", "5.5", ",", "\[IndentingNewLine]", "5.25", 
     ",", "5", ",", "4.75", ",", "4.5", ",", "4.25", ",", "4"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.480082947570427*^9, 3.4800831719740562`*^9}},
 CellLabel->
  "In[172]:=",ExpressionUUID->"bfd1fe49-5c2f-42b5-a27b-fbf16023de9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f5b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "21.9", ",", "22.5", ",", "23.0", ",", "23.4", ",", "23.9", ",", "24.4", 
     ",", "24.9", ",", "25.4", ",", "25.8", ",", "26.2", ",", 
     "\[IndentingNewLine]", "26.5", ",", "26.9", ",", "27.3", ",", "27.5", 
     ",", "27.6", ",", "27.7", ",", "27.8", ",", "27.9", ",", 
     "\[IndentingNewLine]", "27.7", ",", "27.5", ",", "27.1", ",", "26.6", 
     ",", "26.1", ",", "25.4", ",", "24.7", ",", "23.8", ",", "22.8", ",", 
     "21.8", ",", "20.7", ",", "19.4", ",", "\[IndentingNewLine]", "18", ",", 
     "16.6", ",", "15.0", ",", "13.4", ",", "11.7", ",", "10.0", ",", "8.17", 
     ",", "6.34", ",", "4.45", ",", "2.53", ",", "\[IndentingNewLine]", 
     "1.61", ",", "0.658", ",", "0.290", ",", "0.124", ",", "0.222", ",", 
     "3.19"}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48008383483594*^9, 3.4800841583652897`*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"a2cbe80f-09bc-4b53-8bff-04c2ae7c47c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c5b", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m5b", "-", 
         RowBox[{"m5b", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478370938123036*^9, 3.478370942043363*^9}, {
   3.478961639423946*^9, 3.478961643935979*^9}, 3.4789735974419727`*^9, 
   3.479490549175753*^9, {3.480085294755208*^9, 3.480085305264647*^9}},
 CellLabel->
  "In[174]:=",ExpressionUUID->"bfb484d5-820f-4006-ab1e-d64c012102c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"c5b", ",", "f5b"}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.480244170219839*^9, 3.480244174751951*^9}},
 CellLabel->
  "In[175]:=",ExpressionUUID->"05db1675-ae50-40f9-b872-a707329c2930"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQvbtKVFJ2Qot9Ggg8M3XIflu7iou3xZ4BBBrMHKQT
nln/6GyG8BnMHU5f8jv7lK0Zoj7N3KHGdXvc5eYmqH5zB50d8h8OMED5aRYO
d7Q6GtfVNkLlLRx65n4QmvOrASpv6WAjELmks7zB/uwZELB0uMHanP3uRb29
MRhYOVi8Du47+agO6h4rh5kXVDYuuVMLNc/K4efWr5frr9VA9PtYO0TOPvYt
6kI1VL21w66G6ZJmp6rsZ80EAWsHqbQMG8EjlRDzN1s7VHlbxr/ZWwG139rh
lgFX0/Ht5VDzrR2sxW4vWbSxDK5+9u/Vx2tXl8LN//2g5lXE0hKI+ZLWDld7
y92PZRVD7bNy2LNazoB/ZhFU3spBZuL7oFeTCuH+ryk7UHq0pwBqvoXDju1K
ho68+VD3mDtUNR0p+86QC+WbOVj5pu1Z+yULyjd1+CXOwZTyIgOq38Rh16OV
7lJ30qDmGzvUrPXuvXA+BRp/Rg42FW8vtR1OgrrPwOGPU7+E7fYEqLyeQ4V0
0p5nobFQ87UcfmxY6h5sGwk1T92hwu3lpf0qoVD1Kg4Md3TidHgC7a8vLrDl
CldwYHj84JLhc0/7mP5DXzViJB0Y+DJecm1zhJon6MBQdO//cU5je1sukA4W
Bwar0zpOG1XtDwNV9x/6ac/gkJZ+0ZrVvnSyBEsY31N7BhODT5vUxPaDjeu/
ZM9whNNnean2/gjLLSfK9u23Z9he2//rten+i0q3f9ZlnbFn6PlWoShrt7/1
deAOuVZOBwCkWD22
     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.0004595000000000016, 0.010040499999999999`}, {0, 27.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480244175910057*^9, 3.480244564266391*^9, 
  3.480245921792756*^9, 3.4806923262774763`*^9, 3.481941626785322*^9, 
  3.48194209932056*^9, 3.662626054674625*^9, 3.799212568412122*^9, 
  3.7992128144993067`*^9, 3.814193920341157*^9, 3.814249511301242*^9, 
  3.832246862205941*^9, 3.8324037476103897`*^9, 3.832579144528038*^9, 
  3.889696195780974*^9, 3.890118988204426*^9},
 CellLabel->
  "Out[175]=",ExpressionUUID->"2f022ee6-5178-4f82-95a0-c7216eebb9b0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"g5", " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c5", ",", "f5"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "6"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, 
   3.479664850461237*^9, {3.479666071209745*^9, 3.479666118376079*^9}},
 CellLabel->
  "In[176]:=",ExpressionUUID->"7a1d2727-4002-416b-a42f-e21aef650e48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g5b", " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c5b", ",", "f5b"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", 
       RowBox[{"-", "10"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, 
   3.479664850461237*^9, {3.479666071209745*^9, 3.479666118376079*^9}, {
   3.4800842394941673`*^9, 3.480084256187529*^9}, {3.480085381741091*^9, 
   3.4800854050584*^9}},
 CellLabel->
  "In[177]:=",ExpressionUUID->"f483904d-facb-4226-90a0-92506a67fe1f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "g5b", "]"}]], "Input",
 CellChangeTimes->{{3.479492922070776*^9, 3.479492925832822*^9}, 
   3.480084241379088*^9},
 CellLabel->
  "In[178]:=",ExpressionUUID->"d7ded7f2-fd4e-48bc-afff-313ea28ab95e"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`], 
    AbsoluteThickness[1.6], 
    PointBox[{{0.004290499999999999, 25.4}, {0.004540499999999999, 26.1}, {
     0.004740499999999999, 26.6}, {0.005040499999999999, 27.1}, {
     0.005290499999999999, 27.5}, {0.005540499999999999, 27.7}, {
     0.005790499999999999, 27.9}, {0.006040499999999999, 27.8}, {
     0.006290499999999999, 27.7}, {0.0065404999999999994`, 27.6}, {
     0.006790499999999999, 27.5}, {0.007040499999999999, 27.3}, {
     0.007290499999999999, 26.9}, {0.007540499999999999, 26.5}, {
     0.007790499999999999, 26.2}}]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.0042175833333335635`, 25.26111111111117},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.0042175833333335635`, 0.007790499999999999}, {
   25.26111111111117, 27.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.47949292648037*^9, {3.4794929901025677`*^9, 3.479493006913755*^9}, 
   3.479493322040373*^9, {3.479493571055421*^9, 3.479493582720769*^9}, {
   3.479493654111162*^9, 3.479493680849517*^9}, 3.479494594442368*^9, 
   3.4794951275012083`*^9, 3.479664646222107*^9, 3.479665767557681*^9, 
   3.4796658002277327`*^9, {3.479666082950231*^9, 3.479666122957705*^9}, 
   3.480085257681452*^9, 3.48008532219565*^9, {3.480085387449814*^9, 
   3.480085408824621*^9}, 3.4802445643515987`*^9, 3.480245921875152*^9, 
   3.4806923263613043`*^9, 3.481941626886848*^9, 3.481942099405159*^9, 
   3.662626054790688*^9, 3.799212568454192*^9, 3.7992128145398893`*^9, 
   3.814193920374393*^9, 3.814249511350589*^9, 3.8322468622732897`*^9, 
   3.832403747688438*^9, 3.832579144583559*^9, 3.88969619580445*^9, 
   3.890118988230792*^9},
 CellLabel->
  "Out[178]=",ExpressionUUID->"d99843b9-7b13-4389-8a4e-3b37ded296d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"BO5", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{"g5b", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "z", ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479492821084407*^9, 3.479492906857025*^9}, {
   3.479493026130746*^9, 3.479493088769916*^9}, 3.47966554034807*^9, 
   3.480085337997651*^9},
 CellLabel->
  "In[179]:=",ExpressionUUID->"3b0690d8-576a-4f50-805c-848c9bf88016"],

Cell[BoxData[
 RowBox[{"2.6127607538418625`", "\[VeryThinSpace]", "+", 
  RowBox[{"8218.0613716447`", " ", "z"}], "-", 
  RowBox[{"669099.8444305126`", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.479493065534417*^9, 3.479493090921401*^9}, 
   3.479493347575324*^9, 3.479493687032943*^9, 3.4794945945082073`*^9, 
   3.479495127601207*^9, 3.4796646462647676`*^9, 3.4796655437102633`*^9, 
   3.479665767592616*^9, 3.479665800264008*^9, {3.4796660829847727`*^9, 
   3.479666123040353*^9}, 3.480085339448057*^9, 3.480085414970368*^9, 
   3.4802445643682337`*^9, 3.4802459219083157`*^9, 3.48069232640238*^9, 
   3.481941626925313*^9, 3.481942099421473*^9, 3.662626054845523*^9, 
   3.7992125684643803`*^9, 3.7992128145497*^9, 3.814193920380443*^9, 
   3.814249511357449*^9, 3.832246862289412*^9, 3.8324037477104263`*^9, 
   3.8325791445929203`*^9, 3.8896961958112288`*^9, 3.890118988237968*^9},
 CellLabel->
  "Out[179]=",ExpressionUUID->"989c87ae-7dc1-480d-b219-9bb38d789cff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "g5b", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"BO5", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.00375", ",", "0.008"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479493098474358*^9, 3.4794931473471107`*^9}, {
   3.4794950541082687`*^9, 3.479495059418387*^9}, 3.479495140140613*^9, {
   3.479498020636153*^9, 3.4794980214908237`*^9}, 3.4796655403666763`*^9, 
   3.480085344678802*^9},
 CellLabel->
  "In[180]:=",ExpressionUUID->"48eeed37-8a15-4b27-b484-77994f6f7a0d"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{0.004290499999999999, 25.4}, {0.004540499999999999, 26.1}, {
      0.004740499999999999, 26.6}, {0.005040499999999999, 27.1}, {
      0.005290499999999999, 27.5}, {0.005540499999999999, 27.7}, {
      0.005790499999999999, 27.9}, {0.006040499999999999, 27.8}, {
      0.006290499999999999, 27.7}, {0.0065404999999999994`, 27.6}, {
      0.006790499999999999, 27.5}, {0.007040499999999999, 27.3}, {
      0.007290499999999999, 26.9}, {0.007540499999999999, 26.5}, {
      0.007790499999999999, 26.2}}]}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13lYTWsXAPAGoUFEXQ1SIeFWUm46Z2O91JdwpZIkDWRK0qDh7H0qHSIN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        "]]},
      Annotation[#, "Charting`Private`Tag$624664#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.0042175833333335635`, 25.26111111111117},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.479493147789712*^9, 3.479493348745586*^9, 3.479493687869093*^9, 
   3.479494594544231*^9, 3.4794950600870647`*^9, {3.479495127635968*^9, 
   3.4794951412551003`*^9}, 3.479498022175354*^9, 3.479664646293791*^9, 
   3.479665767627028*^9, 3.479665800298114*^9, {3.4796660830395527`*^9, 
   3.4796661230758743`*^9}, 3.4800853458498983`*^9, 3.480085417240912*^9, 
   3.480244564408826*^9, 3.48024592195185*^9, 3.4806923264358673`*^9, 
   3.481941626979694*^9, 3.481942099477305*^9, 3.662626054895088*^9, 
   3.799212568521755*^9, 3.79921281460789*^9, 3.8141939204330587`*^9, 
   3.814249511407651*^9, 3.832246862377575*^9, 3.832403747785862*^9, 
   3.832579144652289*^9, 3.889696195835924*^9, 3.890118988262578*^9},
 CellLabel->
  "Out[180]=",ExpressionUUID->"2e3186b9-fc82-4691-ac62-ab1d663dc4f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmaxq", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"BO5", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"BO5", ",", "z"}], "]"}], ",", 
      RowBox[{"z", "^", "2"}]}], "]"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.479495438249634*^9, 3.479495505318678*^9}, 
   3.479662502748355*^9, 3.4796629041886263`*^9, 3.479664469475191*^9, {
   3.479665540402864*^9, 3.479665540432529*^9}, 3.479665679958331*^9},
 CellLabel->
  "In[181]:=",ExpressionUUID->"5e378bec-8eea-41d9-b2cc-c81546e65412"],

Cell[BoxData["0.006141132328792644`"], "Output",
 CellChangeTimes->{{3.479495497456901*^9, 3.479495505729022*^9}, 
   3.479664646330089*^9, 3.479665767660248*^9, 3.4796658003302927`*^9, 
   3.479666123140691*^9, 3.480085429491647*^9, 3.480244564434903*^9, 
   3.480245921975265*^9, 3.480692326468603*^9, 3.481941627025852*^9, 
   3.481942099487645*^9, 3.6626260549302607`*^9, 3.799212568531901*^9, 
   3.799212814617373*^9, 3.814193920439324*^9, 3.814249511414402*^9, 
   3.83224686239357*^9, 3.832403747802292*^9, 3.832579144660462*^9, 
   3.8896961958404417`*^9, 3.890118988269063*^9},
 CellLabel->
  "Out[181]=",ExpressionUUID->"132e439e-1829-40a4-8acf-92938b98c2d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmaxq", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"q", "[", 
   RowBox[{"BO5", ",", 
    RowBox[{"zmaxq", "[", "BO5", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4796645166114473`*^9, 3.4796645680107403`*^9}, {
   3.479664629540166*^9, 3.4796646354272118`*^9}, 3.479665680445608*^9, 
   3.479665788251362*^9},
 CellLabel->
  "In[182]:=",ExpressionUUID->"4d1ac0e4-ef35-46bc-bc7e-5fb5ef8e3016"],

Cell[BoxData["27.846861938546514`"], "Output",
 CellChangeTimes->{3.479664568867193*^9, 3.479664646359799*^9, 
  3.479665585669737*^9, 3.479665767693388*^9, 3.479665800365254*^9, 
  3.479666123176936*^9, 3.48008543183556*^9, 3.480244564491827*^9, 
  3.480245922030847*^9, 3.480692326501891*^9, 3.481941627098565*^9, 
  3.4819420995401154`*^9, 3.6626260549826117`*^9, 3.799212568567286*^9, 
  3.7992128146511183`*^9, 3.814193920461153*^9, 3.8142495114375553`*^9, 
  3.8322468624438133`*^9, 3.8324037478392057`*^9, 3.8325791446849813`*^9, 
  3.8896961958505907`*^9, 3.890118988279982*^9},
 CellLabel->
  "Out[182]=",ExpressionUUID->"fa81b607-58f6-4a3a-ad55-6a239aee553d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"delta", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"zmaxq", "[", "BO5", "]"}], " ", "-", " ", 
   RowBox[{"zmax", "[", "BO5", "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.479495523610161*^9, 3.479495542381401*^9}, 
   3.479661946209796*^9, 3.479662081271207*^9, 3.47966250284426*^9, 
   3.47966290430508*^9, 3.479664469476417*^9, {3.479665683454405*^9, 
   3.479665683520638*^9}},
 CellLabel->
  "In[183]:=",ExpressionUUID->"3aa2d35d-0c01-4b12-8fd5-db47c23e14a8"],

Cell[BoxData[
 RowBox[{"-", "0.000039821978470453746`"}]], "Output",
 CellChangeTimes->{3.4794955436804543`*^9, 3.479665380340073*^9, 
  3.479665767759824*^9, 3.479665800431348*^9, 3.4796661232447157`*^9, 
  3.4800854342417307`*^9, 3.4802445645293713`*^9, 3.480245953636918*^9, 
  3.48069232653566*^9, 3.481941627141439*^9, 3.4819420995770683`*^9, 
  3.662626055031432*^9, 3.799212568575273*^9, 3.7992128146588984`*^9, 
  3.814193920466456*^9, 3.8142495114441566`*^9, 3.832246862475746*^9, 
  3.8324037478511677`*^9, 3.832579144692215*^9, 3.889696195863678*^9, 
  3.890118988286409*^9},
 CellLabel->
  "Out[183]=",ExpressionUUID->"39dd9226-969d-4b12-9213-3d2f7e0a7c0e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Scale factor to make measured and theoretical curves have same maximum\
\>", "Text",
 CellChangeTimes->{{3.478970887912784*^9, 
  3.478970908928837*^9}},ExpressionUUID->"c5a22707-c3e3-4ef3-83ee-\
4d3cf36dcb3b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"fmax", "[", "BO5", "]"}], "/", 
   RowBox[{"fmaxq", "[", "BO5", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970696648231*^9, 3.478970705072441*^9}, {
   3.478970839616865*^9, 3.478970857497159*^9}, 3.4789715324564857`*^9, {
   3.478971784562731*^9, 3.4789717872495337`*^9}, 3.478971846731222*^9, {
   3.4789723755682993`*^9, 3.478972380734989*^9}, {3.4789735142646723`*^9, 
   3.4789735163909893`*^9}, 3.479661959846012*^9, 3.479662130234865*^9, {
   3.479665563524087*^9, 3.479665591276129*^9}, {3.479665788451865*^9, 
   3.479665788518486*^9}},
 CellLabel->
  "In[184]:=",ExpressionUUID->"94effaa2-9976-41e0-982f-16b2ea4c52ce"],

Cell[BoxData["0.034576078894434537`"], "Output",
 CellChangeTimes->{
  3.478971485608411*^9, 3.478971533659111*^9, 3.478971787849442*^9, {
   3.478971841091794*^9, 3.4789718473084917`*^9}, 3.478972382639682*^9, 
   3.4789745781001587`*^9, 3.478974629064003*^9, 3.4794913230668173`*^9, 
   3.4796653804411373`*^9, 3.479665592037429*^9, 3.4796657678267307`*^9, 
   3.47966580051572*^9, 3.479666123310278*^9, 3.480085442306896*^9, 
   3.480085474403487*^9, 3.480244564572826*^9, 3.480245967181128*^9, 
   3.480692326580511*^9, 3.4819416271735687`*^9, 3.481942099628888*^9, 
   3.662626055082137*^9, 3.7992125686094933`*^9, 3.7992128146946173`*^9, 
   3.814193920490775*^9, 3.8142495114764023`*^9, 3.832246862539345*^9, 
   3.832403747889805*^9, 3.832579144719219*^9, 3.889696195874236*^9, 
   3.89011898829852*^9},
 CellLabel->
  "Out[184]=",ExpressionUUID->"88c578ec-4c62-4e9f-b276-43600fd3e005"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BO5", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"c5b", ",", 
        RowBox[{
         RowBox[{"scale", "[", "BO5", "]"}], "*", "f5b"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"scale", "[", "BO5", "]"}], "*", 
      RowBox[{"q", "[", 
       RowBox[{"BO5", ",", "z"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.00375", ",", "0.008"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}},
 CellLabel->
  "In[185]:=",ExpressionUUID->"751718a7-0c82-478d-9e79-edcec149d036"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nk8lNsfB/BuEVESIoUsbbdUlLoUPkRSllKoVISKhBjGzDNDsqaxRBEi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        "]]},
      Annotation[#, "Charting`Private`Tag$603765#1"]& ]}, {}}, {{}, 
    {RGBColor[0, 0, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
     1.6], PointBox[CompressedData["
1:eJw9kW1QywEAxv+4opgKpZaoXUJ1bhHS0qNcosJVuhOVpFZySktr1qZsHWI1
cmQ3dCgdeStq6eU2Lb16qXUSptuValvbZEiSC3euD889X3733P3ucYpLDUuY
SRDE6r/513VsazuH87koDbUPdaCpcVjPvWtOykViTPViy0E17GOHaON5fDy5
uKHhIUODDsXOl4OmfJz9ct1vckADToAkppvPQ4+L47A4TQv3mmWjMoIHStQN
AW1KC6XrmZMPuCeRcoGy5oNgBIJrowuuTuSgrvnWWzZZBx/LyJK8zBwUOs+N
ajmnQ68J/7BBnY0kHkO18LcOXiPhBW39J9A2R7aFFKaHqNO5okTJRTF9RWuk
XI+fVd+7s3s4yGwqCLntaUCkuHlsb2cW4tIbC0KOGFCbU2S3vp2N3iDlw+I8
A8j0JB+rpuPYQRnrNJYawA7euF/XwIL8p4UxoNGA91RzXoskE15dqxaK+gyg
2XwouVnBnObFv8pbuOUZ0/u/VBztntJjEFjvMycm9XiTnxnYnJwOqN7Fx6bo
UV++lGohYuDr3T1SmUqHJRc+h2kL06b9OUxZxnPBUfD7DZ89d4+gRkLx8COl
4sAu0+ZtEVqweU3MH8QRtH6alWXmrYH3Dnr9/W/JoLJnUNuXqjGxeM7MeHUS
nLwG5RuGh1DbfyeQrKRjZeAl6ynmIDj3g/M7X8fj6Qm3renaAfiw9IpT8jgE
VT9jDkf3Y9JfaLtJEotRX+eEqisqsOzj6ociouEqJJWZln3E+KPSwPBNkf//
fgfWVo1C6hwBbThV+cWxB4TSPcZ9Xigql9me9l+kADGgUngMb4exZ+qgi8UL
EPOTNObVfnj1+seslxVyEIy+qRaztbhmnF2oi68G4d3h7l+xHO2eiWpGzj0Q
m+mJXTQTHPKzbSOFFIHwpBorXWyklWKKyCovF0STWUhZhpu02JLs+1iYBkLC
FU6MrJPeFOmGZEezQQjGWE4OvlLry8I1LJ96/AFys2tR
      "]]}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13c4Vm0YAHAzMyN8iJARSvgkUriNklRmRkIIIdm857zWq2GkZRSlNEmJ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        "]]},
      Annotation[#, "Charting`Private`Tag$624770#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.9628352949866623}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480692326631896*^9, 3.481941627229917*^9, 3.481942099677737*^9, 
   3.662626055125484*^9, 3.799212568670271*^9, 3.799212814754312*^9, 
   3.8141939205365067`*^9, 3.81424951153085*^9, 3.832246879913047*^9, 
   3.832403747965784*^9, 3.832579144776374*^9, 3.889696195900202*^9, 
   3.890118988327318*^9},
 CellLabel->
  "Out[185]=",ExpressionUUID->"56de0490-2550-43b2-8dcf-fbb7a254ea2b"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (10x\[OSlash]5 magnet as for tiptilt)", \
"Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}},ExpressionUUID->"4efd5b93-148c-456b-9645-\
92b2cb33f148"],

Cell["\<\
bosemvalsTT = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005/2,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
  3.481940763510077*^9}},
 CellLabel->
  "In[186]:=",ExpressionUUID->"454dd928-09a4-486a-aecd-7774f1d75e6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BOTT", "]"}], " ", ":=", " ", "bosemvalsTT"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9, {3.4819407740626507`*^9, 3.481940800888165*^9}},
 CellLabel->
  "In[187]:=",ExpressionUUID->"e6910de8-019b-40a7-add6-27cfea9f6e47"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.3925374169455943`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.00759707468312686`"}], "}"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"fz", "[", 
        RowBox[{"BOTT", ",", "z"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.008"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, 
   3.662607121040988*^9, 3.832402668576528*^9, 3.8324028808942223`*^9, {
   3.832402953726693*^9, 3.83240295519243*^9}, {3.832403496098639*^9, 
   3.8324035064869137`*^9}},
 CellLabel->
  "In[188]:=",ExpressionUUID->"0c306e42-9206-451e-b276-7f25d1a13d5d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.39253741694525085`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007597067302587177`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662607374243556*^9, 3.6626261664898033`*^9, 
  3.799212568698752*^9, 3.799212814782001*^9, 3.814193920550454*^9, 
  3.814249609543928*^9, 3.832246880040896*^9, 3.832403749287239*^9, 
  3.832579145893622*^9, 3.8896961963437767`*^9, 3.89011898877678*^9},
 CellLabel->
  "Out[188]=",ExpressionUUID->"a4064308-01e9-4878-b5e1-3545e055c63b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4Fe0bB3BR2ZckS5EoKiolhMo3RKVCSrRQka1EQjjOOXOOLR3SqkWb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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.3925374150688015}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, 3.6626071369677134`*^9},
 CellLabel->
  "In[189]:=",ExpressionUUID->"00e8cb3d-befa-4bba-b9d8-2d8e7eaf6b21"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4VWsbBnBRmSWzDolSplJCUblDVMqQEikqMiYqhG2PprRJEypNpgzV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       "]]},
     Annotation[#, "Charting`Private`Tag$626356#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.39253741506880147`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.662607247679082*^9, 3.662626182329171*^9, 
  3.799212568737772*^9, 3.799212814817355*^9, 3.814193920575395*^9, 
  3.814249623485305*^9, 3.832246897403452*^9, 3.8324037646755123`*^9, 
  3.832579159977745*^9, 3.889696202228106*^9, 3.890118994570408*^9},
 CellLabel->
  "Out[189]=",ExpressionUUID->"44a8a491-afbf-483f-ab97-bbceed564e82"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BOTT", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BOTT", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}},
 CellLabel->
  "In[190]:=",ExpressionUUID->"657a4614-756e-46da-90b8-1da0ad443cd5"],

Cell[BoxData["0.007597067302587177`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.479486914888383*^9, 
  3.479659289850292*^9, 3.4796634565750093`*^9, 3.479665742764594*^9, 
  3.479665816570661*^9, 3.480243747684814*^9, 3.480692317253339*^9, 
  3.481566060871256*^9, 3.481940897154257*^9, 3.481940954139496*^9, 
  3.4819414009024477`*^9, 3.481941627387727*^9, 3.481942099804831*^9, 
  3.6626070429154387`*^9, 3.66260724788386*^9, 3.6626261823851137`*^9, 
  3.799212568747365*^9, 3.799212814826435*^9, 3.814193920580821*^9, 
  3.81424962352876*^9, 3.832246897496461*^9, 3.8324037647487707`*^9, 
  3.8325791600230713`*^9, 3.88969620224823*^9, 3.890118994595867*^9},
 CellLabel->
  "Out[190]=",ExpressionUUID->"aecaa70e-0c22-45f7-a370-8c0d0e84535d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BOTT", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BOTT", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}},
 CellLabel->
  "In[191]:=",ExpressionUUID->"4f5e3a6e-21e1-49d9-aa63-433c66fd4a38"],

Cell[BoxData["0.39253741694525085`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.479486914934926*^9, 
  3.479659289887826*^9, 3.479663456628942*^9, 3.479665742793458*^9, 
  3.4796658166882772`*^9, 3.480243747711088*^9, 3.480692317295466*^9, 
  3.481566060924111*^9, 3.48194089720923*^9, 3.48194095418651*^9, 
  3.481941400927742*^9, 3.4819416274500303`*^9, 3.48194209986127*^9, 
  3.6626070429656773`*^9, 3.662607247938093*^9, 3.662626182432036*^9, 
  3.799212568783473*^9, 3.79921281486211*^9, 3.8141939206073923`*^9, 
  3.814249623564185*^9, 3.832246897514015*^9, 3.832403764762453*^9, 
  3.832579160031773*^9, 3.8896962022547483`*^9, 3.89011899460002*^9},
 CellLabel->
  "Out[191]=",ExpressionUUID->"2f165260-1b48-4c67-8af0-f4e67e547ae9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BOTT", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}},
 CellLabel->
  "In[192]:=",ExpressionUUID->"2d21b415-427f-49d4-9f11-30820cfce8dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVx304FAYAx/HbRduahK6Om+ZK1EgsucTpV8nL3JHK0R7NGi7EHNrlZY6j
c+6cVtu43WGrqfbQOu2aHE1ldMxYunOvTJlqzHmZ5cmzJ2ztj+/zeb4bEzmH
2UQCgUB/2f/O17W58MJngggE6pMoWcyekUZG+3y3JyL10iOC3z9H86UUovXf
dFwOvU+OvXIJdrn/hJ3nh4BDupjFdFGAaaEHapKZENoujBZ6/oD8rUfZkbOH
sPhZsH3ehlb4BSSnxGawwCPPMhuutuPbAyKV6873cOjnptt+nR2ooVm+ipg8
hpiCkjEOuQvtwdGPInyOI0GRznT0V0M40SLV2iWiZnUZ5VpuD9TtoekZmiSE
yhVldSW9UFs9X+UrZkO6y/KwNbsP1HeVmvgTKXjnRaxHWv6vmG2vvil1TYOp
w0MyxBiAk5eww3dlOhwn99JcZQ9gZS+VLj3KAIvkH9dWoEHy5gGxWZ4Ji9u9
x43BWthRVmkl9CyQRV17p+0H0bD7p2lf52xcifM47NsziMy4ZeeztjmYrJyq
dCrWgeTdpyxczIE38fp0l7se3K+3sbhDp1D9hXhaqNJjhQ3JxqXvY0ys/vfL
q2EGMO3PazTfceG+tDLQo9MA7oPaRYroNHaUy+7PbDei/6xX4LrcXHCSw+ci
ZEaMjB0ROcbmodlwOUE/Y8SbNMKf/WH5iKmPdpiCCQHB9OtkvwLk1s72/1Zq
wtoJG0G6wyeQRicv+LSYQJEkZWQRC1HIX+NHGDNhWB2VVDRWiNQR6Zo3CGbw
bvXe3XSHB7F11NPatWYwFb94510rAhY8GdS3zDDsOt5kqChG3tQ0dc/LDx0N
oj4L4oOVd5AaQDKj+K/qrOImPlI86rapXzGjYeTmM4NzCdhgMSXjJkz0ygjl
VSUQPJRSeJ0mWBO7qwKtSrFPNXgyRGaC/+6WG+G8UhD5jyk/JppwLDJzxcb5
UrBPm7fo3E14X5E1vJR4Bvtq1pNHJ4zg2tCCfIfPIK3plFB+wYiTqhD3jxgC
DK1z75pnGXEQG/bntAlAN7XaR7xuBKNbNT7gUwb690dTZUoDNsvrSDsuloHT
Xf/HUrwBpPQDfVOOQtR8WBxf+UKPeafm5pxzQrxGlzxpkuuhJGW6LS0JQaML
+ucC9SiztbiMcsvRREu9u1KnAy3mxjc9T8vBvtcVw8zWYVlGV7z6gQhiav3b
fVY6tNz61OJgEOFEo7fKTT4IxlZP5aYQMZb1yqJF30EsVFUQJLfFoK4fr9Gp
teBH7jQueFWAvmW7vTZBi7kqGufOhQrUnauKb3muwX91z8QR
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$646390#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.3924708673072881}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVx304FAYAx/HbRduahK6Om+ZK1EgsucTpV8nL3JHK0R7NGi7EHNrlZY6j
c+6cVtu43WGrqfbQOu2aHE1ldMxYunOvTJlqzHmZ5cmzJ2ztj+/zeb4bEzmH
2UQCgUB/2f/O17W58MJngggE6pMoWcyekUZG+3y3JyL10iOC3z9H86UUovXf
dFwOvU+OvXIJdrn/hJ3nh4BDupjFdFGAaaEHapKZENoujBZ6/oD8rUfZkbOH
sPhZsH3ehlb4BSSnxGawwCPPMhuutuPbAyKV6873cOjnptt+nR2ooVm+ipg8
hpiCkjEOuQvtwdGPInyOI0GRznT0V0M40SLV2iWiZnUZ5VpuD9TtoekZmiSE
yhVldSW9UFs9X+UrZkO6y/KwNbsP1HeVmvgTKXjnRaxHWv6vmG2vvil1TYOp
w0MyxBiAk5eww3dlOhwn99JcZQ9gZS+VLj3KAIvkH9dWoEHy5gGxWZ4Ji9u9
x43BWthRVmkl9CyQRV17p+0H0bD7p2lf52xcifM47NsziMy4ZeeztjmYrJyq
dCrWgeTdpyxczIE38fp0l7se3K+3sbhDp1D9hXhaqNJjhQ3JxqXvY0ys/vfL
q2EGMO3PazTfceG+tDLQo9MA7oPaRYroNHaUy+7PbDei/6xX4LrcXHCSw+ci
ZEaMjB0ROcbmodlwOUE/Y8SbNMKf/WH5iKmPdpiCCQHB9OtkvwLk1s72/1Zq
wtoJG0G6wyeQRicv+LSYQJEkZWQRC1HIX+NHGDNhWB2VVDRWiNQR6Zo3CGbw
bvXe3XSHB7F11NPatWYwFb94510rAhY8GdS3zDDsOt5kqChG3tQ0dc/LDx0N
oj4L4oOVd5AaQDKj+K/qrOImPlI86rapXzGjYeTmM4NzCdhgMSXjJkz0ygjl
VSUQPJRSeJ0mWBO7qwKtSrFPNXgyRGaC/+6WG+G8UhD5jyk/JppwLDJzxcb5
UrBPm7fo3E14X5E1vJR4Bvtq1pNHJ4zg2tCCfIfPIK3plFB+wYiTqhD3jxgC
DK1z75pnGXEQG/bntAlAN7XaR7xuBKNbNT7gUwb690dTZUoDNsvrSDsuloHT
Xf/HUrwBpPQDfVOOQtR8WBxf+UKPeafm5pxzQrxGlzxpkuuhJGW6LS0JQaML
+ucC9SiztbiMcsvRREu9u1KnAy3mxjc9T8vBvtcVw8zWYVlGV7z6gQhiav3b
fVY6tNz61OJgEOFEo7fKTT4IxlZP5aYQMZb1yqJF30EsVFUQJLfFoK4fr9Gp
teBH7jQueFWAvmW7vTZBi7kqGufOhQrUnauKb3muwX91z8QR
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$646390#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.3924708673072881}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {37}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0018958333333333334`, 0.0021666666666666666`, 0.0024375, 
   0.0027083333333333334`, 0.002979166666666667, 0.00325, 
   0.0035208333333333333`, 0.0037916666666666667`, 0.0040625, 
   0.004333333333333333, 0.004604166666666666, 0.004875, 0.005145833333333334,
    0.005416666666666667, 0.0056875, 0.005958333333333334, 
   0.006229166666666668, 0.0065, 0.006770833333333333, 0.0070416666666666666`,
    0.0073124999999999996`, 0.0075833333333333326`, 0.007854166666666666, 
   0.008125, 0.008666666666666666, 0.009208333333333332, 0.00975, 
   0.010291666666666666`, 0.010833333333333334`, 0.011375, 
   0.011916666666666666`, 0.012458333333333332`, 0.013}}, {{0.}, {
   0.047013494159947926`}, {0.09324745034375363}, {0.13794860130965853`}, {
   0.1595022407710808}, {0.18041439040537227`}, {0.20060861124814164`}, {
   0.22001402724221525`}, {0.23856573100456643`}, {0.2562051115590299}, {
   0.27288010703066545`}, {0.2885453862015325}, {0.30316246530475016`}, {
   0.31669976525054433`}, {0.32913261441647784`}, {0.340443206403184}, {
   0.3506205133043768}, {0.3596601625743149}, {0.36756427818720233`}, {
   0.3743412878832522}, {0.38000569731426465`}, {0.3845778331779538}, {
   0.38808354353001595`}, {0.39055387136037434`}, {0.39202467815701775`}, {
   0.3925362408391984}, {0.39213279797323053`}, {0.39086206452845434`}, {
   0.38592380987806774`}, {0.37815229188543875`}, {0.3679984133565307}, {
   0.3559149822897691}, {0.34233995455814425`}, {0.32768241956799377`}, {
   0.3123123552834056}, {0.29655398908142583`}, {0.28068311946827984`}}, {
   Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662626186307064*^9, 3.799212568859078*^9, 3.799212818360805*^9, 
  3.814193924304788*^9, 3.814249627110125*^9, 3.832246901562467*^9, 
  3.832403768471837*^9, 3.8325791636259413`*^9, 3.8896962037675953`*^9, 
  3.890118996058873*^9},
 CellLabel->
  "Out[192]=",ExpressionUUID->"5e4ef03a-21e8-4a29-a5e8-4f4b30c78faa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BOTT", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BOTT", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, 
   3.7992125311458797`*^9},
 CellLabel->
  "In[193]:=",ExpressionUUID->"6a1ad74d-aa0f-455c-b75d-91c2cdcb9618"],

Cell[BoxData["12441.408047207244`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662626186396759*^9, 
   3.799212568872841*^9, 3.7992128184110413`*^9, 3.814193924335485*^9, 
   3.81424962715511*^9, 3.8322469016727057`*^9, 3.8324037685310593`*^9, 
   3.8325791636670027`*^9, 3.889696203790379*^9, 3.89011899607537*^9},
 CellLabel->
  "Out[193]=",ExpressionUUID->"39ff5d46-d553-4e9e-82b7-e41533ff24d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95plus", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BOTT", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "BOTT", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}},
 CellLabel->
  "In[194]:=",ExpressionUUID->"d98c8203-05d9-46c7-9f72-a2b2a847834d"],

Cell[BoxData["0.009502179799031193`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.662607043922553*^9, 
   3.662607248914266*^9, 3.662626187196279*^9, 3.799212568930994*^9, 
   3.799212819110424*^9, 3.814193925109659*^9, 3.814249627898185*^9, 
   3.8322469017704906`*^9, 3.832403769311919*^9, 3.832579164406274*^9, 
   3.889696204088077*^9, 3.890118996373981*^9},
 CellLabel->
  "Out[194]=",ExpressionUUID->"63b12c50-bde3-4987-a548-262020518ed5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95minus", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BOTT", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "BOTT", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}},
 CellLabel->
  "In[195]:=",ExpressionUUID->"c42e2814-1f08-4f70-81a8-0ff89bc9e521"],

Cell[BoxData["0.005897248057577363`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.4819408974084797`*^9, 
   3.481940954404307*^9, 3.481941404076367*^9, 3.481941630539411*^9, 
   3.481942103389555*^9, 3.66260704523952*^9, 3.6626072502629004`*^9, 
   3.66262618829943*^9, 3.799212568959055*^9, 3.79921282007318*^9, 
   3.814193926116148*^9, 3.814249628862711*^9, 3.832246901900724*^9, 
   3.832403770408989*^9, 3.832579165600478*^9, 3.8896962044940777`*^9, 
   3.890118996769864*^9},
 CellLabel->
  "Out[195]=",ExpressionUUID->"9c6d085f-9ba3-4e3d-9dd6-8dbba3bcfba7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BOTT", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}},
 CellLabel->
  "In[196]:=",ExpressionUUID->"9b4a253e-aa44-4989-976d-0d18868730fa"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4VWsbBnBRmSWzDolSplJCUblDVMqQEikqMiYqhG2PprRJEypNpgzV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       "]]},
     Annotation[#, "Charting`Private`Tag$626356#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.013}, {0., 0.39253741506880147`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480252591260969*^9, 3.480252685939891*^9, 3.480692325467414*^9, 
   3.481940897619549*^9, 3.481940954553793*^9, 3.4819414042893677`*^9, 
   3.481941630662005*^9, 3.4819421034795094`*^9, 3.662607045369123*^9, 
   3.6626072503934526`*^9, 3.662626188358437*^9, 3.799212568996962*^9, 
   3.799212820114786*^9, 3.814193926148095*^9, 3.814249628899089*^9, 
   3.83224690192115*^9, 3.8324037704606113`*^9, 3.832579165647592*^9, 
   3.889696204500052*^9, 3.8901189967751503`*^9},
 CellLabel->
  "Out[196]=",ExpressionUUID->"26d15aad-0776-4a3f-8585-94fb2650c05d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Combinations with opposed magnets", "Section",
 CellChangeTimes->{{3.4802635577614393`*^9, 
  3.480263564378763*^9}},ExpressionUUID->"c3b09d43-f3b6-4a18-b0db-\
d33ac90e0b1c"],

Cell[CellGroupData[{

Cell["\<\
10x10 magnets 5 mm apart with hybrid OSEM coil - historical interest only.\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.4807001348451366`*^9}, {
  3.481565209358251*^9, 3.48156521929447*^9}, {3.481565959348879*^9, 
  3.48156595959684*^9}},ExpressionUUID->"3c2133ea-c6b3-4e20-9c0b-\
5677ddc7ddd8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", "z"}], "]"}], "-", 
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", 
       RowBox[{"z", "+", "0.015"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "Black", "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.4802639392440853`*^9, 3.480263973553187*^9}, 3.480264058574482*^9, 
   3.480264152546308*^9, {3.480264362832872*^9, 3.480264366942833*^9}},
 CellLabel->
  "In[197]:=",ExpressionUUID->"3295a945-7d3c-451f-83e8-c148033f7623"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VdsbB3DRJCQlTUhIpJRS/LryVSE0iSQKJSKEMp6zj7Gja6yrLlGi
aDBzyXQkZKhEkaiISukc7N01F7n1W/21n8/z7mftd71r7bXeVQ6e5k7CQkJC
ojOEhH4/tQ0mGEqc3q4qV+t0qaWrSlK7IqmU91RvmZZ++7OqrirFo7Uhwby3
egU7VW7Mze+qWndmt89JXr9edvqk9vnYripNP1EPS96knk6CxV2OaVdVEXvA
dT9PFC/cgxtD6jqrxqZt+k15y2Aq1mTZWva2arHeFVUTnhp8Bc+Tc9JeV5XP
+HTR+MU2uKhrRy1RaquyUeXIug3swrygkFD10eaqxvKA3uC9pmC1ly789r6+
yuEi3ykq2QyOWmV7eT68qhHeWaP81xZQffTf919yd6p2t2ToSB+xwl9m07pa
VBLiO48oKTyxwbsN3dsf3C3BxHs+a/Z/toj5ZW9gVv0IEnypswkVx8HOGrBU
vdaIzKMru2SOOkByUiXm67sW1JiernEdOQk3C163lv4r6OZFFtjlOEF2dIPX
2ubX0L+U1F5l7IwHLiL3Nv/XiXufg0Vq5pxGh/rF3Oi9PYi6n5Yb/9AVlu4F
IfsLP+DbjOLY11buCIstXyIk1YuG2ht+5Ys8ELMwUFgh4BNWivjFzy30xCSt
aHmn8DPOHL3cQ5V7YbBX323TUB8iR/7c2B1/FoeN5063S/Lhauwr53vyHGYf
XGq9ebYAnDfN8213esOIzqbFJgWwWCN/nVrog3oDx+pXdf1wKYrpO9/jAz3x
/ZaL/QeQxzql9a7CF/TxmUKUwiAeVUl4yVT5Qj7lg32d4iA6ZhVnmz3yxcOO
bmfx1YP4FSeiVP/EF1YHY7wS1QZhlnVTKq+dmPf81M1Ngxju7Pwa/K8v/l6X
9t3TYBBaugcylZT84FWvbjjfeRDlP7Xl3aL8kN73K2RvxiBKhoeSBmL9MJbs
4OWaNYjCz5mLXeP8UK+f9fJCziByGldInE70w/e/PYZ4BYO4mfDrx6m7fhgu
Kfl7QfkgIjQev3V45Id5rRKpZ58OwsrucLzNlB/yrY9UiPUPYrzSR9zU1R/H
Xn5KyFCi8UVNZUP5GX/0nK0/eGw1jTfxrw+qnvVHw/Cpq/PX0HhwZtvV2QH+
8NSyqfNYS4MrJ6RYG+4PsxbBbTlNGtKB0dq6t/yx4HlMzhY9Gpt00xw03vhD
2+bNXDMrGsoZFuE3uvyx1azBs/0IDRnpWRni7/2RWfv9lLUNjalBZ2agzx9e
nZ9n29rSqLm+PuDeqD90vEelLE7SMPtRFqsgGYBTuw4GTXnQ8OS9KFtoFIDa
MpEZOuE0js1iio1MAuBbNqc04AINY7N5Rey9AShUO7mp7E8ail8McnvNA/C9
uI61OYpGhxTvVqF9AAJ0Sw6suERD7/TtKHNWAGztn+kWJNKYv5R17HIOiZtI
GQxl0fjhkGDdkE/irzwmRHNoCHKLDk8VBsDYwtdbMZfGo11fzRzKA/CxcP3z
A/k0/DxPGm5qCIBNs7JYchGNnoZ9Gi/fB0CxYEPjVAWNPF9FoYWLWOhU0Ln+
8hmp55mD26NlWFB16WZ1NtGwcQphz1zOwuLU/41+aKYxy7JnbEKBhan4m6X9
L8h8ta71d2mwYLDy+sWBNhrzRqXa7piS+AydO5ldNE55zbj7vzAWfF8oqa8c
oKHrsvFTYTgL4nVO76aIFx63V1gXyYLwoR2a7YM0Kg9UXpP/iwUbTndtOEPW
cwPrkkgKC1WmL650DJH5MUMBzeUsxDU+ktH+RkPe7cOeE8MsXPdX8BwXZvDv
Dupk6hgLl3BO/5oIg+qlMlT3Nxbid3sLts9kcKJhT5b1TxaOjNhWhs5icHtV
6VxzMTbeyHeE/JjDQP1NbP3O1WwEq11OKRVnMJ2n2h2iyoZ4wr0xEwkGTeG1
Yw/V2ahbKK/cReyxeVLpj01sfGl8t2hqPoPCi45hm8HGtf3ZW9dKMdAx/APK
1mw0ifN5FosZiMp2HHY4xobM9tTmNuLOES+Pm/ZszEkVeWguw4Bz8+4N2VNs
NOYX6+xbwqDqh9S0tDcb/g2SyVrLGBgVCspmxbIx9LJkb7MsgyWR51t2/UXy
Oali+YccA4G9vCD0ChvGrG69DOJIiUNLfiax8TFSrDRInuTvUuU7cZcN2bQm
fXkFBhYrEzbxq9kIE/Zk1igxWOqpNixdx0bB6xSrMOKehw/ydz5m4zj/DqeL
2NXu07qUZjZYx5QkopUZhN3YuMayk9SveOuJ7tUMClY8W1E7ygb7vEn8AVUG
fm52nUMTbLxacX9ZErFuxXCi/BQbCQav4z4SP7ZZKsMWojCiJ2PrqUa+l+S0
QFOCws5n1c5BaxmILxWalapCQfq2VbDrOgYvna/UNqlROIRPh9OJE0tVwqbW
UbD9Fbm6i1jJat8vy80UXM4vyNy9nsG2hGuT4voUeva7HpDWYCD0ZX3Ztl0U
hD+O9xkQN2yp8XMxohCCFF8fYvN2/mjtXgpeH2JCWohPS2/5yramoNeXsoez
gYGG45OcjGMU7FvlCm4TjxUddeuwp3A9/ZhkE3GIRZhA8xSFa0PCVUs2kvVK
X3zP/jSFgP/1SuoSi49mOMW6k/nVuh+zJ068/KJXcI7C5War/jRiu16HWzJ+
FH5tMFpbS6y8acLegEXis5qce4nzW2W7U4Mp2LyIeiunSfJf4Pr6cAyF8pen
UyKIfSQkO55eonDCyLg5jVhp3v1XulcoJIQMNlUQh4j8bFW8RiFFUIABYg2h
9Jb4GxT6L7sV/SLunt79Yu4tCp+nV0wu2kTqNxHX9PUehcNr4n7oEAtGtj47
kU3hXRxTZkJ89d+up6/yKBQ2nzWxJjaiQ57sLqTwNtI115l4TLD6Ma+Ygvef
yn0+xOl9jfXryylcTKSHQojNez3rbj6gMJ0q2RpNLPReunZRNQUmrjM8nji/
q7zmQi2FG+euSaYQ272xq55soDBglexxh1i8XaTKvZHk47w+PZu4ojWj8n0z
hX/fXsstIHZ9vu+BeSsZb0zz4n3ipc9GePWvSD3tDQ1LiR8/vlqu84bCxOcl
bWXEfnW6ZdldJC75RbucWLnmY4n8ewo+A2o+v+MvKy8Ux/WS9U/RjCghDuWp
35/5hYL7KjmfIuKNpS2F/v0UtMUO6uQT9xT5/jNAU4hbvaI9kzimYHmB7RCF
VuOnpunEf+RW5bWMUvCwy0y6TjyQ6Zi76xuFXjvRR5eJE++K5pRMkfkd1K6L
+F3f9LwstZ8U2Kq+NwOJx1MtMpNncPDeVs3qLPHt5O/3JGdx4DUdLzj5u75J
N+6GzeWgzFTU0vJ3fRN23hkX46D37Ptkw9/1vcxPd5HkIHv1nmqt3/WM0by1
X4YD4Qyj65LEvIiO1JplHHREeVv8IPvjdDiVoiXHAVcoSND3e/8F1V9frsxB
znKnrFJiX8r1WuwaDkRvf3idQqwcIJkkpM7BVnnJt1zi0LPWCV80OTi3oyZ6
H/FGj59/W2/hQHMttXkjcY9r+pUmHQ6myyN5UsS6jsxfheAgwPSJcyvZ/xOH
Q6OD9nGgtWuF8S7i2xYqUcNmZHzu6lFZYguzZxGOh8j4r38Gj5P/scBk8QXT
oxw4xLrppxO76maGyJzmYOa6OMdh8n9LL+VZ73fn4FToI+t64srRxk0XPDm4
fPC7VSLxgmz687gvB893+nr9QVy6bKNJexgHJRPPlvqR8+X4uL6ixAUO+Ie0
bXcSz2s9+MMgkoPKvuIcCWK7CO/c+5c4SJ7c53GLnE8zv5VI/Z3MwaPnnJBK
dQZ5Lx8PPEvlYF5voHIYsVXem1qRdA7Cja62GxJnOU35emdysEB32fFGch4e
fLW907yEg19BF+SekPMy5Z+6NKkWDlKiHLwT1jAwjm2nTNpIvaKK5+wlHnb5
cii0g4OxnO25QsQGCnPnDL/j4MmPoXXOKgwGL+5xa+nnYMTcc7YaOb913F9u
viQSiOkgXZsQRQZtKh/qxLUDsV/d52gwuW9O5Qv3RG4LhEbr1bb5xN+1V3+b
rReIFjeB7o0VDGRNXNVmGAbCJUPwuWQ5ed9tLHbcPBCTHdl/dS9lMJU/16rH
IxAZ8mvvfpdmoPA/zf78u4HYoRa2yoXct4U1FsLrswLxjwicOsQYGJr6rcjK
DUSNUs/tXcSuRyv23b4fiEWz1JetmMegKNCwMPFRIOqHXN5Xkvvb6JE1FdoT
iLsVwhptpB84sydMwkImCJiVuwnfSX9XuGBG/LIgKDiGOCWR/iFieepYh2wQ
gvLGH45M0Ejrr+iyUQrCcrGPX9LGSf/553imw8YgRAlHLZwcoWFQ52J0zjQI
hRLTWoGkP5HdfiA4LigIt7aKfez7SKNJQ3b4xZcgeF+vZYyf0NgvmR49YyAI
c9Qt4f2YRuu/aiqbmSDoPv6vJbmB9H8F2kcTRoNgXl1czNTR+LDJov6YUDCq
xs9EX6ihMbo1Kql/WTCqjeTmxvNoLMf3HSL7gjH/zZVGZdL/nT7w6vLWomBQ
AlWVVbE0Xr1zP5NbEozH4y8i5sTQ0HedZazMC4Z0ppMcQ/pNmfCt/0nVBOPc
2Zju4gjST/ESnZnnwRhOmKjZziXzUbHVvT0QjOM1u8+soWi4/BwZmSsVAt9q
kURHFxJvp5L9jEPwMVwrIlGf9OsnRLcz+SHIFprQzf86iKfRTe/FFEKxsZP6
pyJ6EHtepZxYeTEUh91NtnJWDWLDNL3x+VgoOmVzZHeXDmBdjZfwascw9Bw1
5ZzdPoBoJ69VS5rCkBHLxB5t6EekavDKn5rnIfczTdhtXz9uRtSujL15HsaR
ySzrBgGWPTl/pnQOFxc0yhvcDQV47tgizRXlQnqN6rM1uwTgzpB7YCZG4jqG
d3r1BRjaVjJvYD4XOVdOdFnpCtCQK7gnK8PFw8lyC/3NApy7sq83VJmLt8di
s0VXCdBkt8Rq7w4uKL9Km+BpPsJ+nPy5dBcXtMo0tWWKD+3Egjt9BlyYLD3P
GvzGR1qryViQMRfb/TXmWY3ywTLgxP1zgAtHj8PR6wb4UFn78ZmMHReH/vys
2Pqaj3cN670/2ZP8uvcohLfzEXeSvbzgBBd3uNv+02njYzp50WkTJy6mJLcc
vvmcjzZJo9kcdy72xEpFnannIyLncq6xBxdbMuIiFGr50DN5f2ixFxfP26Vc
2qr5yAoLSM/zJvnLvGnUecDH8ZX1ppQvFynNIfsHy/lY/EBqZLc/F5URX4pu
lPLReMQuSZrFxYkle34cKOYjZDxL/yObC5v0D8rCRXz8H1LFHXI=
       "]]},
     Annotation[#, "Charting`Private`Tag$648533#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263609670712*^9, 3.480264091847402*^9, 
  3.480264219397868*^9, 3.480692381982799*^9, 3.481568304979225*^9, 
  3.662626226196561*^9, 3.799212569106269*^9, 3.7992128541521072`*^9, 
  3.814193964415565*^9, 3.814249663862363*^9, 3.832246936418186*^9, 
  3.832403814336179*^9, 3.832579199861557*^9, 3.889696218876823*^9, 
  3.890119010714788*^9},
 CellLabel->
  "Out[197]=",ExpressionUUID->"4136d462-acac-44c4-8ed8-2f17db628257"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9124418416937872`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0068007634327481815`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fz", "[", 
          RowBox[{"BM", ",", "z"}], "]"}], "-", 
         RowBox[{"fz", "[", 
          RowBox[{"BM", ",", 
           RowBox[{"z", "+", "0.015"}]}], "]"}]}], ")"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264827573757*^9, 3.480264835420212*^9}, 
   3.480265037916628*^9, 3.480693722607716*^9, 3.8324026736607723`*^9, 
   3.8324027539305143`*^9, 3.832402801536236*^9, {3.832402967182905*^9, 
   3.8324029686295*^9}, 3.832403173304596*^9},
 CellLabel->
  "In[198]:=",ExpressionUUID->"669c2f71-30fd-4ee2-a1be-27ec0e3f0c0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9124418416935745`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006800761661278228`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.832403825104856*^9, 3.8325792081685963`*^9, 
  3.889696222981332*^9, 3.890119014689156*^9},
 CellLabel->
  "Out[198]=",ExpressionUUID->"1249b68e-60a2-49ab-8d76-f4dd29f61c7b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}},
 CellLabel->
  "In[199]:=",ExpressionUUID->"31db6a62-ff27-4e38-bd76-ac28d9c01d8b"],

Cell[BoxData["0.006800761661278228`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480265633025037*^9, 3.480693092364389*^9, 3.481568926517033*^9, 
  3.662626522160326*^9, 3.799212569150943*^9, 3.799212854211009*^9, 
  3.8141939644854813`*^9, 3.814249894404585*^9, 3.8322469367420607`*^9, 
  3.8324038251723127`*^9, 3.8325792082292747`*^9, 3.88969622303761*^9, 
  3.890119014732283*^9},
 CellLabel->
  "Out[199]=",ExpressionUUID->"82c2f79c-aa15-456e-9f85-5d0204112fa4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"fe6f9ed8-6623-4eef-97b8-c489a8a5923b"],

Cell[BoxData["0.9124418416935745`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480265633047605*^9, 
  3.4806930923900967`*^9, 3.481568926569429*^9, 3.6626265222042217`*^9, 
  3.799212569158848*^9, 3.799212854257913*^9, 3.814193964521812*^9, 
  3.814249894411303*^9, 3.832246936821683*^9, 3.832403825184843*^9, 
  3.832579208238537*^9, 3.8896962230415277`*^9, 3.890119014749229*^9},
 CellLabel->
  "Out[200]=",ExpressionUUID->"c9cf63f7-7554-4fc1-8191-c8f3ae0c11e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"97af3af2-c4ae-4e04-a6f7-b5103efeb3a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVyWlM0wcAhvGu1BGwEo7WQamiiIJDVA5xQrtXlKJcCgxUohyDAhtU6NgY
IFe5oQiaUBCmbNMFJ3boMByCtRtmRbGoK4EqV2TlKrS0/QtClgCZ+/Dk9+HZ
GZcWlkAmkUisD/3v8o1uu7yTOjaJZG7hZcz/fKIlULLc54znrgtbfbmtaP8l
ibzpHQvVabTFR3VSmGf+e+KqgIOvxkWKEnEfgjQsbwU3CFE5zdycNy+Q7XQu
IVgfCoZngOGabBCHvLhJZ3gRsCky280OUeK2b0XXLo9IpNMvsZvpo/jBU9MU
sHABDkle6+vtE5AcD3kbcDAWQ84ebVmCSZSpO+sHzeMwnRxjTWGrIJP4pfAU
8Rha2SyLfjkFGWXF1L0yAbldVfJO/xns8G9TnE9Mgk/hsyizoVnoJXUd9bu+
xtz0M+tiNzVsXMr+dP84BdR/7DfUjfOgWNTXr7/lYUUidr4/vQCuw6vKkcZU
RCcKH8ZTtDBnmA5WsfgQX/7ITeKwiDtHehfdmd9gn1RrkDN0SD27waw2S8dI
T4O4bLMetAPytty1dMRQH3FsJ/TI+HFfRMbotyCzLta4+hpgRKVR7eTfwT+c
zuutNSDI4qpCIc7A4a5Qo2sKAzL+vr7GqPgee0qjub+SCQxUu3jTMzOx+DJS
tdeZwITqiwrrM1m4cncsKoxDwNaTND9wIhuhMwZhQgQBr+Os+58cuoR+xl8z
nEgCVmpqSYplDopaSlafhhFgVMXz+ORcmKxtNYn0ITAmOxWfr8rFrb3dasKR
QF5P/x/20jzUOqZ62xoTCGp9fiDrt3zcOqvfcnrMAOXh2HtKYQEWNo6OZ4oN
8Jtk71hiC2C6jaOU8Q0oMNTxC+4J4PKw4/FRDwPuTHQsKZmF2JF8SsRT66Hu
byCViwqRbVIpOxeuxyZyn8ibUoSpot7YF090+OxI54OTeUUYeuLzZeJ2HS4E
pxrtXP7w5y0XczIXEdXKH1uPK0b8O1359GstMqiebPexYoSHMEqbHbVI7uLs
uRhYAh2Vrl0RaHAa246ld5eg9W65JmB8AYF9XXOvDpaikcSXvndagEPjDZrb
z6XY3kTf31Q4D1qKr1xrXYaN0erhkQE1lm3a29OvlCEtRWdZy1SjjZa6e329
DH5D+11bsudQaqaxm8woxxaK1W2yfBae4Q9uPp0px/AI09Tr01lsNLBajWMq
8LuZFUmWP4POnhqNpbIC51k+5rkj0wh0cm6z51Qi8v3wdY9j01gVCUlVjytR
0Kdaqrk5BUGwx+tVFyGYw6vSN2ZTIESeadKfhFgJIoQdeSr8B+ndzKk=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$696422#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.0842951750980083`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVyWlM0wcAhvGu1BGwEo7WQamiiIJDVA5xQrtXlKJcCgxUohyDAhtU6NgY
IFe5oQiaUBCmbNMFJ3boMByCtRtmRbGoK4EqV2TlKrS0/QtClgCZ+/Dk9+HZ
GZcWlkAmkUisD/3v8o1uu7yTOjaJZG7hZcz/fKIlULLc54znrgtbfbmtaP8l
ibzpHQvVabTFR3VSmGf+e+KqgIOvxkWKEnEfgjQsbwU3CFE5zdycNy+Q7XQu
IVgfCoZngOGabBCHvLhJZ3gRsCky280OUeK2b0XXLo9IpNMvsZvpo/jBU9MU
sHABDkle6+vtE5AcD3kbcDAWQ84ebVmCSZSpO+sHzeMwnRxjTWGrIJP4pfAU
8Rha2SyLfjkFGWXF1L0yAbldVfJO/xns8G9TnE9Mgk/hsyizoVnoJXUd9bu+
xtz0M+tiNzVsXMr+dP84BdR/7DfUjfOgWNTXr7/lYUUidr4/vQCuw6vKkcZU
RCcKH8ZTtDBnmA5WsfgQX/7ITeKwiDtHehfdmd9gn1RrkDN0SD27waw2S8dI
T4O4bLMetAPytty1dMRQH3FsJ/TI+HFfRMbotyCzLta4+hpgRKVR7eTfwT+c
zuutNSDI4qpCIc7A4a5Qo2sKAzL+vr7GqPgee0qjub+SCQxUu3jTMzOx+DJS
tdeZwITqiwrrM1m4cncsKoxDwNaTND9wIhuhMwZhQgQBr+Os+58cuoR+xl8z
nEgCVmpqSYplDopaSlafhhFgVMXz+ORcmKxtNYn0ITAmOxWfr8rFrb3dasKR
QF5P/x/20jzUOqZ62xoTCGp9fiDrt3zcOqvfcnrMAOXh2HtKYQEWNo6OZ4oN
8Jtk71hiC2C6jaOU8Q0oMNTxC+4J4PKw4/FRDwPuTHQsKZmF2JF8SsRT66Hu
byCViwqRbVIpOxeuxyZyn8ibUoSpot7YF090+OxI54OTeUUYeuLzZeJ2HS4E
pxrtXP7w5y0XczIXEdXKH1uPK0b8O1359GstMqiebPexYoSHMEqbHbVI7uLs
uRhYAh2Vrl0RaHAa246ld5eg9W65JmB8AYF9XXOvDpaikcSXvndagEPjDZrb
z6XY3kTf31Q4D1qKr1xrXYaN0erhkQE1lm3a29OvlCEtRWdZy1SjjZa6e329
DH5D+11bsudQaqaxm8woxxaK1W2yfBae4Q9uPp0px/AI09Tr01lsNLBajWMq
8LuZFUmWP4POnhqNpbIC51k+5rkj0wh0cm6z51Qi8v3wdY9j01gVCUlVjytR
0Kdaqrk5BUGwx+tVFyGYw6vSN2ZTIESeadKfhFgJIoQdeSr8B+ndzKk=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$696422#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.0842951750980083`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {49}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGJDBgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gb71C/bgCY0Qu1vtH/+e+XHS75NUHc02WcyzzW7kNkMdU+z/RuuCdVn
W1vs14Ld1WqfJ9QMtKIV6r42+0+SZawn9rZB3dluX6yY6XX0Zru9Cdi9HfZf
NWL6D33tsN8GdnenfTnIWsEuqPu77AGyNMFI
   "], CompressedData["
1:eJwBmQFm/iFib1JlAgAAADEAAAABAAAAAAAAAAAAAAD4AMncqMayP4UqdsrG
vMI/9YH4t2ECzD8uYYLNBZXSP/ZmMh69FNc/F+0rnhZ72z+85jqMuMLfP6G0
2iAb8+E/FtspKg7w4z8VVl4kgdXlP9+kYo3QoOc/rGGR7HZP6T+JfsxfG9/q
P6Y+53KgTew/kb+vizKZ7T+7tGjNVMDuP38tCw/swe8/1qrwlaNO8D/DuIcl
EqnwPyTGYt5Z8PA/1aLrIcsk8T8qRpbA7EbxP56nllB4V/E/Sa9jDFVX8T83
Z2tzkUfxP+U4G8NbKfE/qtBCq/n98D/1eyxXwMbwPy3VRd0KhfA/e2/EgzM6
8D+n4sO7GM/vP2/9LveyHO8/u/Ey+5hf7j9KDRCUAprtP/45jVT4zew/TV3h
RFH96z/ypSwQsynrP3ksZeqSVOo/vAjN1zd/6T+E67BavaroPzcXB8cW2Oc/
Hk9itBII5z+AlclNXjvmP5AE3OOIcuU/HQLQHweu5D95fSoYNu7jP9b1cRVe
M+M/pyZmgbV94j8c9smt
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662626531280512*^9, 3.799212569233944*^9, 
  3.7992128623662033`*^9, 3.81419397341387*^9, 3.814249902180788*^9, 
  3.8322469449915*^9, 3.8324038351953297`*^9, 3.832579216126466*^9, 
  3.889696226391469*^9, 3.890119017980686*^9},
 CellLabel->
  "Out[201]=",ExpressionUUID->"e1a53a14-f82a-4fd1-b324-0eb351c24220"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "BM", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "BM", "]"}], "[", 
          RowBox[{"z", "+", "0.015"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, 3.662623730198477*^9, {
   3.662846418987355*^9, 3.6628464235824213`*^9}, 3.799212531148233*^9},
 CellLabel->
  "In[202]:=",ExpressionUUID->"0639adc6-6737-4ad7-851a-9a0285bb4887"],

Cell[BoxData["73712.42445548202`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626265314140587`*^9, 3.662846424961239*^9, 3.799212569296418*^9, 
   3.7992128624416113`*^9, 3.814193973477653*^9, 3.8142499022519827`*^9, 
   3.832246945092414*^9, 3.832403835328871*^9, 3.832579216243937*^9, 
   3.889696226477797*^9, 3.890119018033868*^9},
 CellLabel->
  "Out[202]=",ExpressionUUID->"b1e2ed89-85fe-41e0-9c6c-80a2cb7d6851"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BM", "]"}], ",", 
      RowBox[{"zmax", "[", "BM", "]"}], ",", 
      RowBox[{"fmax", "[", "BM", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BM", "]"}], ",", 
      RowBox[{"zmax2", "[", "BM", "]"}], ",", 
      RowBox[{"fmax2", "[", "BM", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.481567816726468*^9, 
  3.481567818793173*^9}, {3.4815681797948217`*^9, 3.48156818542627*^9}, {
  3.662623414299822*^9, 3.6626234188219624`*^9}, {3.799212531148889*^9, 
  3.799212531149397*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"62f882dc-4d25-432d-8550-6cb963756cf7"],

Cell[BoxData[
 TagBox[GridBox[{
    {"73712.42445548202`", "0.006361538984579861`", "1.0843322046660526`"},
    {"73712.42445548202`", "0.006800761661278228`", "0.9124418416935745`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.481567825373666*^9, 3.481568186322205*^9, 3.4815689269394617`*^9, 
  3.6626265314412413`*^9, 3.6628464281771193`*^9, 3.799212569310655*^9, 
  3.7992128624495077`*^9, 3.814193973503799*^9, 3.814249902281413*^9, 
  3.832246945130382*^9, 3.832403835374387*^9, 3.8325792162728662`*^9, 
  3.8896962264827423`*^9, 3.890119018038314*^9},
 CellLabel->
  "Out[203]//TableForm=",ExpressionUUID->"49ffde4e-0480-411b-9220-\
80521af23213"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
10x10 magnets 20 mm apart (between faces) with BOSEM coil per pitch magnets \
on top mass and UIM of quad\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.480700176213991*^9}, {
  3.481565949718953*^9, 3.481565983045248*^9}, {3.481566089551104*^9, 
  3.48156609404573*^9}, {3.799224311732572*^9, 
  3.799224314556679*^9}},ExpressionUUID->"82549c51-83fb-4a0c-ace5-\
8082f6200c29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8Vc0fB3ASiSRlS7ZKSkmJ0sZHRaEIJUkUZQlJC3HvPede3FK2HipR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{All, All},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"BO10", ",", "z"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"BO10", ",", 
          RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.480263536719996*^9, 3.480263537125444*^9}, {3.480263833591049*^9, 
   3.480263861642727*^9}, {3.48026393264508*^9, 3.48026393627591*^9}, {
   3.480264005377029*^9, 3.4802640754825783`*^9}, {3.4802641643969183`*^9, 
   3.480264165325192*^9}, {3.4806937485908546`*^9, 3.480693765401557*^9}, {
   3.481566119159527*^9, 3.481566119550919*^9}, 3.4815661573148108`*^9, 
   3.4815682113946342`*^9},
 CellLabel->
  "In[204]:=",ExpressionUUID->"9ba64c0b-d7f4-4cf4-aebd-e3d6ae2a9ab6"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k8VN8bB3ASyZKULSmSlJIopfrio6JQ1pIkCllC0kLMzJ0ZTJutbypR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       "]]},
     Annotation[#, "Charting`Private`Tag$696633#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263682317749*^9, 3.4802639921266336`*^9, 
  3.480264150342636*^9, 3.480265704722389*^9, 3.480693170005075*^9, 
  3.481566223913733*^9, 3.662626577706636*^9, 3.799212569353179*^9, 
  3.799212862488722*^9, 3.8141939735104723`*^9, 3.8142499421104794`*^9, 
  3.832246988140246*^9, 3.8324038869150352`*^9, 3.832579256002413*^9, 
  3.8896962432151403`*^9, 3.890119034367679*^9},
 CellLabel->
  "Out[204]=",ExpressionUUID->"e8bad392-db5f-454c-90f4-abb2b61b1d65"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.6263677836045267`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.007300967534849954`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fz", "[", 
          RowBox[{"BO10", ",", "z"}], "]"}], "-", 
         RowBox[{"fz", "[", 
          RowBox[{"BO10", ",", 
           RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264796714196*^9, 3.4802647976619177`*^9}, {
   3.480264858240645*^9, 3.4802648706070433`*^9}, 3.480265044282831*^9, 
   3.48069378671309*^9, {3.48156613564054*^9, 3.4815661608653307`*^9}, 
   3.481568221803894*^9, 3.832402677676004*^9, 3.8324027547309847`*^9, 
   3.8324028025348997`*^9, 3.8324029753996363`*^9, 3.832403174244034*^9},
 CellLabel->
  "In[205]:=",ExpressionUUID->"d0eeecc0-a2d1-45fd-96cf-dfc5a8a565b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.6263677836057786`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007300972176217677`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480266848202059*^9, 3.4806936239876947`*^9, 
  3.4815667132643127`*^9, 3.662626914105783*^9, 3.799212569394408*^9, 
  3.79921286249854*^9, 3.81419397353841*^9, 3.8142502186175823`*^9, 
  3.832246988200233*^9, 3.832403900089319*^9, 3.832579267181753*^9, 
  3.889696247138883*^9, 3.890119038197027*^9},
 CellLabel->
  "Out[205]=",ExpressionUUID->"64379b5f-5ccf-429f-b9c5-312324c2398b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}, {3.4802647989584846`*^9, 3.480264799487084*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"bb35c655-1d44-477b-ac6b-b958d5fc1ff1"],

Cell[BoxData["0.007300972176217677`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480266848415159*^9, 3.480693624043004*^9, 3.481566713311575*^9, 
  3.662626914153386*^9, 3.7992125694021072`*^9, 3.799212862534831*^9, 
  3.814193973544565*^9, 3.814250218659563*^9, 3.8322469882336197`*^9, 
  3.8324039001595*^9, 3.832579267245818*^9, 3.8896962471631823`*^9, 
  3.890119038250575*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"5e973f6f-e79a-4b6d-b047-ccefabe407c6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}, {3.480264800442628*^9, 3.480264800914262*^9}},
 CellLabel->
  "In[207]:=",ExpressionUUID->"4ece9598-59a5-4f96-beb1-ee15b0d78481"],

Cell[BoxData["1.6263677836057786`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480266848444786*^9, 
  3.4806936240713797`*^9, 3.481566713335513*^9, 3.662626914178856*^9, 
  3.799212569438169*^9, 3.7992128625428247`*^9, 3.814193973569758*^9, 
  3.8142502186652203`*^9, 3.832246988310131*^9, 3.832403900173805*^9, 
  3.832579267262738*^9, 3.8896962471910763`*^9, 3.890119038256975*^9},
 CellLabel->
  "Out[207]=",ExpressionUUID->"6d6d1fbb-047d-4c85-99b7-44bff4a8ab9d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO10", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, 3.6626237826767893`*^9, 3.662623817129786*^9, {
   3.6626238562340107`*^9, 3.662623857953149*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"3162c008-6aed-430c-8662-2321d7d5e472"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AAOCro4J3Pt2pS7z0
xis/qg0Qjc6NtT+0o2cCBfI8P/+JjRp2bMY/EHf5R5CART/Yc5vXap3QP0zr
PDvRZEw/Na8lxyvd1T95KFhlTe9RP8zlGwigfNs/NTpkZ1ZsVT9vc8GIdFPg
P6ZEiLcjNFk/NDeInUYS4z+aNuudSupcP+0jWLRZtOU/vENQ30owYD8TPyC0
IRnoP4botpbSEGI/wq5+zl2e6j/FvEZrbNFjP/NLCpAe5ew/xQT2CjOJZT+K
UOEusAzvPyBJsdFbZmc/faZOK9yl8D/vvJW1liNpPxhZuBySpvE/GS2GwDMG
az/pQDkTpq/yPwQRlpb932w/pPxYcwam8z9kJM+J2ZluP7S4qBYIf/Q/EBoK
0os8cD/2HhXxHFz1P6g5we0zHHE/FAV0WMcc9j9uV/4cjQ5yP0BAfXti3vY/
FC/LsXz8cj+tz2Ut8Yz3P3WeLFV12nM/pfaReM8h+D8DDBQMH8t0Pz6f44jp
s/g/TBGQ0dGrdT93YmQs8y35P3XQm/waiHY/ryc5tSmY+T/MjS07FXd3Pxfe
vzJ0/Pk/3eJTiBhWeD/fW9KiKkz6Pxs2AOnMR3k/ZhsO6aOT+j86QzyvFzV6
P1eCYVT7yvo/E+gMhGsSez+FZYDTpPH6PxqLY2xwAnw/JKGYS8wN+z/bxU5j
fuJ8P/IFpDCGG/s/fbrJvyK+fT+/brAmmh37P0ytyi94rH4/lA2LZZkT+z/W
N2Cu1op/P3ENZJhA//o/RuA9IPM9gD8yc+3Pxt36P3/wlXB/roA/gZjHyF+0
+j+o3bXz1hyBPxZUkXLVgvo/6MmYAIeUgT+lEcguxEP6PwUCxpQ7BII/1S9B
O8UA+j84ObaySH2CP2YTGAIJsPk/XE1uAyH0gj9bgEhmS1n5P12tcNv9YoM/
X2EQBl4C+T91DDY9M9uDPxnqB1pCnvg/ardFJm1LhD/gPnjb9jv4P08/HUJy
uYQ/hGvxfqfX9z9LxrfnzzCFP1M2JywJZ/c/JJmcFDKghT/elPQo9fr2PxRr
RMvsGIY/nuiUeCeD9j/0GbS0co+GP+K+MB5rC/Y/sRRuJf39hj9e5a7vUpr1
P4UO6x/gdYc/RWjNFJce9T82VLKhx+WHPw28uxR8qvQ//pg8rQdfiD/mGdNb
biz0P7a6jusS1og/GqxHAsuw8z9LKCuxIkWJP1b8Y+jaPfM/95SKAIu9iT+B
B49P/MHyP4BNNNf3LYo/zjHlJ0NP8j/xlDZvvp+KP3EtSARM3PE/de3JBA==

                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$742608#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.6947270880981902`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AAOCro4J3Pt2pS7z0
xis/qg0Qjc6NtT+0o2cCBfI8P/+JjRp2bMY/EHf5R5CART/Yc5vXap3QP0zr
PDvRZEw/Na8lxyvd1T95KFhlTe9RP8zlGwigfNs/NTpkZ1ZsVT9vc8GIdFPg
P6ZEiLcjNFk/NDeInUYS4z+aNuudSupcP+0jWLRZtOU/vENQ30owYD8TPyC0
IRnoP4botpbSEGI/wq5+zl2e6j/FvEZrbNFjP/NLCpAe5ew/xQT2CjOJZT+K
UOEusAzvPyBJsdFbZmc/faZOK9yl8D/vvJW1liNpPxhZuBySpvE/GS2GwDMG
az/pQDkTpq/yPwQRlpb932w/pPxYcwam8z9kJM+J2ZluP7S4qBYIf/Q/EBoK
0os8cD/2HhXxHFz1P6g5we0zHHE/FAV0WMcc9j9uV/4cjQ5yP0BAfXti3vY/
FC/LsXz8cj+tz2Ut8Yz3P3WeLFV12nM/pfaReM8h+D8DDBQMH8t0Pz6f44jp
s/g/TBGQ0dGrdT93YmQs8y35P3XQm/waiHY/ryc5tSmY+T/MjS07FXd3Pxfe
vzJ0/Pk/3eJTiBhWeD/fW9KiKkz6Pxs2AOnMR3k/ZhsO6aOT+j86QzyvFzV6
P1eCYVT7yvo/E+gMhGsSez+FZYDTpPH6PxqLY2xwAnw/JKGYS8wN+z/bxU5j
fuJ8P/IFpDCGG/s/fbrJvyK+fT+/brAmmh37P0ytyi94rH4/lA2LZZkT+z/W
N2Cu1op/P3ENZJhA//o/RuA9IPM9gD8yc+3Pxt36P3/wlXB/roA/gZjHyF+0
+j+o3bXz1hyBPxZUkXLVgvo/6MmYAIeUgT+lEcguxEP6PwUCxpQ7BII/1S9B
O8UA+j84ObaySH2CP2YTGAIJsPk/XE1uAyH0gj9bgEhmS1n5P12tcNv9YoM/
X2EQBl4C+T91DDY9M9uDPxnqB1pCnvg/ardFJm1LhD/gPnjb9jv4P08/HUJy
uYQ/hGvxfqfX9z9LxrfnzzCFP1M2JywJZ/c/JJmcFDKghT/elPQo9fr2PxRr
RMvsGIY/nuiUeCeD9j/0GbS0co+GP+K+MB5rC/Y/sRRuJf39hj9e5a7vUpr1
P4UO6x/gdYc/RWjNFJce9T82VLKhx+WHPw28uxR8qvQ//pg8rQdfiD/mGdNb
biz0P7a6jusS1og/GqxHAsuw8z9LKCuxIkWJP1b8Y+jaPfM/95SKAIu9iT+B
B49P/MHyP4BNNNf3LYo/zjHlJ0NP8j/xlDZvvp+KP3EtSARM3PE/de3JBA==

                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$742608#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.6947270880981902`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {46}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGI9BgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gaovY1Qe5ug9jbbv+GaUH22tcV+Ldj+Vvs8oWagUa1Qd7TZf5IsYz2x
tw3qnnb7YsVMr6M32+1NwO7qsP+qEdN/6GuH/Taw+zrty0HWCHZB3dllDwCe
S7Qu
   "], CompressedData["
1:eJwBgQF+/iFib1JlAgAAAC4AAAABAAAAAAAAAAAAAAA4ioxNc4m7P2Q0/HmX
eMs/Or5lU3eF1D8R1V6ZujXbP5iJJ9yb4uA/w5audDYW5D8G/89kIzLnP0eF
V+MXM+o/egcvBg8W7T/x39TDSdjvP736IaesO/E/pV+NnIx48j/4nril2KHz
P+sZapvKtvQ/a62a68C29T8kt2mAPaH2P52zt5Hkdfc/YNVJaXs0+D83xyZL
59z4P5uZCXosb/k/WK98dG3r+T/JmJ9A6lH6P28p+e//ovo/8htLKSjf+j/H
G+Cy+Ab7P9Ftg9giG/s/bASuxHIc+z+CkIj9zQv7P1fF1lgy6vo/T2EOJLO4
+j/DvEY2sir6P4S7qTCaa/k//jhFb56F+D8koFeRMAf4PzNzks68gvc/hFkZ
5WP59j8ogVIqNGz2P29lwbcn3PU/b5UqSCNK9T9w2XoH9rb0Pw278INZI/Q/
rdlrh/KP8z9YNsH1Uf3yPxD/Wh/2a/I/u8Ks/Evc8T9Ks8D/
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626269251419783`*^9, 3.799212569519064*^9, 
  3.799212871180344*^9, 3.8141939828025293`*^9, 3.814250227688661*^9, 
  3.832246999733964*^9, 3.832403911241786*^9, 3.832579277028329*^9, 
  3.88969625110928*^9, 3.890119042060802*^9},
 CellLabel->
  "Out[208]=",ExpressionUUID->"37de60ad-88c7-467b-a95b-fb99ce9cba80"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "BO10", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "BO10", "]"}], "[", 
          RowBox[{"z", "+", "0.030"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO10", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.66262382061903*^9, 
   3.662623864201857*^9}, 3.799212531150227*^9, 3.799224399347836*^9},
 CellLabel->
  "In[209]:=",ExpressionUUID->"6201ac92-f07c-47ff-8558-6d88b251ed7c"],

Cell[BoxData["194679.0041486842`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662626925257122*^9, 3.7992125695508966`*^9, 3.7992128712481937`*^9, 
   3.7992244031562033`*^9, 3.814193982869981*^9, 3.8142502277535467`*^9, 
   3.832246999832946*^9, 3.832403911342226*^9, 3.8325792771095123`*^9, 
   3.889696251178855*^9, 3.8901190421162453`*^9},
 CellLabel->
  "Out[209]=",ExpressionUUID->"6fa2554d-4158-4723-89f2-d785f2755751"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BO10", "]"}], ",", 
      RowBox[{"zmax", "[", "BO10", "]"}], ",", 
      RowBox[{"fmax", "[", "BO10", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BO10", "]"}], ",", 
      RowBox[{"zmax2", "[", "BO10", "]"}], ",", 
      RowBox[{"fmax2", "[", "BO10", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.481567816726468*^9, 
  3.481567818793173*^9}, {3.662623447715229*^9, 3.662623458100728*^9}, {
  3.7992125311509438`*^9, 3.799212531151538*^9}},
 CellLabel->
  "In[210]:=",ExpressionUUID->"4e67aaea-56ba-4a55-95cd-e7b96b1a29b4"],

Cell[BoxData[
 TagBox[GridBox[{
    {"61049.691287075046`", "0.007195845077775158`", "1.6948582028560362`"},
    {"61049.691287075046`", "0.007300972176217677`", "1.6263677836057786`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.481567825373666*^9, 3.662626925288307*^9, 3.799212569589025*^9, 
  3.7992128712563353`*^9, 3.814193982876007*^9, 3.814250227761793*^9, 
  3.832246999869734*^9, 3.83240391135404*^9, 3.832579277118725*^9, 
  3.8896962511844053`*^9, 3.890119042122018*^9},
 CellLabel->
  "Out[210]//TableForm=",ExpressionUUID->"2d79bb2d-30c2-42d2-8b40-\
57d19870ccff"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
6x2 magnets 24 mm apart with AOSEM coil per pitch magnets on top mass and UIM \
of quad\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.480700176213991*^9}, {
   3.481565949718953*^9, 3.481565983045248*^9}, {3.481566089551104*^9, 
   3.48156609404573*^9}, 3.4815663420577517`*^9, {3.4815664004646187`*^9, 
   3.4815664245209103`*^9}},ExpressionUUID->"27fb99ae-188f-4fd3-a1df-\
84be7dfb2362"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nlUjG8UB/CKIqKQtEhRSEjCL5S+lqKylHZp06oSLTPzzjRpM0VlSRhK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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{All, All},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"AODL", ",", "z"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"AODL", ",", 
          RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.480263536719996*^9, 3.480263537125444*^9}, {3.480263833591049*^9, 
   3.480263861642727*^9}, {3.48026393264508*^9, 3.48026393627591*^9}, {
   3.480264005377029*^9, 3.4802640754825783`*^9}, {3.4802641643969183`*^9, 
   3.480264165325192*^9}, {3.4806937485908546`*^9, 3.480693765401557*^9}, {
   3.481566119159527*^9, 3.481566119550919*^9}, 3.4815661573148108`*^9, {
   3.481566453354445*^9, 3.481566453404786*^9}, 3.481568229036901*^9},
 CellLabel->
  "In[211]:=",ExpressionUUID->"34044e2a-61a5-4bfa-b5da-0a2bd8a8ebc4"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VG8UB3AUbfpRSSJRSdokLSryLanQQvZkKWsUWWbmzhjZGgotUk2R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       "]]},
     Annotation[#, "Charting`Private`Tag$742813#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263682317749*^9, 3.4802639921266336`*^9, 
  3.480264150342636*^9, 3.480265704722389*^9, 3.480693170005075*^9, 
  3.481566223913733*^9, 3.48156671551313*^9, 3.4815668538117313`*^9, 
  3.481567024102026*^9, 3.6626269381991873`*^9, 3.79921256959971*^9, 
  3.799212871295436*^9, 3.814193982902213*^9, 3.8142502401384497`*^9, 
  3.832247015074099*^9, 3.8324039250369787`*^9, 3.832579289160647*^9, 
  3.88969625593816*^9, 3.890119046750605*^9},
 CellLabel->
  "Out[211]=",ExpressionUUID->"c8801eee-0aab-4d13-9863-6b20ebe954fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.030257769468565232`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005750794119386763`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FindMinimum", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fz", "[", 
          RowBox[{"AODL", ",", "z"}], "]"}], "-", 
         RowBox[{"fz", "[", 
          RowBox[{"AODL", ",", 
           RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0.005"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264796714196*^9, 3.4802647976619177`*^9}, {
   3.480264858240645*^9, 3.4802648706070433`*^9}, 3.480265044282831*^9, 
   3.48069378671309*^9, {3.48156613564054*^9, 3.4815661608653307`*^9}, {
   3.481566453424974*^9, 3.481566453476396*^9}, 3.481568237964075*^9, 
   3.832402681530348*^9, {3.832402715315731*^9, 3.832402743578886*^9}, 
   3.832402982019595*^9, {3.832403175533519*^9, 3.832403194356689*^9}},
 CellLabel->
  "In[212]:=",ExpressionUUID->"48c13e77-6162-429e-b30a-a6280ec31a0b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030257769468521954`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005750788020102526`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480266848202059*^9, 3.4806936239876947`*^9, 
  3.481566715791988*^9, 3.481566854139357*^9, 3.481567149415079*^9, 
  3.662627026022953*^9, 3.7992125696385307`*^9, 3.799212871306295*^9, 
  3.8141939829079647`*^9, 3.8142503178343554`*^9, 3.832247015122919*^9, 
  3.832403926202759*^9, 3.8325792902383223`*^9, 3.8896962563748903`*^9, 
  3.890119047166738*^9},
 CellLabel->
  "Out[212]=",ExpressionUUID->"838b9532-69e4-4e51-ba54-66ab0a697a32"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}, {3.4802647989584846`*^9, 3.480264799487084*^9}, {
   3.4815664535103188`*^9, 3.481566453543878*^9}},
 CellLabel->
  "In[213]:=",ExpressionUUID->"7407c218-030e-4a0a-95c7-515136a82998"],

Cell[BoxData["0.005750788020102526`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480266848415159*^9, 3.480693624043004*^9, 3.481566716026739*^9, 
  3.481566854410817*^9, 3.481567149455831*^9, 3.662627026053196*^9, 
  3.7992125696471977`*^9, 3.7992128713423853`*^9, 3.814193982929804*^9, 
  3.8142503178793287`*^9, 3.832247015162754*^9, 3.832403926271224*^9, 
  3.8325792902780523`*^9, 3.8896962563797693`*^9, 3.890119047174469*^9},
 CellLabel->
  "Out[213]=",ExpressionUUID->"39049fa7-064c-4361-b2a6-c29b65217503"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}, {3.480264800442628*^9, 3.480264800914262*^9}, {
   3.481566453577557*^9, 3.4815664536106653`*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"23050121-1a11-4e89-b4ab-3962d9f51f56"],

Cell[BoxData["0.030257769468521954`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480266848444786*^9, 
  3.4806936240713797`*^9, 3.481566716286377*^9, 3.481566854706884*^9, 
  3.481567149468693*^9, 3.662627026079937*^9, 3.7992125696830797`*^9, 
  3.799212871353738*^9, 3.8141939829366283`*^9, 3.81425031791743*^9, 
  3.8322470152351723`*^9, 3.8324039262842407`*^9, 3.8325792902889843`*^9, 
  3.889696256390524*^9, 3.890119047187598*^9},
 CellLabel->
  "Out[214]=",ExpressionUUID->"a72fda66-9778-4123-9d02-a4b0058e1fe0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623917008511*^9, 3.662623918671576*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"c4ef1199-6327-463a-b14b-bc193aa91401"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXs8FAYAB/ALp099KHGWsCFUi6v7DJfHnR8h5rHaGSYseSTzuqkbyftx
7k7e57rjHqn1sMZ2Pt5dV/Jh4+pj7g8yHzHVRievNJ8Utv3x/XytYtIY8VoE
AoH2n/9fFXdb5Pgt0AkEj5W+fCv3yaYAxeqAHXgvb7MKdkSj7UaCFnGFhqXd
vzz/5EcmDDLe+Vbl+2COcfNu9+1MBGpobiNxgeB3SXUPUPJx6dDX8UGLX2Kl
RhI8418MJ9e4hNDkEAgWbdQ+uhzc8uZ0WjuGY4HBrXy3XIZ6qkbi/yoSP9DD
mnbfqoTC69SUPyUaC3zx9KOsarBnOwRqgxj0FTunh1Jq0a84kZQ8Eov1qGBR
VCsf/Tr/7HTgxkNZEua59JEAlp/LRyLOJcAFbXb38q5iUVHXLrBORJNT4qMj
nULsI7MfOugmIes9b+vavAg6ewSCjalkqCNn+rW36hFnM8wdF6XiMGX94OiL
BhiY7lSX0ZjoqRivtOgV445L72sH8+/g7exZu3BBgtSwTfPyXen4bWqH6RMT
KUhHVfLsD+k4b654OyyRgiW1D2H9cQFn4+hco20yaOuR9CxUF8FoTxmyZcgQ
uKdqZOQuCzGaQXsztgys3xs+mHK+x4MIcm3HDRkel5PdjDMycMpCi0FqlmFy
JphjEpoJT3aRi6pRBjMqYe6x7yUY12z5bCuQwdWL9vNepyzYbZdb1QXJYDSr
V5xkeBlDS1cyB/RlMC2LTWZqZeOeSnj5YZcUE/1fxObOZGM55vTNPyOkyOkZ
fLBfmYMuVXha3lsJApuHjmb+lIvmwpD1tSwJRo9Ft4zy8qC0OS933RLjxDTd
8g09HwTip4dtmGLkLdUx81ry8eysguD9vAF3JtvfjJoXQFdJvM8NbsDsoJBQ
yi9AH+P0kG9rPYhaA3w3nUI4B+gfebq3Hs4uHa1+OYW4kugXZZciQmRQqrbV
aiHGrr9qONgnRFQzc2IjpgjuLfODXtZCsPSodIeJIky5dpYZs67i206fAykB
xcj2sB3PVgtwEh8fT+8uBnndsKXKQYCAgc6/hyklINYVHHfi1MFGJCZ9dq0E
JSvfGD+d44OU5K2aN2EjutvxHNmDj9V9bW3plWzkpjyZtRTXQk5Ktd3YYOPi
s80yEbEWJbs0FtOsUrgkv7YOia8B9avWxl9flqLqr/djQ+pqbAppzdvPcGDf
eIaccawaHT0VGsNRDl4o3U3ar1ch4JCdfL8PF7G9fZqTZlVY4/MIZfe5CKNa
zUlNKpEf5Di2RuZBQTHSnyJVYJlPTVPKeFjV4a2EG5fjX4g+vH4=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$780754#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.030933682923687755`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXs8FAYAB/ALp099KHGWsCFUi6v7DJfHnR8h5rHaGSYseSTzuqkbyftx
7k7e57rjHqn1sMZ2Pt5dV/Jh4+pj7g8yHzHVRievNJ8Utv3x/XytYtIY8VoE
AoH2n/9fFXdb5Pgt0AkEj5W+fCv3yaYAxeqAHXgvb7MKdkSj7UaCFnGFhqXd
vzz/5EcmDDLe+Vbl+2COcfNu9+1MBGpobiNxgeB3SXUPUPJx6dDX8UGLX2Kl
RhI8418MJ9e4hNDkEAgWbdQ+uhzc8uZ0WjuGY4HBrXy3XIZ6qkbi/yoSP9DD
mnbfqoTC69SUPyUaC3zx9KOsarBnOwRqgxj0FTunh1Jq0a84kZQ8Eov1qGBR
VCsf/Tr/7HTgxkNZEua59JEAlp/LRyLOJcAFbXb38q5iUVHXLrBORJNT4qMj
nULsI7MfOugmIes9b+vavAg6ewSCjalkqCNn+rW36hFnM8wdF6XiMGX94OiL
BhiY7lSX0ZjoqRivtOgV445L72sH8+/g7exZu3BBgtSwTfPyXen4bWqH6RMT
KUhHVfLsD+k4b654OyyRgiW1D2H9cQFn4+hco20yaOuR9CxUF8FoTxmyZcgQ
uKdqZOQuCzGaQXsztgys3xs+mHK+x4MIcm3HDRkel5PdjDMycMpCi0FqlmFy
JphjEpoJT3aRi6pRBjMqYe6x7yUY12z5bCuQwdWL9vNepyzYbZdb1QXJYDSr
V5xkeBlDS1cyB/RlMC2LTWZqZeOeSnj5YZcUE/1fxObOZGM55vTNPyOkyOkZ
fLBfmYMuVXha3lsJApuHjmb+lIvmwpD1tSwJRo9Ft4zy8qC0OS933RLjxDTd
8g09HwTip4dtmGLkLdUx81ry8eysguD9vAF3JtvfjJoXQFdJvM8NbsDsoJBQ
yi9AH+P0kG9rPYhaA3w3nUI4B+gfebq3Hs4uHa1+OYW4kugXZZciQmRQqrbV
aiHGrr9qONgnRFQzc2IjpgjuLfODXtZCsPSodIeJIky5dpYZs67i206fAykB
xcj2sB3PVgtwEh8fT+8uBnndsKXKQYCAgc6/hyklINYVHHfi1MFGJCZ9dq0E
JSvfGD+d44OU5K2aN2EjutvxHNmDj9V9bW3plWzkpjyZtRTXQk5Ktd3YYOPi
s80yEbEWJbs0FtOsUrgkv7YOia8B9avWxl9flqLqr/djQ+pqbAppzdvPcGDf
eIaccawaHT0VGsNRDl4o3U3ar1ch4JCdfL8PF7G9fZqTZlVY4/MIZfe5CKNa
zUlNKpEf5Di2RuZBQTHSnyJVYJlPTVPKeFjV4a2EG5fjX4g+vH4=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$780754#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.030933682923687755`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {25}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.0037916666666666667`, 0.004333333333333333, 0.004875, 
   0.005416666666666667, 0.005958333333333334, 0.0065, 0.0070416666666666666`,
    0.0075833333333333326`, 0.008125, 0.008666666666666666, 
   0.009208333333333332, 0.00975, 0.010291666666666666`, 
   0.010833333333333334`, 0.011375, 0.011916666666666666`, 
   0.012458333333333332`, 0.013}}, {{0.}, {0.004980807111936512}, {
   0.009810238162392296}, {0.014346227217215901`}, {0.018464393153341006`}, {
   0.022064704980054188`}, {0.02507593216416842}, {0.02745766837337204}, {
   0.029199977122328285`}, {0.030320906486767236`}, {0.030862268772346026`}, {
   0.0308842021317498}, {0.030459093699435374`}, {0.029665456441492124`}, {
   0.02858268400791406}, {0.02728600390974771}, {0.025843747988008547`}, {
   0.024315097005136864`}, {0.02274929181787214}, {0.021185702162765375`}, {
   0.019654527865652402`}, {0.018177876179563502`}, {0.016771007101224995`}, {
   0.015443590647925323`}, {0.014200880244211496`}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662627027437167*^9, 3.7992125697648478`*^9, 
  3.7992128725071907`*^9, 3.814193984083186*^9, 3.814250319037212*^9, 
  3.832247016694989*^9, 3.8324039275843277`*^9, 3.832579291501952*^9, 
  3.889696256889887*^9, 3.8901190476734457`*^9},
 CellLabel->
  "Out[215]=",ExpressionUUID->"37be146e-c2ce-4543-9125-e968fa9bde8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "AODL", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "AODL", "]"}], "[", 
          RowBox[{"z", "+", "0.030"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AODL", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626238917931423`*^9, 
   3.662623924815764*^9}, 3.662846392788566*^9, 3.799212531152573*^9, 
   3.7992244344427013`*^9},
 CellLabel->
  "In[216]:=",ExpressionUUID->"47b08cef-d50b-43a2-939c-7ef319780418"],

Cell[BoxData["2694.630378958691`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662627027471949*^9, 3.66284639360896*^9, 3.799212569794455*^9, 
   3.7992128725817823`*^9, 3.799224546890793*^9, 3.8141939841405783`*^9, 
   3.814250319101461*^9, 3.832247016796062*^9, 3.832403927701116*^9, 
   3.832579291572542*^9, 3.88969625690911*^9, 3.890119047691423*^9},
 CellLabel->
  "Out[216]=",ExpressionUUID->"4d6a07cf-8468-4d0c-ad25-141e04593a40"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "AODL", "]"}], ",", 
      RowBox[{"zmax", "[", "AODL", "]"}], ",", 
      RowBox[{"fmax", "[", "AODL", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "AODL", "]"}], ",", 
      RowBox[{"zmax2", "[", "AODL", "]"}], ",", 
      RowBox[{"fmax2", "[", "AODL", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.662623496752969*^9, 
  3.66262350152312*^9}, {3.799212531153256*^9, 3.799212531153904*^9}},
 CellLabel->
  "In[217]:=",ExpressionUUID->"3f0f2b2a-e80e-44a7-9ea0-2218c7848732"],

Cell[BoxData[
 TagBox[GridBox[{
    {"1637.373176226694`", "0.0057086431276502595`", 
     "0.030934223187089303`"},
    {"1637.373176226694`", "0.005750788020102526`", "0.030257769468521954`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.662627027501245*^9, 3.662846404962121*^9, 3.799212569833867*^9, 
  3.799212872590466*^9, 3.799223694543845*^9, 3.814193984166407*^9, 
  3.8142503191106377`*^9, 3.832247016831348*^9, 3.832403927720318*^9, 
  3.8325792915801907`*^9, 3.889696256921153*^9, 3.8901190477051067`*^9},
 CellLabel->
  "Out[217]//TableForm=",ExpressionUUID->"d426e8b1-8b6c-468c-9278-\
d205bddf91b4"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Summary
\
\>", "Section",
 CellChangeTimes->{{3.799216876183823*^9, 
  3.799216878453554*^9}},ExpressionUUID->"2a1553c3-fbc1-49a8-a5b4-\
16e3cd7262a5"],

Cell["Numbers for Table 2 of Word document.", "Subsection",
 CellChangeTimes->{{3.799216693820692*^9, 
  3.799216716843322*^9}},ExpressionUUID->"542471c3-8166-4b61-b583-\
dbe9e3bb3f72"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cases2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"BO5", ",", "BO10", ",", "BM5", ",", " ", "BM"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.479668457935833*^9, 3.479668481450539*^9}, {
  3.479668587715115*^9, 3.4796685878908243`*^9}, {3.4819414768722143`*^9, 
  3.481941481456056*^9}, {3.7992219237632113`*^9, 3.7992219303911877`*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"70244e5a-db23-4530-91b2-e1ac2c7ed63c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Join", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "\"\<\>\"", "}"}], "~", "Join", "~", "cases2"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
          "\"\<Config\>\"", ",", "\"\<fmax (theory) [N/A]\>\"", ",", 
           "\"\<zmax (theory) [mm]\>\"", ",", "\"\<zmaxq (meas) [mm]\>\"", 
           ",", "\"\<delta [mm]\>\"", ",", 
           "\"\<coupling [N/A/\!\(\*SuperscriptBox[\(m\), \(2\)]\)]\>\""}], 
          "}"}], "}"}], "\[IndentingNewLine]", "~", "Join", "~", 
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fmax", "[", 
             RowBox[{"cases2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
            RowBox[{"fmax", "[", 
             RowBox[{"cases2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
            RowBox[{"1000", "*", 
             RowBox[{"zmax", "[", 
              RowBox[{"cases2", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
            RowBox[{"1000", "*", 
             RowBox[{"zmaxq", "[", 
              RowBox[{"cases2", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
            RowBox[{"1000", " ", 
             RowBox[{"delta", "[", 
              RowBox[{"cases2", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
            RowBox[{"coupling", "[", 
             RowBox[{"cases2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "cases2", "]"}]}], "}"}]}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}], "/.", 
    RowBox[{
     RowBox[{"zmaxq", "[", "_", "]"}], "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    RowBox[{"delta", "[", "_", "]"}], "\[Rule]", "0"}]}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.479668483217331*^9, 3.479668563563539*^9}, {
   3.4796686215578623`*^9, 3.479668666780747*^9}, {3.479668701726816*^9, 
   3.479668747295388*^9}, {3.481942141220706*^9, 3.481942165968225*^9}, {
   3.481942240350567*^9, 3.481942242583256*^9}, {3.6626233925731487`*^9, 
   3.662623394158786*^9}, 3.799212531147224*^9, {3.799217054153356*^9, 
   3.799217058198593*^9}, {3.799217090370521*^9, 3.799217110391349*^9}, {
   3.799217193532177*^9, 3.799217248736793*^9}, {3.799217300662807*^9, 
   3.799217347795745*^9}, {3.799217377925261*^9, 3.7992174636554747`*^9}, {
   3.7992174945367937`*^9, 3.799217515461955*^9}, {3.799217596916654*^9, 
   3.799217632144773*^9}, {3.799221933928629*^9, 3.799221945442816*^9}, {
   3.8896958424184*^9, 3.8896959086768837`*^9}, 3.889697021500041*^9, {
   3.889697121726631*^9, 3.889697154080319*^9}},
 CellLabel->
  "In[219]:=",ExpressionUUID->"6c8b20fb-1f3d-48d4-b5b6-68c0bbfa6224"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "BO5", "BO10", "BM5", "BM"},
    {"\<\"Config\"\>", "0.9628352953496105`", "1.6948582028560362`", 
     "0.6371543615427959`", "1.0843322046660526`"},
    {"\<\"fmax (theory) [N/A]\"\>", "0.9628352953496105`", 
     "1.6948582028560362`", "0.6371543615427959`", "1.0843322046660526`"},
    {"\<\"zmax (theory) [mm]\"\>", "6.1809543072630975`", 
     "7.195845077775158`", "5.09002348796162`", "6.3615389845798616`"},
    {"\<\"zmaxq (meas) [mm]\"\>", "6.141132328792644`", "7.352611334002001`", 
     "0", "0"},
    {"\<\"delta [mm]\"\>", 
     RowBox[{"-", "0.039821978470453746`"}], "0.1567662562268427`", "0", 
     "0"},
    {"\<\"coupling [N/A/\\!\\(\\*SuperscriptBox[\\(m\\), \\(2\\)]\\)]\"\>", 
     "43704.611046694976`", "61049.691287075046`", "38794.56848394872`", 
     "73712.42445548202`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.799217249329832*^9, 3.79921734838474*^9, 3.799217379473974*^9, {
   3.7992174421885967`*^9, 3.799217464862462*^9}, {3.799217496428701*^9, 
   3.799217515838039*^9}, 3.799217633630611*^9, {3.799221948391423*^9, 
   3.799221961501369*^9}, 3.814193984195879*^9, 3.8142503191471443`*^9, 
   3.832247016968417*^9, 3.832403927839699*^9, 3.832579291614092*^9, 
   3.889696256942821*^9, 3.88969697830128*^9, 3.8896970219488897`*^9, 
   3.88969716588943*^9, 3.8901190477266693`*^9},
 CellLabel->
  "Out[219]//TableForm=",ExpressionUUID->"05134b86-cf91-4a42-8416-\
3371f99820d3"]
}, Open  ]],

Cell["Numbers for Table 3 of Word document.", "Subsection",
 CellChangeTimes->{{3.799216693820692*^9, 3.799216716843322*^9}, 
   3.799216938051504*^9},ExpressionUUID->"41a35b4a-1db5-4578-9c3e-\
c053b6900733"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cases3", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "AO", ",", "AODL", ",", "AOES", ",", " ", "BOTT", ",", "HDS0", ",", 
     "HDDS"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479668457935833*^9, 3.479668481450539*^9}, {
   3.479668587715115*^9, 3.4796685878908243`*^9}, {3.4819414768722143`*^9, 
   3.481941481456056*^9}, {3.7992219237632113`*^9, 3.7992219303911877`*^9}, 
   3.799222013357449*^9, {3.7992224823127317`*^9, 3.799222482598113*^9}, 
   3.7992226400708027`*^9, {3.832578660657721*^9, 3.8325786652612743`*^9}, {
   3.890120073867799*^9, 3.890120078948938*^9}},
 CellLabel->
  "In[227]:=",ExpressionUUID->"d6aa081b-fe2b-411e-92f9-931ec6ac2f96"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"1000", " ", "l"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"1000", " ", "a"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"1000", " ", "coillen"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"1000", " ", "coilrad1"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"1000", " ", "coilrad2"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"coilturns", "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"mz", "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"coilsigma", "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"fmax", "[", 
           RowBox[{"cases3", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"1000", "*", 
           RowBox[{"zmax", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"coupling", "[", 
           RowBox[{"cases3", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "cases3", "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}], "/.", 
     RowBox[{
      RowBox[{"zmaxq", "[", "_", "]"}], "\[Rule]", "0"}]}], "/.", 
    RowBox[{
     RowBox[{"delta", "[", "_", "]"}], "\[Rule]", "0"}]}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<l [mm]\>\"", ",", "\"\<a [mm]\>\"", ",", "\"\<coillen [mm]\>\"", 
        ",", "\"\<coilrad1 [mm]\>\"", ",", "\"\<coilrad2 [mm]\>\"", ",", 
        "\"\<coilturns\>\"", ",", "\"\<mz\>\"", ",", "\"\<coilsigma\>\"", 
        ",", "\"\<fmax [N/A]\>\"", ",", "\"\<zmax [mm]\>\"", ",", 
        "\"\<coupling [N/A/\!\(\*SuperscriptBox[\(m\), \(2\)]\)]\>\""}], 
       "}"}], ",", "cases3"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.479668483217331*^9, 3.479668563563539*^9}, {
   3.4796686215578623`*^9, 3.479668666780747*^9}, {3.479668701726816*^9, 
   3.479668747295388*^9}, {3.481942141220706*^9, 3.481942165968225*^9}, {
   3.481942240350567*^9, 3.481942242583256*^9}, {3.6626233925731487`*^9, 
   3.662623394158786*^9}, 3.799212531147224*^9, {3.799217054153356*^9, 
   3.799217058198593*^9}, {3.799217090370521*^9, 3.799217110391349*^9}, {
   3.799217193532177*^9, 3.799217248736793*^9}, {3.799217300662807*^9, 
   3.799217347795745*^9}, {3.799217377925261*^9, 3.7992174636554747`*^9}, {
   3.7992174945367937`*^9, 3.799217515461955*^9}, {3.799217596916654*^9, 
   3.799217632144773*^9}, {3.799221933928629*^9, 3.799221945442816*^9}, {
   3.7992220140494337`*^9, 3.799222048007722*^9}, {3.799222091962309*^9, 
   3.799222207358107*^9}, {3.799222279856093*^9, 3.7992224088460073`*^9}, {
   3.79922461871211*^9, 3.7992247896535797`*^9}, 3.799224820308196*^9, {
   3.799224863673407*^9, 3.799224883558642*^9}, {3.889695850624651*^9, 
   3.889695852723942*^9}, {3.8896959187029343`*^9, 3.889695940115296*^9}, {
   3.889696596981492*^9, 3.88969659746577*^9}, {3.89011947909943*^9, 
   3.890119503412231*^9}, {3.890119590217201*^9, 3.8901195957235813`*^9}, {
   3.89012020570689*^9, 3.890120209320808*^9}, {3.890120258765045*^9, 
   3.890120269178575*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"c8d1f20a-e908-45fa-82e6-ba37973431dc"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["AO",
       HoldForm], 
      TagBox["AODL",
       HoldForm], 
      TagBox["AOES",
       HoldForm], 
      TagBox["BOTT",
       HoldForm], 
      TagBox["HDS0",
       HoldForm], 
      TagBox["HDDS",
       HoldForm]},
     {
      TagBox["\<\"l [mm]\"\>",
       HoldForm], "3.175`", "6.`", "0.5`", "10.`", "6.`", "6.`"},
     {
      TagBox["\<\"a [mm]\"\>",
       HoldForm], "0.9525`", "1.`", "1.`", "2.5`", "1.`", "1.`"},
     {
      TagBox["\<\"coillen [mm]\"\>",
       HoldForm], "5.257799999999999`", "5.257799999999999`", 
      "5.257799999999999`", "8.001`", "5.`", "10.16`"},
     {
      TagBox["\<\"coilrad1 [mm]\"\>",
       HoldForm], "7.7216`", "7.7216`", "7.7216`", "8.889999999999999`", 
      "5.`", "3.4925`"},
     {
      TagBox["\<\"coilrad2 [mm]\"\>",
       HoldForm], "12.649199999999999`", "12.649199999999999`", 
      "12.649199999999999`", "16.51`", "10.`", "9.10336`"},
     {
      TagBox["\<\"coilturns\"\>",
       HoldForm], "400", "400", "400", "800", "385.9763967713846`", "1000"},
     {
      TagBox["\<\"mz\"\>",
       HoldForm], "878020.9598010788`", "878020.9598010788`", 
      "878020.9598010788`", "878020.9598010788`", "878020.9598010788`", 
      "878020.9598010788`"},
     {
      TagBox["\<\"coilsigma\"\>",
       HoldForm], "1.5439046765338914`*^7", "1.5439046765338914`*^7", 
      "1.5439046765338914`*^7", "1.312171936513185`*^7", 
      "1.5439055870855384`*^7", "1.7541909235018108`*^7"},
     {
      TagBox["\<\"fmax [N/A]\"\>",
       HoldForm], "0.015773312789701857`", "0.030934223187089303`", 
      "0.002807824198069128`", "0.39253741694525085`", "0.05125731583409274`",
       "0.13030351516936067`"},
     {
      TagBox["\<\"zmax [mm]\"\>",
       HoldForm], "5.342364901049084`", "5.70864312765026`", 
      "5.198470254921349`", "7.5970673025871776`", "4.554203052992813`", 
      "5.607360550437446`"},
     {
      TagBox["\<\"coupling [N/A/\\!\\(\\*SuperscriptBox[\\(m\\), \\(2\\)]\\)]\
\"\>",
       HoldForm], "919.3144173821112`", "1637.373176226694`", 
      "169.00623530595902`", "12441.408047207244`", "4533.877170403583`", 
      "9622.729378687809`"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, 
      "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "l [mm]", "a [mm]", "coillen [mm]", "coilrad1 [mm]", "coilrad2 [mm]", 
       "coilturns", "mz", "coilsigma", "fmax [N/A]", "zmax [mm]", 
       "coupling [N/A/\!\(\*SuperscriptBox[\(m\), \(2\)]\)]"}, \
{$CellContext`AO, $CellContext`AODL, $CellContext`AOES, $CellContext`BOTT, \
$CellContext`HDS0, $CellContext`HDDS}}]]]], "Output",
 CellChangeTimes->{{3.890119494490424*^9, 3.890119504687995*^9}, 
   3.8901195963300543`*^9, 3.89012008987707*^9, 3.8901202109910088`*^9, 
   3.89012027436413*^9},
 CellLabel->
  "Out[230]//TableForm=",ExpressionUUID->"bc82d2a3-2b77-42b9-9ca2-\
8b15a222c5ea"]
}, Open  ]],

Cell["Numbers for Table 4 of Word document.", "Subsection",
 CellChangeTimes->{{3.799216693820692*^9, 3.799216716843322*^9}, {
  3.799225095119976*^9, 
  3.799225095438384*^9}},ExpressionUUID->"cc517d30-9eb6-4ae9-85bc-\
b20209ced5be"],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fmax", "[", "BO10", "]"}], ",", 
        RowBox[{"1000", " ", 
         RowBox[{"zmax", "[", "BO10", "]"}]}], ",", 
        RowBox[{"coupling", "[", "BO10", "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fmax2", "[", "BO10", "]"}], ",", 
        RowBox[{"1000", " ", 
         RowBox[{"zmax2", "[", "BO10", "]"}]}], ",", 
        RowBox[{"coupling2", "[", "BO10", "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fmax", "[", "AODL", "]"}], ",", 
        RowBox[{"1000", " ", 
         RowBox[{"zmax", "[", "AODL", "]"}]}], ",", 
        RowBox[{"coupling", "[", "AODL", "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fmax2", "[", "AODL", "]"}], ",", 
        RowBox[{"1000", " ", 
         RowBox[{"zmax2", "[", "AODL", "]"}]}], ",", 
        RowBox[{"coupling2", "[", "AODL", "]"}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}], "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<fmax [N/A]\>\"", ",", "\"\<zmax [mm]\>\"", ",", 
        "\"\<coupling [N/A/\!\(\*SuperscriptBox[\(m\), \(2\)]\)]\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<BO10 single\>\"", ",", "\"\<BO10 pair\>\"", ",", 
        "\"\<AODL single\>\"", ",", "\"\<AODL pair\>\""}], "}"}]}], "}"}]}]}],
   "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
   3.4815676689801073`*^9, 3.481567724116664*^9}, {3.662623496752969*^9, 
   3.66262350152312*^9}, {3.799212531153256*^9, 3.799212531153904*^9}, {
   3.7992237926291847`*^9, 3.7992238500042467`*^9}, {3.7992240713157997`*^9, 
   3.799224115165062*^9}, {3.7992241851271*^9, 3.799224237489109*^9}, {
   3.7992243398690653`*^9, 3.799224365191326*^9}, {3.799224962286886*^9, 
   3.7992250603926992`*^9}, {3.7992252070834084`*^9, 
   3.7992252110646343`*^9}, {3.83257855379465*^9, 3.8325786218425703`*^9}, 
   3.8325786841658783`*^9, {3.8896959532002563`*^9, 3.889695985251624*^9}, {
   3.889696569525878*^9, 3.889696573557572*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"d769e62a-9a58-4688-800b-67ebe350b93e"]
}, Open  ]],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"BO10 single\"\>",
       HoldForm], 
      TagBox["\<\"BO10 pair\"\>",
       HoldForm], 
      TagBox["\<\"AODL single\"\>",
       HoldForm], 
      TagBox["\<\"AODL pair\"\>",
       HoldForm]},
     {
      TagBox["\<\"fmax [N/A]\"\>",
       HoldForm], "1.6948582028560362`", "1.6263677836057786`", 
      "0.030934223187089303`", "0.030257769468521954`"},
     {
      TagBox["\<\"zmax [mm]\"\>",
       HoldForm], "7.195845077775158`", "7.300972176217677`", 
      "5.70864312765026`", "5.750788020102526`"},
     {
      TagBox["\<\"coupling [N/A/\\!\\(\\*SuperscriptBox[\\(m\\), \\(2\\)]\\)]\
\"\>",
       HoldForm], "61049.691287075046`", "194679.0041486842`", 
      "1637.373176226694`", "2694.630378958691`"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, 
      "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "fmax [N/A]", "zmax [mm]", 
       "coupling [N/A/\!\(\*SuperscriptBox[\(m\), \(2\)]\)]"}, {
      "BO10 single", "BO10 pair", "AODL single", "AODL pair"}}]]]], "Output",
 CellChangeTimes->{
  3.4815677247383738`*^9, 3.48156775513408*^9, 3.662627027501245*^9, 
   3.662846404962121*^9, 3.799212569833867*^9, 3.799212872590466*^9, 
   3.799223694543845*^9, 3.799223850608693*^9, 3.799224115910757*^9, {
   3.799224209361107*^9, 3.79922423809077*^9}, 3.799224367504829*^9, {
   3.799224536473153*^9, 3.799224551760214*^9}, {3.799225028458828*^9, 
   3.799225061750265*^9}, 3.799225211941506*^9, 3.814193984233119*^9, 
   3.814250319209455*^9, 3.832247017175976*^9, 3.8324039279521*^9, 
   3.8325792916856737`*^9, 3.8896962570042048`*^9, 3.8896965742928753`*^9, 
   3.890119047763689*^9},
 CellLabel->
  "Out[222]//TableForm=",ExpressionUUID->"28bf89cb-98ae-4701-a732-\
204cbcd5eaed"]
},
CellGrouping->Manual,
WindowSize->{1316, 997},
WindowMargins->{{-1590, Automatic}, {-320, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PaperOrientation"->"Portrait",
"PaperSize"->{595, 842}},
FrontEndVersion->"13.2 for Mac OS X ARM (64-bit) (January 30, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"01c72458-c3b1-40a0-b780-1e977edfca24"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 512, 9, 77, "Title",ExpressionUUID->"3dfe1237-ce63-495a-9b65-ebf5ff37ac1c"],
Cell[CellGroupData[{
Cell[1104, 35, 139, 2, 68, "Section",ExpressionUUID->"bb0d3673-5957-440e-805b-8cf3d0ee019a"],
Cell[1246, 39, 827, 15, 71, "Text",ExpressionUUID->"639e0d4b-79f4-4554-935e-ec18c521377a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2110, 59, 187, 4, 68, "Section",ExpressionUUID->"ae6c7bba-54b3-4d61-9f0a-2d04a3ee297b",
 Evaluatable->False],
Cell[2300, 65, 1050, 20, 31, "Input",ExpressionUUID->"880f8f56-0e29-4ae5-b330-3294a7b28cc9"],
Cell[CellGroupData[{
Cell[3375, 89, 89, 0, 35, "Subsection",ExpressionUUID->"c8619771-36ca-45a5-aa35-9b680d81934d"],
Cell[CellGroupData[{
Cell[3489, 93, 283, 6, 24, "Subsubsection",ExpressionUUID->"a0d974f5-90d7-4db0-ad7e-fd24e90e28de"],
Cell[3775, 101, 548, 10, 31, "Input",ExpressionUUID->"cdb3efd8-18de-4355-af3a-39095dd99e02"]
}, Open  ]]
}, Open  ]],
Cell[4350, 115, 112, 1, 31, "Input",ExpressionUUID->"5372f101-ca2f-49e6-9a12-063152ae5f8d"],
Cell[4465, 118, 158, 2, 31, "Input",ExpressionUUID->"c342b927-7087-4eee-8bf4-9e186f897796"],
Cell[CellGroupData[{
Cell[4648, 124, 99, 0, 35, "Subsection",ExpressionUUID->"9780a3d9-9540-4886-9697-f741c422a5fb"],
Cell[4750, 126, 228, 5, 31, "Input",ExpressionUUID->"cf85e739-cd86-4302-aacd-ac44fc545330"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5015, 136, 126, 0, 35, "Subsection",ExpressionUUID->"9adcfee4-a22e-4c6d-bdb2-90b11cf7b5de"],
Cell[CellGroupData[{
Cell[5166, 140, 109, 0, 24, "Subsubsection",ExpressionUUID->"ffc09f59-ca70-4cb8-affb-eabdf7057e11"],
Cell[5278, 142, 630, 17, 31, "Input",ExpressionUUID->"a8c3bb97-4087-4d53-8662-a22df462b79d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5945, 164, 226, 5, 24, "Subsubsection",ExpressionUUID->"506e45ed-ac8b-4ade-b72f-98885d921fd4"],
Cell[6174, 171, 200, 5, 48, "Input",ExpressionUUID->"6e6dff58-ddc2-4d85-a678-de8a16047112"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6411, 181, 155, 2, 24, "Subsubsection",ExpressionUUID->"6638e03a-c5f4-4afd-9d19-0630b8b3b919"],
Cell[6569, 185, 244, 6, 48, "Input",ExpressionUUID->"c7541543-1c68-47d5-98c0-53e6f0bec293"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6862, 197, 120, 0, 35, "Subsection",ExpressionUUID->"678e8115-2bb6-4ba0-aeb9-afed12599c78"],
Cell[CellGroupData[{
Cell[7007, 201, 229, 14, 218, "Input",ExpressionUUID->"d534ff9f-4118-48a0-8862-c08ac405a88b"],
Cell[7239, 217, 1408, 30, 70, "Output",ExpressionUUID->"15d278e7-78bc-45cf-864c-27891c65dd47"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8684, 252, 163, 3, 31, "Input",ExpressionUUID->"2456c139-a623-4985-af3d-765900d42720"],
Cell[8850, 257, 1106, 20, 70, "Output",ExpressionUUID->"72251593-aae5-47aa-89aa-38dc32f73a6b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9993, 282, 234, 13, 201, "Input",ExpressionUUID->"fa895aba-bd45-47e1-b999-8f3ea924fac8"],
Cell[10230, 297, 1379, 29, 70, "Output",ExpressionUUID->"b96e4a03-66d2-4819-bba2-a2c47d5ab46d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11646, 331, 192, 4, 31, "Input",ExpressionUUID->"657f57ee-cbd8-4b4b-ad07-337e3f815d14"],
Cell[11841, 337, 1052, 17, 70, "Output",ExpressionUUID->"6ab945c6-9801-4d7e-85ed-c30911b5a5f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12930, 359, 491, 14, 31, "Input",ExpressionUUID->"b11f8f4d-4fab-4c28-89c0-ba9ed0b4562c"],
Cell[13424, 375, 946, 13, 70, "Output",ExpressionUUID->"eb0564cd-7731-49de-83c4-4f871a2ea820"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[14419, 394, 141, 3, 27, "Subsection",ExpressionUUID->"edcb98b6-a535-42a2-abc3-024a620de9bf",
 Evaluatable->False],
Cell[14563, 399, 966, 25, 354, "Input",ExpressionUUID->"19e1338f-4a6c-44a8-827f-3217503d699e"],
Cell[15532, 426, 288, 9, 133, "Input",ExpressionUUID->"fdca09ed-d11f-4dbe-b709-0ac511c38634"],
Cell[15823, 437, 770, 22, 337, "Input",ExpressionUUID->"84d4f767-3885-464a-9226-6977164a18a0"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16654, 466, 267, 6, 68, "Section",ExpressionUUID->"2ae1367f-56e4-4279-9cb4-f02578c0d682"],
Cell[CellGroupData[{
Cell[16946, 476, 1806, 45, 677, "Input",ExpressionUUID->"1a638f07-39e3-4615-8baa-7d495e3444de"],
Cell[18755, 523, 3162, 58, 171, "Output",ExpressionUUID->"8952b828-1e54-4302-b85a-a7fd0c927fc2"]
}, Open  ]],
Cell[21932, 584, 271, 6, 31, "Input",ExpressionUUID->"902df673-dd1f-4fb6-888a-fc33cf3e4da3"],
Cell[CellGroupData[{
Cell[22228, 594, 1125, 25, 108, "Input",ExpressionUUID->"445ff0c9-759b-41bc-bd85-1effc873d84c"],
Cell[23356, 621, 546, 11, 31, "Output",ExpressionUUID->"de548478-e796-4e65-8ef6-61c2493efb8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23939, 637, 6620, 117, 174, "Input",ExpressionUUID->"449b716a-aa12-4cf6-bd1e-313b91961256"],
Cell[30562, 756, 7181, 136, 235, "Output",ExpressionUUID->"99ebf50e-d20c-4cdd-93bc-400e90bc76cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37780, 897, 579, 11, 31, "Input",ExpressionUUID->"95d58a8b-5990-4a03-a515-fea0840c57ce"],
Cell[38362, 910, 739, 10, 31, "Output",ExpressionUUID->"dca5cfb5-7a26-4b5f-bf2a-8913b90b1f8a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39138, 925, 573, 11, 31, "Input",ExpressionUUID->"58b82fc2-4281-4e19-9c58-3ceab85f654e"],
Cell[39714, 938, 727, 10, 31, "Output",ExpressionUUID->"ffb24ee5-1c65-4765-bb49-f25fb71dba43"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40478, 953, 1268, 22, 31, "Input",ExpressionUUID->"34545ddd-03f8-4d06-b2de-379474b8d110"],
Cell[41749, 977, 14718, 293, 58, "Output",ExpressionUUID->"1f396b2a-dc0c-41a0-9061-a3425bdb2a35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56504, 1275, 1834, 34, 31, "Input",ExpressionUUID->"64ff4a14-8871-4129-af87-06c0713c3594"],
Cell[58341, 1311, 813, 12, 31, "Output",ExpressionUUID->"ec9390d8-1303-4e51-b1eb-a22563c4c163"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59191, 1328, 247, 5, 31, "Input",ExpressionUUID->"f8cf4648-752b-474a-bc39-f37770b6d3f7"],
Cell[59441, 1335, 747, 11, 31, "Output",ExpressionUUID->"13c60b1e-7dcb-4a27-b72d-98ed14ba4edf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60225, 1351, 459, 10, 31, "Input",ExpressionUUID->"53a96b9e-449f-4ee8-9791-f3779fc8cb23"],
Cell[60687, 1363, 715, 11, 31, "Output",ExpressionUUID->"ca3ed090-a762-4c54-bce6-1d78810d464a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61439, 1379, 321, 6, 31, "Input",ExpressionUUID->"401ce758-5327-4811-82da-38866b3dedee"],
Cell[61763, 1387, 679, 11, 31, "Output",ExpressionUUID->"cd59c321-27e8-4254-a3d1-fa3d1b029132"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62479, 1403, 219, 3, 26, "Text",ExpressionUUID->"36002a4d-5c80-4599-85a4-f80a15a9331b"],
Cell[CellGroupData[{
Cell[62723, 1410, 6511, 119, 167, "Input",ExpressionUUID->"a754fc22-647b-40ae-bb7f-9655f6a4fb9d"],
Cell[69237, 1531, 7507, 140, 231, "Output",ExpressionUUID->"7ac88fbb-6007-4dd5-811a-e5f3fb272088"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76781, 1676, 385, 10, 99, "Input",ExpressionUUID->"beec4926-b1cd-4634-9cc5-b505164c56d2"],
Cell[77169, 1688, 761, 14, 31, "Output",ExpressionUUID->"8ea39ccc-2552-4d73-a1fb-87452671904f"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[77991, 1709, 219, 4, 68, "Section",ExpressionUUID->"c37bd691-811c-4570-8675-b60bafa8e5bf"],
Cell[CellGroupData[{
Cell[78235, 1717, 1796, 42, 592, "Input",ExpressionUUID->"b4827e9a-2581-400c-b635-ff1b6db624ad"],
Cell[80034, 1761, 3474, 63, 70, "Output",ExpressionUUID->"38dcb07c-b710-4018-95e7-bce594ff6b65"]
}, Open  ]],
Cell[83523, 1827, 362, 8, 31, "Input",ExpressionUUID->"75fa72e5-f61a-4b00-87b8-d570a6556952"],
Cell[CellGroupData[{
Cell[83910, 1839, 295, 6, 31, "Input",ExpressionUUID->"20077e92-d012-4e5b-862a-5fbaddf3cbfd"],
Cell[84208, 1847, 861, 13, 70, "Output",ExpressionUUID->"3afdb193-bc7c-4f18-b8bc-b271d6e91377"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85106, 1865, 459, 10, 31, "Input",ExpressionUUID->"bc336c19-1cb1-43a6-baa9-f8f5c9d85fcc"],
Cell[85568, 1877, 770, 12, 70, "Output",ExpressionUUID->"68d152e1-5b22-41bd-8814-2208e683ca26"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86375, 1894, 393, 7, 31, "Input",ExpressionUUID->"27952e17-6cd1-4d1f-ac44-4d2f63fd648a"],
Cell[86771, 1903, 725, 12, 70, "Output",ExpressionUUID->"d3fd5428-f955-4db0-9e2f-51af12d7fb43"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87533, 1920, 330, 7, 31, "Input",ExpressionUUID->"3a518087-6cae-40e0-983d-81d102009411"],
Cell[87866, 1929, 753, 12, 70, "Output",ExpressionUUID->"27f74ec4-1455-4fb3-86b9-ad19586fbee1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88656, 1946, 330, 7, 31, "Input",ExpressionUUID->"11708426-b2bc-4205-9106-debb6efe02c5"],
Cell[88989, 1955, 760, 12, 70, "Output",ExpressionUUID->"d2899fad-810e-466a-a295-3ed242224d2f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89786, 1972, 178, 3, 26, "Text",ExpressionUUID->"18b6656e-f25d-4227-9736-711dee46383f"],
Cell[CellGroupData[{
Cell[89989, 1979, 469, 11, 31, "Input",ExpressionUUID->"7f8d5b99-3877-44ef-993a-cb12d9cd2d89"],
Cell[90461, 1992, 11058, 200, 70, "Output",ExpressionUUID->"2b58a7af-bcac-4356-bac6-5a2acff40d20"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101556, 2197, 491, 10, 31, "Input",ExpressionUUID->"25973c72-5333-4fd9-80f7-7ac37d6298d6"],
Cell[102050, 2209, 7542, 142, 70, "Output",ExpressionUUID->"64d0aa98-0e64-4c62-b7f6-8f5dda9aeb33"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109629, 2356, 780, 16, 31, "Input",ExpressionUUID->"f0fefd8d-0148-4c32-af44-6cb5456687f0"],
Cell[110412, 2374, 992, 18, 70, "Output",ExpressionUUID->"193218bf-1610-45ea-82dc-e624dc8f8b80"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[111453, 2398, 402, 9, 31, "Input",ExpressionUUID->"313eb942-123a-45f1-b00f-bd8283f90fa0"],
Cell[111858, 2409, 550, 7, 70, "Output",ExpressionUUID->"1e6cc67d-a854-4e75-8b6a-b420836c291d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112445, 2421, 395, 9, 31, "Input",ExpressionUUID->"2f158e54-941f-4e8f-ab4b-59c160c12ea7"],
Cell[112843, 2432, 500, 7, 70, "Output",ExpressionUUID->"6c725f26-6aa6-44f2-b261-c2d338f16566"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[113392, 2445, 284, 4, 38, "Section",ExpressionUUID->"ec1821fe-d639-4dd4-9f6a-4568230a7630"],
Cell[CellGroupData[{
Cell[113701, 2453, 2350, 53, 711, "Input",ExpressionUUID->"56560bf5-235e-4f9a-a92f-cf475feab4d5"],
Cell[116054, 2508, 3286, 60, 70, "Output",ExpressionUUID->"76abb933-2112-4b8b-ba33-495e91773e45"]
}, Open  ]],
Cell[119355, 2571, 410, 8, 31, "Input",ExpressionUUID->"7e81a715-9ca1-4856-9954-33ef64603726"],
Cell[CellGroupData[{
Cell[119790, 2583, 1149, 25, 108, "Input",ExpressionUUID->"4f67205c-9f43-4fbf-838f-c912f0c00cca"],
Cell[120942, 2610, 520, 11, 70, "Output",ExpressionUUID->"8962ea9e-65a2-4df5-a7c8-72fe02ce14a4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121499, 2626, 6831, 121, 167, "Input",ExpressionUUID->"9fb2e2ba-9280-42e7-a100-e0021c15e7da"],
Cell[128333, 2749, 7317, 139, 70, "Output",ExpressionUUID->"441ad41c-de78-4231-9068-d2a165700b8d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[135687, 2893, 574, 11, 31, "Input",ExpressionUUID->"32643f23-3336-44ca-99ec-f76e90a3f4e3"],
Cell[136264, 2906, 681, 9, 70, "Output",ExpressionUUID->"f52285f8-95bf-4d8d-8e49-36449ed36a80"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136982, 2920, 573, 11, 31, "Input",ExpressionUUID->"1b78dee0-4370-4b8b-84b3-39acbd94d674"],
Cell[137558, 2933, 685, 9, 70, "Output",ExpressionUUID->"69b67000-72da-4ed7-9552-d713efa4ee14"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138280, 2947, 1314, 22, 31, "Input",ExpressionUUID->"91096579-c078-45df-9be3-2862295967db"],
Cell[139597, 2971, 14479, 285, 70, "Output",ExpressionUUID->"09bf9214-f28d-4989-8f54-9070f2d0db80"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154113, 3261, 1888, 35, 31, "Input",ExpressionUUID->"bc47da5d-ca01-4d8c-8301-7c1274c233c7"],
Cell[156004, 3298, 809, 12, 70, "Output",ExpressionUUID->"f120a0f7-4985-491f-a3bf-231edd6432be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[156850, 3315, 1456, 23, 89, "Input",ExpressionUUID->"f177b1a4-497f-4cd3-a2b6-4e2abe2cce05"],
Cell[158309, 3340, 7469, 142, 70, "Output",ExpressionUUID->"8a8ca9a9-6955-4abc-88e8-0db7b5603197"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165815, 3487, 325, 6, 31, "Input",ExpressionUUID->"d9a8c6be-6da5-4103-bcc6-df8f9e62e8bc"],
Cell[166143, 3495, 818, 12, 70, "Output",ExpressionUUID->"45404ec7-bd5c-44e1-a887-29b0d2ef2b61"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166998, 3512, 459, 10, 31, "Input",ExpressionUUID->"c841c6ca-eda9-4bed-9488-ff5a80345e79"],
Cell[167460, 3524, 720, 11, 70, "Output",ExpressionUUID->"e17c1642-203f-467e-b84f-87c0cddbd9c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168217, 3540, 415, 7, 31, "Input",ExpressionUUID->"852f2c59-3560-4124-807e-a41c924f82e6"],
Cell[168635, 3549, 690, 11, 70, "Output",ExpressionUUID->"3a18bbd8-7a48-47ce-a416-e95536ce6eb7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169362, 3565, 352, 7, 31, "Input",ExpressionUUID->"ee93f305-a43a-4d89-be9d-92f02104aeb3"],
Cell[169717, 3574, 706, 12, 70, "Output",ExpressionUUID->"b82e90df-e092-4cb3-8c71-49c7ef7ac2fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170460, 3591, 352, 7, 31, "Input",ExpressionUUID->"f54f6b89-9c65-45e5-b085-01740ff4004d"],
Cell[170815, 3600, 711, 12, 70, "Output",ExpressionUUID->"dd06969b-dd7b-4f30-a6e7-c1ef69e7ae7a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171563, 3617, 178, 3, 26, "Text",ExpressionUUID->"548ecba9-2816-4f3d-b1ee-a36844dfb2ab"],
Cell[CellGroupData[{
Cell[171766, 3624, 491, 11, 31, "Input",ExpressionUUID->"854f4323-71fb-46f6-9e95-f9c32d166838"],
Cell[172260, 3637, 11055, 199, 70, "Output",ExpressionUUID->"d33c3715-63ae-4950-b036-401b4c007d28"]
}, Open  ]],
Cell[CellGroupData[{
Cell[183352, 3841, 517, 11, 31, "Input",ExpressionUUID->"a531a3ec-79d9-4e67-a8a0-42db602ff2ca"],
Cell[183872, 3854, 7495, 141, 70, "Output",ExpressionUUID->"b0326fc2-dccf-414a-8ecb-91aff459eb7f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[191416, 4001, 829, 17, 31, "Input",ExpressionUUID->"da98ea8e-ec18-4fb9-bbee-2bc2c2834481"],
Cell[192248, 4020, 1017, 18, 70, "Output",ExpressionUUID->"2a71b9c2-a481-4e89-8cf0-d4ac649a6d2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193302, 4043, 450, 10, 31, "Input",ExpressionUUID->"d60bd202-0290-480e-b2e6-e79e6533ec6f"],
Cell[193755, 4055, 580, 8, 70, "Output",ExpressionUUID->"76e58164-c409-4c77-b267-aec63fd001b1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[194372, 4068, 446, 10, 31, "Input",ExpressionUUID->"4c9c9ec2-9442-4edb-8b9c-33797d9b231d"],
Cell[194821, 4080, 523, 7, 70, "Output",ExpressionUUID->"c1718071-00a7-456b-913f-b1c5942590d9"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[195393, 4093, 345, 5, 38, "Section",ExpressionUUID->"82586c70-4af1-4da1-b79a-96177a9bd8e0"],
Cell[CellGroupData[{
Cell[195763, 4102, 2573, 56, 711, "Input",ExpressionUUID->"dfd7ef58-4e21-45e6-92c1-45dafe32170f"],
Cell[198339, 4160, 3220, 58, 70, "Output",ExpressionUUID->"808c2d12-1d19-4df5-93e4-c3fa6e7a0cda"]
}, Open  ]],
Cell[201574, 4221, 490, 9, 31, "Input",ExpressionUUID->"2d189b41-9222-4a58-8e19-ccb2814792be"],
Cell[CellGroupData[{
Cell[202089, 4234, 178, 3, 26, "Text",ExpressionUUID->"90754ed9-7f5e-430b-bf5c-44472a83d5ba"],
Cell[CellGroupData[{
Cell[202292, 4241, 514, 11, 31, "Input",ExpressionUUID->"b4d67e0f-c1af-4f6b-88d6-e95aa3eb5c9f"],
Cell[202809, 4254, 11346, 204, 70, "Output",ExpressionUUID->"bd4778ec-890e-4883-ade5-dcadb909c3c6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214192, 4463, 540, 11, 31, "Input",ExpressionUUID->"e7191882-4686-421a-b6f1-453a24ea51af"],
Cell[214735, 4476, 7564, 142, 70, "Output",ExpressionUUID->"82b7126b-deff-4ce2-8010-67ab08320c0c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[222336, 4623, 657, 13, 31, "Input",ExpressionUUID->"8c873269-2f83-46ca-9455-031edfe1f7e4"],
Cell[222996, 4638, 917, 17, 70, "Output",ExpressionUUID->"23a4d42d-3006-4601-a356-981a96d22c3f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[223962, 4661, 262, 5, 31, "Input",ExpressionUUID->"ba4ea7a9-e82a-4e5e-9d30-94aeec41edf7"],
Cell[224227, 4668, 474, 6, 70, "Output",ExpressionUUID->"53568528-cfec-4733-aeb2-5f53b9d554a3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[224750, 4680, 399, 6, 38, "Section",ExpressionUUID->"46df04c7-2007-4642-9b1f-9ec7b09d28cd"],
Cell[CellGroupData[{
Cell[225174, 4690, 2493, 55, 677, "Input",ExpressionUUID->"1409a6fd-6943-472f-9135-d85b2b6bf26a"],
Cell[227670, 4747, 3124, 57, 191, "Output",ExpressionUUID->"454fc121-d90c-4273-ab46-4ade39d18e20"]
}, Open  ]],
Cell[230809, 4807, 538, 10, 31, "Input",ExpressionUUID->"487e2fda-2a80-4287-b27d-746da4ecf6fe"],
Cell[CellGroupData[{
Cell[231372, 4821, 1225, 26, 108, "Input",ExpressionUUID->"8f7817b5-563b-4f5f-af31-f465c6488b7c"],
Cell[232600, 4849, 529, 11, 31, "Output",ExpressionUUID->"8c901930-9198-407c-a48d-050e6f6abcdf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233166, 4865, 6740, 119, 168, "Input",ExpressionUUID->"e162c8e4-f5a2-40d6-858a-8d9f8094479b"],
Cell[239909, 4986, 7210, 137, 229, "Output",ExpressionUUID->"b88bde2d-85be-4919-b346-114c011be677"]
}, Open  ]],
Cell[CellGroupData[{
Cell[247156, 5128, 575, 11, 31, "Input",ExpressionUUID->"429d9939-6034-4001-9360-c57125af8fcc"],
Cell[247734, 5141, 686, 9, 31, "Output",ExpressionUUID->"e4b78ba3-7545-41b9-a076-9aab699725ee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248457, 5155, 571, 11, 31, "Input",ExpressionUUID->"5b4d0698-1f1e-4aaa-ad24-9ac9c6332d15"],
Cell[249031, 5168, 683, 9, 31, "Output",ExpressionUUID->"ce33cff3-6a2f-43ee-bc62-4de9de29684b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[249751, 5182, 1316, 22, 31, "Input",ExpressionUUID->"7f5887ee-98f1-42d5-b63c-2b9651d20454"],
Cell[251070, 5206, 14635, 287, 58, "Output",ExpressionUUID->"8758c84c-481b-404b-82d3-3eb9ebcc4fcb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265742, 5498, 1884, 35, 31, "Input",ExpressionUUID->"4bf6b1ea-d75e-4ae1-b0e8-b869c889ad9f"],
Cell[267629, 5535, 813, 12, 31, "Output",ExpressionUUID->"a1784ff8-6a03-4223-ab1e-86024d66548a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[268479, 5552, 790, 21, 51, "Input",ExpressionUUID->"f61de3d9-71a3-4818-af8b-1595bc09f16a"],
Cell[269272, 5575, 12818, 231, 229, "Output",ExpressionUUID->"7043cdb4-4c30-4102-a589-3a481563ab10"]
}, Open  ]],
Cell[CellGroupData[{
Cell[282127, 5811, 178, 3, 26, "Text",ExpressionUUID->"0049aa13-92b2-432b-b51a-22a4c957b0b5"],
Cell[CellGroupData[{
Cell[282330, 5818, 541, 12, 31, "Input",ExpressionUUID->"d87e340b-f959-45cb-b783-62f31ee81cd3"],
Cell[282874, 5832, 11068, 200, 231, "Output",ExpressionUUID->"23eae4d7-dfe5-41e6-a08e-22d39a4931cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[293979, 6037, 561, 11, 31, "Input",ExpressionUUID->"bf29ff74-3fde-4839-941c-f36d95b618c9"],
Cell[294543, 6050, 7557, 142, 226, "Output",ExpressionUUID->"a4fb964c-c1c6-4b21-b69e-b4d77f80b107"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302137, 6197, 682, 14, 31, "Input",ExpressionUUID->"bc34bb23-ffa4-4c43-9f52-1efa7479be62"],
Cell[302822, 6213, 916, 17, 31, "Output",ExpressionUUID->"b9500fa9-6697-4046-ac4b-c5059ccd1036"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[303799, 6237, 562, 10, 38, "Section",ExpressionUUID->"b7ab0cf5-cedb-47b9-b53a-ccf94e68fe80"],
Cell[CellGroupData[{
Cell[304386, 6251, 2617, 56, 677, "Input",ExpressionUUID->"b19586bb-2c7d-4055-af11-8df359e66e66"],
Cell[307006, 6309, 3190, 58, 70, "Output",ExpressionUUID->"071570ad-2aee-47f4-aeac-68c9c50ef409"]
}, Open  ]],
Cell[310211, 6370, 594, 11, 31, "Input",ExpressionUUID->"c52d5242-bbcc-40db-a078-c25af1a1a30f"],
Cell[CellGroupData[{
Cell[310830, 6385, 1299, 27, 108, "Input",ExpressionUUID->"9d4f343d-a4ba-47fb-921e-e99e5a4ea1c0"],
Cell[312132, 6414, 642, 13, 70, "Output",ExpressionUUID->"d5678ccf-c634-4023-a014-4ced1791130b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312811, 6432, 6711, 118, 162, "Input",ExpressionUUID->"a06c1d25-0451-4c24-b8a2-00e990c77f60"],
Cell[319525, 6552, 7218, 137, 70, "Output",ExpressionUUID->"a2de952a-6509-4021-a1ac-282bf59742f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326780, 6694, 628, 12, 31, "Input",ExpressionUUID->"ef704f4c-43be-4ad3-afed-5069b47c3194"],
Cell[327411, 6708, 745, 10, 70, "Output",ExpressionUUID->"bc0eaf68-1cb3-495d-a499-4f87d6e0a380"]
}, Open  ]],
Cell[CellGroupData[{
Cell[328193, 6723, 627, 12, 31, "Input",ExpressionUUID->"d9119b47-bb99-4d17-b0c5-4e3ac9c41aa2"],
Cell[328823, 6737, 756, 10, 70, "Output",ExpressionUUID->"c8d79368-6088-493b-b26a-0ace50a5fe07"]
}, Open  ]],
Cell[CellGroupData[{
Cell[329616, 6752, 1320, 22, 31, "Input",ExpressionUUID->"17ec380f-903d-48ad-840f-942a66457bc7"],
Cell[330939, 6776, 14385, 284, 70, "Output",ExpressionUUID->"733e2c0e-978b-43f1-be46-b4a508a11116"]
}, Open  ]],
Cell[CellGroupData[{
Cell[345361, 7065, 1893, 35, 31, "Input",ExpressionUUID->"71f8cc29-6a67-4f1f-8629-2e048d5742fa"],
Cell[347257, 7102, 808, 12, 70, "Output",ExpressionUUID->"382d63b1-62e8-4934-995a-e755f520cf92"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348102, 7119, 178, 3, 26, "Text",ExpressionUUID->"671e63b2-895c-417b-b8b0-1aa4e7ad2546"],
Cell[CellGroupData[{
Cell[348305, 7126, 564, 12, 31, "Input",ExpressionUUID->"f3feb58d-577f-4328-83e7-9422619e6a79"],
Cell[348872, 7140, 11121, 201, 70, "Output",ExpressionUUID->"98d763d7-53e6-43dd-95fc-a61c94941946"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360030, 7346, 589, 12, 31, "Input",ExpressionUUID->"52d51435-012e-48ca-8a75-f644918ad052"],
Cell[360622, 7360, 7658, 143, 70, "Output",ExpressionUUID->"ef0ffc7e-2dd8-43af-8ae0-394fe6bfc1dd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[368317, 7508, 708, 14, 31, "Input",ExpressionUUID->"58668235-e7ab-469b-a144-2d91f6ec5bda"],
Cell[369028, 7524, 985, 18, 70, "Output",ExpressionUUID->"5515de2c-ccfb-43fd-a8b5-fb2869eba226"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[370074, 7549, 699, 12, 38, "Section",ExpressionUUID->"ea161608-72ba-489b-84b2-a25ca58a24b6"],
Cell[CellGroupData[{
Cell[370798, 7565, 2664, 57, 677, "Input",ExpressionUUID->"833a7cc4-7698-419b-8138-47a32295faaf"],
Cell[373465, 7624, 3211, 58, 115, "Output",ExpressionUUID->"ff254159-8e20-41ae-92cf-a15a75644094"]
}, Open  ]],
Cell[376691, 7685, 640, 11, 31, "Input",ExpressionUUID->"be4e8432-0b2c-4c7b-8ead-9006ac266c55"],
Cell[CellGroupData[{
Cell[377356, 7700, 1349, 28, 108, "Input",ExpressionUUID->"ef0bc78a-c785-440d-86b2-44ebe6c8e09d"],
Cell[378708, 7730, 644, 13, 31, "Output",ExpressionUUID->"b96607ab-1d4a-4b34-8b6b-565c2ece997c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[379389, 7748, 6850, 121, 168, "Input",ExpressionUUID->"7be5236c-19c8-4a9a-acc4-e94c22ff0d3d"],
Cell[386242, 7871, 7412, 140, 229, "Output",ExpressionUUID->"a09a2a65-1a87-4f48-bab7-6634b54d8f10"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393691, 8016, 680, 13, 31, "Input",ExpressionUUID->"61afc4f0-c899-47cb-b3ea-0b99486537da"],
Cell[394374, 8031, 781, 11, 31, "Output",ExpressionUUID->"b7df5935-b8cd-444e-bb91-bccb23ff5c2c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[395192, 8047, 679, 13, 31, "Input",ExpressionUUID->"f1dc5dde-6f3b-400d-b913-88e2d8e5ff9a"],
Cell[395874, 8062, 777, 11, 31, "Output",ExpressionUUID->"fd181db9-1c09-4e6e-988d-b136debf14a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[396688, 8078, 1318, 22, 31, "Input",ExpressionUUID->"440efa85-b8a4-4816-83fc-a299e3eb1262"],
Cell[398009, 8102, 14799, 289, 58, "Output",ExpressionUUID->"6ae9ff4e-8d28-4279-a914-86eeefdd9a51"]
}, Open  ]],
Cell[CellGroupData[{
Cell[412845, 8396, 1893, 35, 31, "Input",ExpressionUUID->"90692c4b-af96-47c0-bba3-84fe2d59ded3"],
Cell[414741, 8433, 854, 12, 31, "Output",ExpressionUUID->"a4bb7413-6558-49a3-bb08-433a8d422f09"]
}, Open  ]],
Cell[CellGroupData[{
Cell[415632, 8450, 178, 3, 26, "Text",ExpressionUUID->"ed069afb-65a9-4706-a035-58555d00a52a"],
Cell[CellGroupData[{
Cell[415835, 8457, 585, 12, 31, "Input",ExpressionUUID->"de04cda8-cce7-4f5f-8e4c-19e1df4a03ea"],
Cell[416423, 8471, 11158, 200, 231, "Output",ExpressionUUID->"a49138a1-5431-446a-9467-77dde69ced16"]
}, Open  ]],
Cell[CellGroupData[{
Cell[427618, 8676, 615, 13, 31, "Input",ExpressionUUID->"c546244e-c6e7-4dcf-8f92-58c09faf7ac7"],
Cell[428236, 8691, 7583, 143, 226, "Output",ExpressionUUID->"412763f3-32e4-4f22-8dc6-33b97de63e8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[435856, 8839, 736, 15, 31, "Input",ExpressionUUID->"82eafcc7-3e81-42cc-8856-b31f68018464"],
Cell[436595, 8856, 1010, 19, 31, "Output",ExpressionUUID->"15ddf1a9-fc3b-4917-a9fe-1fffd6ffba91"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[437666, 8882, 885, 13, 38, "Section",ExpressionUUID->"15c61cc8-f405-4731-8c4f-20dd7c6baf74"],
Cell[CellGroupData[{
Cell[438576, 8899, 3951, 63, 711, "Input",ExpressionUUID->"9fd1e2ef-a506-4fc5-bf65-c8c766bb0595"],
Cell[442530, 8964, 3371, 62, 133, "Output",ExpressionUUID->"cd440c3f-07fa-44ef-9116-e7fe37c579c4"]
}, Open  ]],
Cell[445916, 9029, 695, 13, 31, "Input",ExpressionUUID->"089f13c1-0769-4ba7-a784-1e1e57798c72"],
Cell[CellGroupData[{
Cell[446636, 9046, 1402, 29, 108, "Input",ExpressionUUID->"75c012f6-a2db-4e29-9109-38e62a6e26b6"],
Cell[448041, 9077, 669, 14, 31, "Output",ExpressionUUID->"2d1db70a-d2d9-4dfb-96ed-a4c276c250e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448747, 9096, 6902, 122, 168, "Input",ExpressionUUID->"7c6ec243-96e8-44a2-8d68-e3decc755f1d"],
Cell[455652, 9220, 7306, 139, 232, "Output",ExpressionUUID->"8a9e47cb-9b6d-4cf1-a10e-bd86e1beb834"]
}, Open  ]],
Cell[CellGroupData[{
Cell[462995, 9364, 732, 14, 31, "Input",ExpressionUUID->"4b1376f1-44cd-40b5-aed1-69982f1c6526"],
Cell[463730, 9380, 806, 12, 31, "Output",ExpressionUUID->"eeb6bf81-65c4-427a-9e0b-81f4dd692446"]
}, Open  ]],
Cell[CellGroupData[{
Cell[464573, 9397, 731, 14, 31, "Input",ExpressionUUID->"9c801f8f-3922-4118-9b24-9f2c78b2eace"],
Cell[465307, 9413, 807, 12, 31, "Output",ExpressionUUID->"dd39d9e2-928e-4aa9-af04-712f3efe6b86"]
}, Open  ]],
Cell[CellGroupData[{
Cell[466151, 9430, 1372, 24, 31, "Input",ExpressionUUID->"86c974b5-7a08-4eaa-a24f-09ed09efde10"],
Cell[467526, 9456, 15362, 299, 58, "Output",ExpressionUUID->"0c6c878a-6c05-423e-bc86-e1dad73fc6b9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[482925, 9760, 1946, 37, 31, "Input",ExpressionUUID->"cfe72ccd-d1d0-4461-9af4-93719237c0c9"],
Cell[484874, 9799, 884, 14, 31, "Output",ExpressionUUID->"72ecd707-c5ac-40bd-976e-11279002251f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[485795, 9818, 178, 3, 26, "Text",ExpressionUUID->"e0bca399-1539-4b8e-931d-5f0814c26a4c"],
Cell[CellGroupData[{
Cell[485998, 9825, 615, 14, 31, "Input",ExpressionUUID->"d3bd0671-a5c6-4dca-bf62-2e3bdd6896fa"],
Cell[486616, 9841, 10871, 197, 231, "Output",ExpressionUUID->"18a81e2f-8f1f-414a-87de-213b3fa49094"]
}, Open  ]],
Cell[CellGroupData[{
Cell[497524, 10043, 639, 13, 31, "Input",ExpressionUUID->"b81c3c04-ef0c-456c-8765-09f9ff63e5a4"],
Cell[498166, 10058, 7568, 143, 229, "Output",ExpressionUUID->"28adfdf4-4a29-425e-9e4b-abd7fd51d244"]
}, Open  ]],
Cell[CellGroupData[{
Cell[505771, 10206, 764, 16, 31, "Input",ExpressionUUID->"5fceeffa-2b7c-483d-88ab-075b2aeb142a"],
Cell[506538, 10224, 1035, 20, 31, "Output",ExpressionUUID->"8843d219-c193-42bc-8907-6f48696d6e59"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[507634, 10251, 912, 15, 68, "Section",ExpressionUUID->"eeb9e2a3-0791-419c-9e73-f668f10e8371"],
Cell[508549, 10268, 1131, 23, 101, "Text",ExpressionUUID->"75120ed2-659f-43e4-98b2-2ae4ab0c2b87"],
Cell[509683, 10293, 323080, 5308, 295, "Input",ExpressionUUID->"48d6f201-f071-4acc-bd07-04681ea7255c",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[832788, 15605, 4548, 72, 728, "Input",ExpressionUUID->"ec495fa6-01e9-4245-92ed-ccdfaff6db26"],
Cell[837339, 15679, 3635, 66, 133, "Output",ExpressionUUID->"da8ced68-99fd-48df-bb68-e3f69f3c79e0"]
}, Open  ]],
Cell[840989, 15748, 745, 14, 31, "Input",ExpressionUUID->"f6052a88-9fe1-4b8f-9f01-d87cf17b0939"],
Cell[CellGroupData[{
Cell[841759, 15766, 1449, 30, 108, "Input",ExpressionUUID->"8e0bb816-94ea-4e37-a97a-6ce3311929e8"],
Cell[843211, 15798, 479, 11, 31, "Output",ExpressionUUID->"d2a0fba9-7fde-41c2-b892-1fe0eed62c84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[843727, 15814, 6952, 123, 168, "Input",ExpressionUUID->"d66a1f31-b8f9-45d2-9740-47f621c6c0b9"],
Cell[850682, 15939, 7331, 139, 232, "Output",ExpressionUUID->"057a2134-7b48-47f6-864c-967498c6bef2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[858050, 16083, 784, 15, 31, "Input",ExpressionUUID->"3af80dbb-cd80-4d70-81b3-de5fc9c3cb15"],
Cell[858837, 16100, 900, 13, 31, "Output",ExpressionUUID->"4fb8cd59-ed15-4c45-b6fb-ecffbdeb24b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[859774, 16118, 781, 15, 31, "Input",ExpressionUUID->"18141311-8995-4ce3-9390-69e5b18bbd18"],
Cell[860558, 16135, 332, 5, 31, "Output",ExpressionUUID->"e8efdf6d-7f81-40d6-951b-8caf9f1cc42a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[860927, 16145, 1424, 25, 31, "Input",ExpressionUUID->"65ade7c5-c901-42ae-b528-b3f35d131c4d"],
Cell[862354, 16172, 14785, 295, 58, "Output",ExpressionUUID->"4d760d37-0486-4a2a-9df2-2b942f89e5d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[877176, 16472, 1994, 37, 31, "Input",ExpressionUUID->"530ad6cf-6e30-41cc-8cd8-d2201e3f7dd8"],
Cell[879173, 16511, 978, 15, 31, "Output",ExpressionUUID->"eddf33f3-89c4-441f-946e-3097ea6b9f12"]
}, Open  ]],
Cell[CellGroupData[{
Cell[880188, 16531, 178, 3, 26, "Text",ExpressionUUID->"f4e72ab5-1dac-4fdd-84a5-a651f9e74607"],
Cell[CellGroupData[{
Cell[880391, 16538, 637, 14, 31, "Input",ExpressionUUID->"f124276a-fbb4-403a-bc9e-e87a075eb6cd"],
Cell[881031, 16554, 10984, 199, 231, "Output",ExpressionUUID->"599baba7-67e9-4744-9990-c6d3d047715f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[892052, 16758, 665, 14, 31, "Input",ExpressionUUID->"b4181ed8-2fab-4bad-9ece-701e50b45b57"],
Cell[892720, 16774, 7632, 144, 229, "Output",ExpressionUUID->"a7346cfe-f9d3-49bb-8c7b-46ffa1d996a2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[900413, 16925, 288, 6, 68, "Section",ExpressionUUID->"2813d2a2-de64-4046-a4e2-dd4ff7805916"],
Cell[CellGroupData[{
Cell[900726, 16935, 1870, 47, 677, "Input",ExpressionUUID->"377650f6-9d15-4e9d-b438-1fb4d43219f2"],
Cell[902599, 16984, 3105, 58, 70, "Output",ExpressionUUID->"5d8fcf77-ebec-4fc8-996c-25d23facc312"]
}, Open  ]],
Cell[905719, 17045, 325, 8, 31, "Input",ExpressionUUID->"d7341d39-4812-48b4-ab2d-5d6ef0b56354"],
Cell[CellGroupData[{
Cell[906069, 17057, 1081, 25, 108, "Input",ExpressionUUID->"e34482ee-c873-4a58-8d7e-00471656aa43"],
Cell[907153, 17084, 525, 12, 70, "Output",ExpressionUUID->"94f1bace-a028-4192-8c44-104bed563498"]
}, Open  ]],
Cell[CellGroupData[{
Cell[907715, 17101, 6623, 119, 175, "Input",ExpressionUUID->"94469ae9-0aa1-4d7b-bde4-deec403b3e7a"],
Cell[914341, 17222, 7184, 138, 70, "Output",ExpressionUUID->"5fa0fec5-f2cf-45b2-aa0a-25d87312eed4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[921562, 17365, 535, 12, 31, "Input",ExpressionUUID->"cc740a61-a5f2-4a3e-95e3-83f535b4fb22"],
Cell[922100, 17379, 692, 10, 70, "Output",ExpressionUUID->"d192db3c-cb25-4946-af10-a670eddf760d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[922829, 17394, 531, 12, 31, "Input",ExpressionUUID->"9a31230c-7433-4b9d-99bf-6abf92d55d95"],
Cell[923363, 17408, 687, 10, 70, "Output",ExpressionUUID->"8bdcdb74-65a1-490f-a122-261697faad7b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[924087, 17423, 1320, 23, 31, "Input",ExpressionUUID->"ed33ce46-c711-4ecf-9625-01290b2a55e5"],
Cell[925410, 17448, 14780, 295, 70, "Output",ExpressionUUID->"0903474e-429b-4c47-87df-50fb621adf3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[940227, 17748, 1891, 36, 31, "Input",ExpressionUUID->"f6234f0a-64d6-4d54-b176-b040b7db139d"],
Cell[942121, 17786, 816, 13, 70, "Output",ExpressionUUID->"d937230f-068e-443f-b421-13d89b82bb84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[942974, 17804, 1439, 24, 89, "Input",ExpressionUUID->"837fae9f-d025-4dd0-a738-adfe2d58ee62"],
Cell[944416, 17830, 7887, 149, 70, "Output",ExpressionUUID->"218b0327-2526-4a8f-ae10-6beeb5dcedad"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[952352, 17985, 310, 5, 38, "Section",ExpressionUUID->"50028e12-664d-4797-b26a-9e356f598b23"],
Cell[952665, 17992, 2180, 51, 694, "Input",ExpressionUUID->"f15ccc8c-1273-46df-894d-99940b8f8b0a"],
Cell[954848, 18045, 447, 10, 31, "Input",ExpressionUUID->"65d4aeeb-a263-4296-9eb2-cfe938d46820"],
Cell[CellGroupData[{
Cell[955320, 18059, 1054, 25, 108, "Input",ExpressionUUID->"9e29d255-97ef-4440-b21e-f182851efff1"],
Cell[956377, 18086, 519, 12, 70, "Output",ExpressionUUID->"fbfe4546-fcdb-4c73-bba6-4f8df494e5cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[956933, 18103, 6566, 117, 173, "Input",ExpressionUUID->"86da488b-07c5-42ac-abad-116c78ad154d"],
Cell[963502, 18222, 7099, 136, 70, "Output",ExpressionUUID->"4b13d64b-3932-4bfb-93ea-3bb3b7014b07"]
}, Open  ]],
Cell[CellGroupData[{
Cell[970638, 18363, 441, 10, 31, "Input",ExpressionUUID->"7fb93265-7e27-4cad-8673-f16f2172d585"],
Cell[971082, 18375, 642, 10, 70, "Output",ExpressionUUID->"9319a46a-f4b8-475c-a060-7efbef969672"]
}, Open  ]],
Cell[CellGroupData[{
Cell[971761, 18390, 435, 10, 31, "Input",ExpressionUUID->"4f528aab-fdf6-421c-af92-23b463b6b6bd"],
Cell[972199, 18402, 638, 10, 70, "Output",ExpressionUUID->"d17fb2be-4b33-46ea-907d-a4c13db9eac8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[972874, 18417, 1322, 23, 31, "Input",ExpressionUUID->"3b437d79-499c-427c-93bd-703723471f2e"],
Cell[974199, 18442, 14653, 295, 70, "Output",ExpressionUUID->"e037af32-21eb-4302-833e-a928f69d0292"]
}, Open  ]],
Cell[CellGroupData[{
Cell[988889, 18742, 1897, 36, 31, "Input",ExpressionUUID->"757f8d27-49aa-4b6a-bf4d-99a07057acb5"],
Cell[990789, 18780, 838, 13, 70, "Output",ExpressionUUID->"7875f9d8-8780-4200-b8a2-9c130a68f9bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[991664, 18798, 1174, 27, 51, "Input",ExpressionUUID->"4d8ac11c-2d99-4a2c-9304-7c7688c4bfc1"],
Cell[992841, 18827, 708, 10, 70, "Output",ExpressionUUID->"0e7d2ec1-6272-4e6c-aecf-90203e5f0e30"]
}, Open  ]],
Cell[CellGroupData[{
Cell[993586, 18842, 1172, 26, 51, "Input",ExpressionUUID->"bace1cb2-a4e2-4b19-8fa7-dd30a5449edf"],
Cell[994761, 18870, 697, 11, 70, "Output",ExpressionUUID->"4599a4a8-3bc2-4839-a1ef-b0a582273ebd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[995495, 18886, 162, 3, 24, "Subsubsection",ExpressionUUID->"17a3342e-9e8b-4795-a16a-47c460a7b7cb"],
Cell[CellGroupData[{
Cell[995682, 18893, 1953, 39, 165, "Input",ExpressionUUID->"bfa8b184-c367-4662-ac83-aa02c4a7b9f3"],
Cell[997638, 18934, 933, 17, 70, "Output",ExpressionUUID->"23920a7b-b63a-4ab1-82bd-7eed0cc044f7"]
}, Open  ]],
Cell[998586, 18954, 1347, 22, 146, "Input",ExpressionUUID->"385289ce-be9a-46d2-8000-5cd05c46f4d7"],
Cell[999936, 18978, 1506, 24, 127, "Input",ExpressionUUID->"85cc34c7-864e-4269-8e0f-16cbc322e570"],
Cell[1001445, 19004, 602, 17, 31, "Input",ExpressionUUID->"137e75f8-6f4d-40fa-ad7e-bad45f9f505f"],
Cell[1002050, 19023, 1516, 26, 165, "Input",ExpressionUUID->"08ac2375-fbe3-484d-8d93-994ce7d26d31"],
Cell[1003569, 19051, 1569, 25, 165, "Input",ExpressionUUID->"fb52f218-0295-4138-aee9-078f0f6dbdfd"],
Cell[1005141, 19078, 652, 17, 31, "Input",ExpressionUUID->"89f9ff9b-b7d8-44c6-a739-d7366d4e4c08"],
Cell[CellGroupData[{
Cell[1005818, 19099, 1063, 21, 31, "Input",ExpressionUUID->"d71f22e6-3597-4777-981b-faefce5cd1af"],
Cell[1006884, 19122, 4951, 117, 70, "Output",ExpressionUUID->"4b91e163-7c3e-4b74-868b-4def991c71fe"]
}, Open  ]],
Cell[1011850, 19242, 1275, 29, 31, "Input",ExpressionUUID->"0e5bf6c5-df10-4466-adb0-1a4bb5380fbc"],
Cell[CellGroupData[{
Cell[1013150, 19275, 319, 6, 31, "Input",ExpressionUUID->"aab122d0-9757-415d-acd6-ff7fa2ba159a"],
Cell[1013472, 19283, 4675, 109, 70, "Output",ExpressionUUID->"dd52cbcf-6fd0-4970-8c83-41ad1b290c4a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1018184, 19397, 632, 15, 31, "Input",ExpressionUUID->"f79e74b4-094f-44cd-87ce-9907a0a87f23"],
Cell[1018819, 19414, 979, 16, 70, "Output",ExpressionUUID->"7b9e5c4e-f27e-42c6-94f9-19cb84fafd35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1019835, 19435, 812, 18, 31, "Input",ExpressionUUID->"c769e96c-c61c-40a0-9e0c-b4f689616d07"],
Cell[1020650, 19455, 10046, 201, 70, "Output",ExpressionUUID->"d5c132e9-ad49-4d80-88fd-dc6e81103b91"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1030745, 19662, 795, 20, 31, "Input",ExpressionUUID->"becee2b2-4d84-4484-9d32-defedfca584e"],
Cell[1031543, 19684, 695, 10, 70, "Output",ExpressionUUID->"35e1181f-8255-4dd9-a221-2086716cd00e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1032275, 19699, 485, 10, 31, "Input",ExpressionUUID->"2b309981-7b7d-440a-b82c-8c01b1981b68"],
Cell[1032763, 19711, 681, 10, 70, "Output",ExpressionUUID->"5c16b886-75ff-4181-b868-0db0ef795689"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1033481, 19726, 564, 11, 31, "Input",ExpressionUUID->"7c49e19e-4363-4f73-8b6e-1a43e496b3ee"],
Cell[1034048, 19739, 676, 10, 70, "Output",ExpressionUUID->"c2d8eb67-a675-40f6-b834-9110924336e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1034761, 19754, 220, 5, 26, "Text",ExpressionUUID->"33369bd6-4667-4e2d-9f02-e69a722930b7"],
Cell[CellGroupData[{
Cell[1035006, 19763, 783, 14, 31, "Input",ExpressionUUID->"c7efb6f5-403c-4fe9-808d-5c2ffef498ea"],
Cell[1035792, 19779, 919, 14, 70, "Output",ExpressionUUID->"e2a95a20-e697-418b-a5a1-320bd7a97568"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1036760, 19799, 2255, 45, 127, "Input",ExpressionUUID->"cf9944be-38ea-4989-849a-5e06ab1b9d29"],
Cell[1039018, 19846, 14663, 261, 70, "Output",ExpressionUUID->"0fed83f0-22e9-4693-97d2-1d59c9ba1999"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1053730, 20113, 305, 5, 38, "Section",ExpressionUUID->"3e8ab641-d0ac-4724-a259-68c331873309"],
Cell[1054038, 20120, 2173, 50, 677, "Input",ExpressionUUID->"fd944fd5-79d6-47c7-8f61-db697a9b9078"],
Cell[1056214, 20172, 491, 10, 31, "Input",ExpressionUUID->"8ab6d7d1-aec3-4982-9aeb-d4f7c5ad9135"],
Cell[CellGroupData[{
Cell[1056730, 20186, 1210, 27, 108, "Input",ExpressionUUID->"f55e7bfe-ea93-4c0f-8155-1bd9f471e265"],
Cell[1057943, 20215, 525, 12, 31, "Output",ExpressionUUID->"5ffc35eb-79ee-4234-a79f-753d0611d8b4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1058505, 20232, 6437, 116, 173, "Input",ExpressionUUID->"7e4b96fe-abcd-4197-ae39-f1075f7afa58"],
Cell[1064945, 20350, 7070, 136, 236, "Output",ExpressionUUID->"ee26ccea-0ad9-4f7b-830f-6106f390342b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1072052, 20491, 485, 11, 31, "Input",ExpressionUUID->"126f4d47-0600-43f1-aa14-0dd4c6aaac9c"],
Cell[1072540, 20504, 717, 11, 31, "Output",ExpressionUUID->"bf245c1c-a53b-4ba0-837f-a42f74f4929f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1073294, 20520, 481, 11, 31, "Input",ExpressionUUID->"4917d071-f59b-4f1e-a96c-a6c9042c6636"],
Cell[1073778, 20533, 683, 10, 31, "Output",ExpressionUUID->"816b8f23-cca0-43a0-a07a-3b8ddbc03461"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1074498, 20548, 1320, 23, 31, "Input",ExpressionUUID->"2c444fb3-82df-43cc-9185-44884396c783"],
Cell[1075821, 20573, 14681, 294, 58, "Output",ExpressionUUID->"031e278a-e25c-41c1-b8a0-d83ea4dcf1a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1090539, 20872, 1892, 36, 31, "Input",ExpressionUUID->"2a59b881-d376-43d8-b396-175d1e1c9938"],
Cell[1092434, 20910, 816, 13, 31, "Output",ExpressionUUID->"36568276-99df-4e62-8ced-daa936201418"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1093287, 20928, 162, 3, 24, "Subsubsection",ExpressionUUID->"8741529c-9780-4efa-acce-b0a7f8555815"],
Cell[CellGroupData[{
Cell[1093474, 20935, 1827, 37, 165, "Input",ExpressionUUID->"40407238-0b55-4802-84a1-94f993312b98"],
Cell[1095304, 20974, 1006, 18, 31, "Output",ExpressionUUID->"5a48644c-ac79-4405-9ce4-e696db5dc7f5"]
}, Open  ]],
Cell[1096325, 20995, 259, 6, 31, "Input",ExpressionUUID->"c4821a4d-17ad-4a62-868d-79afc8bf9aef"],
Cell[1096587, 21003, 794, 15, 146, "Input",ExpressionUUID->"fab4ed2e-8b7b-4354-a878-ca8d74d41502"],
Cell[1097384, 21020, 1347, 26, 146, "Input",ExpressionUUID->"efcfd2d9-3339-4b5f-a21c-c05beabe29d0"],
Cell[1098734, 21048, 574, 16, 31, "Input",ExpressionUUID->"9dc654f5-12e7-4376-b988-c7b6004ee35f"],
Cell[1099311, 21066, 997, 17, 146, "Input",ExpressionUUID->"bfd1fe49-5c2f-42b5-a27b-fbf16023de9c"],
Cell[1100311, 21085, 1061, 18, 146, "Input",ExpressionUUID->"a2cbe80f-09bc-4b53-8bff-04c2ae7c47c3"],
Cell[1101375, 21105, 623, 16, 31, "Input",ExpressionUUID->"bfb484d5-820f-4006-ab1e-d64c012102c0"],
Cell[CellGroupData[{
Cell[1102023, 21125, 299, 7, 31, "Input",ExpressionUUID->"05db1675-ae50-40f9-b872-a707329c2930"],
Cell[1102325, 21134, 4556, 111, 245, "Output",ExpressionUUID->"2f022ee6-5178-4f82-95a0-c7216eebb9b0"]
}, Open  ]],
Cell[1106896, 21248, 1001, 25, 31, "Input",ExpressionUUID->"7a1d2727-4002-416b-a42f-e21aef650e48"],
Cell[1107900, 21275, 1106, 27, 31, "Input",ExpressionUUID->"f483904d-facb-4226-90a0-92506a67fe1f"],
Cell[CellGroupData[{
Cell[1109031, 21306, 238, 5, 31, "Input",ExpressionUUID->"d7ded7f2-fd4e-48bc-afff-313ea28ab95e"],
Cell[1109272, 21313, 4719, 112, 233, "Output",ExpressionUUID->"d99843b9-7b13-4389-8a4e-3b37ded296d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1114028, 21430, 514, 13, 31, "Input",ExpressionUUID->"3b0690d8-576a-4f50-805c-848c9bf88016"],
Cell[1114545, 21445, 999, 16, 32, "Output",ExpressionUUID->"989c87ae-7dc1-480d-b219-9bb38d789cff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1115581, 21466, 680, 16, 31, "Input",ExpressionUUID->"48eeed37-8a15-4b27-b484-77994f6f7a0d"],
Cell[1116264, 21484, 10086, 202, 235, "Output",ExpressionUUID->"2e3186b9-fc82-4691-ac62-ab1d663dc4f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1126387, 21691, 740, 19, 31, "Input",ExpressionUUID->"5e378bec-8eea-41d9-b2cc-c81546e65412"],
Cell[1127130, 21712, 670, 10, 31, "Output",ExpressionUUID->"132e439e-1829-40a4-8acf-92938b98c2d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1127837, 21727, 436, 10, 31, "Input",ExpressionUUID->"4d1ac0e4-ef35-46bc-bc7e-5fb5ef8e3016"],
Cell[1128276, 21739, 669, 10, 31, "Output",ExpressionUUID->"fa81b607-58f6-4a3a-ad55-6a239aee553d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1128994, 21755, 515, 11, 31, "Input",ExpressionUUID->"3aa2d35d-0c01-4b12-8fd5-db47c23e14a8"],
Cell[1129512, 21768, 669, 11, 31, "Output",ExpressionUUID->"39dd9226-969d-4b12-9213-3d2f7e0a7c0e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1130218, 21784, 220, 5, 26, "Text",ExpressionUUID->"c5a22707-c3e3-4ef3-83ee-4d3cf36dcb3b"],
Cell[CellGroupData[{
Cell[1130463, 21793, 732, 14, 31, "Input",ExpressionUUID->"94effaa2-9976-41e0-982f-16b2ea4c52ce"],
Cell[1131198, 21809, 894, 14, 31, "Output",ExpressionUUID->"88c578ec-4c62-4e9f-b276-43600fd3e005"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1132141, 21829, 2195, 44, 127, "Input",ExpressionUUID->"751718a7-0c82-478d-9e79-edcec149d036"],
Cell[1134339, 21875, 14494, 260, 233, "Output",ExpressionUUID->"56de0490-2550-43b2-8dcf-fbb7a254ea2b"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1148882, 22141, 379, 6, 38, "Section",ExpressionUUID->"4efd5b93-148c-456b-9645-92b2cb33f148"],
Cell[1149264, 22149, 2130, 50, 677, "Input",ExpressionUUID->"454dd928-09a4-486a-aecd-7774f1d75e6c"],
Cell[1151397, 22201, 495, 10, 31, "Input",ExpressionUUID->"e6910de8-019b-40a7-add6-27cfea9f6e47"],
Cell[CellGroupData[{
Cell[1151917, 22215, 1203, 27, 108, "Input",ExpressionUUID->"0c306e42-9206-451e-b276-7f25d1a13d5d"],
Cell[1153123, 22244, 546, 12, 70, "Output",ExpressionUUID->"a4064308-01e9-4878-b5e1-3545e055c63b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1153706, 22261, 6851, 121, 179, "Input",ExpressionUUID->"00e8cb3d-befa-4bba-b9d8-2d8e7eaf6b21"],
Cell[1160560, 22384, 7251, 138, 70, "Output",ExpressionUUID->"44a8a491-afbf-483f-ab97-bbceed564e82"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1167848, 22527, 490, 11, 31, "Input",ExpressionUUID->"657a4614-756e-46da-90b8-1da0ad443cd5"],
Cell[1168341, 22540, 756, 11, 70, "Output",ExpressionUUID->"aecaa70e-0c22-45f7-a370-8c0d0e84535d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1169134, 22556, 485, 11, 31, "Input",ExpressionUUID->"4f5e3a6e-21e1-49d9-aa63-433c66fd4a38"],
Cell[1169622, 22569, 751, 11, 70, "Output",ExpressionUUID->"2f165260-1b48-4c67-8af0-f4e67e547ae9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1170410, 22585, 1226, 22, 31, "Input",ExpressionUUID->"2d21b415-427f-49d4-9f11-30820cfce8dd"],
Cell[1171639, 22609, 15271, 298, 70, "Output",ExpressionUUID->"5e4ef03a-21e8-4a29-a5e8-4f4b30c78faa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1186947, 22912, 1801, 35, 31, "Input",ExpressionUUID->"6a1ad74d-aa0f-455c-b75d-91c2cdcb9618"],
Cell[1188751, 22949, 790, 12, 70, "Output",ExpressionUUID->"39ff5d46-d553-4e9e-82b7-e41533ff24d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1189578, 22966, 1226, 28, 51, "Input",ExpressionUUID->"d98c8203-05d9-46c7-9f72-a2b2a847834d"],
Cell[1190807, 22996, 821, 12, 70, "Output",ExpressionUUID->"63b12c50-bde3-4987-a548-262020518ed5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1191665, 23013, 1222, 27, 51, "Input",ExpressionUUID->"c42e2814-1f08-4f70-81a8-0ff89bc9e521"],
Cell[1192890, 23042, 815, 13, 70, "Output",ExpressionUUID->"9c6d085f-9ba3-4e3d-9dd6-8dbba3bcfba7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1193742, 23060, 1593, 26, 89, "Input",ExpressionUUID->"9b4a253e-aa44-4989-976d-0d18868730fa"],
Cell[1195338, 23088, 8177, 152, 70, "Output",ExpressionUUID->"26d15aad-0776-4a3f-8585-94fb2650c05d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1203564, 23246, 180, 3, 38, "Section",ExpressionUUID->"c3b09d43-f3b6-4a18-b0db-d33ac90e0b1c"],
Cell[CellGroupData[{
Cell[1203769, 23253, 325, 6, 35, "Subsection",ExpressionUUID->"3c2133ea-c6b3-4e20-9c0b-5677ddc7ddd8"],
Cell[CellGroupData[{
Cell[1204119, 23263, 816, 20, 31, "Input",ExpressionUUID->"3295a945-7d3c-451f-83e8-c148033f7623"],
Cell[1204938, 23285, 7380, 141, 70, "Output",ExpressionUUID->"4136d462-acac-44c4-8ed8-2f17db628257"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1212355, 23431, 1535, 34, 108, "Input",ExpressionUUID->"669c2f71-30fd-4ee2-a1be-27ec0e3f0c0e"],
Cell[1213893, 23467, 384, 10, 70, "Output",ExpressionUUID->"1249b68e-60a2-49ab-8d76-f4dd29f61c7b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1214314, 23482, 537, 12, 31, "Input",ExpressionUUID->"31db6a62-ff27-4e38-bd76-ac28d9c01d8b"],
Cell[1214854, 23496, 716, 11, 70, "Output",ExpressionUUID->"82c2f79c-aa15-456e-9f85-5d0204112fa4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1215607, 23512, 535, 12, 31, "Input",ExpressionUUID->"fe6f9ed8-6623-4eef-97b8-c489a8a5923b"],
Cell[1216145, 23526, 686, 10, 70, "Output",ExpressionUUID->"c9cf63f7-7554-4fc1-8191-c8f3ae0c11e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1216868, 23541, 1272, 23, 31, "Input",ExpressionUUID->"97af3af2-c4ae-4e04-a6f7-b5103efeb3a5"],
Cell[1218143, 23566, 14704, 294, 70, "Output",ExpressionUUID->"e1a53a14-f82a-4fd1-b324-0eb351c24220"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1232884, 23865, 2052, 40, 31, "Input",ExpressionUUID->"0639adc6-6737-4ad7-851a-9a0285bb4887"],
Cell[1234939, 23907, 837, 13, 70, "Output",ExpressionUUID->"b1e2ed89-85fe-41e0-9c6c-80a2cb7d6851"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1235813, 23925, 853, 20, 31, "Input",ExpressionUUID->"62f882dc-4d25-432d-8550-6cb963756cf7"],
Cell[1236669, 23947, 1049, 23, 70, "Output",ExpressionUUID->"49ffde4e-0480-411b-9220-80521af23213"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1237767, 23976, 404, 8, 35, "Subsection",ExpressionUUID->"82549c51-83fb-4a0c-ace5-8082f6200c29"],
Cell[CellGroupData[{
Cell[1238196, 23988, 6958, 125, 165, "Input",ExpressionUUID->"9ba64c0b-d7f4-4cf4-aebd-e3d6ae2a9ab6"],
Cell[1245157, 24115, 7410, 141, 70, "Output",ExpressionUUID->"e8bad392-db5f-454c-90f4-abb2b61b1d65"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1252604, 24261, 1642, 35, 108, "Input",ExpressionUUID->"d0eeecc0-a2d1-45fd-96cf-dfc5a8a565b2"],
Cell[1254249, 24298, 593, 13, 70, "Output",ExpressionUUID->"64379b5f-5ccf-429f-b9c5-312324c2398b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1254879, 24316, 589, 12, 31, "Input",ExpressionUUID->"bb35c655-1d44-477b-ac6b-b958d5fc1ff1"],
Cell[1255471, 24330, 713, 11, 70, "Output",ExpressionUUID->"5e973f6f-e79a-4b6d-b047-ccefabe407c6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1256221, 24346, 585, 12, 31, "Input",ExpressionUUID->"4ece9598-59a5-4f96-beb1-ee15b0d78481"],
Cell[1256809, 24360, 688, 10, 70, "Output",ExpressionUUID->"6d6d1fbb-047d-4c85-99b7-44bff4a8ab9d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1257534, 24375, 1374, 24, 31, "Input",ExpressionUUID->"3162c008-6aed-430c-8662-2321d7d5e472"],
Cell[1258911, 24401, 14651, 295, 70, "Output",ExpressionUUID->"37de60ad-88c7-467b-a95b-fb99ce9cba80"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1273599, 24701, 2059, 40, 51, "Input",ExpressionUUID->"6201ac92-f07c-47ff-8558-6d88b251ed7c"],
Cell[1275661, 24743, 843, 13, 70, "Output",ExpressionUUID->"6fa2554d-4158-4723-89f2-d785f2755751"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1276541, 24761, 815, 19, 31, "Input",ExpressionUUID->"4e67aaea-56ba-4a55-95cd-e7b96b1a29b4"],
Cell[1277359, 24782, 973, 22, 70, "Output",ExpressionUUID->"2d79bb2d-30c2-42d2-8b40-57d19870ccff"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1278381, 24810, 417, 8, 35, "Subsection",ExpressionUUID->"27fb99ae-188f-4fd3-a1df-84be7dfb2362"],
Cell[CellGroupData[{
Cell[1278823, 24822, 6921, 124, 164, "Input",ExpressionUUID->"34044e2a-61a5-4bfa-b5da-0a2bd8a8ebc4"],
Cell[1285747, 24948, 7399, 141, 70, "Output",ExpressionUUID->"c8801eee-0aab-4d13-9863-6b20ebe954fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1293183, 25094, 1714, 36, 108, "Input",ExpressionUUID->"48c13e77-6162-429e-b30a-a6280ec31a0b"],
Cell[1294900, 25132, 650, 14, 70, "Output",ExpressionUUID->"838b9532-69e4-4e51-ba54-66ab0a697a32"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1295587, 25151, 641, 13, 31, "Input",ExpressionUUID->"7407c218-030e-4a0a-95c7-515136a82998"],
Cell[1296231, 25166, 763, 11, 70, "Output",ExpressionUUID->"39049fa7-064c-4361-b2a6-c29b65217503"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1297031, 25182, 637, 13, 31, "Input",ExpressionUUID->"23050121-1a11-4e89-b4ab-3962d9f51f56"],
Cell[1297671, 25197, 740, 11, 70, "Output",ExpressionUUID->"a72fda66-9778-4123-9d02-a4b0058e1fe0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1298448, 25213, 1322, 23, 31, "Input",ExpressionUUID->"c4ef1199-6327-463a-b14b-bc193aa91401"],
Cell[1299773, 25238, 14788, 290, 70, "Output",ExpressionUUID->"37be146e-c2ce-4543-9125-e968fa9bde8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1314598, 25533, 2090, 41, 51, "Input",ExpressionUUID->"47b08cef-d50b-43a2-939c-7ef319780418"],
Cell[1316691, 25576, 855, 13, 70, "Output",ExpressionUUID->"4d6a07cf-8468-4d0c-ad25-141e04593a40"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1317583, 25594, 763, 18, 31, "Input",ExpressionUUID->"3f0f2b2a-e80e-44a7-9ea0-2218c7848732"],
Cell[1318349, 25614, 1007, 23, 70, "Output",ExpressionUUID->"d426e8b1-8b6c-468c-9278-d205bddf91b4"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1319417, 25644, 161, 6, 61, "Section",ExpressionUUID->"2a1553c3-fbc1-49a8-a5b4-16e3cd7262a5"],
Cell[1319581, 25652, 185, 3, 35, "Subsection",ExpressionUUID->"542471c3-8166-4b61-b583-dbe9e3bb3f72"],
Cell[1319769, 25657, 468, 10, 25, "Input",ExpressionUUID->"70244e5a-db23-4530-91b2-e1ac2c7ed63c"],
Cell[CellGroupData[{
Cell[1320262, 25671, 3141, 69, 217, "Input",ExpressionUUID->"6c8b20fb-1f3d-48d4-b5b6-68c0bbfa6224"],
Cell[1323406, 25742, 1816, 38, 147, "Output",ExpressionUUID->"05134b86-cf91-4a42-8416-3371f99820d3"]
}, Open  ]],
Cell[1325237, 25783, 208, 3, 35, "Subsection",ExpressionUUID->"41a35b4a-1db5-4578-9c3e-c053b6900733"],
Cell[1325448, 25788, 706, 14, 25, "Input",ExpressionUUID->"d6aa081b-fe2b-411e-92f9-931ec6ac2f96"],
Cell[CellGroupData[{
Cell[1326179, 25806, 4865, 107, 404, "Input",ExpressionUUID->"c8d1f20a-e908-45fa-82e6-ba37973431dc"],
Cell[1331047, 25915, 3449, 92, 285, "Output",ExpressionUUID->"bc82d2a3-2b77-42b9-9ca2-8b15a222c5ea"]
}, Open  ]],
Cell[1334511, 26010, 234, 4, 35, "Subsection",ExpressionUUID->"cc517d30-9eb6-4ae9-85bc-b20209ced5be"],
Cell[1334748, 26016, 2443, 58, 126, "Input",ExpressionUUID->"d769e62a-9a58-4688-800b-67ebe350b93e"]
}, Open  ]],
Cell[1337206, 26077, 2322, 59, 97, "Output",ExpressionUUID->"28bf89cb-98ae-4701-a732-204cbcd5eaed"]
}
]
*)

